; File generated automatically from ./setupapi.spec; do not edit!

LIBRARY setupapi.dll

EXPORTS
  AssertFail@12 @5
  CMP_WaitNoPendingInstallEvents@4 @10
  CM_Connect_MachineW@8 @22
  CM_Disconnect_Machine@4 @37
  CM_Get_Device_ID_ListA@16 @78
  CaptureAndConvertAnsiArg@8 @193
  CaptureStringArg@8 @194
  DelayedMove@8 @197
  DoesUserHavePrivilege@4 @200
  DuplicateString@4 @201
  EnablePrivilege@8 @202
  FileExists@8 @204
  InstallCatalog@12 @211
  InstallHinfSection@16=InstallHinfSectionA@16 @212
  InstallHinfSectionA@16 @213
  InstallHinfSectionW@16 @214
  IsUserAdmin@0 @217
  MultiByteToUnicode@8 @220
  MyFree@4 @222
  MyMalloc@4 @224
  MyRealloc@8 @225
  OpenAndMapFileForRead@20 @226
  QueryRegistryValue@20 @229
  RegistryDelnode@8 @231
  RetreiveFileSecurity@8 @232
  SetupAddInstallSectionToDiskSpaceListA@24 @236
  SetupCloseFileQueue@4 @247
  SetupCloseInfFile@4 @248
  SetupCloseLog@0 @249
  SetupCommitFileQueue@16=SetupCommitFileQueueW@16 @250
  SetupCommitFileQueueA@16 @251
  SetupCommitFileQueueW@16 @252
  SetupCopyErrorA@44 @253
  SetupCopyErrorW@44 @254
  SetupCopyOEMInfA@32 @255
  SetupCopyOEMInfW@32 @256
  SetupCreateDiskSpaceListA@12 @257
  SetupCreateDiskSpaceListW@12 @258
  SetupDecompressOrCopyFileA@12 @259
  SetupDecompressOrCopyFileW@12 @260
  SetupDefaultQueueCallbackA@16 @262
  SetupDefaultQueueCallbackW@16 @263
  SetupDeleteErrorA@20 @264
  SetupDeleteErrorW@20 @265
  SetupDestroyDiskSpaceList@4 @266
  SetupDiBuildClassInfoList@16 @268
  SetupDiBuildClassInfoListExA@24 @269
  SetupDiBuildClassInfoListExW@24 @270
  SetupDiCallClassInstaller@12 @272
  SetupDiClassGuidsFromNameA@16 @275
  SetupDiClassGuidsFromNameExA@24 @276
  SetupDiClassGuidsFromNameExW@24 @277
  SetupDiClassGuidsFromNameW@16 @278
  SetupDiClassNameFromGuidA@16 @279
  SetupDiClassNameFromGuidExA@24 @280
  SetupDiClassNameFromGuidExW@24 @281
  SetupDiClassNameFromGuidW@16 @282
  SetupDiCreateDeviceInfoA@28 @285
  SetupDiCreateDeviceInfoList@8 @286
  SetupDiCreateDeviceInfoListExA@16 @287
  SetupDiCreateDeviceInfoListExW@16 @288
  SetupDiCreateDeviceInfoW@28 @289
  SetupDiDestroyDeviceInfoList@4 @295
  SetupDiEnumDeviceInfo@12 @298
  SetupDiEnumDeviceInterfaces@20 @299
  SetupDiGetActualSectionToInstallA@24 @302
  SetupDiGetActualSectionToInstallW@24 @303
  SetupDiGetClassDescriptionA@16 @305
  SetupDiGetClassDescriptionExA@24 @306
  SetupDiGetClassDescriptionExW@24 @307
  SetupDiGetClassDescriptionW@16 @308
  SetupDiGetClassDevsA@16 @311
  SetupDiGetClassDevsExA@28 @312
  SetupDiGetClassDevsExW@28 @313
  SetupDiGetClassDevsW@16 @314
  SetupDiGetDeviceInfoListDetailA@8 @322
  SetupDiGetDeviceInfoListDetailW@8 @323
  SetupDiGetDeviceInstallParamsA@12 @324
  SetupDiGetDeviceInterfaceDetailA@24 @329
  SetupDiGetDeviceInterfaceDetailW@24 @330
  SetupDiGetDeviceRegistryPropertyA@28 @331
  SetupDiGetINFClassA@20 @344
  SetupDiGetINFClassW@20 @345
  SetupDiInstallClassA@16 @350
  SetupDiInstallClassW@16 @353
  SetupDiOpenClassRegKey@8 @358
  SetupDiOpenClassRegKeyExA@20 @359
  SetupDiOpenClassRegKeyExW@20 @360
  SetupDiOpenDevRegKey@24 @361
  SetupDiOpenDeviceInterfaceA@16 @364
  SetupDiOpenDeviceInterfaceW@16 @366
  SetupDiSetClassInstallParamsA@16 @372
  SetupFindFirstLineA@16 @386
  SetupFindFirstLineW@16 @387
  SetupFindNextLine@8 @388
  SetupFindNextMatchLineA@12 @389
  SetupFindNextMatchLineW@12 @390
  SetupGetBinaryField@20 @395
  SetupGetFieldCount@4 @396
  SetupGetFileCompressionInfoA@20 @397
  SetupGetFileCompressionInfoExA@28 @398
  SetupGetFileCompressionInfoExW@28 @399
  SetupGetFileCompressionInfoW@20 @400
  SetupGetFileQueueCount@12 @401
  SetupGetFileQueueFlags@8 @402
  SetupGetInfInformationA@20 @405
  SetupGetInfInformationW@20 @406
  SetupGetIntField@12 @408
  SetupGetLineByIndexA@16 @409
  SetupGetLineByIndexW@16 @410
  SetupGetLineCountA@8 @411
  SetupGetLineCountW@8 @412
  SetupGetLineTextA@28 @413
  SetupGetLineTextW@28 @414
  SetupGetMultiSzFieldA@20 @415
  SetupGetMultiSzFieldW@20 @416
  SetupGetSourceFileLocationA@28 @417
  SetupGetSourceFileLocationW@28 @418
  SetupGetSourceInfoA@24 @421
  SetupGetSourceInfoW@24 @422
  SetupGetStringFieldA@20 @423
  SetupGetStringFieldW@20 @424
  SetupGetTargetPathA@24 @425
  SetupGetTargetPathW@24 @426
  SetupInitDefaultQueueCallback@4 @427
  SetupInitDefaultQueueCallbackEx@20 @428
  SetupInitializeFileLogA@8 @429
  SetupInitializeFileLogW@8 @430
  SetupInstallFilesFromInfSectionA@24 @435
  SetupInstallFilesFromInfSectionW@24 @436
  SetupInstallFromInfSectionA@44 @437
  SetupInstallFromInfSectionW@44 @438
  SetupIterateCabinetA@16 @443
  SetupIterateCabinetW@16 @444
  SetupLogErrorW@8 @446
  SetupOpenAppendInfFileA@12 @449
  SetupOpenAppendInfFileW@12 @450
  SetupOpenFileQueue@0 @451
  SetupOpenInfFileA@16 @452
  SetupOpenInfFileW@16 @453
  SetupOpenLog@4 @454
  SetupOpenMasterInf@0 @455
  SetupPromptReboot@12 @458
  SetupQueryInfFileInformationA@20 @463
  SetupQueryInfFileInformationW@20 @464
  SetupQueryInfOriginalFileInformationA@16 @465
  SetupQueryInfOriginalFileInformationW@16 @466
  SetupQuerySpaceRequiredOnDriveA@20 @471
  SetupQueueCopyA@36 @473
  SetupQueueCopyIndirectA@4 @474
  SetupQueueCopyIndirectW@4 @475
  SetupQueueCopySectionA@24 @476
  SetupQueueCopySectionW@24 @477
  SetupQueueCopyW@36 @478
  SetupQueueDefaultCopyA@24 @479
  SetupQueueDefaultCopyW@24 @480
  SetupQueueDeleteA@12 @481
  SetupQueueDeleteSectionA@16 @482
  SetupQueueDeleteSectionW@16 @483
  SetupQueueDeleteW@12 @484
  SetupQueueRenameA@20 @485
  SetupQueueRenameSectionA@16 @486
  SetupQueueRenameSectionW@16 @487
  SetupQueueRenameW@20 @488
  SetupRenameErrorA@24 @499
  SetupRenameErrorW@24 @500
  SetupScanFileQueueA@24 @502
  SetupScanFileQueueW@24 @503
  SetupSetDirectoryIdA@12 @504
  SetupSetDirectoryIdW@12 @507
  SetupSetFileQueueAlternatePlatformA@12 @508
  SetupSetFileQueueAlternatePlatformW@12 @509
  SetupSetFileQueueFlags@12 @510
  SetupSetSourceListA@12 @513
  SetupSetSourceListW@12 @514
  SetupTermDefaultQueueCallback@4 @515
  SetupTerminateFileLog@4 @516
  StampFileSecurity@8 @518
  StringTableAddString@12 @519
  StringTableAddStringEx@20 @520
  StringTableDestroy@4 @521
  StringTableDuplicate@4 @522
  StringTableGetExtraData@16 @524
  StringTableInitialize@0 @525
  StringTableInitializeEx@8 @526
  StringTableLookUpString@12 @527
  StringTableLookUpStringEx@20 @528
  StringTableSetExtraData@16 @529
  StringTableStringFromId@8 @530
  StringTableStringFromIdEx@16 @531
  StringTableTrim@4 @532
  TakeOwnershipOfFile@4 @533
  UnicodeToMultiByte@8 @534
  UnmapAndCloseFile@12 @535
  pSetupGetField@8 @544
  pSetupGetGlobalFlags@0 @545
  pSetupGetQueueFlags@4 @547
  pSetupSetGlobalFlags@4 @552
  pSetupSetQueueFlags@8 @553
  pSetupStringTableAddString@12=StringTableAddString@12 @556
  pSetupStringTableAddStringEx@20=StringTableAddStringEx@20 @557
  pSetupStringTableDestroy@4=StringTableDestroy@4 @558
  pSetupStringTableDuplicate@4=StringTableDuplicate@4 @559
  pSetupStringTableGetExtraData@16=StringTableGetExtraData@16 @561
  pSetupStringTableInitialize@0=StringTableInitialize@0 @562
  pSetupStringTableInitializeEx@8=StringTableInitializeEx@8 @563
  pSetupStringTableLookUpString@12=StringTableLookUpString@12 @564
  pSetupStringTableLookUpStringEx@20=StringTableLookUpStringEx@20 @565
  pSetupStringTableSetExtraData@16=StringTableSetExtraData@16 @566
