; File generated automatically from ./ddraw.spec; do not edit!

LIBRARY ddraw.dll

EXPORTS
  DirectDrawCreate@12 @6
  DirectDrawCreateClipper@12 @7
  DirectDrawCreateEx@16 @8
  DirectDrawEnumerateA@8 @9
  DirectDrawEnumerateExA@12 @10
  DllCanUnloadNow@0 @13 PRIVATE
  DllGetClassObject@12 @14 PRIVATE
  DllRegisterServer@0 @15 PRIVATE
  DllUnregisterServer@0 @16 PRIVATE
