; File generated automatically from ./d3d9.spec; do not edit!

LIBRARY d3d9.dll

EXPORTS
  D3D9GetSWInfo@0 @1
  DebugSetMute@0 @2
  Direct3DCreate9@4 @3
  D3DPERF_BeginEvent@8 @4
  D3DPERF_EndEvent@0 @5
  D3DPERF_GetStatus@0 @6
  D3DPERF_SetOptions@4 @7
  D3DPERF_QueryRepeatFrame@0 @8
  D3DPERF_SetMarker@8 @9
  D3DPERF_SetRegion@8 @10
