; File generated automatically from ./urlmon.spec; do not edit!

LIBRARY urlmon.dll

EXPORTS
  BindAsyncMoniker@20 @5
  CoGetClassObjectFromURL@40 @6
  CoInternetCombineUrl@28 @8
  CoInternetCompareUrl@12 @9
  CoInternetCreateSecurityManager@12 @10
  CoInternetCreateZoneManager@12 @11
  CoInternetGetSession@12 @14
  CoInternetParseUrl@28 @15
  CoInternetQueryInfo@28 @16
  CreateAsyncBindCtx@16 @20
  CreateAsyncBindCtxEx@24 @21
  CreateFormatEnumerator@12 @22
  CreateURLMoniker@12 @23
  CreateURLMonikerEx@16 @24
  DllCanUnloadNow@0 @25 PRIVATE
  DllGetClassObject@12 @26 PRIVATE
  DllInstall@8 @27 PRIVATE
  DllRegisterServer@0 @28 PRIVATE
  DllRegisterServerEx@0 @29 PRIVATE
  DllUnregisterServer@0 @30 PRIVATE
  Extract@8 @31
  FaultInIEFeature@16 @32
  FindMimeFromData@32 @35
  GetSoftwareUpdateInfo@8 @40
  HlinkNavigateString@8 @44
  HlinkSimpleNavigateToString@32 @46
  IsAsyncMoniker@4 @47
  IsValidURL@12 @50
  MkParseDisplayNameEx@16=ole32.MkParseDisplayName @51
  ObtainUserAgentString@12 @52
  RegisterBindStatusCallback@16 @54
  RegisterFormatEnumerator@12 @55
  ReleaseBindInfo@4 @58
  RevokeBindStatusCallback@8 @59
  RevokeFormatEnumerator@8 @60
  URLDownloadToCacheFileA@24 @63
  URLDownloadToCacheFileW@24 @64
  URLDownloadToFileA@20 @65
  URLDownloadToFileW@20 @66
  UrlMkGetSessionOption@20 @75
  UrlMkSetSessionOption@16 @76
