; File generated automatically from ./mswsock.spec; do not edit!

LIBRARY mswsock.dll

EXPORTS
  AcceptEx@32 @1
  EnumProtocolsA@12=ws2_32.WSAEnumProtocolsA @2
  EnumProtocolsW@12=ws2_32.WSAEnumProtocolsW @3
  GetAcceptExSockaddrs@32 @4
  TransmitFile@28 @22
