( cd usr/bin ; rm -rf wineg++ )
( cd usr/bin ; ln -sf winegcc wineg++ )
( cd usr/bin ; rm -rf winecpp )
( cd usr/bin ; ln -sf winegcc winecpp )
( cd usr/man/man1 ; rm -rf wineg++.1.gz )
( cd usr/man/man1 ; ln -sf winegcc.1.gz wineg++.1.gz )
( cd usr/lib ; rm -rf libwine.so.1 )
( cd usr/lib ; ln -sf libwine.so.1.0 libwine.so.1 )
( cd usr/lib ; rm -rf libwine.so )
( cd usr/lib ; ln -sf libwine.so.1.0 libwine.so )
