; File generated automatically from ./winspool.drv.spec; do not edit!

LIBRARY winspool.drv

EXPORTS
  GetDefaultPrinterA@8 @201
  SetDefaultPrinterA@4 @202
  GetDefaultPrinterW@8 @203
  SetDefaultPrinterW@4 @204
  AbortPrinter@4 @108
  AddFormA@12 @109
  AddFormW@12 @110
  AddJobA@20 @111
  AddJobW@20 @112
  AddMonitorA@12 @113
  AddMonitorW@12 @114
  AddPortA@12 @115
  AddPortExA@16 @116
  AddPortExW@16 @117
  AddPortW@12 @118
  AddPrintProcessorA@16 @119
  AddPrintProcessorW@16 @120
  AddPrintProvidorA@12 @121
  AddPrintProvidorW@12 @122
  AddPrinterA@12 @123
  AddPrinterConnectionA@4 @124
  AddPrinterConnectionW@4 @125
  AddPrinterDriverA@12 @126
  AddPrinterDriverExA@16 @127
  AddPrinterDriverExW@16 @128
  AddPrinterDriverW@12 @129
  AddPrinterW@12 @130
  AdvancedDocumentPropertiesA@20 @131
  AdvancedDocumentPropertiesW@20 @132
  ClosePrinter@4 @134
  ConfigurePortA@12 @135
  ConfigurePortW@12 @136
  ConnectToPrinterDlg@8 @137
  DeleteFormA@8 @141
  DeleteFormW@8 @142
  DeleteMonitorA@12 @143
  DeleteMonitorW@12 @144
  DeletePortA@12 @145
  DeletePortW@12 @146
  DeletePrintProcessorA@12 @147
  DeletePrintProcessorW@12 @148
  DeletePrintProvidorA@12 @149
  DeletePrintProvidorW@12 @150
  DeletePrinter@4 @151
  DeletePrinterConnectionA@4 @152
  DeletePrinterConnectionW@4 @153
  DeletePrinterDataExA@12 @154
  DeletePrinterDataExW@12 @155
  DeletePrinterDriverA@12 @156
  DeletePrinterDriverExA@20 @157
  DeletePrinterDriverExW@20 @158
  DeletePrinterDriverW@12 @159
  DeviceCapabilities@20=DeviceCapabilitiesA@20 @162
  DeviceCapabilitiesA@20 @163
  DeviceCapabilitiesW@20 @164
  DocumentPropertiesA@24 @167
  DocumentPropertiesW@24 @168
  EndDocPrinter@4 @170
  EndPagePrinter@4 @171
  EnumFormsA@24 @172
  EnumFormsW@24 @173
  EnumJobsA@32 @174
  EnumJobsW@32 @175
  EnumMonitorsA@24 @176
  EnumMonitorsW@24 @177
  EnumPortsA@24 @178
  EnumPortsW@24 @179
  EnumPrintProcessorDatatypesA@28 @180
  EnumPrintProcessorDatatypesW@28 @181
  EnumPrintProcessorsA@28 @182
  EnumPrintProcessorsW@28 @183
  EnumPrinterDataA@36 @184
  EnumPrinterDataExA@24 @185
  EnumPrinterDataExW@24 @186
  EnumPrinterDataW@36 @187
  EnumPrinterDriversA@28 @188
  EnumPrinterDriversW@28 @189
  EnumPrintersA@28 @190
  EnumPrintersW@28 @191
  ExtDeviceMode@32 @192
  FindClosePrinterChangeNotification@4 @193
  FindFirstPrinterChangeNotification@16 @194
  FindNextPrinterChangeNotification@16 @195
  FreePrinterNotifyInfo@4 @196
  GetFormA@24 @197
  GetFormW@24 @198
  GetJobA@24 @199
  GetJobW@24 @200
  GetPrintProcessorDirectoryA@24 @225
  GetPrintProcessorDirectoryW@24 @233
  GetPrinterA@20 @234
  GetPrinterDataA@24 @235
  GetPrinterDataExA@28 @236
  GetPrinterDataExW@28 @237
  GetPrinterDataW@24 @238
  GetPrinterDriverA@24 @239
  GetPrinterDriverDirectoryA@24 @240
  GetPrinterDriverDirectoryW@24 @241
  GetPrinterDriverW@24 @242
  GetPrinterW@20 @243
  OpenPrinterA@12 @244
  OpenPrinterW@12 @245
  PrinterProperties@8 @249
  ReadPrinter@16 @250
  ResetPrinterA@8 @251
  ResetPrinterW@8 @252
  ScheduleJob@8 @253
  SetFormA@16 @255
  SetFormW@16 @256
  SetJobA@20 @257
  SetJobW@20 @258
  SetPrinterA@16 @259
  SetPrinterDataA@20 @260
  SetPrinterDataExA@24 @261
  SetPrinterDataExW@24 @262
  SetPrinterDataW@20 @263
  SetPrinterW@16 @264
  StartDocDlgA@8 @267
  StartDocDlgW@8 @268
  StartDocPrinterA@12 @269
  StartDocPrinterW@12 @270
  StartPagePrinter@4 @271
  WritePrinter@16 @273
  XcvDataW@32 @274
