; File generated automatically from ./tapi32.spec; do not edit!

LIBRARY tapi32.dll

EXPORTS
  lineAccept@12 @1
  lineAddProvider@12=lineAddProviderA@12 @2
  lineAddProviderA@12 @3
  lineAddToConference@8 @4
  lineAnswer@12 @5
  lineBlindTransfer@12=lineBlindTransferA@12 @6
  lineBlindTransferA@12 @7
  lineClose@4 @8
  lineCompleteCall@16 @9
  lineCompleteTransfer@16 @10
  lineConfigDialog@12=lineConfigDialogA@12 @11
  lineConfigDialogA@12 @12
  lineConfigDialogEdit@24=lineConfigDialogEditA@24 @13
  lineConfigDialogEditA@24 @14
  lineConfigProvider@8 @15
  lineDeallocateCall@4 @16
  lineDevSpecific@20 @17
  lineDevSpecificFeature@16 @18
  lineDial@12=lineDialA@12 @19
  lineDialA@12 @20
  lineDrop@12 @21
  lineForward@28=lineForwardA@28 @22
  lineForwardA@28 @23
  lineGatherDigits@28=lineGatherDigitsA@28 @24
  lineGatherDigitsA@28 @25
  lineGenerateDigits@16=lineGenerateDigitsA@16 @26
  lineGenerateDigitsA@16 @27
  lineGenerateTone@20 @28
  lineGetAddressCaps@24=lineGetAddressCapsA@24 @29
  lineGetAddressCapsA@24 @30
  lineGetAddressID@20=lineGetAddressIDA@20 @31
  lineGetAddressIDA@20 @32
  lineGetAddressStatus@12=lineGetAddressStatusA@12 @33
  lineGetAddressStatusA@12 @34
  lineGetAppPriority@24=lineGetAppPriorityA@24 @35
  lineGetAppPriorityA@24 @36
  lineGetCallInfo@8=lineGetCallInfoA@8 @37
  lineGetCallInfoA@8 @38
  lineGetCallStatus@8 @39
  lineGetConfRelatedCalls@8 @40
  lineGetCountry@12=lineGetCountryA@12 @41
  lineGetCountryA@12 @42
  lineGetDevCaps@20=lineGetDevCapsA@20 @43
  lineGetDevCapsA@20 @44
  lineGetDevConfig@12=lineGetDevConfigA@12 @45
  lineGetDevConfigA@12 @46
  lineGetID@24=lineGetIDA@24 @47
  lineGetIDA@24 @48
  lineGetIcon@12=lineGetIconA@12 @49
  lineGetIconA@12 @50
  lineGetLineDevStatus@8=lineGetLineDevStatusA@8 @51
  lineGetLineDevStatusA@8 @52
  lineGetNewCalls@16 @53
  lineGetNumRings@12 @54
  lineGetProviderList@8=lineGetProviderListA@8 @55
  lineGetProviderListA@8 @56
  lineGetRequest@12=lineGetRequestA@12 @57
  lineGetRequestA@12 @58
  lineGetStatusMessages@12 @59
  lineGetTranslateCaps@12=lineGetTranslateCapsA@12 @60
  lineGetTranslateCapsA@12 @61
  lineHandoff@12=lineHandoffA@12 @62
  lineHandoffA@12 @63
  lineHold@4 @64
  lineInitialize@20 @65
  lineMakeCall@20=lineMakeCallA@20 @66
  lineMakeCallA@20 @67
  lineMonitorDigits@8 @68
  lineMonitorMedia@8 @69
  lineMonitorTones@12 @70
  lineNegotiateAPIVersion@24 @71
  lineNegotiateExtVersion@24 @72
  lineOpen@36=lineOpenA@36 @73
  lineOpenA@36 @74
  linePark@16=lineParkA@16 @75
  lineParkA@16 @76
  linePickup@20=linePickupA@20 @77
  linePickupA@20 @78
  linePrepareAddToConference@12=linePrepareAddToConferenceA@12 @79
  linePrepareAddToConferenceA@12 @80
  lineRedirect@12=lineRedirectA@12 @81
  lineRedirectA@12 @82
  lineRegisterRequestRecipient@16 @83
  lineReleaseUserUserInfo@4 @84
  lineRemoveFromConference@4 @85
  lineRemoveProvider@8 @86
  lineSecureCall@4 @87
  lineSendUserUserInfo@12 @88
  lineSetAppPriority@24=lineSetAppPriorityA@24 @89
  lineSetAppPriorityA@24 @90
  lineSetAppSpecific@8 @91
  lineSetCallParams@20 @92
  lineSetCallPrivilege@8 @93
  lineSetCurrentLocation@8 @94
  lineSetDevConfig@16=lineSetDevConfigA@16 @95
  lineSetDevConfigA@16 @96
  lineSetMediaControl@48 @97
  lineSetMediaMode@8 @98
  lineSetNumRings@12 @99
  lineSetStatusMessages@12 @100
  lineSetTerminal@28 @101
  lineSetTollList@16=lineSetTollListA@16 @102
  lineSetTollListA@16 @103
  lineSetupConference@24=lineSetupConferenceA@24 @104
  lineSetupConferenceA@24 @105
  lineSetupTransfer@12=lineSetupTransferA@12 @106
  lineSetupTransferA@12 @107
  lineShutdown@4 @108
  lineSwapHold@8 @109
  lineTranslateAddress@28=lineTranslateAddressA@28 @110
  lineTranslateAddressA@28 @111
  lineTranslateDialog@20=lineTranslateDialogA@20 @112
  lineTranslateDialogA@20 @113
  lineUncompleteCall@8 @114
  lineUnhold@4 @115
  lineUnpark@16=lineUnparkA@16 @116
  lineUnparkA@16 @117
  phoneClose@4 @118
  phoneConfigDialog@12=phoneConfigDialogA@12 @119
  phoneConfigDialogA@12 @120
  phoneDevSpecific@12 @121
  phoneGetButtonInfo@12=phoneGetButtonInfoA@12 @122
  phoneGetButtonInfoA@12 @123
  phoneGetData@16 @124
  phoneGetDevCaps@20=phoneGetDevCapsA@20 @125
  phoneGetDevCapsA@20 @126
  phoneGetDisplay@8 @127
  phoneGetGain@12 @128
  phoneGetHookSwitch@8 @129
  phoneGetID@12=phoneGetIDA@12 @130
  phoneGetIDA@12 @131
  phoneGetIcon@12=phoneGetIconA@12 @132
  phoneGetIconA@12 @133
  phoneGetLamp@12 @134
  phoneGetRing@12 @135
  phoneGetStatus@8=phoneGetStatusA@8 @136
  phoneGetStatusA@8 @137
  phoneGetStatusMessages@16 @138
  phoneGetVolume@12 @139
  phoneInitialize@20 @140
  phoneNegotiateAPIVersion@24 @141
  phoneNegotiateExtVersion@24 @142
  phoneOpen@28 @143
  phoneSetButtonInfo@12=phoneSetButtonInfoA@12 @144
  phoneSetButtonInfoA@12 @145
  phoneSetData@16 @146
  phoneSetDisplay@20 @147
  phoneSetGain@12 @148
  phoneSetHookSwitch@12 @149
  phoneSetLamp@12 @150
  phoneSetRing@12 @151
  phoneSetStatusMessages@16 @152
  phoneSetVolume@12 @153
  phoneShutdown@4 @154
  tapiGetLocationInfo@8=tapiGetLocationInfoA@8 @155
  tapiGetLocationInfoA@8 @156
  tapiRequestMakeCall@16=tapiRequestMakeCallA@16 @158
  tapiRequestMakeCallA@16 @159
