; File generated automatically from ./dbghelp.spec; do not edit!

LIBRARY dbghelp.dll

EXPORTS
  EnumDirTree@24 @3
  EnumDirTreeW@24 @4
  EnumerateLoadedModules@12 @5
  EnumerateLoadedModules64@12 @6
  EnumerateLoadedModulesW64@12 @7
  ExtensionApiVersion@0 @8
  FindDebugInfoFile@12 @9
  FindDebugInfoFileEx@20 @10
  FindExecutableImage@12 @12
  FindExecutableImageEx@20 @13
  FindExecutableImageExW@20 @14
  GetTimestampForLoadedLibrary@4 @17
  ImageDirectoryEntryToData@16=ntdll.RtlImageDirectoryEntryToData @18
  ImageNtHeader@4=ntdll.RtlImageNtHeader @20
  ImageRvaToSection@12=ntdll.RtlImageRvaToSection @21
  ImageRvaToVa@16=ntdll.RtlImageRvaToVa @22
  ImagehlpApiVersion@0 @23
  ImagehlpApiVersionEx@4 @24
  MakeSureDirectoryPathExists@4 @25
  MapDebugInformation@16 @26
  MiniDumpReadDumpStream@20 @27
  MiniDumpWriteDump@28 @28
  SearchTreeForFile@12 @29
  SearchTreeForFileW@12 @30
  StackWalk@36 @31
  StackWalk64@36 @32
  SymCleanup@4 @35
  SymEnumLines@28 @36
  SymEnumSourceFiles@24 @38
  SymEnumSymbols@24 @41
  SymEnumSymbolsW@24 @42
  SymEnumTypes@20 @45
  SymEnumTypesW@20 @46
  SymEnumerateModules@12 @47
  SymEnumerateModules64@12 @48
  SymEnumerateModulesW64@12 @49
  SymEnumerateSymbols@16 @50
  SymFindFileInPath@40 @56
  SymFindFileInPathW@40 @57
  SymFromAddr@20 @58
  SymFromAddrW@20 @59
  SymFromName@12 @62
  SymFunctionTableAccess@8 @66
  SymFunctionTableAccess64@12 @67
  SymGetLineFromAddr@16 @71
  SymGetLineFromAddr64@20 @72
  SymGetLineFromAddrW64@20 @73
  SymGetLineNext@8 @76
  SymGetLineNext64@8 @77
  SymGetLinePrev@8 @79
  SymGetLinePrev64@8 @80
  SymGetModuleBase@8 @82
  SymGetModuleBase64@12 @83
  SymGetModuleInfo@12 @84
  SymGetModuleInfo64@16 @85
  SymGetModuleInfoW@12 @86
  SymGetModuleInfoW64@16 @87
  SymGetOptions@0 @89
  SymGetSearchPath@12 @92
  SymGetSearchPathW@12 @93
  SymGetSourceFileToken@24 @96
  SymGetSourceFileTokenW@24 @97
  SymGetSymFromAddr@16 @101
  SymGetSymFromAddr64@20 @102
  SymGetSymFromName@12 @103
  SymGetSymNext@8 @105
  SymGetSymPrev@8 @107
  SymGetTypeFromName@20 @111
  SymGetTypeInfo@24 @113
  SymInitialize@12 @115
  SymInitializeW@12 @116
  SymLoadModule@24 @117
  SymLoadModule64@28 @118
  SymLoadModuleEx@36 @119
  SymLoadModuleExW@36 @120
  SymMatchFileName@16 @121
  SymMatchFileNameW@16 @122
  SymMatchString@12 @123
  SymRegisterCallback@12 @131
  SymRegisterCallback64@16 @132
  SymRegisterCallbackW64@16 @133
  SymRegisterFunctionEntryCallback@12 @134
  SymRegisterFunctionEntryCallback64@16 @135
  SymSearch@44 @136
  SymSearchW@44 @137
  SymSetContext@12 @138
  SymSetOptions@4 @141
  SymSetParentWindow@4 @142
  SymSetSearchPath@8 @143
  SymSetSearchPathW@8 @144
  SymUnDName@12 @162
  SymUnloadModule@8 @164
  SymUnloadModule64@12 @165
  UnDecorateSymbolName@16 @166
  UnmapDebugInformation@4 @168
  WinDbgExtensionDllInit@12 @169
