; File generated automatically from ./kernel32.spec; do not edit!

LIBRARY kernel32.dll

EXPORTS
  VxDCall0@4=VxDCall@4 @1 NONAME
  VxDCall1@4=VxDCall@4 @2 NONAME
  VxDCall2@4=VxDCall@4 @3 NONAME
  VxDCall3@4=VxDCall@4 @4 NONAME
  VxDCall4@4=VxDCall@4 @5 NONAME
  VxDCall5@4=VxDCall@4 @6 NONAME
  VxDCall6@4=VxDCall@4 @7 NONAME
  VxDCall7@4=VxDCall@4 @8 NONAME
  VxDCall8@4=VxDCall@4 @9 NONAME
  k32CharToOemA@8 @10 NONAME
  k32CharToOemBuffA@12 @11 NONAME
  k32OemToCharA@8 @12 NONAME
  k32OemToCharBuffA@12 @13 NONAME
  k32LoadStringA@16 @14 NONAME
  k32wsprintfA @15 NONAME
  k32wvsprintfA@12 @16 NONAME
  CommonUnimpStub@0 @17 NONAME
  GetProcessDword@8 @18 NONAME
  DosFileHandleToWin32Handle@4 @20 NONAME
  Win32HandleToDosFileHandle@4 @21 NONAME
  DisposeLZ32Handle@4 @22 NONAME
  GlobalAlloc16@8 @24 NONAME
  GlobalLock16@4 @25 NONAME
  GlobalUnlock16@4 @26 NONAME
  GlobalFix16@4 @27 NONAME
  GlobalUnfix16@4 @28 NONAME
  GlobalWire16@4 @29 NONAME
  GlobalUnWire16@4 @30 NONAME
  GlobalFree16@4 @31 NONAME
  GlobalSize16@4 @32 NONAME
  HouseCleanLogicallyDeadHandles@0 @33 NONAME
  GetWin16DOSEnv@0 @34 NONAME
  LoadLibrary16@4 @35 NONAME
  FreeLibrary16@4 @36 NONAME
  GetProcAddress16@8=WIN32_GetProcAddress16@8 @37 NONAME
  AllocMappedBuffer@0 @38 NONAME
  FreeMappedBuffer@0 @39 NONAME
  OT_32ThkLSF@0 @40 NONAME
  ThunkInitLSF@20 @41 NONAME
  LogApiThkLSF@4 @42 NONAME
  ThunkInitLS@20 @43 NONAME
  LogApiThkSL@4 @44 NONAME
  Common32ThkLS@0 @45 NONAME
  ThunkInitSL@20 @46 NONAME
  LogCBThkSL@4 @47 NONAME
  ReleaseThunkLock@4 @48 NONAME
  RestoreThunkLock@4 @49 NONAME
  W32S_BackTo32@0 @51 NONAME
  GetThunkBuff@0 @52 NONAME
  GetThunkStuff@8 @53 NONAME
  K32WOWCallback16@8 @54 NONAME
  K32WOWCallback16Ex@20 @55 NONAME
  K32WOWGetVDMPointer@12 @56 NONAME
  K32WOWHandle32@8 @57 NONAME
  K32WOWHandle16@8 @58 NONAME
  K32WOWGlobalAlloc16@8 @59 NONAME
  K32WOWGlobalLock16@4 @60 NONAME
  K32WOWGlobalUnlock16@4 @61 NONAME
  K32WOWGlobalFree16@4 @62 NONAME
  K32WOWGlobalAllocLock16@12 @63 NONAME
  K32WOWGlobalUnlockFree16@4 @64 NONAME
  K32WOWGlobalLockSize16@8 @65 NONAME
  K32WOWYield16@0 @66 NONAME
  K32WOWDirectedYield16@4 @67 NONAME
  K32WOWGetVDMPointerFix@12 @68 NONAME
  K32WOWGetVDMPointerUnfix@4 @69 NONAME
  K32WOWGetDescriptor@8 @70 NONAME
  K32RtlLargeIntegerAdd@16=ntdll.RtlLargeIntegerAdd @72 NONAME
  K32RtlEnlargedIntegerMultiply@8=ntdll.RtlEnlargedIntegerMultiply @73 NONAME
  K32RtlEnlargedUnsignedMultiply@8=ntdll.RtlEnlargedUnsignedMultiply @74 NONAME
  K32RtlEnlargedUnsignedDivide@16=ntdll.RtlEnlargedUnsignedDivide @75 NONAME
  K32RtlExtendedLargeIntegerDivide@16=ntdll.RtlExtendedLargeIntegerDivide @76 NONAME
  K32RtlExtendedMagicDivide@20=ntdll.RtlExtendedMagicDivide @77 NONAME
  K32RtlExtendedIntegerMultiply@12=ntdll.RtlExtendedIntegerMultiply @78 NONAME
  K32RtlLargeIntegerShiftLeft@12=ntdll.RtlLargeIntegerShiftLeft @79 NONAME
  K32RtlLargeIntegerShiftRight@12=ntdll.RtlLargeIntegerShiftRight @80 NONAME
  K32RtlLargeIntegerArithmeticShift@12=ntdll.RtlLargeIntegerArithmeticShift @81 NONAME
  K32RtlLargeIntegerNegate@8=ntdll.RtlLargeIntegerNegate @82 NONAME
  K32RtlLargeIntegerSubtract@16=ntdll.RtlLargeIntegerSubtract @83 NONAME
  K32RtlConvertLongToLargeInteger@4=ntdll.RtlConvertLongToLargeInteger @84 NONAME
  K32RtlConvertUlongToLargeInteger@4=ntdll.RtlConvertUlongToLargeInteger @85 NONAME
  SSOnBigStack@0 @87 NONAME
  SSCall @88 NONAME
  FT_PrologPrime@0 @89 NONAME
  QT_ThunkPrime@0 @90 NONAME
  PK16FNF@4 @91 NONAME
  GetPK16SysVar@0 @92 NONAME
  GetpWin16Lock@4 @93 NONAME
  _CheckNotSysLevel@4 @94 NONAME
  _ConfirmSysLevel@4 @95 NONAME
  _ConfirmWin16Lock@0 @96 NONAME
  _EnterSysLevel@4 @97 NONAME
  _LeaveSysLevel@4 @98 NONAME
  ActivateActCtx@8 @50
  AddAtomA@4 @118
  AddAtomW@4 @123
  AddRefActCtx@4 @126
  AddVectoredExceptionHandler@8=ntdll.RtlAddVectoredExceptionHandler @127
  AllocConsole@0 @128
  AllocSLCallback@8 @130
  AreFileApisANSI@0 @132
  AssignProcessToJobObject@8 @133
  AttachConsole@4 @134
  BackupRead@28 @135
  BackupSeek@24 @136
  BackupWrite@28 @137
  Beep@8 @149
  BeginUpdateResourceA@8 @150
  BeginUpdateResourceW@8 @151
  BindIoCompletionCallback@12 @152
  BuildCommDCBA@8 @153
  BuildCommDCBAndTimeoutsA@12 @154
  BuildCommDCBAndTimeoutsW@12 @155
  BuildCommDCBW@8 @156
  CallNamedPipeA@28 @157
  CallNamedPipeW@28 @158
  CancelIo@4 @160
  CancelWaitableTimer@4 @161
  CheckRemoteDebuggerPresent@8 @163
  ClearCommBreak@4 @164
  ClearCommError@12 @165
  CloseConsoleHandle@4 @166
  CloseHandle@4 @167
  CloseProfileUserMapping@0 @168
  CmdBatNotification@4 @170
  CommConfigDialogA@12 @171
  CommConfigDialogW@12 @172
  CompareFileTime@8 @173
  CompareStringA@24 @174
  CompareStringW@24 @175
  ConnectNamedPipe@8 @176
  ContinueDebugEvent@12 @179
  ConvertDefaultLocale@4 @180
  ConvertFiberToThread@0 @181
  ConvertThreadToFiber@4 @182
  ConvertThreadToFiberEx@8 @183
  ConvertToGlobalHandle@4 @184
  CopyFileA@12 @185
  CopyFileExA@24 @186
  CopyFileExW@24 @187
  CopyFileW@12 @188
  CopyLZFile@8=LZCopy@8 @189
  CreateActCtxA@4 @190
  CreateActCtxW@4 @191
  CreateConsoleScreenBuffer@20 @192
  CreateDirectoryA@8 @193
  CreateDirectoryExA@12 @194
  CreateDirectoryExW@12 @195
  CreateDirectoryW@8 @196
  CreateEventA@16 @197
  CreateEventW@16 @198
  CreateFiber@12 @199
  CreateFiberEx@20 @200
  CreateFileA@28 @201
  CreateFileMappingA@24 @202
  CreateFileMappingW@24 @203
  CreateFileW@28 @204
  CreateIoCompletionPort@16 @205
  CreateJobObjectA@8 @206
  CreateJobObjectW@8 @207
  CreateMailslotA@16 @209
  CreateMailslotW@16 @210
  CreateMutexA@12 @211
  CreateMutexW@12 @212
  CreateNamedPipeA@32 @213
  CreateNamedPipeW@32 @214
  CreatePipe@16 @215
  CreateProcessA@40 @216
  CreateProcessW@40 @217
  CreateRemoteThread@28 @218
  CreateSemaphoreA@16 @219
  CreateSemaphoreW@16 @220
  CreateSocketHandle@0 @221
  CreateTapePartition@16 @222
  CreateThread@24 @223
  CreateTimerQueue@0 @224
  CreateTimerQueueTimer@28 @225
  CreateToolhelp32Snapshot@8 @226
  CreateWaitableTimerA@12 @228
  CreateWaitableTimerW@12 @229
  DeactivateActCtx@8 @230
  DebugActiveProcess@4 @231
  DebugActiveProcessStop@4 @232
  DebugBreak@0 @233
  DebugBreakProcess@4 @234
  DebugSetProcessKillOnExit@4 @235
  DecodePointer@4=ntdll.RtlDecodePointer @236
  DefineDosDeviceA@12 @237
  DefineDosDeviceW@12 @238
  DelayLoadFailureHook@8 @239
  DeleteAtom@4 @240
  DeleteCriticalSection@4=ntdll.RtlDeleteCriticalSection @241
  DeleteFiber@4 @242
  DeleteFileA@4 @243
  DeleteFileW@4 @244
  DeleteTimerQueueEx@8 @245
  DeleteTimerQueueTimer@12 @246
  DeviceIoControl@32 @247
  DisableThreadLibraryCalls@4 @248
  DisconnectNamedPipe@4 @249
  DnsHostnameToComputerNameA@12 @250
  DnsHostnameToComputerNameW@12 @251
  DosDateTimeToFileTime@12 @252
  DuplicateConsoleHandle@16 @253
  DuplicateHandle@28 @254
  EncodePointer@4=ntdll.RtlEncodePointer @255
  EndUpdateResourceA@8 @256
  EndUpdateResourceW@8 @257
  EnterCriticalSection@4=ntdll.RtlEnterCriticalSection @258
  EnumCalendarInfoA@16 @259
  EnumCalendarInfoExA@16 @260
  EnumCalendarInfoExW@16 @261
  EnumCalendarInfoW@16 @262
  EnumDateFormatsA@12 @263
  EnumDateFormatsExA@12 @264
  EnumDateFormatsExW@12 @265
  EnumDateFormatsW@12 @266
  EnumLanguageGroupLocalesA@16 @267
  EnumLanguageGroupLocalesW@16 @268
  EnumResourceLanguagesA@20 @269
  EnumResourceLanguagesW@20 @270
  EnumResourceNamesA@16 @271
  EnumResourceNamesW@16 @272
  EnumResourceTypesA@12 @273
  EnumResourceTypesW@12 @274
  EnumSystemCodePagesA@8 @275
  EnumSystemCodePagesW@8 @276
  EnumSystemGeoID@12 @277
  EnumSystemLanguageGroupsA@12 @278
  EnumSystemLanguageGroupsW@12 @279
  EnumSystemLocalesA@8 @280
  EnumSystemLocalesW@8 @281
  EnumTimeFormatsA@12 @282
  EnumTimeFormatsW@12 @283
  EnumUILanguagesA@12 @284
  EnumUILanguagesW@12 @285
  EraseTape@12 @286
  EscapeCommFunction@8 @287
  ExitProcess@4 @288
  ExitThread@4 @289
  ExpandEnvironmentStringsA@12 @291
  ExpandEnvironmentStringsW@12 @292
  FT_Exit0@0 @296
  FT_Exit12@0 @297
  FT_Exit16@0 @298
  FT_Exit20@0 @299
  FT_Exit24@0 @300
  FT_Exit28@0 @301
  FT_Exit32@0 @302
  FT_Exit36@0 @303
  FT_Exit40@0 @304
  FT_Exit44@0 @305
  FT_Exit48@0 @306
  FT_Exit4@0 @307
  FT_Exit52@0 @308
  FT_Exit56@0 @309
  FT_Exit8@0 @310
  FT_Prolog@0 @311
  FT_Thunk@0 @312
  FatalAppExitA@8 @313
  FatalAppExitW@8 @314
  FatalExit@4 @315
  FileTimeToDosDateTime@12 @316
  FileTimeToLocalFileTime@8 @317
  FileTimeToSystemTime@8 @318
  FillConsoleOutputAttribute@20 @319
  FillConsoleOutputCharacterA@20 @320
  FillConsoleOutputCharacterW@20 @321
  FindActCtxSectionGuid@20 @322
  FindActCtxSectionStringA@20 @323
  FindActCtxSectionStringW@20 @324
  FindAtomA@4 @325
  FindAtomW@4 @326
  FindClose@4 @327
  FindCloseChangeNotification@4 @328
  FindFirstChangeNotificationA@12 @329
  FindFirstChangeNotificationW@12 @330
  FindFirstFileA@8 @331
  FindFirstFileExA@24 @332
  FindFirstFileExW@24 @333
  FindFirstFileW@8 @334
  FindFirstVolumeMountPointA@12 @336
  FindFirstVolumeMountPointW@12 @337
  FindNextChangeNotification@4 @339
  FindNextFileA@8 @340
  FindNextFileW@8 @341
  FindResourceA@12 @346
  FindResourceExA@16 @347
  FindResourceExW@16 @348
  FindResourceW@12 @349
  FlushConsoleInputBuffer@4 @352
  FlushFileBuffers@4 @353
  FlushInstructionCache@12 @354
  FlushViewOfFile@8 @355
  FoldStringA@20 @356
  FoldStringW@20 @357
  FormatMessageA@28 @358
  FormatMessageW@28 @359
  FreeConsole@0 @360
  FreeEnvironmentStringsA@4 @361
  FreeEnvironmentStringsW@4 @362
  FreeLibrary@4 @364
  FreeLibraryAndExitThread@8 @365
  FreeResource@4 @366
  FreeSLCallback@4 @367
  GenerateConsoleCtrlEvent@8 @370
  Get16DLLAddress@8 @371
  GetACP@0 @372
  GetAtomNameA@12 @373
  GetAtomNameW@12 @374
  GetBinaryType@8=GetBinaryTypeA@8 @375
  GetBinaryTypeA@8 @376
  GetBinaryTypeW@8 @377
  GetCPInfo@8 @378
  GetCPInfoExA@12 @379
  GetCPInfoExW@12 @380
  GetCalendarInfoA@24 @381
  GetCalendarInfoW@24 @382
  GetCommConfig@12 @383
  GetCommMask@8 @384
  GetCommModemStatus@8 @385
  GetCommProperties@8 @386
  GetCommState@8 @387
  GetCommTimeouts@8 @388
  GetCommandLineA@0 @389
  GetCommandLineW@0 @390
  GetCompressedFileSizeA@8 @391
  GetCompressedFileSizeW@8 @392
  GetComputerNameA@8 @393
  GetComputerNameExA@12 @394
  GetComputerNameExW@12 @395
  GetComputerNameW@8 @396
  GetConsoleCP@0 @407
  GetConsoleCursorInfo@8 @413
  GetConsoleInputWaitHandle@0 @421
  GetConsoleMode@8 @424
  GetConsoleOutputCP@0 @426
  GetConsoleScreenBufferInfo@8 @427
  GetConsoleTitleA@8 @428
  GetConsoleTitleW@8 @429
  GetConsoleWindow@0 @430
  GetCurrencyFormatA@24 @431
  GetCurrencyFormatW@24 @432
  GetCurrentActCtx@4 @433
  GetCurrentDirectoryA@8 @435
  GetCurrentDirectoryW@8 @436
  GetCurrentProcess@0 @437
  GetCurrentProcessId@0 @438
  GetCurrentThread@0 @439
  GetCurrentThreadId@0 @440
  GetDateFormatA@24 @441
  GetDateFormatW@24 @442
  GetDaylightFlag@0 @443
  GetDefaultCommConfigA@12 @444
  GetDefaultCommConfigW@12 @445
  GetDevicePowerState@8 @447
  GetDiskFreeSpaceA@20 @448
  GetDiskFreeSpaceExA@16 @449
  GetDiskFreeSpaceExW@16 @450
  GetDiskFreeSpaceW@20 @451
  GetDllDirectoryA@8 @452
  GetDllDirectoryW@8 @453
  GetDriveTypeA@4 @454
  GetDriveTypeW@4 @455
  GetEnvironmentStrings@0=GetEnvironmentStringsA@0 @456
  GetEnvironmentStringsA@0 @457
  GetEnvironmentStringsW@0 @458
  GetEnvironmentVariableA@12 @459
  GetEnvironmentVariableW@12 @460
  GetExitCodeProcess@8 @462
  GetExitCodeThread@8 @463
  GetExpandedNameA@8 @464
  GetExpandedNameW@8 @465
  GetFileAttributesA@4 @466
  GetFileAttributesExA@12 @467
  GetFileAttributesExW@12 @468
  GetFileAttributesW@4 @469
  GetFileInformationByHandle@8 @470
  GetFileSize@8 @471
  GetFileSizeEx@8 @472
  GetFileTime@16 @473
  GetFileType@4 @474
  GetFullPathNameA@16 @475
  GetFullPathNameW@16 @476
  GetGeoInfoA@20 @477
  GetGeoInfoW@20 @478
  GetHandleContext@4 @479
  GetHandleInformation@8 @480
  GetLargestConsoleWindowSize@4 @483
  GetLastError@0 @484
  GetLocalTime@4 @486
  GetLocaleInfoA@16 @487
  GetLocaleInfoW@16 @488
  GetLogicalDriveStringsA@8 @489
  GetLogicalDriveStringsW@8 @490
  GetLogicalDrives@0 @491
  GetLongPathNameA@12 @492
  GetLongPathNameW@12 @493
  GetMailslotInfo@20 @494
  GetModuleFileNameA@12 @495
  GetModuleFileNameW@12 @496
  GetModuleHandleA@4 @497
  GetModuleHandleExA@12 @498
  GetModuleHandleExW@12 @499
  GetModuleHandleW@4 @500
  GetNamedPipeHandleStateA@28 @501
  GetNamedPipeHandleStateW@28 @502
  GetNamedPipeInfo@20 @503
  GetNativeSystemInfo@4 @504
  GetNumberFormatA@24 @507
  GetNumberFormatW@24 @508
  GetNumberOfConsoleInputEvents@8 @510
  GetNumberOfConsoleMouseButtons@4 @511
  GetOEMCP@0 @512
  GetOverlappedResult@16 @513
  GetPriorityClass@4 @514
  GetPrivateProfileIntA@16 @515
  GetPrivateProfileIntW@16 @516
  GetPrivateProfileSectionA@16 @517
  GetPrivateProfileSectionNamesA@12 @518
  GetPrivateProfileSectionNamesW@12 @519
  GetPrivateProfileSectionW@16 @520
  GetPrivateProfileStringA@24 @521
  GetPrivateProfileStringW@24 @522
  GetPrivateProfileStructA@20 @523
  GetPrivateProfileStructW@20 @524
  GetProcAddress@8 @525
  GetProcessAffinityMask@12 @526
  GetProcessFlags@4 @527
  GetProcessHeap@0 @528
  GetProcessHeaps@8 @529
  GetProcessId@4 @530
  GetProcessIoCounters@8 @531
  GetProcessPriorityBoost@8 @532
  GetProcessShutdownParameters@8 @533
  GetProcessTimes@20 @534
  GetProcessVersion@4 @535
  GetProcessWorkingSetSize@12 @536
  GetProfileIntA@12 @538
  GetProfileIntW@12 @539
  GetProfileSectionA@12 @540
  GetProfileSectionW@12 @541
  GetProfileStringA@20 @542
  GetProfileStringW@20 @543
  GetQueuedCompletionStatus@20 @544
  GetShortPathNameA@12 @547
  GetShortPathNameW@12 @548
  GetStartupInfoA@4 @549
  GetStartupInfoW@4 @550
  GetStdHandle@4 @551
  GetStringTypeA@20 @552
  GetStringTypeExA@20 @553
  GetStringTypeExW@20 @554
  GetStringTypeW@16 @555
  GetSystemDefaultLCID@0 @556
  GetSystemDefaultLangID@0 @557
  GetSystemDefaultUILanguage@0 @558
  GetSystemDirectoryA@8 @559
  GetSystemDirectoryW@8 @560
  GetSystemInfo@4 @561
  GetSystemPowerStatus@4 @562
  GetSystemTime@4 @563
  GetSystemTimeAdjustment@12 @564
  GetSystemTimeAsFileTime@4 @565
  GetSystemWindowsDirectoryA@8 @566
  GetSystemWindowsDirectoryW@8 @567
  GetSystemWow64DirectoryA@8 @568
  GetSystemWow64DirectoryW@8 @569
  GetTapeParameters@16 @570
  GetTapePosition@20 @571
  GetTapeStatus@4 @572
  GetTempFileNameA@16 @573
  GetTempFileNameW@16 @574
  GetTempPathA@8 @575
  GetTempPathW@8 @576
  GetThreadContext@8 @577
  GetThreadLocale@0 @578
  GetThreadPriority@4 @579
  GetThreadPriorityBoost@8 @580
  GetThreadSelectorEntry@12 @581
  GetThreadTimes@20 @582
  GetTickCount@0 @583
  GetTimeFormatA@24 @584
  GetTimeFormatW@24 @585
  GetTimeZoneInformation@4 @586
  GetUserDefaultLCID@0 @587
  GetUserDefaultLangID@0 @588
  GetUserDefaultUILanguage@0 @589
  GetUserGeoID@4 @590
  GetVersion@0 @592
  GetVersionExA@4 @593
  GetVersionExW@4 @594
  GetVolumeInformationA@32 @595
  GetVolumeInformationW@32 @596
  GetVolumeNameForVolumeMountPointA@12 @597
  GetVolumeNameForVolumeMountPointW@12 @598
  GetVolumePathNameA@12 @599
  GetVolumePathNameW@12 @600
  GetWindowsDirectoryA@8 @601
  GetWindowsDirectoryW@8 @602
  GlobalAddAtomA@4 @604
  GlobalAddAtomW@4 @605
  GlobalAlloc@8 @606
  GlobalCompact@4 @607
  GlobalDeleteAtom@4 @608
  GlobalFindAtomA@4 @609
  GlobalFindAtomW@4 @610
  GlobalFix@4 @611
  GlobalFlags@4 @612
  GlobalFree@4 @613
  GlobalGetAtomNameA@12 @614
  GlobalGetAtomNameW@12 @615
  GlobalHandle@4 @616
  GlobalLock@4 @617
  GlobalMemoryStatus@4 @618
  GlobalMemoryStatusEx@4 @619
  GlobalReAlloc@12 @620
  GlobalSize@4 @621
  GlobalUnWire@4 @622
  GlobalUnfix@4 @623
  GlobalUnlock@4 @624
  GlobalWire@4 @625
  Heap32ListFirst@8 @627
  HeapAlloc@12=ntdll.RtlAllocateHeap @630
  HeapCompact@8 @631
  HeapCreate@12 @632
  HeapDestroy@4 @634
  HeapFree@12=ntdll.RtlFreeHeap @636
  HeapLock@4 @637
  HeapReAlloc@16=ntdll.RtlReAllocateHeap @639
  HeapSetInformation@16 @641
  HeapSize@12=ntdll.RtlSizeHeap @642
  HeapUnlock@4 @644
  HeapValidate@12 @646
  HeapWalk@8 @647
  InitAtomTable@4 @648
  InitializeCriticalSection@4 @649
  InitializeCriticalSectionAndSpinCount@8 @650
  InitializeSListHead@4=ntdll.RtlInitializeSListHead @651
  InterlockedCompareExchange@12 @652
  InterlockedDecrement@4 @653
  InterlockedExchange@8 @654
  InterlockedExchangeAdd@8 @655
  InterlockedFlushSList@4=ntdll.RtlInterlockedFlushSList @656
  InterlockedIncrement@4 @657
  InterlockedPopEntrySList@4=ntdll.RtlInterlockedPopEntrySList @658
  InterlockedPushEntrySList@8=ntdll.RtlInterlockedPushEntrySList @659
  InvalidateNLSCache@0 @661
  IsBadCodePtr@4 @662
  IsBadHugeReadPtr@8 @663
  IsBadHugeWritePtr@8 @664
  IsBadReadPtr@8 @665
  IsBadStringPtrA@8 @666
  IsBadStringPtrW@8 @667
  IsBadWritePtr@8 @668
  IsDBCSLeadByte@4 @669
  IsDBCSLeadByteEx@8 @670
  IsDebuggerPresent@0 @671
  IsProcessorFeaturePresent@4 @673
  IsSystemResumeAutomatic@0 @675
  IsValidCodePage@4 @676
  IsValidLanguageGroup@8 @677
  IsValidLocale@8 @678
  IsWow64Process@8 @679
  K32Thk1632Epilog@0 @680
  K32Thk1632Prolog@0 @681
  LCMapStringA@24 @682
  LCMapStringW@24 @683
  LZClose@4 @684
  LZCopy@8 @685
  LZDone@0 @686
  LZInit@4 @687
  LZOpenFileA@12 @688
  LZOpenFileW@12 @689
  LZRead@12 @690
  LZSeek@12 @691
  LZStart@0 @692
  LeaveCriticalSection@4=ntdll.RtlLeaveCriticalSection @693
  LoadLibraryA@4 @694
  LoadLibraryExA@12 @695
  LoadLibraryExW@12 @696
  LoadLibraryW@4 @697
  LoadModule@8 @698
  LoadResource@8 @699
  LocalAlloc@8 @700
  LocalCompact@4 @701
  LocalFileTimeToFileTime@8 @702
  LocalFlags@4 @703
  LocalFree@4 @704
  LocalHandle@4 @705
  LocalLock@4 @706
  LocalReAlloc@12 @707
  LocalShrink@8 @708
  LocalSize@4 @709
  LocalUnlock@4 @710
  LockFile@20 @711
  LockFileEx@24 @712
  LockResource@4 @713
  MakeCriticalSectionGlobal@4 @714
  MapHInstLS@0 @715
  MapHInstLS_PN@0 @716
  MapHInstSL@0 @717
  MapHInstSL_PN@0 @718
  MapHModuleLS@4 @719
  MapHModuleSL@4 @720
  MapLS@4 @721
  MapSL@4 @722
  MapSLFix@4 @723
  MapViewOfFile@20 @724
  MapViewOfFileEx@24 @725
  Module32First@8 @726
  Module32FirstW@8 @727
  Module32Next@8 @728
  Module32NextW@8 @729
  MoveFileA@8 @730
  MoveFileExA@12 @731
  MoveFileExW@12 @732
  MoveFileW@8 @733
  MoveFileWithProgressA@20 @734
  MoveFileWithProgressW@20 @735
  MulDiv@12 @736
  MultiByteToWideChar@24 @737
  NeedCurrentDirectoryForExePathA@4 @738
  NeedCurrentDirectoryForExePathW@4 @739
  OpenConsoleW@16 @741
  OpenEventA@12 @743
  OpenEventW@12 @744
  OpenFile@12 @745
  OpenFileMappingA@12 @746
  OpenFileMappingW@12 @747
  OpenMutexA@12 @750
  OpenMutexW@12 @751
  OpenProcess@12 @752
  OpenSemaphoreA@12 @754
  OpenSemaphoreW@12 @755
  OpenThread@12 @756
  OpenVxDHandle@4 @757
  OpenWaitableTimerA@12 @758
  OpenWaitableTimerW@12 @759
  OutputDebugStringA@4 @760
  OutputDebugStringW@4 @761
  PeekConsoleInputA@16 @762
  PeekConsoleInputW@16 @763
  PeekNamedPipe@24 @764
  PostQueuedCompletionStatus@16 @765
  PrepareTape@12 @766
  PrivateFreeLibrary@4 @769
  PrivateLoadLibrary@4 @770
  Process32First@8 @771
  Process32FirstW@8 @772
  Process32Next@8 @773
  Process32NextW@8 @774
  ProcessIdToSessionId@8 @775
  PulseEvent@4 @776
  PurgeComm@8 @777
  QT_Thunk@0 @778
  QueryActCtxW@28 @779
  QueryDepthSList@4=ntdll.RtlQueryDepthSList @780
  QueryDosDeviceA@12 @781
  QueryDosDeviceW@12 @782
  QueryPerformanceCounter@4 @786
  QueryPerformanceFrequency@4 @787
  QueueUserAPC@12 @789
  QueueUserWorkItem@12 @790
  RaiseException@16 @791
  ReadConsoleA@20 @792
  ReadConsoleInputA@16 @793
  ReadConsoleInputW@16 @796
  ReadConsoleOutputA@20 @797
  ReadConsoleOutputAttribute@20 @798
  ReadConsoleOutputCharacterA@20 @799
  ReadConsoleOutputCharacterW@20 @800
  ReadConsoleOutputW@20 @801
  ReadConsoleW@20 @802
  ReadDirectoryChangesW@32 @803
  ReadFile@20 @804
  ReadFileEx@20 @805
  ReadProcessMemory@20 @807
  RegisterServiceProcess@8 @811
  RegisterWaitForSingleObject@24 @814
  RegisterWaitForSingleObjectEx@20 @815
  ReinitializeCriticalSection@4 @818
  ReleaseActCtx@4 @819
  ReleaseMutex@4 @820
  ReleaseSemaphore@12 @821
  RemoveDirectoryA@4 @822
  RemoveDirectoryW@4 @823
  RemoveVectoredExceptionHandler@4=ntdll.RtlRemoveVectoredExceptionHandler @824
  ReplaceFile@24=ReplaceFileW@24 @825
  ReplaceFileA@24 @826
  ReplaceFileW@24 @827
  RequestWakeupLatency@4 @829
  ResetEvent@4 @830
  ResumeThread@4 @832
  RtlFillMemory@12=ntdll.RtlFillMemory @833
  RtlMoveMemory@12=ntdll.RtlMoveMemory @834
  RtlUnwind@16=ntdll.RtlUnwind @835
  RtlZeroMemory@8=ntdll.RtlZeroMemory @836
  SMapLS@0 @837
  SMapLS_IP_EBP_12@0 @838
  SMapLS_IP_EBP_16@0 @839
  SMapLS_IP_EBP_20@0 @840
  SMapLS_IP_EBP_24@0 @841
  SMapLS_IP_EBP_28@0 @842
  SMapLS_IP_EBP_32@0 @843
  SMapLS_IP_EBP_36@0 @844
  SMapLS_IP_EBP_40@0 @845
  SMapLS_IP_EBP_8@0 @846
  SUnMapLS@0 @847
  SUnMapLS_IP_EBP_12@0 @848
  SUnMapLS_IP_EBP_16@0 @849
  SUnMapLS_IP_EBP_20@0 @850
  SUnMapLS_IP_EBP_24@0 @851
  SUnMapLS_IP_EBP_28@0 @852
  SUnMapLS_IP_EBP_32@0 @853
  SUnMapLS_IP_EBP_36@0 @854
  SUnMapLS_IP_EBP_40@0 @855
  SUnMapLS_IP_EBP_8@0 @856
  ScrollConsoleScreenBufferA@20 @857
  ScrollConsoleScreenBufferW@20 @858
  SearchPathA@24 @859
  SearchPathW@24 @860
  SetCPGlobal@4 @861
  SetCalendarInfoA@16 @862
  SetCalendarInfoW@16 @863
  SetCommBreak@4 @864
  SetCommConfig@12 @865
  SetCommMask@8 @866
  SetCommState@8 @867
  SetCommTimeouts@8 @868
  SetComputerNameA@4 @869
  SetComputerNameExA@8 @870
  SetComputerNameExW@8 @871
  SetComputerNameW@4 @872
  SetConsoleActiveScreenBuffer@4 @873
  SetConsoleCP@4 @874
  SetConsoleCtrlHandler@8 @876
  SetConsoleCursorInfo@8 @878
  SetConsoleCursorPosition@8 @880
  SetConsoleInputExeNameA@4 @885
  SetConsoleInputExeNameW@4 @886
  SetConsoleMode@8 @891
  SetConsoleOutputCP@4 @896
  SetConsoleScreenBufferSize@8 @898
  SetConsoleTextAttribute@8 @899
  SetConsoleTitleA@4 @900
  SetConsoleTitleW@4 @901
  SetConsoleWindowInfo@12 @902
  SetCriticalSectionSpinCount@8=ntdll.RtlSetCriticalSectionSpinCount @903
  SetCurrentDirectoryA@4 @904
  SetCurrentDirectoryW@4 @905
  SetDefaultCommConfigA@12 @907
  SetDefaultCommConfigW@12 @908
  SetDllDirectoryA@4 @909
  SetDllDirectoryW@4 @910
  SetEndOfFile@4 @911
  SetEnvironmentVariableA@8 @912
  SetEnvironmentVariableW@8 @913
  SetErrorMode@4 @914
  SetEvent@4 @915
  SetFileApisToANSI@0 @916
  SetFileApisToOEM@0 @917
  SetFileAttributesA@8 @918
  SetFileAttributesW@8 @919
  SetFilePointer@16 @920
  SetFilePointerEx@20 @921
  SetFileTime@16 @922
  SetHandleContext@8 @923
  SetHandleCount@4 @924
  SetHandleInformation@12 @925
  SetLastError@4 @928
  SetLocalTime@4 @929
  SetLocaleInfoA@12 @930
  SetLocaleInfoW@12 @931
  SetMailslotInfo@8 @932
  SetNamedPipeHandleState@16 @934
  SetPriorityClass@8 @935
  SetProcessAffinityMask@8 @936
  SetProcessPriorityBoost@8 @937
  SetProcessShutdownParameters@8 @938
  SetProcessWorkingSetSize@12 @939
  SetStdHandle@8 @940
  SetSystemPowerState@8 @941
  SetSystemTime@4 @942
  SetSystemTimeAdjustment@8 @943
  SetTapeParameters@12 @944
  SetTapePosition@24 @945
  SetTermsrvAppInstallMode@4 @946
  SetThreadAffinityMask@8 @947
  SetThreadContext@8 @948
  SetThreadExecutionState@4 @949
  SetThreadIdealProcessor@8 @950
  SetThreadLocale@4 @951
  SetThreadPriority@8 @952
  SetThreadPriorityBoost@8 @953
  SetThreadUILanguage@4 @954
  SetTimeZoneInformation@4 @955
  SetUnhandledExceptionFilter@4 @957
  SetUserGeoID@4 @958
  SetVolumeLabelA@8 @960
  SetVolumeLabelW@8 @961
  SetWaitableTimer@24 @964
  SetupComm@12 @965
  SignalObjectAndWait@16 @967
  SizeofResource@8 @968
  Sleep@4 @969
  SleepEx@8 @970
  SuspendThread@4 @971
  SwitchToFiber@4 @972
  SwitchToThread@0 @973
  SystemTimeToFileTime@8 @974
  SystemTimeToTzSpecificLocalTime@12 @975
  TerminateProcess@8 @977
  TerminateThread@8 @978
  TermsrvAppInstallMode@0 @979
  Thread32First@8 @980
  Thread32Next@8 @981
  ThunkConnect32@24 @982
  TlsAlloc@0 @983
  TlsFree@4 @985
  TlsGetValue@4 @987
  TlsSetValue@8 @988
  Toolhelp32ReadProcessMemory@20 @989
  TransactNamedPipe@28 @990
  TransmitCommChar@8 @991
  TryEnterCriticalSection@4=ntdll.RtlTryEnterCriticalSection @993
  TzSpecificLocalTimeToSystemTime@12 @994
  UTRegister@28 @995
  UTUnRegister@4 @996
  UnMapLS@4 @997
  UnMapSLFixArray@8 @998
  UnhandledExceptionFilter@4 @999
  UninitializeCriticalSection@4 @1000
  UnlockFile@20 @1001
  UnlockFileEx@20 @1002
  UnmapViewOfFile@4 @1003
  UnregisterWait@4 @1004
  UnregisterWaitEx@8 @1005
  UpdateResourceA@24 @1006
  UpdateResourceW@24 @1007
  VerLanguageNameA@12 @1012
  VerLanguageNameW@12 @1013
  VerSetConditionMask@16=ntdll.VerSetConditionMask @1014
  VerifyConsoleIoHandle@4 @1015
  VerifyVersionInfoA@16 @1016
  VerifyVersionInfoW@16 @1017
  VirtualAlloc@16 @1018
  VirtualAllocEx@20 @1019
  VirtualFree@12 @1021
  VirtualFreeEx@16 @1022
  VirtualLock@8 @1023
  VirtualProtect@16 @1024
  VirtualProtectEx@20 @1025
  VirtualQuery@12 @1026
  VirtualQueryEx@16 @1027
  VirtualUnlock@8 @1028
  WaitCommEvent@12 @1029
  WaitForDebugEvent@8 @1030
  WaitForMultipleObjects@16 @1031
  WaitForMultipleObjectsEx@20 @1032
  WaitForSingleObject@8 @1033
  WaitForSingleObjectEx@12 @1034
  WaitNamedPipeA@8 @1035
  WaitNamedPipeW@8 @1036
  WideCharToMultiByte@32 @1037
  WinExec@8 @1038
  WriteConsoleA@20 @1039
  WriteConsoleInputA@16 @1040
  WriteConsoleInputW@16 @1043
  WriteConsoleOutputA@20 @1044
  WriteConsoleOutputAttribute@20 @1045
  WriteConsoleOutputCharacterA@20 @1046
  WriteConsoleOutputCharacterW@20 @1047
  WriteConsoleOutputW@20 @1048
  WriteConsoleW@20 @1049
  WriteFile@20 @1050
  WriteFileEx@20 @1051
  WritePrivateProfileSectionA@12 @1053
  WritePrivateProfileSectionW@12 @1054
  WritePrivateProfileStringA@16 @1055
  WritePrivateProfileStringW@16 @1056
  WritePrivateProfileStructA@20 @1057
  WritePrivateProfileStructW@20 @1058
  WriteProcessMemory@20 @1059
  WriteProfileSectionA@8 @1060
  WriteProfileSectionW@8 @1061
  WriteProfileStringA@12 @1062
  WriteProfileStringW@12 @1063
  WriteTapemark@16 @1064
  ZombifyActCtx@4 @1065
  _hread@12 @1068
  _hwrite@12 @1069
  _lclose@4 @1070
  _lcreat@8 @1071
  _llseek@12 @1072
  _lopen@8 @1073
  _lread@12 @1074
  _lwrite@12 @1075
  lstrcat@8=lstrcatA@8 @1077
  lstrcatA@8 @1078
  lstrcatW@8 @1079
  lstrcmp@8=lstrcmpA@8 @1080
  lstrcmpA@8 @1081
  lstrcmpW@8 @1082
  lstrcmpi@8=lstrcmpiA@8 @1083
  lstrcmpiA@8 @1084
  lstrcmpiW@8 @1085
  lstrcpy@8=lstrcpyA@8 @1086
  lstrcpyA@8 @1087
  lstrcpyW@8 @1088
  lstrcpyn@12=lstrcpynA@12 @1089
  lstrcpynA@12 @1090
  lstrcpynW@12 @1091
  lstrlen@4=lstrlenA@4 @1092
  lstrlenA@4 @1093
  lstrlenW@4 @1094
  _lclose16@4 @1095
  AllocCStoDSAlias16@4 @1096
  AllocSelectorArray16@4 @1097
  ConvertDialog32To16@12 @1098
  FarGetOwner16@4 @1099
  FarSetOwner16@8 @1100
  FindResource16@12 @1101
  FreeResource16@4 @1102
  FreeSelector16@4 @1103
  GetCurrentPDB16@0 @1104
  GetCurrentTask@0 @1105
  GetDOSEnvironment16@0 @1106
  GetExePtr@4 @1107
  GetExpWinVer16@4 @1108
  GetModuleHandle16@4 @1109
  GetSelectorLimit16@4 @1110
  GetVersion16@0 @1111
  GetWinFlags16@0 @1112
  GlobalDOSAlloc16@4 @1113
  GlobalDOSFree16@4 @1114
  GlobalFlags16@4 @1115
  GlobalReAlloc16@12 @1116
  IsBadReadPtr16@8 @1117
  IsTask16@4 @1118
  LoadModule16@8 @1119
  LoadResource16@8 @1120
  LocalAlloc16@8 @1121
  LocalInit16@12 @1122
  LocalLock16@4 @1123
  LocalUnlock16@4 @1124
  LocalReAlloc16@12 @1125
  LocalFree16@4 @1126
  LocalSize16@4 @1127
  LocalCompact16@4 @1128
  LocalCountFree16@0 @1129
  LocalHeapSize16@0 @1130
  LockResource16@4 @1131
  SelectorAccessRights16@12 @1132
  SetSelectorBase@8 @1133
  SetSelectorLimit16@8 @1134
  SizeofResource16@8 @1135
  WinExec16@8 @1136
  __wine_dll_register_16 @1137
  __wine_dll_unregister_16 @1138
  __wine_call_from_16_regs @1139 PRIVATE
  __wine_emulate_instruction @1140
  wine_get_unix_file_name @1141
  wine_get_dos_file_name @1142
  __wine_kernel_init @1143
