; File generated automatically from ./winscard.spec; do not edit!

LIBRARY winscard.dll

EXPORTS
  SCardEstablishContext@16 @15
  g_rgSCardRawPci @61 DATA
  g_rgSCardT0Pci @62 DATA
  g_rgSCardT1Pci @63 DATA
