; File generated automatically from ./shdocvw.spec; do not edit!

LIBRARY shdocvw.dll

EXPORTS
  IEWinMain@8 @101 NONAME
  WhichPlatformFORWARD@0 @104 NONAME
  WinList_Init@0 @110 NONAME
  ShellDDEInit@4 @118 NONAME
  StopWatchModeFORWARD@0 @121 NONAME
  StopWatchFlushFORWARD@0 @122 NONAME
  StopWatchAFORWARD@20 @123 NONAME
  StopWatchWFORWARD@20 @124 NONAME
  RunInstallUninstallStubs@0 @125 NONAME
  DllCanUnloadNow@0 @109 PRIVATE
  DllGetClassObject@12 @112 PRIVATE
  DllGetVersion@4 @113 PRIVATE
  DllInstall@8 @114 PRIVATE
  DllRegisterServer@0 @126 PRIVATE
  DllUnregisterServer@0 @128 PRIVATE
  OpenURL@16 @186
  SetQueryNetSessionCount@4 @201
