; File generated automatically from ./spoolss.spec; do not edit!

LIBRARY spoolss.dll

EXPORTS
  AllocSplStr@4 @15
  DllAllocSplMem@4 @41
  DllFreeSplMem@4 @42
  DllFreeSplStr@4 @43
  EnumPortsW@24=winspool.drv.EnumPortsW @50
  RevertToPrinterSelf@0 @104
