; File generated automatically from ./wininet.spec; do not edit!

LIBRARY wininet.dll

EXPORTS
  CommitUrlCacheEntryA@44 @106
  CommitUrlCacheEntryW@44 @107
  CreateMD5SSOHash@16 @113
  CreateUrlCacheContainerA@32 @114
  CreateUrlCacheContainerW@32 @115
  CreateUrlCacheEntryA@20 @119
  CreateUrlCacheEntryW@20 @124
  CreateUrlCacheGroup@8 @125
  DeleteIE3Cache@16 @126
  DeleteUrlCacheContainerA@8 @127
  DeleteUrlCacheContainerW@8 @128
  DeleteUrlCacheEntry@4=DeleteUrlCacheEntryA@4 @129
  DeleteUrlCacheEntryA@4 @130
  DeleteUrlCacheEntryW@4 @131
  DeleteUrlCacheGroup@16 @132
  DetectAutoProxyUrl@12 @133
  DllInstall@8 @134 PRIVATE
  FindCloseUrlCache@4 @135
  FindFirstUrlCacheContainerA@16 @136
  FindFirstUrlCacheContainerW@16 @137
  FindFirstUrlCacheEntryA@12 @138
  FindFirstUrlCacheEntryExA@40 @139
  FindFirstUrlCacheEntryExW@40 @140
  FindFirstUrlCacheEntryW@12 @141
  FindFirstUrlCacheGroup@24 @142
  FindNextUrlCacheContainerA@12 @143
  FindNextUrlCacheContainerW@12 @144
  FindNextUrlCacheEntryA@12 @145
  FindNextUrlCacheEntryExA@24 @146
  FindNextUrlCacheEntryExW@24 @147
  FindNextUrlCacheEntryW@12 @148
  FindNextUrlCacheGroup@12 @149
  FtpCommandA@24 @154
  FtpCommandW@24 @155
  FtpCreateDirectoryA@8 @156
  FtpCreateDirectoryW@8 @157
  FtpDeleteFileA@8 @158
  FtpDeleteFileW@8 @159
  FtpFindFirstFileA@20 @160
  FtpFindFirstFileW@20 @161
  FtpGetCurrentDirectoryA@12 @162
  FtpGetCurrentDirectoryW@12 @163
  FtpGetFileA@28 @164
  FtpGetFileSize@8 @166
  FtpGetFileW@28 @167
  FtpOpenFileA@20 @168
  FtpOpenFileW@20 @169
  FtpPutFileA@20 @170
  FtpPutFileW@20 @172
  FtpRemoveDirectoryA@8 @173
  FtpRemoveDirectoryW@8 @174
  FtpRenameFileA@12 @175
  FtpRenameFileW@12 @176
  FtpSetCurrentDirectoryA@8 @177
  FtpSetCurrentDirectoryW@8 @178
  GetUrlCacheConfigInfoA@12 @179
  GetUrlCacheConfigInfoW@12 @180
  GetUrlCacheEntryInfoA@12 @181
  GetUrlCacheEntryInfoExA@28 @182
  GetUrlCacheEntryInfoExW@28 @183
  GetUrlCacheEntryInfoW@12 @184
  GetUrlCacheGroupAttributeA@28 @185
  GetUrlCacheGroupAttributeW@28 @186
  GopherCreateLocatorA@28 @188
  GopherCreateLocatorW@28 @189
  GopherFindFirstFileA@24 @190
  GopherFindFirstFileW@24 @191
  GopherGetAttributeA@32 @192
  GopherGetAttributeW@32 @193
  GopherGetLocatorTypeA@8 @194
  GopherGetLocatorTypeW@8 @195
  GopherOpenFileA@20 @196
  GopherOpenFileW@20 @197
  HttpAddRequestHeadersA@16 @198
  HttpAddRequestHeadersW@16 @199
  HttpEndRequestA@16 @201
  HttpEndRequestW@16 @202
  HttpOpenRequestA@32 @203
  HttpOpenRequestW@32 @204
  HttpQueryInfoA@20 @205
  HttpQueryInfoW@20 @206
  HttpSendRequestA@20 @207
  HttpSendRequestExA@20 @208
  HttpSendRequestExW@20 @209
  HttpSendRequestW@20 @210
  InternetAttemptConnect@4 @214
  InternetAutodial@8 @215
  InternetAutodialHangup@4 @217
  InternetCanonicalizeUrlA@16 @218
  InternetCanonicalizeUrlW@16 @219
  InternetCheckConnectionA@12 @220
  InternetCheckConnectionW@12 @221
  InternetClearAllPerSiteCookieDecisions@0 @222
  InternetCloseHandle@4 @223
  InternetCombineUrlA@20 @224
  InternetCombineUrlW@20 @225
  InternetConfirmZoneCrossing@16=InternetConfirmZoneCrossingA@16 @226
  InternetConfirmZoneCrossingA@16 @227
  InternetConfirmZoneCrossingW@16 @228
  InternetConnectA@32 @229
  InternetConnectW@32 @230
  InternetCrackUrlA@16 @231
  InternetCrackUrlW@16 @232
  InternetCreateUrlA@16 @233
  InternetCreateUrlW@16 @234
  InternetDial@20=InternetDialA@20 @236
  InternetDialA@20 @237
  InternetDialW@20 @238
  InternetEnumPerSiteCookieDecisionA@16 @239
  InternetEnumPerSiteCookieDecisionW@16 @240
  InternetErrorDlg@20 @241
  InternetFindNextFileA@8 @242
  InternetFindNextFileW@8 @243
  InternetGetConnectedState@8 @247
  InternetGetConnectedStateEx@16=InternetGetConnectedStateExA@16 @248
  InternetGetConnectedStateExA@16 @249
  InternetGetConnectedStateExW@16 @250
  InternetGetCookieA@16 @251
  InternetGetCookieExA@24 @252
  InternetGetCookieExW@24 @253
  InternetGetCookieW@16 @254
  InternetGetLastResponseInfoA@12 @255
  InternetGetLastResponseInfoW@12 @256
  InternetGetPerSiteCookieDecisionA@8 @257
  InternetGetPerSiteCookieDecisionW@8 @258
  InternetGoOnline@12=InternetGoOnlineA@12 @259
  InternetGoOnlineA@12 @260
  InternetGoOnlineW@12 @261
  InternetHangUp@8 @262
  InternetInitializeAutoProxyDll@4 @263
  InternetLockRequestFile@8 @264
  InternetOpenA@20 @265
  InternetOpenUrlA@24 @267
  InternetOpenUrlW@24 @268
  InternetOpenW@20 @269
  InternetQueryDataAvailable@16 @270
  InternetQueryOptionA@16 @272
  InternetQueryOptionW@16 @273
  InternetReadFile@16 @274
  InternetReadFileExA@16 @275
  InternetReadFileExW@16 @276
  InternetSetCookieA@12 @280
  InternetSetCookieExA@20 @281
  InternetSetCookieExW@20 @282
  InternetSetCookieW@12 @283
  InternetSetFilePointer@20 @287
  InternetSetOptionA@16 @288
  InternetSetOptionExA@20 @289
  InternetSetOptionExW@20 @290
  InternetSetOptionW@16 @291
  InternetSetPerSiteCookieDecisionA@8 @292
  InternetSetPerSiteCookieDecisionW@8 @293
  InternetSetStatusCallback@8=InternetSetStatusCallbackA@8 @294
  InternetSetStatusCallbackA@8 @295
  InternetSetStatusCallbackW@8 @296
  InternetTimeFromSystemTime@16=InternetTimeFromSystemTimeA@16 @300
  InternetTimeFromSystemTimeA@16 @301
  InternetTimeFromSystemTimeW@16 @302
  InternetTimeToSystemTime@12=InternetTimeToSystemTimeA@12 @303
  InternetTimeToSystemTimeA@12 @304
  InternetTimeToSystemTimeW@12 @305
  InternetUnlockRequestFile@4 @306
  InternetWriteFile@16 @307
  IsHostInProxyBypassList@12 @310
  ReadUrlCacheEntryStream@20 @317
  ResumeSuspendedDownload@8 @319
  RetrieveUrlCacheEntryFileA@16 @320
  RetrieveUrlCacheEntryFileW@16 @321
  RetrieveUrlCacheEntryStreamA@20 @322
  RetrieveUrlCacheEntryStreamW@20 @323
  SetUrlCacheConfigInfoA@8 @325
  SetUrlCacheConfigInfoW@8 @326
  SetUrlCacheEntryGroup@28=SetUrlCacheEntryGroupA@28 @327
  SetUrlCacheEntryGroupA@28 @328
  SetUrlCacheEntryGroupW@28 @329
  SetUrlCacheEntryInfoA@12 @330
  SetUrlCacheEntryInfoW@12 @331
  SetUrlCacheGroupAttributeA@24 @332
  SetUrlCacheGroupAttributeW@24 @333
  UnlockUrlCacheEntryFile@8=UnlockUrlCacheEntryFileA@8 @339
  UnlockUrlCacheEntryFileA@8 @340
  UnlockUrlCacheEntryFileW@8 @341
  UnlockUrlCacheEntryStream@8 @342
