; File generated automatically from ./shell32.spec; do not edit!

LIBRARY shell32.dll

EXPORTS
  SHChangeNotifyRegister@24 @2 NONAME
  SHDefExtractIconA@24 @3
  SHChangeNotifyDeregister@4 @4 NONAME
  SHChangeNotifyUpdateEntryList@16 @5 NONAME
  SHDefExtractIconW@24 @6
  ILGetDisplayName@8 @15 NONAME
  ILFindLastID@4 @16 NONAME
  ILRemoveLastID@4 @17 NONAME
  ILClone@4 @18 NONAME
  ILCloneFirst@4 @19 NONAME
  ILGlobalClone@4 @20 NONAME
  ILIsEqual@8 @21 NONAME
  ILIsParent@12 @23 NONAME
  ILFindChild@8 @24 NONAME
  ILCombine@8 @25 NONAME
  ILLoadFromStream@8 @26 NONAME
  ILSaveToStream@8 @27 NONAME
  SHILCreateFromPath@12=SHILCreateFromPathAW@12 @28 NONAME
  PathIsRoot@4=PathIsRootAW@4 @29 NONAME
  PathBuildRoot@8=PathBuildRootAW@8 @30 NONAME
  PathFindExtension@4=PathFindExtensionAW@4 @31 NONAME
  PathAddBackslash@4=PathAddBackslashAW@4 @32 NONAME
  PathRemoveBlanks@4=PathRemoveBlanksAW@4 @33 NONAME
  PathFindFileName@4=PathFindFileNameAW@4 @34 NONAME
  PathRemoveFileSpec@4=PathRemoveFileSpecAW@4 @35 NONAME
  PathAppend@8=PathAppendAW@8 @36 NONAME
  PathCombine@12=PathCombineAW@12 @37 NONAME
  PathStripPath@4=PathStripPathAW@4 @38 NONAME
  PathIsUNC@4=PathIsUNCAW@4 @39 NONAME
  PathIsRelative@4=PathIsRelativeAW@4 @40 NONAME
  IsLFNDriveA@4 @41 NONAME
  IsLFNDriveW@4 @42 NONAME
  PathIsExe@4=PathIsExeAW@4 @43 NONAME
  PathFileExists@4=PathFileExistsAW@4 @45 NONAME
  PathMatchSpec@8=PathMatchSpecAW@8 @46 NONAME
  PathMakeUniqueName@20=PathMakeUniqueNameAW@20 @47 NONAME
  PathSetDlgItemPath@12=PathSetDlgItemPathAW@12 @48 NONAME
  PathQualify@4=PathQualifyAW@4 @49 NONAME
  PathStripToRoot@4=PathStripToRootAW@4 @50 NONAME
  PathResolve@12=PathResolveAW@12 @51
  PathGetArgs@4=PathGetArgsAW@4 @52 NONAME
  DoEnvironmentSubst@8=DoEnvironmentSubstAW@8 @53
  PathQuoteSpaces@4=PathQuoteSpacesAW@4 @55 NONAME
  PathUnquoteSpaces@4=PathUnquoteSpacesAW@4 @56 NONAME
  PathGetDriveNumber@4=PathGetDriveNumberAW@4 @57 NONAME
  ParseField@16=ParseFieldAW@16 @58 NONAME
  RestartDialog@12 @59 NONAME
  ExitWindowsDialog@4 @60 NONAME
  RunFileDlg@24 @61 NONAME
  PickIconDlg@16 @62 NONAME
  GetFileNameFromBrowse@28 @63 NONAME
  DriveType@4 @64 NONAME
  InvalidateDriveType@4 @65 NONAME
  IsNetDrive@4 @66 NONAME
  Shell_MergeMenus@24 @67 NONAME
  SHGetSetSettings@12 @68 NONAME
  SHCreateDefClassObject@20 @70 NONAME
  Shell_GetImageList@8 @71 NONAME
  Shell_GetCachedImageIndex@12=Shell_GetCachedImageIndexAW@12 @72 NONAME
  SHShellFolderView_Message@12 @73 NONAME
  SHCreateStdEnumFmtEtc@12 @74 NONAME
  PathYetAnotherMakeUniqueName@16 @75 NONAME
  SHMapPIDLToSystemImageListIndex@12 @77 NONAME
  OleStrToStrN@16=OleStrToStrNAW@16 @78 NONAME
  StrToOleStrN@16=StrToOleStrNAW@16 @79 NONAME
  CIDLData_CreateFromIDArray@16 @83 NONAME
  OpenRegStream@16=shlwapi.SHOpenRegStreamA @85 NONAME
  SHRegisterDragDrop@8 @86 NONAME
  SHRevokeDragDrop@4 @87 NONAME
  SHDoDragDrop@20 @88 NONAME
  SHCloneSpecialIDList@12 @89 NONAME
  SHFindFiles@8 @90 NONAME
  PathGetShortPath@4=PathGetShortPathAW@4 @92 NONAME
  Win32CreateDirectory@8=Win32CreateDirectoryAW@8 @93 NONAME
  Win32RemoveDirectory@4=Win32RemoveDirectoryAW@4 @94 NONAME
  SHLogILFromFSIL@4 @95 NONAME
  StrRetToStrN@16=StrRetToStrNAW@16 @96 NONAME
  SHWaitForFileToOpen@12 @97 NONAME
  SHGetRealIDL@12 @98 NONAME
  SetAppStartingCursor@8 @99 NONAME
  SHRestricted@4 @100 NONAME
  SHCoCreateInstance@20 @102 NONAME
  SignalFileOpen@4 @103 NONAME
  FileMenu_DeleteAllItems@4 @104 NONAME
  FileMenu_DrawItem@8 @105 NONAME
  FileMenu_FindSubMenuByPidl@8 @106 NONAME
  FileMenu_GetLastSelectedItemPidls@12 @107 NONAME
  FileMenu_HandleMenuChar@8 @108 NONAME
  FileMenu_InitMenuPopup@4 @109 NONAME
  FileMenu_InsertUsingPidl@24 @110 NONAME
  FileMenu_Invalidate@4 @111 NONAME
  FileMenu_MeasureItem@8 @112 NONAME
  FileMenu_ReplaceUsingPidl@20 @113 NONAME
  FileMenu_Create@20 @114 NONAME
  FileMenu_AppendItem@24=FileMenu_AppendItemAW@24 @115 NONAME
  FileMenu_TrackPopupMenuEx@24 @116 NONAME
  FileMenu_DeleteItemByCmd@8 @117 NONAME
  FileMenu_Destroy@4 @118 NONAME
  IsLFNDrive@4=IsLFNDriveAW@4 @119 NONAME
  FileMenu_AbortInitMenu@0 @120 NONAME
  SHFlushClipboard@0 @121 NONAME
  RunDLL_CallEntry16@20 @122 NONAME
  SHFreeUnusedLibraries@0 @123 NONAME
  FileMenu_AppendFilesForPidl@12 @124 NONAME
  FileMenu_AddFilesForPidl@28 @125 NONAME
  SHOutOfMemoryMessageBox@12 @126 NONAME
  SHWinHelp@16 @127 NONAME
  SHDllGetClassObject@12=DllGetClassObject@12 @128 NONAME
  DAD_AutoScroll@12 @129 NONAME
  DAD_DragEnter@4 @130 NONAME
  DAD_DragEnterEx@12 @131 NONAME
  DAD_DragLeave@0 @132 NONAME
  DAD_DragMove@8 @134 NONAME
  DAD_SetDragImage@8 @136 NONAME
  DAD_ShowDragImage@4 @137 NONAME
  FileMenu_DeleteItemByIndex@8 @140 NONAME
  FileMenu_DeleteItemByFirstID@8 @141 NONAME
  FileMenu_DeleteSeparator@4 @142 NONAME
  FileMenu_EnableItemByCmd@12 @143 NONAME
  FileMenu_GetItemExtent@8 @144 NONAME
  PathFindOnPath@8=PathFindOnPathAW@8 @145 NONAME
  RLBuildListOfPaths@0 @146 NONAME
  SHCLSIDFromString@8=SHCLSIDFromStringAW@8 @147 NONAME
  SHMapIDListToImageListIndexAsync@36 @148 NONAME
  SHFind_InitMenuPopup@16 @149 NONAME
  SHLoadOLE@4 @151 NONAME
  ILGetSize@4 @152 NONAME
  ILGetNext@4 @153 NONAME
  ILAppend@12 @154 NONAME
  ILFree@4 @155 NONAME
  ILGlobalFree@4 @156 NONAME
  ILCreateFromPath@4=ILCreateFromPathAW@4 @157 NONAME
  PathGetExtension@12=PathGetExtensionAW@12 @158 NONAME
  PathIsDirectory@4=PathIsDirectoryAW@4 @159 NONAME
  SHRunControlPanel@8 @161 NONAME
  SHSimpleIDListFromPath@4=SHSimpleIDListFromPathAW@4 @162 NONAME
  StrToOleStr@8=StrToOleStrAW@8 @163 NONAME
  Win32DeleteFile@4=Win32DeleteFileAW@4 @164 NONAME
  SHCreateDirectory@8 @165 NONAME
  CallCPLEntry16@24 @166 NONAME
  SHAddFromPropSheetExtArray@12 @167 NONAME
  SHCreatePropSheetExtArray@12 @168 NONAME
  SHDestroyPropSheetExtArray@4 @169 NONAME
  SHReplaceFromPropSheetExtArray@16 @170 NONAME
  PathCleanupSpec@8 @171 NONAME
  SHCreateLinks@20 @172 NONAME
  SHValidateUNC@12 @173 NONAME
  SHCreateShellFolderViewEx@8 @174 NONAME
  SHGetSpecialFolderPath@16=SHGetSpecialFolderPathAW@16 @175 NONAME
  SHSetInstanceExplorer@4 @176 NONAME
  SHObjectProperties@16 @178 NONAME
  SHGetNewLinkInfoA@20 @179 NONAME
  SHGetNewLinkInfoW@20 @180 NONAME
  RegisterShellHook@8 @181 NONAME
  ShellMessageBoxW @182 NONAME
  ShellMessageBoxA @183 NONAME
  ArrangeWindows@20 @184 NONAME
  ILGetDisplayNameEx@16 @186 NONAME
  ShellDDEInit@4 @188 NONAME
  ILCreateFromPathA@4 @189 NONAME
  ILCreateFromPathW@4 @190 NONAME
  SHUpdateImageA@16 @191 NONAME
  SHUpdateImageW@16 @192 NONAME
  SHHandleUpdateImage@4 @193 NONAME
  SHFree@4 @195 NONAME
  SHAlloc@4 @196 NONAME
  SHAbortInvokeCommand@0 @198 NONAME
  Printer_LoadIconsW@12 @205
  Printers_RegisterWindowW@16 @213
  Printers_UnregisterWindow@8 @214
  SHStartNetConnectionDialog@12 @215 NONAME
  SHInitRestricted@8 @244 NONAME
  PathParseIconLocation@4=PathParseIconLocationAW@4 @249 NONAME
  PathRemoveExtension@4=PathRemoveExtensionAW@4 @250 NONAME
  PathRemoveArgs@4=PathRemoveArgsAW@4 @251 NONAME
  SHRegCloseKey@4 @505
  SHRegOpenKeyA@12 @506
  SHRegOpenKeyW@12 @507
  SHRegQueryValueA@16 @508
  SHRegQueryValueExA@24 @509
  SHRegQueryValueW@16 @510
  SHRegQueryValueExW@24 @511
  SHRegDeleteKeyW@8 @512
  SHAllocShared@12 @520 NONAME
  SHLockShared@8 @521 NONAME
  SHUnlockShared@4 @522 NONAME
  SHFreeShared@8 @523 NONAME
  RealDriveType@8 @524 NONAME
  NTSHChangeNotifyRegister@24 @640 NONAME
  NTSHChangeNotifyDeregister@4 @641 NONAME
  SHChangeNotification_Lock@16 @644 NONAME
  SHChangeNotification_Unlock@4 @645 NONAME
  PathIsSameRoot@8=PathIsSameRootAW@8 @650 NONAME
  ReadCabinetState@8 @651 NONAME
  WriteCabinetState@4 @652 NONAME
  PathProcessCommand@16=PathProcessCommandAW@16 @653 NONAME
  FileIconInit@4 @660 NONAME
  IsUserAdmin@0 @680 NONAME
  RestartDialogEx@16 @730 NONAME
  CheckEscapesA@8 @7
  CheckEscapesW@8 @8
  CommandLineToArgvW@8 @12
  Control_FillCache_RunDLL@16=Control_FillCache_RunDLLA@16 @14
  Control_FillCache_RunDLLA@16 @22
  Control_FillCache_RunDLLW@16 @44
  Control_RunDLL@16=Control_RunDLLA@16 @54
  Control_RunDLLA@16 @80
  Control_RunDLLW@16 @82
  DllCanUnloadNow@0 @101 PRIVATE
  DllGetClassObject@12 @133 PRIVATE
  DllGetVersion@4 @135 PRIVATE
  DllInstall@8 @138 PRIVATE
  DllRegisterServer@0 @150 PRIVATE
  DllUnregisterServer@0 @216 PRIVATE
  DoEnvironmentSubstA@8 @217
  DoEnvironmentSubstW@8 @218
  DragAcceptFiles@8 @219
  DragFinish@4 @220
  DragQueryFile@16=DragQueryFileA@16 @221
  DragQueryFileA@16 @222
  DragQueryFileW@16 @224
  DragQueryPoint@8 @225
  DuplicateIcon@8 @226
  ExtractAssociatedIconA@12 @227
  ExtractAssociatedIconExA@16 @228
  ExtractAssociatedIconExW@16 @229
  ExtractAssociatedIconW@12 @230
  ExtractIconA@12 @231
  ExtractIconEx@20=ExtractIconExA@20 @232
  ExtractIconExA@20 @233
  ExtractIconExW@20 @234
  ExtractIconW@12 @237
  FindExecutableA@12 @240
  FindExecutableW@12 @241
  FreeIconList@4 @245
  OpenAs_RunDLL@16=OpenAs_RunDLLA@16 @252
  OpenAs_RunDLLA@16 @253
  OpenAs_RunDLLW@16 @254
  SHAddToRecentDocs@8 @264
  SHAppBarMessage@8 @265
  SHBindToParent@16 @266
  SHBrowseForFolder@4=SHBrowseForFolderA@4 @267
  SHBrowseForFolderA@4 @268
  SHBrowseForFolderW@4 @269
  SHChangeNotify@16 @270
  SHCreateDirectoryExA@12 @272
  SHCreateDirectoryExW@12 @273
  SHEmptyRecycleBinA@12 @275
  SHEmptyRecycleBinW@12 @276
  SHFileOperation@4=SHFileOperationA@4 @278
  SHFileOperationA@4 @279
  SHFileOperationW@4 @280
  SHFormatDrive@16 @281
  SHFreeNameMappings@4 @282
  SHGetDataFromIDListA@20 @283
  SHGetDataFromIDListW@20 @284
  SHGetDesktopFolder@4 @285
  SHGetDiskFreeSpaceA@16=kernel32.GetDiskFreeSpaceExA @286
  SHGetDiskFreeSpaceExA@16=kernel32.GetDiskFreeSpaceExA @287
  SHGetDiskFreeSpaceExW@16=kernel32.GetDiskFreeSpaceExW @288
  SHGetFileInfo@20=SHGetFileInfoA@20 @289
  SHGetFileInfoA@20 @290
  SHGetFileInfoW@20 @291
  SHGetFolderLocation@20 @292
  SHGetFolderPathA@20 @293
  SHGetFolderPathW@20 @294
  SHGetInstanceExplorer@4 @298
  SHGetMalloc@4 @299
  SHGetNewLinkInfo@20=SHGetNewLinkInfoA@20 @300
  SHGetPathFromIDList@8=SHGetPathFromIDListA@8 @301
  SHGetPathFromIDListA@8 @302
  SHGetPathFromIDListW@8 @303
  SHGetSettings@8 @304
  SHGetSpecialFolderLocation@12 @305
  SHGetSpecialFolderPathA@16 @306
  SHGetSpecialFolderPathW@16 @307
  SHHelpShortcuts_RunDLL@16=SHHelpShortcuts_RunDLLA@16 @308
  SHHelpShortcuts_RunDLLA@16 @309
  SHHelpShortcuts_RunDLLW@16 @310
  SHIsFileAvailableOffline@8 @313
  SHLoadInProc@4 @314
  SHLoadNonloadedIconOverlayIdentifiers@0 @315
  SHPathPrepareForWriteA@16 @316
  SHPathPrepareForWriteW@16 @317
  SHQueryRecycleBinA@8 @318
  SHQueryRecycleBinW@8 @319
  SHSetLocalizedName@12 @320
  SHUpdateRecycleBinIcon@0 @321
  SheChangeDirA@4 @322
  SheChangeDirW@4 @325
  SheGetDirA@8 @330
  SheGetDirW@8 @332
  ShellAboutA@16 @339
  ShellAboutW@16 @340
  ShellExecuteA@24 @344
  ShellExecuteEx@4=ShellExecuteExA@4 @345
  ShellExecuteExA@4 @346
  ShellExecuteExW@4 @347
  ShellExecuteW@24 @348
  Shell_NotifyIcon@8=Shell_NotifyIconA@8 @350
  Shell_NotifyIconA@8 @351
  Shell_NotifyIconW@8 @352
  StrChrA@8=shlwapi.StrChrA @353
  StrChrIA@8=shlwapi.StrChrIA @354
  StrChrIW@8=shlwapi.StrChrIW @355
  StrChrW@8=shlwapi.StrChrW @356
  StrCmpNA@12=shlwapi.StrCmpNA @357
  StrCmpNIA@12=shlwapi.StrCmpNIA @358
  StrCmpNIW@12=shlwapi.StrCmpNIW @359
  StrCmpNW@12=shlwapi.StrCmpNW @360
  StrCpyNA@12=kernel32.lstrcpynA @361
  StrCpyNW@12=shlwapi.StrCpyNW @362
  StrNCmpA@12=shlwapi.StrCmpNA @363
  StrNCmpIA@12=shlwapi.StrCmpNIA @364
  StrNCmpIW@12=shlwapi.StrCmpNIW @365
  StrNCmpW@12=shlwapi.StrCmpNW @366
  StrNCpyA@12=kernel32.lstrcpynA @367
  StrNCpyW@12=shlwapi.StrCpyNW @368
  StrRChrA@12=shlwapi.StrRChrA @369
  StrRChrIA@12=shlwapi.StrRChrIA @370
  StrRChrIW@12=shlwapi.StrRChrIW @371
  StrRChrW@12=shlwapi.StrRChrW @372
  StrRStrIA@12=shlwapi.StrRStrIA @374
  StrRStrIW@12=shlwapi.StrRStrIW @375
  StrStrA@8=shlwapi.StrStrA @377
  StrStrIA@8=shlwapi.StrStrIA @378
  StrStrIW@8=shlwapi.StrStrIW @379
  StrStrW@8=shlwapi.StrStrW @380
