; File generated automatically from ./msvcrtd.spec; do not edit!

LIBRARY msvcrtd.dll

EXPORTS
  $I10_OUTPUT=msvcrt.$I10_OUTPUT @1
  ??0__non_rtti_object@@QAE@ABV0@@Z=msvcrt.??0__non_rtti_object@@QAE@ABV0@@Z @2
  ??0__non_rtti_object@@QAE@PBD@Z=msvcrt.??0__non_rtti_object@@QAE@PBD@Z @3
  ??0bad_cast@@QAE@ABQBD@Z=msvcrt.??0bad_cast@@QAE@ABQBD@Z @4
  ??0bad_cast@@QAE@ABV0@@Z=msvcrt.??0bad_cast@@QAE@ABV0@@Z @5
  ??0bad_typeid@@QAE@ABV0@@Z=msvcrt.??0bad_typeid@@QAE@ABV0@@Z @6
  ??0bad_typeid@@QAE@PBD@Z=msvcrt.??0bad_typeid@@QAE@PBD@Z @7
  ??0exception@@QAE@ABQBD@Z=msvcrt.??0exception@@QAE@ABQBD@Z @8
  ??0exception@@QAE@ABV0@@Z=msvcrt.??0exception@@QAE@ABV0@@Z @9
  ??0exception@@QAE@XZ=msvcrt.??0exception@@QAE@XZ @10
  ??1__non_rtti_object@@UAE@XZ=msvcrt.??1__non_rtti_object@@UAE@XZ @11
  ??1bad_cast@@UAE@XZ=msvcrt.??1bad_cast@@UAE@XZ @12
  ??1bad_typeid@@UAE@XZ=msvcrt.??1bad_typeid@@UAE@XZ @13
  ??1exception@@UAE@XZ=msvcrt.??1exception@@UAE@XZ @14
  ??1type_info@@UAE@XZ=msvcrt.??1type_info@@UAE@XZ @15
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @16
  ??2@YAPAXIHPBDH@Z=MSVCRTD_operator_new_dbg @17
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @18
  ??4__non_rtti_object@@QAEAAV0@ABV0@@Z=msvcrt.??4__non_rtti_object@@QAEAAV0@ABV0@@Z @19
  ??4bad_cast@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_cast@@QAEAAV0@ABV0@@Z @20
  ??4bad_typeid@@QAEAAV0@ABV0@@Z=msvcrt.??4bad_typeid@@QAEAAV0@ABV0@@Z @21
  ??4exception@@QAEAAV0@ABV0@@Z=msvcrt.??4exception@@QAEAAV0@ABV0@@Z @22
  ??8type_info@@QBEHABV0@@Z=msvcrt.??8type_info@@QBEHABV0@@Z @23
  ??9type_info@@QBEHABV0@@Z=msvcrt.??9type_info@@QBEHABV0@@Z @24
  ??_7__non_rtti_object@@6B@=msvcrt.??_7__non_rtti_object@@6B@ @25 DATA
  ??_7bad_cast@@6B@=msvcrt.??_7bad_cast@@6B@ @26 DATA
  ??_7bad_typeid@@6B@=msvcrt.??_7bad_typeid@@6B@ @27 DATA
  ??_7exception@@6B@=msvcrt.??_7exception@@6B@ @28 DATA
  ??_E__non_rtti_object@@UAEPAXI@Z=msvcrt.??_E__non_rtti_object@@UAEPAXI@Z @29
  ??_Ebad_cast@@UAEPAXI@Z=msvcrt.??_Ebad_cast@@UAEPAXI@Z @30
  ??_Ebad_typeid@@UAEPAXI@Z=msvcrt.??_Ebad_typeid@@UAEPAXI@Z @31
  ??_Eexception@@UAEPAXI@Z=msvcrt.??_Eexception@@UAEPAXI@Z @32
  ??_G__non_rtti_object@@UAEPAXI@Z=msvcrt.??_G__non_rtti_object@@UAEPAXI@Z @33
  ??_Gbad_cast@@UAEPAXI@Z=msvcrt.??_Gbad_cast@@UAEPAXI@Z @34
  ??_Gbad_typeid@@UAEPAXI@Z=msvcrt.??_Gbad_typeid@@UAEPAXI@Z @35
  ??_Gexception@@UAEPAXI@Z=msvcrt.??_Gexception@@UAEPAXI@Z @36
  ?_query_new_handler@@YAP6AHI@ZXZ=msvcrt.?_query_new_handler@@YAP6AHI@ZXZ @37
  ?_query_new_mode@@YAHXZ=msvcrt.?_query_new_mode@@YAHXZ @38
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @39
  ?_set_new_mode@@YAHH@Z=msvcrt.?_set_new_mode@@YAHH@Z @40
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=msvcrt.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z @41
  ?before@type_info@@QBEHABV1@@Z=msvcrt.?before@type_info@@QBEHABV1@@Z @42
  ?name@type_info@@QBEPBDXZ=msvcrt.?name@type_info@@QBEPBDXZ @43
  ?raw_name@type_info@@QBEPBDXZ=msvcrt.?raw_name@type_info@@QBEPBDXZ @44
  ?set_new_handler@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_new_handler@@YAP6AXXZP6AXXZ@Z @45
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_terminate@@YAP6AXXZP6AXXZ@Z @46
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_unexpected@@YAP6AXXZP6AXXZ@Z @47
  ?terminate@@YAXXZ=msvcrt.?terminate@@YAXXZ @48
  ?unexpected@@YAXXZ=msvcrt.?unexpected@@YAXXZ @49
  ?what@exception@@UBEPBDXZ=msvcrt.?what@exception@@UBEPBDXZ @50
  _CIacos=msvcrt._CIacos @51
  _CIasin=msvcrt._CIasin @52
  _CIatan=msvcrt._CIatan @53
  _CIatan2=msvcrt._CIatan2 @54
  _CIcos=msvcrt._CIcos @55
  _CIcosh=msvcrt._CIcosh @56
  _CIexp=msvcrt._CIexp @57
  _CIfmod=msvcrt._CIfmod @58
  _CIlog=msvcrt._CIlog @59
  _CIlog10=msvcrt._CIlog10 @60
  _CIpow=msvcrt._CIpow @61
  _CIsin=msvcrt._CIsin @62
  _CIsinh=msvcrt._CIsinh @63
  _CIsqrt=msvcrt._CIsqrt @64
  _CItan=msvcrt._CItan @65
  _CItanh=msvcrt._CItanh @66
  _CrtCheckMemory @67
  _CrtDbgReport @69
  _CrtDumpMemoryLeaks @71
  _CrtSetBreakAlloc @80
  _CrtSetDbgFlag @82
  _CrtSetDumpClient @83
  _CrtSetReportHook @85
  _CrtSetReportMode @86
  _CxxThrowException=msvcrt._CxxThrowException @87
  _EH_prolog=msvcrt._EH_prolog @88
  _Getdays=msvcrt._Getdays @89
  _Getmonths=msvcrt._Getmonths @90
  _Gettnames=msvcrt._Gettnames @91
  _HUGE=msvcrt._HUGE @92 DATA
  _Strftime=msvcrt._Strftime @93
  _XcptFilter=msvcrt._XcptFilter @94
  __CxxFrameHandler=msvcrt.__CxxFrameHandler @95
  __CxxLongjmpUnwind@4=msvcrt.__CxxLongjmpUnwind @96
  __RTCastToVoid=msvcrt.__RTCastToVoid @97
  __RTDynamicCast=msvcrt.__RTDynamicCast @98
  __RTtypeid=msvcrt.__RTtypeid @99
  __STRINGTOLD=msvcrt.__STRINGTOLD @100
  __argc=msvcrt.__argc @101 DATA
  __argv=msvcrt.__argv @102 DATA
  __badioinfo=msvcrt.__badioinfo @103 DATA
  __crtCompareStringA=msvcrt.__crtCompareStringA @104
  __crtGetLocaleInfoW=msvcrt.__crtGetLocaleInfoW @105
  __crtLCMapStringA=msvcrt.__crtLCMapStringA @106
  __dllonexit=msvcrt.__dllonexit @107
  __doserrno=msvcrt.__doserrno @108
  __fpecode=msvcrt.__fpecode @109
  __getmainargs=msvcrt.__getmainargs @110
  __initenv=msvcrt.__initenv @111 DATA
  __isascii=msvcrt.__isascii @112
  __iscsym=msvcrt.__iscsym @113
  __iscsymf=msvcrt.__iscsymf @114
  __lc_codepage=msvcrt.__lc_codepage @115 DATA
  __lc_collate_cp=msvcrt.__lc_collate_cp @116 DATA
  __lc_handle=msvcrt.__lc_handle @117 DATA
  __lconv_init=msvcrt.__lconv_init @118
  __mb_cur_max=msvcrt.__mb_cur_max @119 DATA
  __p___argc=msvcrt.__p___argc @120
  __p___argv=msvcrt.__p___argv @121
  __p___initenv=msvcrt.__p___initenv @122
  __p___mb_cur_max=msvcrt.__p___mb_cur_max @123
  __p___wargv=msvcrt.__p___wargv @124
  __p___winitenv=msvcrt.__p___winitenv @125
  __p__acmdln=msvcrt.__p__acmdln @126
  __p__amblksiz=msvcrt.__p__amblksiz @127
  __p__commode=msvcrt.__p__commode @128
  __p__crtAssertBusy @129
  __p__crtBreakAlloc @130
  __p__crtDbgFlag @131
  __p__daylight=msvcrt.__p__daylight @132
  __p__dstbias=msvcrt.__p__dstbias @133
  __p__environ=msvcrt.__p__environ @134
  __p__fileinfo=msvcrt.__p__fileinfo @135
  __p__fmode=msvcrt.__p__fmode @136
  __p__iob=msvcrt.__p__iob @137
  __p__mbcasemap=msvcrt.__p__mbcasemap @138
  __p__mbctype=msvcrt.__p__mbctype @139
  __p__osver=msvcrt.__p__osver @140
  __p__pctype=msvcrt.__p__pctype @141
  __p__pgmptr=msvcrt.__p__pgmptr @142
  __p__pwctype=msvcrt.__p__pwctype @143
  __p__timezone=msvcrt.__p__timezone @144
  __p__tzname=msvcrt.__p__tzname @145
  __p__wcmdln=msvcrt.__p__wcmdln @146
  __p__wenviron=msvcrt.__p__wenviron @147
  __p__winmajor=msvcrt.__p__winmajor @148
  __p__winminor=msvcrt.__p__winminor @149
  __p__winver=msvcrt.__p__winver @150
  __p__wpgmptr=msvcrt.__p__wpgmptr @151
  __pioinfo=msvcrt.__pioinfo @152 DATA
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @153
  __set_app_type=msvcrt.__set_app_type @154
  __setlc_active=msvcrt.__setlc_active @155 DATA
  __setusermatherr=msvcrt.__setusermatherr @156
  __threadhandle=kernel32.GetCurrentThread @157
  __threadid=kernel32.GetCurrentThreadId @158
  __toascii=msvcrt.__toascii @159
  __unDName=msvcrt.__unDName @160
  __unDNameEx=msvcrt.__unDNameEx @161
  __unguarded_readlc_active=msvcrt.__unguarded_readlc_active @162 DATA
  __wargv=msvcrt.__wargv @163 DATA
  __wgetmainargs=msvcrt.__wgetmainargs @164
  __winitenv=msvcrt.__winitenv @165 DATA
  _abnormal_termination=msvcrt._abnormal_termination @166
  _access=msvcrt._access @167
  _acmdln=msvcrt._acmdln @168 DATA
  _adj_fdiv_m16i@4=msvcrt._adj_fdiv_m16i @169
  _adj_fdiv_m32@4=msvcrt._adj_fdiv_m32 @170
  _adj_fdiv_m32i@4=msvcrt._adj_fdiv_m32i @171
  _adj_fdiv_m64@8=msvcrt._adj_fdiv_m64 @172
  _adj_fdiv_r=msvcrt._adj_fdiv_r @173
  _adj_fdivr_m16i@4=msvcrt._adj_fdivr_m16i @174
  _adj_fdivr_m32@4=msvcrt._adj_fdivr_m32 @175
  _adj_fdivr_m32i@4=msvcrt._adj_fdivr_m32i @176
  _adj_fdivr_m64@8=msvcrt._adj_fdivr_m64 @177
  _adj_fpatan=msvcrt._adj_fpatan @178
  _adj_fprem=msvcrt._adj_fprem @179
  _adj_fprem1=msvcrt._adj_fprem1 @180
  _adj_fptan=msvcrt._adj_fptan @181
  _adjust_fdiv=msvcrt._adjust_fdiv @182
  _aexit_rtn=msvcrt._aexit_rtn @183 DATA
  _amsg_exit=msvcrt._amsg_exit @184
  _assert=msvcrt._assert @185
  _atodbl=msvcrt._atodbl @186
  _atoi64=ntdll._atoi64 @187
  _atoldbl=msvcrt._atoldbl @188
  _beep=msvcrt._beep @189
  _beginthread=msvcrt._beginthread @190
  _beginthreadex=msvcrt._beginthreadex @191
  _c_exit=msvcrt._c_exit @192
  _cabs=msvcrt._cabs @193
  _callnewh=msvcrt._callnewh @194
  _calloc_dbg=msvcrt.calloc @195
  _cexit=msvcrt._cexit @196
  _cgets=msvcrt._cgets @197
  _chdir=msvcrt._chdir @198
  _chdrive=msvcrt._chdrive @199
  _chgsign=msvcrt._chgsign @200
  _chkesp=msvcrt._chkesp @201
  _chmod=msvcrt._chmod @202
  _chsize=msvcrt._chsize @203
  _clearfp=msvcrt._clearfp @204
  _close=msvcrt._close @205
  _commit=msvcrt._commit @206
  _commode=msvcrt._commode @207 DATA
  _control87=msvcrt._control87 @208
  _controlfp=msvcrt._controlfp @209
  _copysign=msvcrt._copysign @210
  _cprintf=msvcrt._cprintf @211
  _cputs=msvcrt._cputs @212
  _creat=msvcrt._creat @213
  _crtAssertBusy @214 DATA
  _crtBreakAlloc @215 DATA
  _crtDbgFlag @216 DATA
  _cscanf=msvcrt._cscanf @217
  _ctype=msvcrt._ctype @218 DATA
  _cwait=msvcrt._cwait @219
  _daylight=msvcrt._daylight @220 DATA
  _dstbias=msvcrt._dstbias @221 DATA
  _dup=msvcrt._dup @222
  _dup2=msvcrt._dup2 @223
  _ecvt=msvcrt._ecvt @224
  _endthread=msvcrt._endthread @225
  _endthreadex=msvcrt._endthreadex @226
  _environ=msvcrt._environ @227 DATA
  _eof=msvcrt._eof @228
  _errno=msvcrt._errno @229
  _except_handler2=msvcrt._except_handler2 @230
  _except_handler3=msvcrt._except_handler3 @231
  _execl=msvcrt._execl @232
  _execle=msvcrt._execle @233
  _execlp=msvcrt._execlp @234
  _execlpe=msvcrt._execlpe @235
  _execv=msvcrt._execv @236
  _execve=msvcrt._execve @237
  _execvp=msvcrt._execvp @238
  _execvpe=msvcrt._execvpe @239
  _exit=msvcrt._exit @240
  _expand=msvcrt._expand @241
  _expand_dbg=msvcrt._expand @242
  _fcloseall=msvcrt._fcloseall @243
  _fcvt=msvcrt._fcvt @244
  _fdopen=msvcrt._fdopen @245
  _fgetchar=msvcrt._fgetchar @246
  _fgetwchar=msvcrt._fgetwchar @247
  _filbuf=msvcrt._filbuf @248
  _fileinfo=msvcrt._fileinfo @249 DATA
  _filelength=msvcrt._filelength @250
  _filelengthi64=msvcrt._filelengthi64 @251
  _fileno=msvcrt._fileno @252
  _findclose=msvcrt._findclose @253
  _findfirst=msvcrt._findfirst @254
  _findfirsti64=msvcrt._findfirsti64 @255
  _findnext=msvcrt._findnext @256
  _findnexti64=msvcrt._findnexti64 @257
  _finite=msvcrt._finite @258
  _flsbuf=msvcrt._flsbuf @259
  _flushall=msvcrt._flushall @260
  _fmode=msvcrt._fmode @261 DATA
  _fpclass=msvcrt._fpclass @262
  _fpieee_flt=msvcrt._fpieee_flt @263
  _fpreset=msvcrt._fpreset @264
  _fputchar=msvcrt._fputchar @265
  _fputwchar=msvcrt._fputwchar @266
  _free_dbg=msvcrt.free @267
  _fsopen=msvcrt._fsopen @268
  _fstat=msvcrt._fstat @269
  _fstati64=msvcrt._fstati64 @270
  _ftime=msvcrt._ftime @271
  _ftol=ntdll._ftol @272
  _fullpath=msvcrt._fullpath @273
  _futime=msvcrt._futime @274
  _gcvt=msvcrt._gcvt @275
  _get_osfhandle=msvcrt._get_osfhandle @276
  _get_sbh_threshold=msvcrt._get_sbh_threshold @277
  _getch=msvcrt._getch @278
  _getche=msvcrt._getche @279
  _getcwd=msvcrt._getcwd @280
  _getdcwd=msvcrt._getdcwd @281
  _getdiskfree=msvcrt._getdiskfree @282
  _getdllprocaddr=msvcrt._getdllprocaddr @283
  _getdrive=msvcrt._getdrive @284
  _getdrives=kernel32.GetLogicalDrives @285
  _getmaxstdio=msvcrt._getmaxstdio @286
  _getmbcp=msvcrt._getmbcp @287
  _getpid=kernel32.GetCurrentProcessId @288
  _getsystime=msvcrt._getsystime @289
  _getw=msvcrt._getw @290
  _getws=msvcrt._getws @291
  _global_unwind2=msvcrt._global_unwind2 @292
  _heapadd=msvcrt._heapadd @293
  _heapchk=msvcrt._heapchk @294
  _heapmin=msvcrt._heapmin @295
  _heapset=msvcrt._heapset @296
  _heapused=msvcrt._heapused @297
  _heapwalk=msvcrt._heapwalk @298
  _hypot=msvcrt._hypot @299
  _i64toa=ntdll._i64toa @300
  _i64tow=ntdll._i64tow @301
  _initterm=msvcrt._initterm @302
  _inp=msvcrt._inp @303
  _inpd=msvcrt._inpd @304
  _inpw=msvcrt._inpw @305
  _iob=msvcrt._iob @306 DATA
  _isatty=msvcrt._isatty @307
  _isctype=msvcrt._isctype @308
  _ismbbalnum=msvcrt._ismbbalnum @309
  _ismbbalpha=msvcrt._ismbbalpha @310
  _ismbbgraph=msvcrt._ismbbgraph @311
  _ismbbkalnum=msvcrt._ismbbkalnum @312
  _ismbbkana=msvcrt._ismbbkana @313
  _ismbbkprint=msvcrt._ismbbkprint @314
  _ismbbkpunct=msvcrt._ismbbkpunct @315
  _ismbblead=msvcrt._ismbblead @316
  _ismbbprint=msvcrt._ismbbprint @317
  _ismbbpunct=msvcrt._ismbbpunct @318
  _ismbbtrail=msvcrt._ismbbtrail @319
  _ismbcalnum=msvcrt._ismbcalnum @320
  _ismbcalpha=msvcrt._ismbcalpha @321
  _ismbcdigit=msvcrt._ismbcdigit @322
  _ismbcgraph=msvcrt._ismbcgraph @323
  _ismbchira=msvcrt._ismbchira @324
  _ismbckata=msvcrt._ismbckata @325
  _ismbcl0=msvcrt._ismbcl0 @326
  _ismbcl1=msvcrt._ismbcl1 @327
  _ismbcl2=msvcrt._ismbcl2 @328
  _ismbclegal=msvcrt._ismbclegal @329
  _ismbclower=msvcrt._ismbclower @330
  _ismbcprint=msvcrt._ismbcprint @331
  _ismbcpunct=msvcrt._ismbcpunct @332
  _ismbcspace=msvcrt._ismbcspace @333
  _ismbcsymbol=msvcrt._ismbcsymbol @334
  _ismbcupper=msvcrt._ismbcupper @335
  _ismbslead=msvcrt._ismbslead @336
  _ismbstrail=msvcrt._ismbstrail @337
  _isnan=msvcrt._isnan @338
  _itoa=ntdll._itoa @339
  _itow=ntdll._itow @340
  _j0=msvcrt._j0 @341
  _j1=msvcrt._j1 @342
  _jn=msvcrt._jn @343
  _kbhit=msvcrt._kbhit @344
  _lfind=msvcrt._lfind @345
  _loaddll=msvcrt._loaddll @346
  _local_unwind2=msvcrt._local_unwind2 @347
  _lock=msvcrt._lock @348
  _locking=msvcrt._locking @349
  _logb=msvcrt._logb @350
  _longjmpex=msvcrt._longjmpex @351
  _lrotl=msvcrt._lrotl @352
  _lrotr=msvcrt._lrotr @353
  _lsearch=msvcrt._lsearch @354
  _lseek=msvcrt._lseek @355
  _lseeki64=msvcrt._lseeki64 @356
  _ltoa=ntdll._ltoa @357
  _ltow=ntdll._ltow @358
  _makepath=msvcrt._makepath @359
  _malloc_dbg=msvcrt.malloc @360
  _mbbtombc=msvcrt._mbbtombc @361
  _mbbtype=msvcrt._mbbtype @362
  _mbcasemap=msvcrt._mbcasemap @363 DATA
  _mbccpy=msvcrt._mbccpy @364
  _mbcjistojms=msvcrt._mbcjistojms @365
  _mbcjmstojis=msvcrt._mbcjmstojis @366
  _mbclen=msvcrt._mbclen @367
  _mbctohira=msvcrt._mbctohira @368
  _mbctokata=msvcrt._mbctokata @369
  _mbctolower=msvcrt._mbctolower @370
  _mbctombb=msvcrt._mbctombb @371
  _mbctoupper=msvcrt._mbctoupper @372
  _mbctype=msvcrt._mbctype @373 DATA
  _mbsbtype=msvcrt._mbsbtype @374
  _mbscat=msvcrt._mbscat @375
  _mbschr=msvcrt._mbschr @376
  _mbscmp=msvcrt._mbscmp @377
  _mbscoll=msvcrt._mbscoll @378
  _mbscpy=msvcrt._mbscpy @379
  _mbscspn=msvcrt._mbscspn @380
  _mbsdec=msvcrt._mbsdec @381
  _mbsdup=msvcrt._strdup @382
  _mbsicmp=msvcrt._mbsicmp @383
  _mbsicoll=msvcrt._mbsicoll @384
  _mbsinc=msvcrt._mbsinc @385
  _mbslen=msvcrt._mbslen @386
  _mbslwr=msvcrt._mbslwr @387
  _mbsnbcat=msvcrt._mbsnbcat @388
  _mbsnbcmp=msvcrt._mbsnbcmp @389
  _mbsnbcnt=msvcrt._mbsnbcnt @390
  _mbsnbcoll=msvcrt._mbsnbcoll @391
  _mbsnbcpy=msvcrt._mbsnbcpy @392
  _mbsnbicmp=msvcrt._mbsnbicmp @393
  _mbsnbicoll=msvcrt._mbsnbicoll @394
  _mbsnbset=msvcrt._mbsnbset @395
  _mbsncat=msvcrt._mbsncat @396
  _mbsnccnt=msvcrt._mbsnccnt @397
  _mbsncmp=msvcrt._mbsncmp @398
  _mbsncoll=msvcrt._mbsncoll @399
  _mbsncpy=msvcrt._mbsncpy @400
  _mbsnextc=msvcrt._mbsnextc @401
  _mbsnicmp=msvcrt._mbsnicmp @402
  _mbsnicoll=msvcrt._mbsnicoll @403
  _mbsninc=msvcrt._mbsninc @404
  _mbsnset=msvcrt._mbsnset @405
  _mbspbrk=msvcrt._mbspbrk @406
  _mbsrchr=msvcrt._mbsrchr @407
  _mbsrev=msvcrt._mbsrev @408
  _mbsset=msvcrt._mbsset @409
  _mbsspn=msvcrt._mbsspn @410
  _mbsspnp=msvcrt._mbsspnp @411
  _mbsstr=msvcrt._mbsstr @412
  _mbstok=msvcrt._mbstok @413
  _mbstrlen=msvcrt._mbstrlen @414
  _mbsupr=msvcrt._mbsupr @415
  _memccpy=msvcrt._memccpy @416
  _memicmp=ntdll._memicmp @417
  _mkdir=msvcrt._mkdir @418
  _mktemp=msvcrt._mktemp @419
  _msize=msvcrt._msize @420
  _msize_dbg=msvcrt._msize @421
  _nextafter=msvcrt._nextafter @422
  _onexit=msvcrt._onexit @423
  _open=msvcrt._open @424
  _open_osfhandle=msvcrt._open_osfhandle @425
  _osver=msvcrt._osver @426 DATA
  _outp=msvcrt._outp @427
  _outpd=msvcrt._outpd @428
  _outpw=msvcrt._outpw @429
  _pclose=msvcrt._pclose @430
  _pctype=msvcrt._pctype @431 DATA
  _pgmptr=msvcrt._pgmptr @432 DATA
  _pipe=msvcrt._pipe @433
  _popen=msvcrt._popen @434
  _purecall=msvcrt._purecall @435
  _putch=msvcrt._putch @436
  _putenv=msvcrt._putenv @437
  _putw=msvcrt._putw @438
  _putws=msvcrt._putws @439
  _pwctype=msvcrt._pwctype @440 DATA
  _read=msvcrt._read @441
  _realloc_dbg=msvcrt.realloc @442
  _rmdir=msvcrt._rmdir @443
  _rmtmp=msvcrt._rmtmp @444
  _rotl=msvcrt._rotl @445
  _rotr=msvcrt._rotr @446
  _safe_fdiv=msvcrt._safe_fdiv @447
  _safe_fdivr=msvcrt._safe_fdivr @448
  _safe_fprem=msvcrt._safe_fprem @449
  _safe_fprem1=msvcrt._safe_fprem1 @450
  _scalb=msvcrt._scalb @451
  _searchenv=msvcrt._searchenv @452
  _seh_longjmp_unwind@4=msvcrt._seh_longjmp_unwind @453
  _set_error_mode=msvcrt._set_error_mode @454
  _set_sbh_threshold=msvcrt._set_sbh_threshold @455
  _seterrormode=msvcrt._seterrormode @456
  _setjmp=msvcrt._setjmp @457
  _setjmp3=msvcrt._setjmp3 @458
  _setmaxstdio=msvcrt._setmaxstdio @459
  _setmbcp=msvcrt._setmbcp @460
  _setmode=msvcrt._setmode @461
  _setsystime=msvcrt._setsystime @462
  _sleep=msvcrt._sleep @463
  _snprintf=msvcrt._snprintf @464
  _snwprintf=ntdll._snwprintf @465
  _sopen=msvcrt._sopen @466
  _spawnl=msvcrt._spawnl @467
  _spawnle=msvcrt._spawnle @468
  _spawnlp=msvcrt._spawnlp @469
  _spawnlpe=msvcrt._spawnlpe @470
  _spawnv=msvcrt._spawnv @471
  _spawnve=msvcrt._spawnve @472
  _spawnvp=msvcrt._spawnvp @473
  _spawnvpe=msvcrt._spawnvpe @474
  _splitpath=ntdll._splitpath @475
  _stat=msvcrt._stat @476
  _stati64=msvcrt._stati64 @477
  _statusfp=msvcrt._statusfp @478
  _strcmpi=msvcrt._strcmpi @479
  _strdate=msvcrt._strdate @480
  _strdup=msvcrt._strdup @481
  _strerror=msvcrt._strerror @482
  _stricmp=msvcrt._stricmp @483
  _stricoll=msvcrt._stricoll @484
  _strlwr=ntdll._strlwr @485
  _strncoll=msvcrt._strncoll @486
  _strnicmp=msvcrt._strnicmp @487
  _strnicoll=msvcrt._strnicoll @488
  _strnset=msvcrt._strnset @489
  _strrev=msvcrt._strrev @490
  _strset=msvcrt._strset @491
  _strtime=msvcrt._strtime @492
  _strupr=ntdll._strupr @493
  _swab=msvcrt._swab @494
  _sys_errlist=msvcrt._sys_errlist @495 DATA
  _sys_nerr=msvcrt._sys_nerr @496 DATA
  _tell=msvcrt._tell @497
  _telli64=msvcrt._telli64 @498
  _tempnam=msvcrt._tempnam @499
  _timezone=msvcrt._timezone @500 DATA
  _tolower=msvcrt._tolower @501
  _toupper=msvcrt._toupper @502
  _tzname=msvcrt._tzname @503 DATA
  _tzset=msvcrt._tzset @504
  _ui64toa=ntdll._ui64toa @505
  _ui64tow=ntdll._ui64tow @506
  _ultoa=ntdll._ultoa @507
  _ultow=ntdll._ultow @508
  _umask=msvcrt._umask @509
  _ungetch=msvcrt._ungetch @510
  _unlink=msvcrt._unlink @511
  _unloaddll=msvcrt._unloaddll @512
  _unlock=msvcrt._unlock @513
  _utime=msvcrt._utime @514
  _vsnprintf=msvcrt._vsnprintf @515
  _vsnwprintf=msvcrt._vsnwprintf @516
  _waccess=msvcrt._waccess @517
  _wasctime=msvcrt._wasctime @518
  _wchdir=msvcrt._wchdir @519
  _wchmod=msvcrt._wchmod @520
  _wcmdln=msvcrt._wcmdln @521 DATA
  _wcreat=msvcrt._wcreat @522
  _wcsdup=msvcrt._wcsdup @523
  _wcsicmp=ntdll._wcsicmp @524
  _wcsicoll=msvcrt._wcsicoll @525
  _wcslwr=ntdll._wcslwr @526
  _wcsncoll=msvcrt._wcsncoll @527
  _wcsnicmp=ntdll._wcsnicmp @528
  _wcsnicoll=msvcrt._wcsnicoll @529
  _wcsnset=msvcrt._wcsnset @530
  _wcsrev=msvcrt._wcsrev @531
  _wcsset=msvcrt._wcsset @532
  _wcsupr=ntdll._wcsupr @533
  _wctime=msvcrt._wctime @534
  _wenviron=msvcrt._wenviron @535 DATA
  _wexecl=msvcrt._wexecl @536
  _wexecle=msvcrt._wexecle @537
  _wexeclp=msvcrt._wexeclp @538
  _wexeclpe=msvcrt._wexeclpe @539
  _wexecv=msvcrt._wexecv @540
  _wexecve=msvcrt._wexecve @541
  _wexecvp=msvcrt._wexecvp @542
  _wexecvpe=msvcrt._wexecvpe @543
  _wfdopen=msvcrt._wfdopen @544
  _wfindfirst=msvcrt._wfindfirst @545
  _wfindfirsti64=msvcrt._wfindfirsti64 @546
  _wfindnext=msvcrt._wfindnext @547
  _wfindnexti64=msvcrt._wfindnexti64 @548
  _wfopen=msvcrt._wfopen @549
  _wfreopen=msvcrt._wfreopen @550
  _wfsopen=msvcrt._wfsopen @551
  _wfullpath=msvcrt._wfullpath @552
  _wgetcwd=msvcrt._wgetcwd @553
  _wgetdcwd=msvcrt._wgetdcwd @554
  _wgetenv=msvcrt._wgetenv @555
  _winmajor=msvcrt._winmajor @556 DATA
  _winminor=msvcrt._winminor @557 DATA
  _winver=msvcrt._winver @558 DATA
  _wmakepath=msvcrt._wmakepath @559
  _wmkdir=msvcrt._wmkdir @560
  _wmktemp=msvcrt._wmktemp @561
  _wopen=msvcrt._wopen @562
  _wperror=msvcrt._wperror @563
  _wpgmptr=msvcrt._wpgmptr @564 DATA
  _wpopen=msvcrt._wpopen @565
  _wputenv=msvcrt._wputenv @566
  _wremove=msvcrt._wremove @567
  _wrename=msvcrt._wrename @568
  _write=msvcrt._write @569
  _wrmdir=msvcrt._wrmdir @570
  _wsearchenv=msvcrt._wsearchenv @571
  _wsetlocale=msvcrt._wsetlocale @572
  _wsopen=msvcrt._wsopen @573
  _wspawnl=msvcrt._wspawnl @574
  _wspawnle=msvcrt._wspawnle @575
  _wspawnlp=msvcrt._wspawnlp @576
  _wspawnlpe=msvcrt._wspawnlpe @577
  _wspawnv=msvcrt._wspawnv @578
  _wspawnve=msvcrt._wspawnve @579
  _wspawnvp=msvcrt._wspawnvp @580
  _wspawnvpe=msvcrt._wspawnvpe @581
  _wsplitpath=msvcrt._wsplitpath @582
  _wstat=msvcrt._wstat @583
  _wstati64=msvcrt._wstati64 @584
  _wstrdate=msvcrt._wstrdate @585
  _wstrtime=msvcrt._wstrtime @586
  _wsystem=msvcrt._wsystem @587
  _wtempnam=msvcrt._wtempnam @588
  _wtmpnam=msvcrt._wtmpnam @589
  _wtoi=ntdll._wtoi @590
  _wtoi64=ntdll._wtoi64 @591
  _wtol=ntdll._wtol @592
  _wunlink=msvcrt._wunlink @593
  _wutime=msvcrt._wutime @594
  _y0=msvcrt._y0 @595
  _y1=msvcrt._y1 @596
  _yn=msvcrt._yn @597
  abort=msvcrt.abort @598
  abs=msvcrt.abs @599
  acos=msvcrt.acos @600
  asctime=msvcrt.asctime @601
  asin=msvcrt.asin @602
  atan=msvcrt.atan @603
  atan2=msvcrt.atan2 @604
  atexit=msvcrt.atexit @605
  atof=msvcrt.atof @606
  atoi=msvcrt.atoi @607
  atol=msvcrt.atol @608
  bsearch=msvcrt.bsearch @609
  calloc=msvcrt.calloc @610
  ceil=msvcrt.ceil @611
  clearerr=msvcrt.clearerr @612
  clock=msvcrt.clock @613
  cos=msvcrt.cos @614
  cosh=msvcrt.cosh @615
  ctime=msvcrt.ctime @616
  difftime=msvcrt.difftime @617
  div=msvcrt.div @618
  exit=msvcrt.exit @619
  exp=msvcrt.exp @620
  fabs=msvcrt.fabs @621
  fclose=msvcrt.fclose @622
  feof=msvcrt.feof @623
  ferror=msvcrt.ferror @624
  fflush=msvcrt.fflush @625
  fgetc=msvcrt.fgetc @626
  fgetpos=msvcrt.fgetpos @627
  fgets=msvcrt.fgets @628
  fgetwc=msvcrt.fgetwc @629
  fgetws=msvcrt.fgetws @630
  floor=msvcrt.floor @631
  fmod=msvcrt.fmod @632
  fopen=msvcrt.fopen @633
  fprintf=msvcrt.fprintf @634
  fputc=msvcrt.fputc @635
  fputs=msvcrt.fputs @636
  fputwc=msvcrt.fputwc @637
  fputws=msvcrt.fputws @638
  fread=msvcrt.fread @639
  free=msvcrt.free @640
  freopen=msvcrt.freopen @641
  frexp=msvcrt.frexp @642
  fscanf=msvcrt.fscanf @643
  fseek=msvcrt.fseek @644
  fsetpos=msvcrt.fsetpos @645
  ftell=msvcrt.ftell @646
  fwprintf=msvcrt.fwprintf @647
  fwrite=msvcrt.fwrite @648
  fwscanf=msvcrt.fwscanf @649
  getc=msvcrt.getc @650
  getchar=msvcrt.getchar @651
  getenv=msvcrt.getenv @652
  gets=msvcrt.gets @653
  getwc=msvcrt.getwc @654
  getwchar=msvcrt.getwchar @655
  gmtime=msvcrt.gmtime @656
  is_wctype=ntdll.iswctype @657
  isalnum=msvcrt.isalnum @658
  isalpha=msvcrt.isalpha @659
  iscntrl=msvcrt.iscntrl @660
  isdigit=msvcrt.isdigit @661
  isgraph=msvcrt.isgraph @662
  isleadbyte=msvcrt.isleadbyte @663
  islower=msvcrt.islower @664
  isprint=msvcrt.isprint @665
  ispunct=msvcrt.ispunct @666
  isspace=msvcrt.isspace @667
  isupper=msvcrt.isupper @668
  iswalnum=msvcrt.iswalnum @669
  iswalpha=ntdll.iswalpha @670
  iswascii=msvcrt.iswascii @671
  iswcntrl=msvcrt.iswcntrl @672
  iswctype=ntdll.iswctype @673
  iswdigit=msvcrt.iswdigit @674
  iswgraph=msvcrt.iswgraph @675
  iswlower=msvcrt.iswlower @676
  iswprint=msvcrt.iswprint @677
  iswpunct=msvcrt.iswpunct @678
  iswspace=msvcrt.iswspace @679
  iswupper=msvcrt.iswupper @680
  iswxdigit=msvcrt.iswxdigit @681
  isxdigit=msvcrt.isxdigit @682
  labs=msvcrt.labs @683
  ldexp=msvcrt.ldexp @684
  ldiv=msvcrt.ldiv @685
  localeconv=msvcrt.localeconv @686
  localtime=msvcrt.localtime @687
  log=msvcrt.log @688
  log10=msvcrt.log10 @689
  longjmp=msvcrt.longjmp @690
  malloc=msvcrt.malloc @691
  mblen=msvcrt.mblen @692
  mbstowcs=ntdll.mbstowcs @693
  mbtowc=msvcrt.mbtowc @694
  memchr=msvcrt.memchr @695
  memcmp=msvcrt.memcmp @696
  memcpy=msvcrt.memcpy @697
  memmove=msvcrt.memmove @698
  memset=msvcrt.memset @699
  mktime=msvcrt.mktime @700
  modf=msvcrt.modf @701
  perror=msvcrt.perror @702
  pow=msvcrt.pow @703
  printf=msvcrt.printf @704
  putc=msvcrt.putc @705
  putchar=msvcrt.putchar @706
  puts=msvcrt.puts @707
  putwc=msvcrt.putwc @708
  putwchar=msvcrt._fputwchar @709
  qsort=msvcrt.qsort @710
  raise=msvcrt.raise @711
  rand=msvcrt.rand @712
  realloc=msvcrt.realloc @713
  remove=msvcrt.remove @714
  rename=msvcrt.rename @715
  rewind=msvcrt.rewind @716
  scanf=msvcrt.scanf @717
  setbuf=msvcrt.setbuf @718
  setlocale=msvcrt.setlocale @719
  setvbuf=msvcrt.setvbuf @720
  signal=msvcrt.signal @721
  sin=msvcrt.sin @722
  sinh=msvcrt.sinh @723
  sprintf=msvcrt.sprintf @724
  sqrt=msvcrt.sqrt @725
  srand=msvcrt.srand @726
  sscanf=msvcrt.sscanf @727
  strcat=msvcrt.strcat @728
  strchr=msvcrt.strchr @729
  strcmp=msvcrt.strcmp @730
  strcoll=msvcrt.strcoll @731
  strcpy=msvcrt.strcpy @732
  strcspn=msvcrt.strcspn @733
  strerror=msvcrt.strerror @734
  strftime=msvcrt.strftime @735
  strlen=msvcrt.strlen @736
  strncat=msvcrt.strncat @737
  strncmp=msvcrt.strncmp @738
  strncpy=msvcrt.strncpy @739
  strpbrk=msvcrt.strpbrk @740
  strrchr=msvcrt.strrchr @741
  strspn=msvcrt.strspn @742
  strstr=msvcrt.strstr @743
  strtod=msvcrt.strtod @744
  strtok=msvcrt.strtok @745
  strtol=msvcrt.strtol @746
  strtoul=msvcrt.strtoul @747
  strxfrm=msvcrt.strxfrm @748
  swprintf=ntdll.swprintf @749
  swscanf=msvcrt.swscanf @750
  system=msvcrt.system @751
  tan=msvcrt.tan @752
  tanh=msvcrt.tanh @753
  time=msvcrt.time @754
  tmpfile=msvcrt.tmpfile @755
  tmpnam=msvcrt.tmpnam @756
  tolower=msvcrt.tolower @757
  toupper=msvcrt.toupper @758
  towlower=ntdll.towlower @759
  towupper=ntdll.towupper @760
  ungetc=msvcrt.ungetc @761
  ungetwc=msvcrt.ungetwc @762
  vfprintf=msvcrt.vfprintf @763
  vfwprintf=msvcrt.vfwprintf @764
  vprintf=msvcrt.vprintf @765
  vsprintf=msvcrt.vsprintf @766
  vswprintf=msvcrt.vswprintf @767
  vwprintf=msvcrt.vwprintf @768
  wcscat=ntdll.wcscat @769
  wcschr=ntdll.wcschr @770
  wcscmp=ntdll.wcscmp @771
  wcscoll=msvcrt.wcscoll @772
  wcscpy=ntdll.wcscpy @773
  wcscspn=ntdll.wcscspn @774
  wcsftime=msvcrt.wcsftime @775
  wcslen=ntdll.wcslen @776
  wcsncat=ntdll.wcsncat @777
  wcsncmp=ntdll.wcsncmp @778
  wcsncpy=ntdll.wcsncpy @779
  wcspbrk=msvcrt.wcspbrk @780
  wcsrchr=ntdll.wcsrchr @781
  wcsspn=ntdll.wcsspn @782
  wcsstr=ntdll.wcsstr @783
  wcstod=msvcrt.wcstod @784
  wcstok=ntdll.wcstok @785
  wcstol=ntdll.wcstol @786
  wcstombs=ntdll.wcstombs @787
  wcstoul=ntdll.wcstoul @788
  wcsxfrm=msvcrt.wcsxfrm @789
  wctomb=msvcrt.wctomb @790
  wprintf=msvcrt.wprintf @791
  wscanf=msvcrt.wscanf @792
