; File generated automatically from ./dnsapi.spec; do not edit!

LIBRARY dnsapi.dll

EXPORTS
  DnsAcquireContextHandle_A@12 @1
  DnsAcquireContextHandle_UTF8@12 @2
  DnsAcquireContextHandle_W@12 @3
  DnsExtractRecordsFromMessage_UTF8@12 @31
  DnsExtractRecordsFromMessage_W@12 @32
  DnsModifyRecordsInSet_A@24 @68
  DnsModifyRecordsInSet_UTF8@24 @69
  DnsModifyRecordsInSet_W@24 @70
  DnsNameCompare_A@8 @71
  DnsNameCompare_W@8 @75
  DnsQuery_A@24 @79
  DnsQueryConfig@24 @80
  DnsQuery_UTF8@24 @82
  DnsQuery_W@24 @83
  DnsRecordCompare@8 @86
  DnsRecordCopyEx@12 @87
  DnsRecordListFree@8 @88
  DnsRecordSetCompare@16 @89
  DnsRecordSetCopyEx@12 @90
  DnsRecordSetDetach@4 @91
  DnsReleaseContextHandle@4 @97
  DnsReplaceRecordSetA@20 @99
  DnsReplaceRecordSetUTF8@20 @101
  DnsReplaceRecordSetW@20 @103
  DnsValidateName_A@8 @120
  DnsValidateName_UTF8@8 @121
  DnsValidateName_W@8 @122
  DnsWriteQuestionToBuffer_UTF8@24 @126
  DnsWriteQuestionToBuffer_W@24 @127
