; File generated automatically from ./msvcrt20.spec; do not edit!

LIBRARY msvcrt20.dll

EXPORTS
  ??2@YAPAXI@Z=msvcrt.??2@YAPAXI@Z @79
  ??3@YAXPAX@Z=msvcrt.??3@YAXPAX@Z @80
  ?_query_new_handler@@YAP6AHI@ZXZ=msvcrt.?_query_new_handler@@YAP6AHI@ZXZ @226
  ?_query_new_mode@@YAHXZ=msvcrt.?_query_new_mode@@YAHXZ @227
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=msvcrt.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z @228
  ?_set_new_mode@@YAHH@Z=msvcrt.?_set_new_mode@@YAHH@Z @229
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=msvcrt.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z @230
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_terminate@@YAP6AXXZP6AXXZ@Z @365
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=msvcrt.?set_unexpected@@YAP6AXXZP6AXXZ@Z @366
  ?terminate@@YAXXZ=msvcrt.?terminate@@YAXXZ @409
  ?unexpected@@YAXXZ=msvcrt.?unexpected@@YAXXZ @418
  _CIacos=msvcrt._CIacos @439
  _CIasin=msvcrt._CIasin @440
  _CIatan=msvcrt._CIatan @441
  _CIatan2=msvcrt._CIatan2 @442
  _CIcos=msvcrt._CIcos @443
  _CIcosh=msvcrt._CIcosh @444
  _CIexp=msvcrt._CIexp @445
  _CIfmod=msvcrt._CIfmod @446
  _CIlog=msvcrt._CIlog @447
  _CIlog10=msvcrt._CIlog10 @448
  _CIpow=msvcrt._CIpow @449
  _CIsin=msvcrt._CIsin @450
  _CIsinh=msvcrt._CIsinh @451
  _CIsqrt=msvcrt._CIsqrt @452
  _CItan=msvcrt._CItan @453
  _CItanh=msvcrt._CItanh @454
  _CxxThrowException=msvcrt._CxxThrowException @455
  _HUGE=msvcrt._HUGE @456 DATA
  _XcptFilter=msvcrt._XcptFilter @457
  __CxxFrameHandler=msvcrt.__CxxFrameHandler @458
  __CxxLongjmpUnwind@4=msvcrt.__CxxLongjmpUnwind @459
  __STRINGTOLD=msvcrt.__STRINGTOLD @460
  __argc=msvcrt.__argc @461 DATA
  __argv=msvcrt.__argv @462 DATA
  __dllonexit=msvcrt.__dllonexit @463
  __doserrno=msvcrt.__doserrno @464
  __fpecode=msvcrt.__fpecode @465
  __getmainargs=MSVCRT20__getmainargs @466
  __initenv=msvcrt.__initenv @467 DATA
  __isascii=msvcrt.__isascii @468
  __iscsym=msvcrt.__iscsym @469
  __iscsymf=msvcrt.__iscsymf @470
  __lconv_init=msvcrt.__lconv_init @471
  __mb_cur_max=msvcrt.__mb_cur_max @472 DATA
  __p___argc=msvcrt.__p___argc @473
  __p___argv=msvcrt.__p___argv @474
  __p___initenv=msvcrt.__p___initenv @475
  __p___mb_cur_max=msvcrt.__p___mb_cur_max @476
  __p___wargv=msvcrt.__p___wargv @477
  __p___winitenv=msvcrt.__p___winitenv @478
  __p__acmdln=msvcrt.__p__acmdln @479
  __p__amblksiz=msvcrt.__p__amblksiz @480
  __p__commode=msvcrt.__p__commode @481
  __p__daylight=msvcrt.__p__daylight @482
  __p__environ=msvcrt.__p__environ @483
  __p__fmode=msvcrt.__p__fmode @484
  __p__iob=msvcrt.__p__iob @485
  __p__mbctype=msvcrt.__p__mbctype @486
  __p__osver=msvcrt.__p__osver @487
  __p__pctype=msvcrt.__p__pctype @488
  __p__pgmptr=msvcrt.__p__pgmptr @489
  __p__pwctype=msvcrt.__p__pwctype @490
  __p__timezone=msvcrt.__p__timezone @491
  __p__tzname=msvcrt.__p__tzname @492
  __p__wcmdln=msvcrt.__p__wcmdln @493
  __p__wenviron=msvcrt.__p__wenviron @494
  __p__winmajor=msvcrt.__p__winmajor @495
  __p__winminor=msvcrt.__p__winminor @496
  __p__winver=msvcrt.__p__winver @497
  __p__wpgmptr=msvcrt.__p__wpgmptr @498
  __pxcptinfoptrs=msvcrt.__pxcptinfoptrs @499
  __threadhandle=msvcrt.__threadhandle @500
  __threadid=msvcrt.__threadid @501
  __toascii=msvcrt.__toascii @502
  __wargv=msvcrt.__wargv @503 DATA
  __wgetmainargs=MSVCRT20__wgetmainargs @504
  __winitenv=msvcrt.__winitenv @505 DATA
  _abnormal_termination=msvcrt._abnormal_termination @506
  _access=msvcrt._access @507
  _acmdln=msvcrt._acmdln @508 DATA
  _adj_fdiv_m16i@4=msvcrt._adj_fdiv_m16i @509
  _adj_fdiv_m32@4=msvcrt._adj_fdiv_m32 @510
  _adj_fdiv_m32i@4=msvcrt._adj_fdiv_m32i @511
  _adj_fdiv_m64@8=msvcrt._adj_fdiv_m64 @512
  _adj_fdiv_r=msvcrt._adj_fdiv_r @513
  _adj_fdivr_m16i@4=msvcrt._adj_fdivr_m16i @514
  _adj_fdivr_m32@4=msvcrt._adj_fdivr_m32 @515
  _adj_fdivr_m32i@4=msvcrt._adj_fdivr_m32i @516
  _adj_fdivr_m64@8=msvcrt._adj_fdivr_m64 @517
  _adj_fpatan=msvcrt._adj_fpatan @518
  _adj_fprem=msvcrt._adj_fprem @519
  _adj_fprem1=msvcrt._adj_fprem1 @520
  _adj_fptan=msvcrt._adj_fptan @521
  _adjust_fdiv=msvcrt._adjust_fdiv @522
  _aexit_rtn=msvcrt._aexit_rtn @523 DATA
  _amsg_exit=msvcrt._amsg_exit @524
  _assert=msvcrt._assert @525
  _atodbl=msvcrt._atodbl @526
  _atoldbl=msvcrt._atoldbl @527
  _beep=msvcrt._beep @528
  _beginthread=msvcrt._beginthread @529
  _beginthreadex=msvcrt._beginthreadex @530
  _c_exit=msvcrt._c_exit @531
  _cabs=msvcrt._cabs @532
  _cexit=msvcrt._cexit @533
  _cgets=msvcrt._cgets @534
  _chdir=msvcrt._chdir @535
  _chdrive=msvcrt._chdrive @536
  _chgsign=msvcrt._chgsign @537
  _chmod=msvcrt._chmod @538
  _chsize=msvcrt._chsize @539
  _clearfp=msvcrt._clearfp @540
  _close=msvcrt._close @541
  _commit=msvcrt._commit @542
  _commode=msvcrt._commode @543 DATA
  _control87=msvcrt._control87 @544
  _controlfp=msvcrt._controlfp @545
  _copysign=msvcrt._copysign @546
  _cprintf=msvcrt._cprintf @547
  _cputs=msvcrt._cputs @548
  _creat=msvcrt._creat @549
  _cscanf=msvcrt._cscanf @550
  _ctype=msvcrt._ctype @551 DATA
  _cwait=msvcrt._cwait @552
  _daylight=msvcrt._daylight @553 DATA
  _dup=msvcrt._dup @554
  _dup2=msvcrt._dup2 @555
  _ecvt=msvcrt._ecvt @556
  _endthread=msvcrt._endthread @557
  _endthreadex=msvcrt._endthreadex @558
  _environ=msvcrt._environ @559 DATA
  _eof=msvcrt._eof @560
  _errno=msvcrt._errno @561
  _except_handler2=msvcrt._except_handler2 @562
  _except_handler3=msvcrt._except_handler3 @563
  _execl=msvcrt._execl @564
  _execle=msvcrt._execle @565
  _execlp=msvcrt._execlp @566
  _execlpe=msvcrt._execlpe @567
  _execv=msvcrt._execv @568
  _execve=msvcrt._execve @569
  _execvp=msvcrt._execvp @570
  _execvpe=msvcrt._execvpe @571
  _exit=msvcrt._exit @572
  _expand=msvcrt._expand @573
  _fcloseall=msvcrt._fcloseall @574
  _fcvt=msvcrt._fcvt @575
  _fdopen=msvcrt._fdopen @576
  _fgetchar=msvcrt._fgetchar @577
  _fgetwchar=msvcrt._fgetwchar @578
  _filbuf=msvcrt._filbuf @579
  _fileinfo=msvcrt._fileinfo @580 DATA
  _filelength=msvcrt._filelength @581
  _fileno=msvcrt._fileno @582
  _findclose=msvcrt._findclose @583
  _findfirst=msvcrt._findfirst @584
  _findnext=msvcrt._findnext @585
  _finite=msvcrt._finite @586
  _flsbuf=msvcrt._flsbuf @587
  _flushall=msvcrt._flushall @588
  _fmode=msvcrt._fmode @589 DATA
  _fpclass=msvcrt._fpclass @590
  _fpieee_flt=msvcrt._fpieee_flt @591
  _fpreset=msvcrt._fpreset @592
  _fputchar=msvcrt._fputchar @593
  _fputwchar=msvcrt._fputwchar @594
  _fsopen=msvcrt._fsopen @595
  _fstat=msvcrt._fstat @596
  _ftime=msvcrt._ftime @597
  _ftol=msvcrt._ftol @598
  _fullpath=msvcrt._fullpath @599
  _futime=msvcrt._futime @600
  _gcvt=msvcrt._gcvt @601
  _get_osfhandle=msvcrt._get_osfhandle @602
  _getch=msvcrt._getch @603
  _getche=msvcrt._getche @604
  _getcwd=msvcrt._getcwd @605
  _getdcwd=msvcrt._getdcwd @606
  _getdiskfree=msvcrt._getdiskfree @607
  _getdllprocaddr=msvcrt._getdllprocaddr @608
  _getdrive=msvcrt._getdrive @609
  _getdrives=msvcrt._getdrives @610
  _getmbcp=msvcrt._getmbcp @611
  _getpid=msvcrt._getpid @612
  _getsystime=msvcrt._getsystime @613
  _getw=msvcrt._getw @614
  _getws=msvcrt._getws @615
  _global_unwind2=msvcrt._global_unwind2 @616
  _heapadd=msvcrt._heapadd @617
  _heapchk=msvcrt._heapchk @618
  _heapmin=msvcrt._heapmin @619
  _heapset=msvcrt._heapset @620
  _heapused=msvcrt._heapused @621
  _heapwalk=msvcrt._heapwalk @622
  _hypot=msvcrt._hypot @623
  _initterm=msvcrt._initterm @624
  _iob=msvcrt._iob @625 DATA
  _isatty=msvcrt._isatty @626
  _isctype=msvcrt._isctype @627
  _ismbbalnum=msvcrt._ismbbalnum @628
  _ismbbalpha=msvcrt._ismbbalpha @629
  _ismbbgraph=msvcrt._ismbbgraph @630
  _ismbbkalnum=msvcrt._ismbbkalnum @631
  _ismbbkana=msvcrt._ismbbkana @632
  _ismbbkprint=msvcrt._ismbbkprint @633
  _ismbbkpunct=msvcrt._ismbbkpunct @634
  _ismbblead=msvcrt._ismbblead @635
  _ismbbprint=msvcrt._ismbbprint @636
  _ismbbpunct=msvcrt._ismbbpunct @637
  _ismbbtrail=msvcrt._ismbbtrail @638
  _ismbcalnum=msvcrt._ismbcalnum @639
  _ismbcalpha=msvcrt._ismbcalpha @640
  _ismbcdigit=msvcrt._ismbcdigit @641
  _ismbcgraph=msvcrt._ismbcgraph @642
  _ismbchira=msvcrt._ismbchira @643
  _ismbckata=msvcrt._ismbckata @644
  _ismbcl0=msvcrt._ismbcl0 @645
  _ismbcl1=msvcrt._ismbcl1 @646
  _ismbcl2=msvcrt._ismbcl2 @647
  _ismbclegal=msvcrt._ismbclegal @648
  _ismbclower=msvcrt._ismbclower @649
  _ismbcprint=msvcrt._ismbcprint @650
  _ismbcpunct=msvcrt._ismbcpunct @651
  _ismbcspace=msvcrt._ismbcspace @652
  _ismbcsymbol=msvcrt._ismbcsymbol @653
  _ismbcupper=msvcrt._ismbcupper @654
  _ismbslead=msvcrt._ismbslead @655
  _ismbstrail=msvcrt._ismbstrail @656
  _isnan=msvcrt._isnan @657
  _itoa=msvcrt._itoa @658
  _itow=msvcrt._itow @659
  _j0=msvcrt._j0 @660
  _j1=msvcrt._j1 @661
  _jn=msvcrt._jn @662
  _kbhit=msvcrt._kbhit @663
  _lfind=msvcrt._lfind @664
  _loaddll=msvcrt._loaddll @665
  _local_unwind2=msvcrt._local_unwind2 @666
  _locking=msvcrt._locking @667
  _logb=msvcrt._logb @668
  _longjmpex=msvcrt._longjmpex @669
  _lrotl=msvcrt._lrotl @670
  _lrotr=msvcrt._lrotr @671
  _lsearch=msvcrt._lsearch @672
  _lseek=msvcrt._lseek @673
  _ltoa=msvcrt._ltoa @674
  _ltow=msvcrt._ltow @675
  _makepath=msvcrt._makepath @676
  _matherr=msvcrt._matherr @677
  _mbbtombc=msvcrt._mbbtombc @678
  _mbbtype=msvcrt._mbbtype @679
  _mbccpy=msvcrt._mbccpy @680
  _mbcjistojms=msvcrt._mbcjistojms @681
  _mbcjmstojis=msvcrt._mbcjmstojis @682
  _mbclen=msvcrt._mbclen @683
  _mbctohira=msvcrt._mbctohira @684
  _mbctokata=msvcrt._mbctokata @685
  _mbctolower=msvcrt._mbctolower @686
  _mbctombb=msvcrt._mbctombb @687
  _mbctoupper=msvcrt._mbctoupper @688
  _mbctype=msvcrt._mbctype @689 DATA
  _mbsbtype=msvcrt._mbsbtype @690
  _mbscat=msvcrt._mbscat @691
  _mbschr=msvcrt._mbschr @692
  _mbscmp=msvcrt._mbscmp @693
  _mbscoll=msvcrt._mbscoll @694
  _mbscpy=msvcrt._mbscpy @695
  _mbscspn=msvcrt._mbscspn @696
  _mbsdec=msvcrt._mbsdec @697
  _mbsdup=msvcrt._mbsdup @698
  _mbsicmp=msvcrt._mbsicmp @699
  _mbsicoll=msvcrt._mbsicoll @700
  _mbsinc=msvcrt._mbsinc @701
  _mbslen=msvcrt._mbslen @702
  _mbslwr=msvcrt._mbslwr @703
  _mbsnbcat=msvcrt._mbsnbcat @704
  _mbsnbcmp=msvcrt._mbsnbcmp @705
  _mbsnbcnt=msvcrt._mbsnbcnt @706
  _mbsnbcoll=msvcrt._mbsnbcoll @707
  _mbsnbcpy=msvcrt._mbsnbcpy @708
  _mbsnbicmp=msvcrt._mbsnbicmp @709
  _mbsnbicoll=msvcrt._mbsnbicoll @710
  _mbsnbset=msvcrt._mbsnbset @711
  _mbsncat=msvcrt._mbsncat @712
  _mbsnccnt=msvcrt._mbsnccnt @713
  _mbsncmp=msvcrt._mbsncmp @714
  _mbsncoll=msvcrt._mbsncoll @715
  _mbsncpy=msvcrt._mbsncpy @716
  _mbsnextc=msvcrt._mbsnextc @717
  _mbsnicmp=msvcrt._mbsnicmp @718
  _mbsnicoll=msvcrt._mbsnicoll @719
  _mbsninc=msvcrt._mbsninc @720
  _mbsnset=msvcrt._mbsnset @721
  _mbspbrk=msvcrt._mbspbrk @722
  _mbsrchr=msvcrt._mbsrchr @723
  _mbsrev=msvcrt._mbsrev @724
  _mbsset=msvcrt._mbsset @725
  _mbsspn=msvcrt._mbsspn @726
  _mbsspnp=msvcrt._mbsspnp @727
  _mbsstr=msvcrt._mbsstr @728
  _mbstok=msvcrt._mbstok @729
  _mbstrlen=msvcrt._mbstrlen @730
  _mbsupr=msvcrt._mbsupr @731
  _memccpy=msvcrt._memccpy @732
  _memicmp=msvcrt._memicmp @733
  _mkdir=msvcrt._mkdir @734
  _mktemp=msvcrt._mktemp @735
  _msize=msvcrt._msize @736
  _nextafter=msvcrt._nextafter @739
  _onexit=msvcrt._onexit @740
  _open=msvcrt._open @741
  _open_osfhandle=msvcrt._open_osfhandle @742
  _osver=msvcrt._osver @743 DATA
  _pclose=msvcrt._pclose @744
  _pctype=msvcrt._pctype @745 DATA
  _pgmptr=msvcrt._pgmptr @746 DATA
  _pipe=msvcrt._pipe @747
  _popen=msvcrt._popen @748
  _purecall=msvcrt._purecall @749
  _putch=msvcrt._putch @750
  _putenv=msvcrt._putenv @751
  _putw=msvcrt._putw @752
  _putws=msvcrt._putws @753
  _pwctype=msvcrt._pwctype @754 DATA
  _read=msvcrt._read @755
  _rmdir=msvcrt._rmdir @756
  _rmtmp=msvcrt._rmtmp @757
  _rotl=msvcrt._rotl @758
  _rotr=msvcrt._rotr @759
  _safe_fdiv=msvcrt._safe_fdiv @760
  _safe_fdivr=msvcrt._safe_fdivr @761
  _safe_fprem=msvcrt._safe_fprem @762
  _safe_fprem1=msvcrt._safe_fprem1 @763
  _scalb=msvcrt._scalb @764
  _searchenv=msvcrt._searchenv @765
  __seh_longjmp_unwind@4@4=msvcrt._seh_longjmp_unwind @766
  _seterrormode=msvcrt._seterrormode @767
  _setjmp=msvcrt._setjmp @768
  _setjmp3=msvcrt._setjmp3 @769
  _setmbcp=msvcrt._setmbcp @770
  _setmode=msvcrt._setmode @771
  _setsystime=msvcrt._setsystime @772
  _sleep=msvcrt._sleep @773
  _snprintf=msvcrt._snprintf @774
  _snwprintf=msvcrt._snwprintf @775
  _sopen=msvcrt._sopen @776
  _spawnl=msvcrt._spawnl @777
  _spawnle=msvcrt._spawnle @778
  _spawnlp=msvcrt._spawnlp @779
  _spawnlpe=msvcrt._spawnlpe @780
  _spawnv=msvcrt._spawnv @781
  _spawnve=msvcrt._spawnve @782
  _spawnvp=msvcrt._spawnvp @783
  _spawnvpe=msvcrt._spawnvpe @784
  _splitpath=msvcrt._splitpath @785
  _stat=msvcrt._stat @786
  _statusfp=msvcrt._statusfp @787
  _strcmpi=msvcrt._strcmpi @788
  _strdate=msvcrt._strdate @789
  _strdup=msvcrt._strdup @790
  _strerror=msvcrt._strerror @791
  _stricmp=msvcrt._stricmp @792
  _stricoll=msvcrt._stricoll @793
  _strlwr=msvcrt._strlwr @794
  _strncoll=msvcrt._strncoll @795
  _strnicmp=msvcrt._strnicmp @796
  _strnicoll=msvcrt._strnicoll @797
  _strnset=msvcrt._strnset @798
  _strrev=msvcrt._strrev @799
  _strset=msvcrt._strset @800
  _strtime=msvcrt._strtime @801
  _strupr=msvcrt._strupr @802
  _swab=msvcrt._swab @803
  _sys_errlist=msvcrt._sys_errlist @804 DATA
  _sys_nerr=msvcrt._sys_nerr @805 DATA
  _tccpy=msvcrt._mbccpy @806
  _tclen=msvcrt._mbclen @807
  _tcschr=msvcrt._mbschr @808
  _tcsclen=msvcrt._mbslen @809
  _tcscmp=msvcrt._mbscmp @810
  _tcscspn=msvcrt._mbscspn @811
  _tcsdec=msvcrt._mbsdec @812
  _tcsicmp=msvcrt._mbsicmp @813
  _tcsinc=msvcrt._mbsinc @814
  _tcslwr=msvcrt._mbslwr @815
  _tcsnbcnt=msvcrt._mbsnbcnt @816
  _tcsncat=msvcrt._mbsnbcat @817
  _tcsnccat=msvcrt._mbsncat @818
  _tcsnccmp=msvcrt._mbsncmp @819
  _tcsnccnt=msvcrt._mbsnccnt @820
  _tcsnccpy=msvcrt._mbsncpy @821
  _tcsncicmp=msvcrt._mbsnicmp @822
  _tcsncmp=msvcrt._mbsnbcmp @823
  _tcsncpy=msvcrt._mbsnbcpy @824
  _tcsncset=msvcrt._mbsnset @825
  _tcsnextc=msvcrt._mbsnextc @826
  _tcsnicmp=msvcrt._mbsnbicmp @827
  _tcsninc=msvcrt._mbsninc @828
  _tcsnset=msvcrt._mbsnbset @829
  _tcspbrk=msvcrt._mbspbrk @830
  _tcsrchr=msvcrt._mbsrchr @831
  _tcsrev=msvcrt._mbsrev @832
  _tcsset=msvcrt._mbsset @833
  _tcsspn=msvcrt._mbsspn @834
  _tcsspnp=msvcrt._mbsspnp @835
  _tcsstr=msvcrt._mbsstr @836
  _tcstok=msvcrt._mbstok @837
  _tcsupr=msvcrt._mbsupr @838
  _tell=msvcrt._tell @839
  _tempnam=msvcrt._tempnam @840
  _timezone=msvcrt._timezone @841 DATA
  _tolower=msvcrt._tolower @842
  _toupper=msvcrt._toupper @843
  _tzname=msvcrt._tzname @844 DATA
  _tzset=msvcrt._tzset @845
  _ultoa=msvcrt._ultoa @846
  _ultow=msvcrt._ultow @847
  _umask=msvcrt._umask @848
  _ungetch=msvcrt._ungetch @849
  _unlink=msvcrt._unlink @850
  _unloaddll=msvcrt._unloaddll @851
  _utime=msvcrt._utime @852
  _vsnprintf=msvcrt._vsnprintf @853
  _vsnwprintf=msvcrt._vsnwprintf @854
  _waccess=msvcrt._waccess @855
  _wasctime=msvcrt._wasctime @856
  _wchdir=msvcrt._wchdir @857
  _wchmod=msvcrt._wchmod @858
  _wcmdln=msvcrt._wcmdln @859 DATA
  _wcreat=msvcrt._wcreat @860
  _wcsdup=msvcrt._wcsdup @861
  _wcsicmp=msvcrt._wcsicmp @862
  _wcsicoll=msvcrt._wcsicoll @863
  _wcslwr=msvcrt._wcslwr @864
  _wcsncoll=msvcrt._wcsncoll @865
  _wcsnicmp=msvcrt._wcsnicmp @866
  _wcsnicoll=msvcrt._wcsnicoll @867
  _wcsnset=msvcrt._wcsnset @868
  _wcsrev=msvcrt._wcsrev @869
  _wcsset=msvcrt._wcsset @870
  _wcsupr=msvcrt._wcsupr @871
  _wctime=msvcrt._wctime @872
  _wenviron=msvcrt._wenviron @873 DATA
  _wexecl=msvcrt._wexecl @874
  _wexecle=msvcrt._wexecle @875
  _wexeclp=msvcrt._wexeclp @876
  _wexeclpe=msvcrt._wexeclpe @877
  _wexecv=msvcrt._wexecv @878
  _wexecve=msvcrt._wexecve @879
  _wexecvp=msvcrt._wexecvp @880
  _wexecvpe=msvcrt._wexecvpe @881
  _wfdopen=msvcrt._wfdopen @882
  _wfindfirst=msvcrt._wfindfirst @883
  _wfindnext=msvcrt._wfindnext @884
  _wfopen=msvcrt._wfopen @885
  _wfreopen=msvcrt._wfreopen @886
  _wfsopen=msvcrt._wfsopen @887
  _wfullpath=msvcrt._wfullpath @888
  _wgetcwd=msvcrt._wgetcwd @889
  _wgetdcwd=msvcrt._wgetdcwd @890
  _wgetenv=msvcrt._wgetenv @891
  _winmajor=msvcrt._winmajor @892 DATA
  _winminor=msvcrt._winminor @893 DATA
  _winver=msvcrt._winver @894 DATA
  _wmakepath=msvcrt._wmakepath @895
  _wmkdir=msvcrt._wmkdir @896
  _wmktemp=msvcrt._wmktemp @897
  _wopen=msvcrt._wopen @898
  _wperror=msvcrt._wperror @899
  _wpgmptr=msvcrt._wpgmptr @900 DATA
  _wpopen=msvcrt._wpopen @901
  _wputenv=msvcrt._wputenv @902
  _wremove=msvcrt._wremove @903
  _wrename=msvcrt._wrename @904
  _write=msvcrt._write @905
  _wrmdir=msvcrt._wrmdir @906
  _wsearchenv=msvcrt._wsearchenv @907
  _wsetlocale=msvcrt._wsetlocale @908
  _wsopen=msvcrt._wsopen @909
  _wspawnl=msvcrt._wspawnl @910
  _wspawnle=msvcrt._wspawnle @911
  _wspawnlp=msvcrt._wspawnlp @912
  _wspawnlpe=msvcrt._wspawnlpe @913
  _wspawnv=msvcrt._wspawnv @914
  _wspawnve=msvcrt._wspawnve @915
  _wspawnvp=msvcrt._wspawnvp @916
  _wspawnvpe=msvcrt._wspawnvpe @917
  _wsplitpath=msvcrt._wsplitpath @918
  _wstat=msvcrt._wstat @919
  _wstrdate=msvcrt._wstrdate @920
  _wstrtime=msvcrt._wstrtime @921
  _wsystem=msvcrt._wsystem @922
  _wtempnam=msvcrt._wtempnam @923
  _wtmpnam=msvcrt._wtmpnam @924
  _wtoi=msvcrt._wtoi @925
  _wtol=msvcrt._wtol @926
  _wunlink=msvcrt._wunlink @927
  _wutime=msvcrt._wutime @928
  _y0=msvcrt._y0 @929
  _y1=msvcrt._y1 @930
  _yn=msvcrt._yn @931
  abort=msvcrt.abort @932
  abs=msvcrt.abs @933
  acos=msvcrt.acos @934
  asctime=msvcrt.asctime @935
  asin=msvcrt.asin @936
  atan=msvcrt.atan @937
  atan2=msvcrt.atan2 @938
  atexit=msvcrt.atexit @939
  atof=msvcrt.atof @940
  atoi=msvcrt.atoi @941
  atol=msvcrt.atol @942
  bsearch=msvcrt.bsearch @943
  calloc=msvcrt.calloc @944
  ceil=msvcrt.ceil @945
  clearerr=msvcrt.clearerr @946
  clock=msvcrt.clock @947
  cos=msvcrt.cos @948
  cosh=msvcrt.cosh @949
  ctime=msvcrt.ctime @950
  difftime=msvcrt.difftime @951
  div=msvcrt.div @952
  exit=msvcrt.exit @953
  exp=msvcrt.exp @954
  fabs=msvcrt.fabs @955
  fclose=msvcrt.fclose @956
  feof=msvcrt.feof @957
  ferror=msvcrt.ferror @958
  fflush=msvcrt.fflush @959
  fgetc=msvcrt.fgetc @960
  fgetpos=msvcrt.fgetpos @961
  fgets=msvcrt.fgets @962
  fgetwc=msvcrt.fgetwc @963
  fgetws=msvcrt.fgetws @964
  floor=msvcrt.floor @965
  fmod=msvcrt.fmod @966
  fopen=msvcrt.fopen @967
  fprintf=msvcrt.fprintf @968
  fputc=msvcrt.fputc @969
  fputs=msvcrt.fputs @970
  fputwc=msvcrt.fputwc @971
  fputws=msvcrt.fputws @972
  fread=msvcrt.fread @973
  free=msvcrt.free @974
  freopen=msvcrt.freopen @975
  frexp=msvcrt.frexp @976
  fscanf=msvcrt.fscanf @977
  fseek=msvcrt.fseek @978
  fsetpos=msvcrt.fsetpos @979
  ftell=msvcrt.ftell @980
  fwprintf=msvcrt.fwprintf @981
  fwrite=msvcrt.fwrite @982
  fwscanf=msvcrt.fwscanf @983
  getc=msvcrt.getc @984
  getchar=msvcrt.getchar @985
  getenv=msvcrt.getenv @986
  gets=msvcrt.gets @987
  getwc=msvcrt.getwc @988
  getwchar=msvcrt.getwchar @989
  gmtime=msvcrt.gmtime @990
  is_wctype=msvcrt.is_wctype @991
  isalnum=msvcrt.isalnum @992
  isalpha=msvcrt.isalpha @993
  iscntrl=msvcrt.iscntrl @994
  isdigit=msvcrt.isdigit @995
  isgraph=msvcrt.isgraph @996
  isleadbyte=msvcrt.isleadbyte @997
  islower=msvcrt.islower @998
  isprint=msvcrt.isprint @999
  ispunct=msvcrt.ispunct @1000
  isspace=msvcrt.isspace @1001
  isupper=msvcrt.isupper @1002
  iswalnum=msvcrt.iswalnum @1003
  iswalpha=msvcrt.iswalpha @1004
  iswascii=msvcrt.iswascii @1005
  iswcntrl=msvcrt.iswcntrl @1006
  iswctype=msvcrt.iswctype @1007
  iswdigit=msvcrt.iswdigit @1008
  iswgraph=msvcrt.iswgraph @1009
  iswlower=msvcrt.iswlower @1010
  iswprint=msvcrt.iswprint @1011
  iswpunct=msvcrt.iswpunct @1012
  iswspace=msvcrt.iswspace @1013
  iswupper=msvcrt.iswupper @1014
  iswxdigit=msvcrt.iswxdigit @1015
  isxdigit=msvcrt.isxdigit @1016
  labs=msvcrt.labs @1017
  ldexp=msvcrt.ldexp @1018
  ldiv=msvcrt.ldiv @1019
  localeconv=msvcrt.localeconv @1020
  localtime=msvcrt.localtime @1021
  log=msvcrt.log @1022
  log10=msvcrt.log10 @1023
  longjmp=msvcrt.longjmp @1024
  malloc=msvcrt.malloc @1025
  mblen=msvcrt.mblen @1026
  mbstowcs=msvcrt.mbstowcs @1027
  mbtowc=msvcrt.mbtowc @1028
  memchr=msvcrt.memchr @1029
  memcmp=msvcrt.memcmp @1030
  memcpy=msvcrt.memcpy @1031
  memmove=msvcrt.memmove @1032
  memset=msvcrt.memset @1033
  mktime=msvcrt.mktime @1034
  modf=msvcrt.modf @1035
  perror=msvcrt.perror @1036
  pow=msvcrt.pow @1037
  printf=msvcrt.printf @1038
  putc=msvcrt.putc @1039
  putchar=msvcrt.putchar @1040
  puts=msvcrt.puts @1041
  putwc=msvcrt.putwc @1042
  putwchar=msvcrt.putwchar @1043
  qsort=msvcrt.qsort @1044
  raise=msvcrt.raise @1045
  rand=msvcrt.rand @1046
  realloc=msvcrt.realloc @1047
  remove=msvcrt.remove @1048
  rename=msvcrt.rename @1049
  rewind=msvcrt.rewind @1050
  scanf=msvcrt.scanf @1051
  setbuf=msvcrt.setbuf @1052
  setlocale=msvcrt.setlocale @1053
  setvbuf=msvcrt.setvbuf @1054
  signal=msvcrt.signal @1055
  sin=msvcrt.sin @1056
  sinh=msvcrt.sinh @1057
  sprintf=msvcrt.sprintf @1058
  sqrt=msvcrt.sqrt @1059
  srand=msvcrt.srand @1060
  sscanf=msvcrt.sscanf @1061
  strcat=msvcrt.strcat @1062
  strchr=msvcrt.strchr @1063
  strcmp=msvcrt.strcmp @1064
  strcoll=msvcrt.strcoll @1065
  strcpy=msvcrt.strcpy @1066
  strcspn=msvcrt.strcspn @1067
  strerror=msvcrt.strerror @1068
  strftime=msvcrt.strftime @1069
  strlen=msvcrt.strlen @1070
  strncat=msvcrt.strncat @1071
  strncmp=msvcrt.strncmp @1072
  strncpy=msvcrt.strncpy @1073
  strpbrk=msvcrt.strpbrk @1074
  strrchr=msvcrt.strrchr @1075
  strspn=msvcrt.strspn @1076
  strstr=msvcrt.strstr @1077
  strtod=msvcrt.strtod @1078
  strtok=msvcrt.strtok @1079
  strtol=msvcrt.strtol @1080
  strtoul=msvcrt.strtoul @1081
  strxfrm=msvcrt.strxfrm @1082
  swprintf=msvcrt.swprintf @1083
  swscanf=msvcrt.swscanf @1084
  system=msvcrt.system @1085
  tan=msvcrt.tan @1086
  tanh=msvcrt.tanh @1087
  time=msvcrt.time @1088
  tmpfile=msvcrt.tmpfile @1089
  tmpnam=msvcrt.tmpnam @1090
  tolower=msvcrt.tolower @1091
  toupper=msvcrt.toupper @1092
  towlower=msvcrt.towlower @1093
  towupper=msvcrt.towupper @1094
  ungetc=msvcrt.ungetc @1095
  ungetwc=msvcrt.ungetwc @1096
  vfprintf=msvcrt.vfprintf @1097
  vfwprintf=msvcrt.vfwprintf @1098
  vprintf=msvcrt.vprintf @1099
  vsprintf=msvcrt.vsprintf @1100
  vswprintf=msvcrt.vswprintf @1101
  vwprintf=msvcrt.vwprintf @1102
  wcscat=msvcrt.wcscat @1103
  wcschr=msvcrt.wcschr @1104
  wcscmp=msvcrt.wcscmp @1105
  wcscoll=msvcrt.wcscoll @1106
  wcscpy=msvcrt.wcscpy @1107
  wcscspn=msvcrt.wcscspn @1108
  wcsftime=msvcrt.wcsftime @1109
  wcslen=msvcrt.wcslen @1110
  wcsncat=msvcrt.wcsncat @1111
  wcsncmp=msvcrt.wcsncmp @1112
  wcsncpy=msvcrt.wcsncpy @1113
  wcspbrk=msvcrt.wcspbrk @1114
  wcsrchr=msvcrt.wcsrchr @1115
  wcsspn=msvcrt.wcsspn @1116
  wcsstr=msvcrt.wcsstr @1117
  wcstod=msvcrt.wcstod @1118
  wcstok=msvcrt.wcstok @1119
  wcstol=msvcrt.wcstol @1120
  wcstombs=msvcrt.wcstombs @1121
  wcstoul=msvcrt.wcstoul @1122
  wcsxfrm=msvcrt.wcsxfrm @1123
  wctomb=msvcrt.wctomb @1124
  wprintf=msvcrt.wprintf @1125
  wscanf=msvcrt.wscanf @1126
