; File generated automatically from ./advpack.spec; do not edit!

LIBRARY advpack.dll

EXPORTS
  AddDelBackupEntryA@16 @1
  AddDelBackupEntryW@16 @2
  AddDelBackupEntry@16=AddDelBackupEntryA@16 @3
  AdvInstallFileA@28 @4
  AdvInstallFileW@28 @5
  AdvInstallFile@28=AdvInstallFileA@28 @6
  CloseINFEngine@4 @7
  DelNodeA@8 @8
  DelNodeW@8 @9
  DelNode@8=DelNodeA@8 @10
  DelNodeRunDLL32A@16 @11
  DelNodeRunDLL32W@16 @12
  DelNodeRunDLL32@16=DelNodeRunDLL32A@16 @13
  DllMain@12 @14 PRIVATE
  DoInfInstall@4 @15
  ExecuteCabA@12 @16
  ExecuteCabW@12 @17
  ExecuteCab@12=ExecuteCabA@12 @18
  ExtractFilesA@24 @19
  ExtractFiles@24=ExtractFilesA@24 @20
  FileSaveMarkNotExistA@12 @21
  FileSaveMarkNotExistW@12 @22
  FileSaveMarkNotExist@12=FileSaveMarkNotExistA@12 @23
  FileSaveRestoreA@20 @24
  FileSaveRestoreW@20 @25
  FileSaveRestore@20=FileSaveRestoreA@20 @26
  FileSaveRestoreOnINFA@28 @27
  FileSaveRestoreOnINFW@28 @28
  FileSaveRestoreOnINF@28=FileSaveRestoreOnINFA@28 @29
  GetVersionFromFileA@16 @30
  GetVersionFromFileW@16 @31
  GetVersionFromFile@16=GetVersionFromFileA@16 @32
  GetVersionFromFileExA@16 @33
  GetVersionFromFileExW@16 @34
  GetVersionFromFileEx@16=GetVersionFromFileExA@16 @35
  IsNTAdmin@8 @36
  LaunchINFSectionA@16 @37
  LaunchINFSectionW@16 @38
  LaunchINFSection@16=LaunchINFSectionA@16 @39
  LaunchINFSectionExA@16 @40
  LaunchINFSectionExW@16 @41
  LaunchINFSectionEx@16=LaunchINFSectionExA@16 @42
  NeedReboot@4 @43
  NeedRebootInit@0 @44
  OpenINFEngineA@20 @45
  OpenINFEngineW@20 @46
  OpenINFEngine@20=OpenINFEngineA@20 @47
  RebootCheckOnInstallA@16 @48
  RebootCheckOnInstallW@16 @49
  RebootCheckOnInstall@16=RebootCheckOnInstallA@16 @50
  RegInstallA@12 @51
  RegInstallW@12 @52
  RegInstall@12=RegInstallA@12 @53
  RegRestoreAllA@12 @54
  RegRestoreAllW@12 @55
  RegRestoreAll@12=RegRestoreAllA@12 @56
  RegSaveRestoreA@28 @57
  RegSaveRestoreW@28 @58
  RegSaveRestore@28=RegSaveRestoreA@28 @59
  RegSaveRestoreOnINFA@28 @60
  RegSaveRestoreOnINFW@28 @61
  RegSaveRestoreOnINF@28=RegSaveRestoreOnINFA@28 @62
  RegisterOCX@16 @63
  RunSetupCommandA@32 @64
  RunSetupCommandW@32 @65
  RunSetupCommand@32=RunSetupCommandA@32 @66
  SetPerUserSecValuesA@4 @67
  SetPerUserSecValuesW@4 @68
  SetPerUserSecValues@4=SetPerUserSecValuesA@4 @69
  TranslateInfStringA@32 @70
  TranslateInfStringW@32 @71
  TranslateInfString@32=TranslateInfStringA@32 @72
  TranslateInfStringExA@32 @73
  TranslateInfStringExW@32 @74
  TranslateInfStringEx@32=TranslateInfStringExA@32 @75
  UserInstStubWrapperA@16 @76
  UserInstStubWrapperW@16 @77
  UserInstStubWrapper@16=UserInstStubWrapperA@16 @78
  UserUnInstStubWrapperA@16 @79
  UserUnInstStubWrapperW@16 @80
  UserUnInstStubWrapper@16=UserUnInstStubWrapperA@16 @81
