; File generated automatically from ./user32.spec; do not edit!

LIBRARY user32.dll

EXPORTS
  ActivateKeyboardLayout@8 @1
  AdjustWindowRect@12 @2
  AdjustWindowRectEx@16 @3
  AlignRects@16 @4
  AllowSetForegroundWindow@4 @5
  AnimateWindow@12 @6
  AnyPopup@0 @7
  AppendMenuA@16 @8
  AppendMenuW@16 @9
  ArrangeIconicWindows@4 @10
  AttachThreadInput@12 @11
  BeginDeferWindowPos@4 @12
  BeginPaint@8 @13
  BlockInput@4 @14
  BringWindowToTop@4 @15
  BroadcastSystemMessage@20=BroadcastSystemMessageA@20 @16
  BroadcastSystemMessageA@20 @17
  BroadcastSystemMessageW@20 @18
  CalcChildScroll@8 @19
  CallMsgFilter@8=CallMsgFilterA@8 @20
  CallMsgFilterA@8 @21
  CallMsgFilterW@8 @22
  CallNextHookEx@16 @23
  CallWindowProcA@20 @24
  CallWindowProcW@20 @25
  CascadeWindows@20 @27
  ChangeClipboardChain@8 @28
  ChangeDisplaySettingsA@8 @29
  ChangeDisplaySettingsExA@20 @30
  ChangeDisplaySettingsExW@20 @31
  ChangeDisplaySettingsW@8 @32
  ChangeMenuA@20 @33
  ChangeMenuW@20 @34
  CharLowerA@4 @35
  CharLowerBuffA@8 @36
  CharLowerBuffW@8 @37
  CharLowerW@4 @38
  CharNextA@4 @39
  CharNextExA@12 @40
  CharNextExW@12 @41
  CharNextW@4 @42
  CharPrevA@8 @43
  CharPrevExA@16 @44
  CharPrevExW@16 @45
  CharPrevW@8 @46
  CharToOemA@8 @47
  CharToOemBuffA@12 @48
  CharToOemBuffW@12 @49
  CharToOemW@8 @50
  CharUpperA@4 @51
  CharUpperBuffA@8 @52
  CharUpperBuffW@8 @53
  CharUpperW@4 @54
  CheckDlgButton@12 @55
  CheckMenuItem@12 @56
  CheckMenuRadioItem@20 @57
  CheckRadioButton@16 @58
  ChildWindowFromPoint@12 @59
  ChildWindowFromPointEx@16 @60
  ClientToScreen@8 @64
  ClipCursor@4 @65
  CloseClipboard@0 @66
  CloseDesktop@4 @67
  CloseWindow@4 @68
  CloseWindowStation@4 @69
  CopyAcceleratorTableA@12 @70
  CopyAcceleratorTableW@12 @71
  CopyIcon@4 @72
  CopyImage@20 @73
  CopyRect@8 @74
  CountClipboardFormats@0 @75
  CreateAcceleratorTableA@8 @76
  CreateAcceleratorTableW@8 @77
  CreateCaret@16 @78
  CreateCursor@28 @79
  CreateDesktopA@24 @80
  CreateDesktopW@24 @81
  CreateDialogIndirectParamA@20 @82
  CreateDialogIndirectParamAorW@24 @83
  CreateDialogIndirectParamW@20 @84
  CreateDialogParamA@20 @85
  CreateDialogParamW@20 @86
  CreateIcon@28 @87
  CreateIconFromResource@16 @88
  CreateIconFromResourceEx@28 @89
  CreateIconIndirect@4 @90
  CreateMDIWindowA@40 @91
  CreateMDIWindowW@40 @92
  CreateMenu@0 @93
  CreatePopupMenu@0 @94
  CreateWindowExA@48 @95
  CreateWindowExW@48 @96
  CreateWindowStationA@16 @97
  CreateWindowStationW@16 @98
  DdeAbandonTransaction@12 @99
  DdeAccessData@8 @100
  DdeAddData@16 @101
  DdeClientTransaction@32 @102
  DdeCmpStringHandles@8 @103
  DdeConnect@16 @104
  DdeConnectList@20 @105
  DdeCreateDataHandle@28 @106
  DdeCreateStringHandleA@12 @107
  DdeCreateStringHandleW@12 @108
  DdeDisconnect@4 @109
  DdeDisconnectList@4 @110
  DdeEnableCallback@12 @111
  DdeFreeDataHandle@4 @112
  DdeFreeStringHandle@8 @113
  DdeGetData@16 @114
  DdeGetLastError@4 @115
  DdeImpersonateClient@4 @117
  DdeInitializeA@16 @118
  DdeInitializeW@16 @119
  DdeKeepStringHandle@8 @120
  DdeNameService@16 @121
  DdePostAdvise@12 @122
  DdeQueryConvInfo@12 @123
  DdeQueryNextServer@8 @124
  DdeQueryStringA@20 @125
  DdeQueryStringW@20 @126
  DdeReconnect@4 @127
  DdeSetQualityOfService@12 @128
  DdeSetUserHandle@12 @129
  DdeUnaccessData@4 @130
  DdeUninitialize@4 @131
  DefDlgProcA@16 @132
  DefDlgProcW@16 @133
  DefFrameProcA@20 @134
  DefFrameProcW@20 @135
  DefMDIChildProcA@16 @136
  DefMDIChildProcW@16 @137
  DefWindowProcA@16 @138
  DefWindowProcW@16 @139
  DeferWindowPos@32 @140
  DeleteMenu@12 @141
  DeregisterShellHookWindow@4 @142
  DestroyAcceleratorTable@4 @143
  DestroyCaret@0 @144
  DestroyCursor@4 @145
  DestroyIcon@4 @146
  DestroyMenu@4 @147
  DestroyWindow@4 @148
  DialogBoxIndirectParamA@20 @149
  DialogBoxIndirectParamAorW@24 @150
  DialogBoxIndirectParamW@20 @151
  DialogBoxParamA@20 @152
  DialogBoxParamW@20 @153
  DispatchMessageA@4 @154
  DispatchMessageW@4 @155
  DlgDirListA@20 @156
  DlgDirListComboBoxA@20 @157
  DlgDirListComboBoxW@20 @158
  DlgDirListW@20 @159
  DlgDirSelectComboBoxExA@16 @160
  DlgDirSelectComboBoxExW@16 @161
  DlgDirSelectExA@16 @162
  DlgDirSelectExW@16 @163
  DragDetect@12 @164
  DrawAnimatedRects@16 @166
  DrawCaption@16 @167
  DrawCaptionTempA@28 @168
  DrawCaptionTempW@28 @169
  DrawEdge@16 @170
  DrawFocusRect@8 @171
  DrawFrameControl@16 @173
  DrawIcon@16 @174
  DrawIconEx@36 @175
  DrawMenuBar@4 @176
  DrawMenuBarTemp@20 @177
  DrawStateA@40 @178
  DrawStateW@40 @179
  DrawTextA@20 @180
  DrawTextExA@24 @181
  DrawTextExW@24 @182
  DrawTextW@20 @183
  EditWndProc@16=EditWndProcA@16 @184
  EmptyClipboard@0 @185
  EnableMenuItem@12 @186
  EnableScrollBar@12 @187
  EnableWindow@8 @188
  EndDeferWindowPos@4 @189
  EndDialog@8 @190
  EndMenu@0 @191
  EndPaint@8 @192
  EnumChildWindows@12 @194
  EnumClipboardFormats@4 @195
  EnumDesktopWindows@12 @196
  EnumDesktopsA@12 @197
  EnumDesktopsW@12 @198
  EnumDisplayDevicesA@16 @201
  EnumDisplayDevicesW@16 @202
  EnumDisplayMonitors@16 @203
  EnumDisplaySettingsA@12 @204
  EnumDisplaySettingsExA@16 @205
  EnumDisplaySettingsExW@16 @206
  EnumDisplaySettingsW@12 @207
  EnumPropsA@8 @208
  EnumPropsExA@12 @209
  EnumPropsExW@12 @210
  EnumPropsW@8 @211
  EnumThreadWindows@12 @212
  EnumWindowStationsA@8 @213
  EnumWindowStationsW@8 @214
  EnumWindows@8 @215
  EqualRect@8 @216
  ExcludeUpdateRgn@8 @217
  ExitWindowsEx@8 @218
  FillRect@12 @219
  FindWindowA@8 @220
  FindWindowExA@16 @221
  FindWindowExW@16 @222
  FindWindowW@8 @223
  FlashWindow@8 @224
  FlashWindowEx@4 @225
  FrameRect@12 @226
  FreeDDElParam@8 @227
  GetActiveWindow@0 @228
  GetAltTabInfo@20=GetAltTabInfoA@20 @229
  GetAltTabInfoA@20 @230
  GetAltTabInfoW@20 @231
  GetAncestor@8 @232
  GetAppCompatFlags@4 @233
  GetAsyncKeyState@4 @234
  GetCapture@0 @235
  GetCaretBlinkTime@0 @236
  GetCaretPos@4 @237
  GetClassInfoA@12 @238
  GetClassInfoExA@12 @239
  GetClassInfoExW@12 @240
  GetClassInfoW@12 @241
  GetClassLongA@8 @242
  GetClassLongW@8 @243
  GetClassLongPtrA@8 @244
  GetClassLongPtrW@8 @245
  GetClassNameA@12 @246
  GetClassNameW@12 @247
  GetClassWord@8 @248
  GetClientRect@8 @249
  GetClipCursor@4 @250
  GetClipboardData@4 @251
  GetClipboardFormatNameA@12 @252
  GetClipboardFormatNameW@12 @253
  GetClipboardOwner@0 @254
  GetClipboardSequenceNumber@0 @255
  GetClipboardViewer@0 @256
  GetComboBoxInfo@8 @257
  GetCursor@0 @258
  GetCursorInfo@4 @259
  GetCursorPos@4 @260
  GetDC@4 @261
  GetDCEx@12 @262
  GetDesktopWindow@0 @263
  GetDialogBaseUnits@0 @264
  GetDlgCtrlID@4 @265
  GetDlgItem@8 @266
  GetDlgItemInt@16 @267
  GetDlgItemTextA@16 @268
  GetDlgItemTextW@16 @269
  GetDoubleClickTime@0 @270
  GetFocus@0 @271
  GetForegroundWindow@0 @272
  GetGUIThreadInfo@8 @273
  GetGuiResources@8 @274
  GetIconInfo@8 @275
  GetInputState@0 @277
  GetInternalWindowPos@12 @278
  GetKBCodePage@0 @279
  GetKeyNameTextA@12 @280
  GetKeyNameTextW@12 @281
  GetKeyState@4 @282
  GetKeyboardLayout@4 @283
  GetKeyboardLayoutList@8 @284
  GetKeyboardLayoutNameA@4 @285
  GetKeyboardLayoutNameW@4 @286
  GetKeyboardState@4 @287
  GetKeyboardType@4 @288
  GetLastActivePopup@4 @289
  GetLastInputInfo@4 @290
  GetMenu@4 @291
  GetMenuBarInfo@16 @292
  GetMenuCheckMarkDimensions@0 @293
  GetMenuContextHelpId@4 @294
  GetMenuDefaultItem@12 @295
  GetMenuInfo@8 @297
  GetMenuItemCount@4 @298
  GetMenuItemID@8 @299
  GetMenuItemInfoA@16 @300
  GetMenuItemInfoW@16 @301
  GetMenuItemRect@16 @302
  GetMenuState@12 @303
  GetMenuStringA@20 @304
  GetMenuStringW@20 @305
  GetMessageA@16 @306
  GetMessageExtraInfo@0 @307
  GetMessagePos@0 @308
  GetMessageTime@0 @309
  GetMessageW@16 @310
  GetMonitorInfoA@8 @311
  GetMonitorInfoW@8 @312
  GetNextDlgGroupItem@12 @313
  GetNextDlgTabItem@12 @314
  GetOpenClipboardWindow@0 @315
  GetParent@4 @316
  GetPriorityClipboardFormat@8 @317
  GetProcessDefaultLayout@4 @318
  GetProcessWindowStation@0 @319
  GetProgmanWindow@0 @320
  GetPropA@8 @321
  GetPropW@8 @322
  GetQueueStatus@4 @323
  GetScrollBarInfo@12 @324
  GetScrollInfo@12 @325
  GetScrollPos@8 @326
  GetScrollRange@16 @327
  GetShellWindow@0 @328
  GetSubMenu@8 @329
  GetSysColor@4 @330
  GetSysColorBrush@4 @331
  GetSystemMenu@8 @332
  GetSystemMetrics@4 @333
  GetTabbedTextExtentA@20 @334
  GetTabbedTextExtentW@20 @335
  GetTaskmanWindow@0 @336
  GetThreadDesktop@4 @337
  GetTitleBarInfo@8 @338
  GetTopWindow@4 @339
  GetUpdateRect@12 @340
  GetUpdateRgn@12 @341
  GetUserObjectInformationA@20 @342
  GetUserObjectInformationW@20 @343
  GetUserObjectSecurity@20 @344
  GetWindow@8 @345
  GetWindowContextHelpId@4 @346
  GetWindowDC@4 @347
  GetWindowInfo@8 @348
  GetWindowLongA@8 @349
  GetWindowLongPtrA@8 @350
  GetWindowLongPtrW@8 @351
  GetWindowLongW@8 @352
  GetWindowModuleFileNameA@12 @353
  GetWindowModuleFileNameW@12 @354
  GetWindowPlacement@8 @355
  GetWindowRect@8 @356
  GetWindowRgn@8 @357
  GetWindowTextA@12 @358
  GetWindowTextLengthA@4 @359
  GetWindowTextLengthW@4 @360
  GetWindowTextW@12 @361
  GetWindowThreadProcessId@8 @362
  GetWindowWord@8 @363
  GrayStringA@36 @364
  GrayStringW@36 @365
  HideCaret@4 @366
  HiliteMenuItem@16 @367
  ImpersonateDdeClientWindow@8 @368
  InSendMessage@0 @369
  InSendMessageEx@4 @370
  InflateRect@12 @371
  InsertMenuA@20 @372
  InsertMenuItemA@16 @373
  InsertMenuItemW@16 @374
  InsertMenuW@20 @375
  InternalGetWindowText@12 @376
  IntersectRect@12 @377
  InvalidateRect@12 @378
  InvalidateRgn@12 @379
  InvertRect@8 @380
  IsCharAlphaA@4 @381
  IsCharAlphaNumericA@4 @382
  IsCharAlphaNumericW@4 @383
  IsCharAlphaW@4 @384
  IsCharLowerA@4 @385
  IsCharLowerW@4 @386
  IsCharUpperA@4 @387
  IsCharUpperW@4 @388
  IsChild@8 @389
  IsClipboardFormatAvailable@4 @390
  IsDialogMessage@8=IsDialogMessageA@8 @391
  IsDialogMessageA@8 @392
  IsDialogMessageW@8 @393
  IsDlgButtonChecked@8 @394
  IsHungAppWindow@4 @395
  IsIconic@4 @396
  IsMenu@4 @397
  IsRectEmpty@4 @398
  IsWinEventHookInstalled@4 @399
  IsWindow@4 @400
  IsWindowEnabled@4 @401
  IsWindowUnicode@4 @402
  IsWindowVisible@4 @403
  IsZoomed@4 @404
  KillSystemTimer@8 @405
  KillTimer@8 @406
  LoadAcceleratorsA@8 @407
  LoadAcceleratorsW@8 @408
  LoadBitmapA@8 @409
  LoadBitmapW@8 @410
  LoadCursorA@8 @411
  LoadCursorFromFileA@4 @412
  LoadCursorFromFileW@4 @413
  LoadCursorW@8 @414
  LoadIconA@8 @415
  LoadIconW@8 @416
  LoadImageA@24 @417
  LoadImageW@24 @418
  LoadKeyboardLayoutA@8 @419
  LoadKeyboardLayoutW@8 @420
  LoadLocalFonts@0 @421
  LoadMenuA@8 @422
  LoadMenuIndirectA@4 @423
  LoadMenuIndirectW@4 @424
  LoadMenuW@8 @425
  LoadStringA@16 @427
  LoadStringW@16 @428
  LockSetForegroundWindow@4 @429
  LockWindowUpdate@4 @431
  LookupIconIdFromDirectory@8 @433
  LookupIconIdFromDirectoryEx@20 @434
  MapDialogRect@8 @436
  MapVirtualKeyA@8 @437
  MapVirtualKeyExA@12 @438
  MapVirtualKeyExW@12 @439
  MapVirtualKeyW@8 @440
  MapWindowPoints@16 @441
  MenuItemFromPoint@16 @442
  MessageBeep@4 @445
  MessageBoxA@16 @446
  MessageBoxExA@20 @447
  MessageBoxExW@20 @448
  MessageBoxIndirectA@4 @449
  MessageBoxIndirectW@4 @450
  MessageBoxW@16 @451
  ModifyMenuA@20 @452
  ModifyMenuW@20 @453
  MonitorFromPoint@12 @454
  MonitorFromRect@8 @455
  MonitorFromWindow@8 @456
  MoveWindow@24 @457
  MsgWaitForMultipleObjects@20 @458
  MsgWaitForMultipleObjectsEx@20 @459
  NotifyWinEvent@16 @460
  OemKeyScan@4 @461
  OemToCharA@8 @462
  OemToCharBuffA@12 @463
  OemToCharBuffW@12 @464
  OemToCharW@8 @465
  OffsetRect@12 @466
  OpenClipboard@4 @467
  OpenDesktopA@16 @468
  OpenDesktopW@16 @469
  OpenIcon@4 @470
  OpenInputDesktop@12 @471
  OpenWindowStationA@12 @472
  OpenWindowStationW@12 @473
  PackDDElParam@12 @474
  PaintDesktop@4 @475
  PeekMessageA@20 @476
  PeekMessageW@20 @477
  PostMessageA@16 @479
  PostMessageW@16 @480
  PostQuitMessage@4 @481
  PostThreadMessageA@16 @482
  PostThreadMessageW@16 @483
  PrivateExtractIconExA@20 @484
  PrivateExtractIconExW@20 @485
  PrivateExtractIconsA@32 @486
  PrivateExtractIconsW@32 @487
  PtInRect@12 @488
  RealChildWindowFromPoint@12 @490
  RealGetWindowClass@12=RealGetWindowClassA@12 @491
  RealGetWindowClassA@12 @492
  RealGetWindowClassW@12 @493
  RedrawWindow@16 @494
  RegisterClassA@4 @495
  RegisterClassExA@4 @496
  RegisterClassExW@4 @497
  RegisterClassW@4 @498
  RegisterClipboardFormatA@4 @499
  RegisterClipboardFormatW@4 @500
  RegisterDeviceNotificationA@12 @501
  RegisterDeviceNotificationW@12 @502
  RegisterHotKey@16 @503
  RegisterLogonProcess@8 @504
  RegisterShellHookWindow@4 @507
  RegisterSystemThread@8 @508
  RegisterTasklist@4 @509
  RegisterWindowMessageA@4 @510
  RegisterWindowMessageW@4 @511
  ReleaseCapture@0 @512
  ReleaseDC@8 @513
  RemoveMenu@12 @514
  RemovePropA@8 @515
  RemovePropW@8 @516
  ReplyMessage@4 @517
  ReuseDDElParam@20 @519
  ScreenToClient@8 @520
  ScrollChildren@16 @521
  ScrollDC@28 @522
  ScrollWindow@20 @523
  ScrollWindowEx@32 @524
  SendDlgItemMessageA@20 @525
  SendDlgItemMessageW@20 @526
  SendIMEMessageExA@8 @527
  SendIMEMessageExW@8 @528
  SendInput@12 @529
  SendMessageA@16 @530
  SendMessageCallbackA@24 @531
  SendMessageCallbackW@24 @532
  SendMessageTimeoutA@28 @533
  SendMessageTimeoutW@28 @534
  SendMessageW@16 @535
  SendNotifyMessageA@16 @536
  SendNotifyMessageW@16 @537
  SetActiveWindow@4 @539
  SetCapture@4 @540
  SetCaretBlinkTime@4 @541
  SetCaretPos@8 @542
  SetClassLongA@12 @543
  SetClassLongPtrA@12 @544
  SetClassLongPtrW@12 @545
  SetClassLongW@12 @546
  SetClassWord@12 @547
  SetClipboardData@8 @548
  SetClipboardViewer@4 @549
  SetCursor@4 @550
  SetCursorPos@8 @552
  SetDebugErrorLevel@4 @553
  SetDeskWallPaper@4 @554
  SetDlgItemInt@16 @555
  SetDlgItemTextA@12 @556
  SetDlgItemTextW@12 @557
  SetDoubleClickTime@4 @558
  SetFocus@4 @559
  SetForegroundWindow@4 @560
  SetInternalWindowPos@16 @561
  SetKeyboardState@4 @562
  SetLastErrorEx@8 @563
  SetLayeredWindowAttributes@16 @564
  SetLogonNotifyWindow@8 @565
  SetMenu@8 @566
  SetMenuContextHelpId@8 @567
  SetMenuDefaultItem@12 @568
  SetMenuInfo@8 @569
  SetMenuItemBitmaps@20 @570
  SetMenuItemInfoA@16 @571
  SetMenuItemInfoW@16 @572
  SetMessageExtraInfo@4 @573
  SetMessageQueue@4 @574
  SetParent@8 @575
  SetProcessDefaultLayout@4 @576
  SetProcessWindowStation@4 @577
  SetProgmanWindow@4 @578
  SetPropA@12 @579
  SetPropW@12 @580
  SetRect@20 @581
  SetRectEmpty@4 @582
  SetScrollInfo@16 @583
  SetScrollPos@16 @584
  SetScrollRange@20 @585
  SetShellWindow@4 @586
  SetShellWindowEx@8 @587
  SetSysColors@12 @588
  SetSysColorsTemp@12 @589
  SetSystemCursor@8 @590
  SetSystemMenu@8 @591
  SetSystemTimer@16 @592
  SetTaskmanWindow@4 @593
  SetThreadDesktop@4 @594
  SetTimer@16 @595
  SetUserObjectInformationA@16 @596
  SetUserObjectInformationW@16 @597
  SetUserObjectSecurity@12 @598
  SetWinEventHook@28 @599
  SetWindowContextHelpId@8 @600
  SetWindowLongA@12 @602
  SetWindowLongPtrA@12 @603
  SetWindowLongPtrW@12 @604
  SetWindowLongW@12 @605
  SetWindowPlacement@8 @606
  SetWindowPos@28 @607
  SetWindowRgn@12 @608
  SetWindowStationUser@8 @609
  SetWindowText@8=SetWindowTextA@8 @610
  SetWindowTextA@8 @611
  SetWindowTextW@8 @612
  SetWindowWord@12 @613
  SetWindowsHookA@8 @614
  SetWindowsHookExA@16 @615
  SetWindowsHookExW@16 @616
  SetWindowsHookW@8 @617
  ShowCaret@4 @618
  ShowCursor@4 @619
  ShowOwnedPopups@8 @620
  ShowScrollBar@12 @621
  ShowWindow@8 @623
  ShowWindowAsync@8 @624
  SubtractRect@12 @625
  SwapMouseButton@4 @626
  SwitchDesktop@4 @627
  SwitchToThisWindow@8 @628
  SystemParametersInfoA@16 @629
  SystemParametersInfoW@16 @630
  TabbedTextOutA@32 @631
  TabbedTextOutW@32 @632
  TileWindows@20 @634
  ToAscii@20 @635
  ToAsciiEx@24 @636
  ToUnicode@24 @637
  ToUnicodeEx@28 @638
  TrackMouseEvent@4 @639
  TrackPopupMenu@28 @640
  TrackPopupMenuEx@24 @641
  TranslateAccelerator@12=TranslateAcceleratorA@12 @642
  TranslateAcceleratorA@12 @643
  TranslateAcceleratorW@12 @644
  TranslateMDISysAccel@8 @645
  TranslateMessage@4 @646
  UnhookWinEvent@4 @647
  UnhookWindowsHook@8 @648
  UnhookWindowsHookEx@4 @649
  UnionRect@12 @650
  UnloadKeyboardLayout@4 @651
  UnpackDDElParam@16 @653
  UnregisterClassA@8 @654
  UnregisterClassW@8 @655
  UnregisterDeviceNotification@4 @656
  UnregisterHotKey@8 @657
  UpdateLayeredWindow@36 @658
  UpdateWindow@4 @660
  User32InitializeImmEntryTable@4 @661
  UserClientDllInitialize@12=DllMain@12 @662
  UserRealizePalette@4 @664
  UserSignalProc@16 @666
  ValidateRect@8 @667
  ValidateRgn@8 @668
  VkKeyScanA@4 @669
  VkKeyScanExA@8 @670
  VkKeyScanExW@8 @671
  VkKeyScanW@4 @672
  WINNLSEnableIME@8 @674
  WINNLSGetEnableStatus@4 @675
  WINNLSGetIMEHotkey@4 @676
  WaitForInputIdle@8 @678
  WaitMessage@0 @679
  WinHelpA@16 @680
  WinHelpW@16 @681
  WindowFromDC@4 @682
  WindowFromPoint@8 @683
  keybd_event@16 @684
  mouse_event@20 @685
  wsprintfA @686
  wsprintfW @687
  wvsprintfA@12 @688
  wvsprintfW@12 @689
  CallWindowProc16@20 @690
  CloseDriver16@12 @691
  CreateDialogIndirectParam16@20 @692
  DefDriverProc16@20 @693
  DefWindowProc16@16 @694
  DestroyIcon32@8 @695
  DialogBoxIndirectParam16@20 @696
  GetDriverModuleHandle16@4 @697
  OpenDriver16@12 @698
  SendDriverMessage16@16 @699
  UserYield16@0 @700
  HOOK_CallHooks @701
  USER_Unlock @702
  WINPOS_ActivateOtherWindow @703
  WINPOS_GetMinMaxInfo @704
  WINPOS_ShowIconTitle @705
  WIN_GetPtr @706
  WIN_SetStyle @707
