; File generated automatically from ./msvcrt.spec; do not edit!

LIBRARY msvcrt.dll

EXPORTS
  $I10_OUTPUT=MSVCRT_I10_OUTPUT @1
  ??0__non_rtti_object@@QAE@ABV0@@Z=__thiscall_MSVCRT___non_rtti_object_copy_ctor @2
  ??0__non_rtti_object@@QAE@PBD@Z=__thiscall_MSVCRT___non_rtti_object_ctor @3
  ??0bad_cast@@QAE@ABQBD@Z=__thiscall_MSVCRT_bad_cast_ctor @4
  ??0bad_cast@@QAE@ABV0@@Z=__thiscall_MSVCRT_bad_cast_copy_ctor @5
  ??0bad_typeid@@QAE@ABV0@@Z=__thiscall_MSVCRT_bad_typeid_copy_ctor @6
  ??0bad_typeid@@QAE@PBD@Z=__thiscall_MSVCRT_bad_typeid_ctor @7
  ??0exception@@QAE@ABQBD@Z=__thiscall_MSVCRT_exception_ctor @8
  ??0exception@@QAE@ABV0@@Z=__thiscall_MSVCRT_exception_copy_ctor @9
  ??0exception@@QAE@XZ=__thiscall_MSVCRT_exception_default_ctor @10
  ??1__non_rtti_object@@UAE@XZ=__thiscall_MSVCRT___non_rtti_object_dtor @11
  ??1bad_cast@@UAE@XZ=__thiscall_MSVCRT_bad_cast_dtor @12
  ??1bad_typeid@@UAE@XZ=__thiscall_MSVCRT_bad_typeid_dtor @13
  ??1exception@@UAE@XZ=__thiscall_MSVCRT_exception_dtor @14
  ??1type_info@@UAE@XZ=__thiscall_MSVCRT_type_info_dtor @15
  ??2@YAPAXI@Z=MSVCRT_operator_new @16
  ??_U@YAPAXI@Z=MSVCRT_operator_new @17
  ??3@YAXPAX@Z=MSVCRT_operator_delete @18
  ??_V@YAXPAX@Z=MSVCRT_operator_delete @19
  ??4__non_rtti_object@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT___non_rtti_object_opequals @20
  ??4bad_cast@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_bad_cast_opequals @21
  ??4bad_typeid@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_bad_typeid_opequals @22
  ??4exception@@QAEAAV0@ABV0@@Z=__thiscall_MSVCRT_exception_opequals @23
  ??8type_info@@QBEHABV0@@Z=__thiscall_MSVCRT_type_info_opequals_equals @24
  ??9type_info@@QBEHABV0@@Z=__thiscall_MSVCRT_type_info_opnot_equals @25
  ??_7__non_rtti_object@@6B@=MSVCRT___non_rtti_object_vtable @26 DATA
  ??_7bad_cast@@6B@=MSVCRT_bad_cast_vtable @27 DATA
  ??_7bad_typeid@@6B@=MSVCRT_bad_typeid_vtable @28 DATA
  ??_7exception@@6B@=MSVCRT_exception_vtable @29 DATA
  ??_E__non_rtti_object@@UAEPAXI@Z=__thiscall_MSVCRT___non_rtti_object_vector_dtor @30
  ??_Ebad_cast@@UAEPAXI@Z=__thiscall_MSVCRT_bad_cast_vector_dtor @31
  ??_Ebad_typeid@@UAEPAXI@Z=__thiscall_MSVCRT_bad_typeid_vector_dtor @32
  ??_Eexception@@UAEPAXI@Z=__thiscall_MSVCRT_exception_vector_dtor @33
  ??_G__non_rtti_object@@UAEPAXI@Z=__thiscall_MSVCRT___non_rtti_object_scalar_dtor @34
  ??_Gbad_cast@@UAEPAXI@Z=__thiscall_MSVCRT_bad_cast_scalar_dtor @35
  ??_Gbad_typeid@@UAEPAXI@Z=__thiscall_MSVCRT_bad_typeid_scalar_dtor @36
  ??_Gexception@@UAEPAXI@Z=__thiscall_MSVCRT_exception_scalar_dtor @37
  ?_query_new_handler@@YAP6AHI@ZXZ=MSVCRT__query_new_handler @38
  ?_query_new_mode@@YAHXZ=MSVCRT__query_new_mode @39
  ?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z=MSVCRT__set_new_handler @40
  ?_set_new_mode@@YAHH@Z=MSVCRT__set_new_mode @41
  ?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z=MSVCRT__set_se_translator @42
  ?before@type_info@@QBEHABV1@@Z=__thiscall_MSVCRT_type_info_before @43
  ?name@type_info@@QBEPBDXZ=__thiscall_MSVCRT_type_info_name @44
  ?raw_name@type_info@@QBEPBDXZ=__thiscall_MSVCRT_type_info_raw_name @45
  ?set_new_handler@@YAP6AXXZP6AXXZ@Z=MSVCRT__set_new_handler @46
  ?set_terminate@@YAP6AXXZP6AXXZ@Z=MSVCRT_set_terminate @47
  ?set_unexpected@@YAP6AXXZP6AXXZ@Z=MSVCRT_set_unexpected @48
  ?terminate@@YAXXZ=MSVCRT_terminate @49
  ?unexpected@@YAXXZ=MSVCRT_unexpected @50
  ?what@exception@@UBEPBDXZ=__thiscall_MSVCRT_what_exception @51
  _CIacos @52
  _CIasin @53
  _CIatan @54
  _CIatan2 @55
  _CIcos @56
  _CIcosh @57
  _CIexp @58
  _CIfmod @59
  _CIlog @60
  _CIlog10 @61
  _CIpow @62
  _CIsin @63
  _CIsinh @64
  _CIsqrt @65
  _CItan @66
  _CItanh @67
  _CxxThrowException @68
  _EH_prolog @69
  _Getdays @70
  _Getmonths @71
  _Gettnames @72
  _HUGE=MSVCRT__HUGE @73 DATA
  _Strftime @74
  _XcptFilter @75
  __CxxFrameHandler @76
  __CxxLongjmpUnwind@4 @77
  __RTCastToVoid=MSVCRT___RTCastToVoid @78
  __RTDynamicCast=MSVCRT___RTDynamicCast @79
  __RTtypeid=MSVCRT___RTtypeid @80
  __argc=MSVCRT___argc @82 DATA
  __argv=MSVCRT___argv @83 DATA
  __badioinfo=MSVCRT___badioinfo @84 DATA
  __crtLCMapStringA @87
  __dllonexit @88
  __doserrno=MSVCRT___doserrno @89
  __fpecode @90
  __getmainargs @92
  __initenv=MSVCRT___initenv @93 DATA
  __isascii=MSVCRT___isascii @94
  __iscsym=MSVCRT___iscsym @95
  __iscsymf=MSVCRT___iscsymf @96
  __lc_codepage=MSVCRT___lc_codepage @97 DATA
  __lc_collate_cp=MSVCRT___lc_collate_cp @99 DATA
  __lc_handle=MSVCRT___lc_handle @100 DATA
  __lconv_init @101
  __mb_cur_max=MSVCRT___mb_cur_max @102 DATA
  __p___argc @103
  __p___argv @104
  __p___initenv @105
  __p___mb_cur_max @106
  __p___wargv @107
  __p___winitenv @108
  __p__acmdln @109
  __p__amblksiz @110
  __p__commode @111
  __p__daylight=MSVCRT___p__daylight @112
  __p__dstbias @113
  __p__environ @114
  __p__fmode @116
  __p__iob @117
  __p__mbctype @119
  __p__osver @120
  __p__pctype @121
  __p__pgmptr @122
  __p__timezone=MSVCRT___p__timezone @124
  __p__tzname @125
  __p__wcmdln @126
  __p__wenviron @127
  __p__winmajor @128
  __p__winminor @129
  __p__winver @130
  __p__wpgmptr @131
  __pioinfo=MSVCRT___pioinfo @132 DATA
  __set_app_type=MSVCRT___set_app_type @134
  __setlc_active=MSVCRT___setlc_active @135 DATA
  __setusermatherr=MSVCRT___setusermatherr @136
  __threadhandle=kernel32.GetCurrentThread @137
  __threadid=kernel32.GetCurrentThreadId @138
  __toascii=MSVCRT___toascii @139
  __unDName @140
  __unDNameEx @141
  __unguarded_readlc_active=MSVCRT___unguarded_readlc_active @142 DATA
  __wargv=MSVCRT___wargv @143 DATA
  __wgetmainargs @144
  __winitenv=MSVCRT___winitenv @145 DATA
  _abnormal_termination @146
  _access @147
  _acmdln=MSVCRT__acmdln @148 DATA
  _adj_fdiv_m16i@4 @149
  _adj_fdiv_m32@4 @150
  _adj_fdiv_m32i@4 @151
  _adj_fdiv_m64@8 @152
  _adj_fdiv_r @153
  _adj_fdivr_m16i@4 @154
  _adj_fdivr_m32@4 @155
  _adj_fdivr_m32i@4 @156
  _adj_fdivr_m64@8 @157
  _adj_fpatan @158
  _adj_fprem @159
  _adj_fprem1 @160
  _adj_fptan @161
  _adjust_fdiv=MSVCRT__adjust_fdiv @162 DATA
  _amsg_exit @163
  _assert=MSVCRT__assert @164
  _atoi64=ntdll._atoi64 @166
  _atoldbl=MSVCRT__atoldbl @167
  _beep @168
  _beginthread @169
  _beginthreadex @170
  _c_exit=MSVCRT__c_exit @171
  _cabs=MSVCRT__cabs @172
  _callnewh @173
  _cexit=MSVCRT__cexit @174
  _cgets @175
  _chdir @176
  _chdrive @177
  _chgsign @178
  _chkesp @179
  _chmod @180
  _chsize @181
  _clearfp @182
  _close @183
  _commit @184
  _commode=MSVCRT__commode @185 DATA
  _control87 @186
  _controlfp @187
  _copysign @188
  _cprintf @189
  _cputs @190
  _creat @191
  _cscanf @192
  _ctype=MSVCRT__ctype @193 DATA
  _cwait @194
  _daylight=MSVCRT___daylight @195 DATA
  _dstbias=MSVCRT__dstbias @196 DATA
  _dup @197
  _dup2 @198
  _ecvt @199
  _endthread @200
  _endthreadex @201
  _environ @202 DATA
  _eof @203
  _errno=MSVCRT__errno @204
  _except_handler2 @205
  _except_handler3 @206
  _execl @207
  _execle @208
  _execlp @209
  _execlpe @210
  _execv @211
  _execve=MSVCRT__execve @212
  _execvp @213
  _execvpe @214
  _exit=MSVCRT__exit @215
  _expand @216
  _fcloseall=MSVCRT__fcloseall @217
  _fcvt @218
  _fdopen=MSVCRT__fdopen @219
  _fgetchar @220
  _fgetwchar @221
  _filbuf=MSVCRT__filbuf @222
  _filelength @223
  _filelengthi64 @224
  _fileno=MSVCRT__fileno @225
  _findclose=MSVCRT__findclose @226
  _findfirst=MSVCRT__findfirst @227
  _findfirsti64=MSVCRT__findfirsti64 @228
  _findnext=MSVCRT__findnext @229
  _findnexti64=MSVCRT__findnexti64 @230
  _finite @231
  _flsbuf=MSVCRT__flsbuf @232
  _flushall @233
  _fmode=MSVCRT__fmode @234 DATA
  _fpclass @235
  _fpreset @237
  _fputchar @238
  _fputwchar @239
  _fsopen=MSVCRT__fsopen @240
  _fstat=MSVCRT__fstat @241
  _fstat64=MSVCRT__fstat64 @242
  _fstati64=MSVCRT__fstati64 @243
  _ftime @244
  _ftol=ntdll._ftol @245
  _fullpath @246
  _futime @247
  _gcvt @248
  _get_osfhandle @249
  _get_sbh_threshold @250
  _getch @253
  _getche @254
  _getcwd @255
  _getdcwd @256
  _getdiskfree=MSVCRT__getdiskfree @257
  _getdllprocaddr @258
  _getdrive @259
  _getdrives=kernel32.GetLogicalDrives @260
  _getmaxstdio @261
  _getmbcp @262
  _getpid=kernel32.GetCurrentProcessId @263
  _getw=MSVCRT__getw @265
  _getws=MSVCRT__getws @266
  _global_unwind2 @267
  _heapadd @268
  _heapchk @269
  _heapmin @270
  _heapset @271
  _heapwalk @273
  _hypot @274
  _i64toa=ntdll._i64toa @275
  _i64tow=ntdll._i64tow @276
  _initterm @277
  _iob=MSVCRT__iob @281 DATA
  _isatty @282
  _isctype @283
  _ismbbkana @288
  _ismbblead @291
  _ismbbtrail @294
  _ismbcalnum @295
  _ismbcalpha @296
  _ismbcdigit @297
  _ismbcgraph @298
  _ismbchira @299
  _ismbckata @300
  _ismbclower @305
  _ismbcprint @306
  _ismbcpunct @307
  _ismbcspace @308
  _ismbcsymbol @309
  _ismbcupper @310
  _ismbslead @311
  _ismbstrail @312
  _isnan @313
  _itoa=ntdll._itoa @314
  _itow=ntdll._itow @315
  _j0 @316
  _j1 @317
  _jn @318
  _kbhit @319
  _lfind @320
  _loaddll @321
  _local_unwind2 @322
  _lock @323
  _locking @324
  _logb @325
  _longjmpex=MSVCRT_longjmp @326
  _lrotl @327
  _lrotr @328
  _lsearch @329
  _lseek @330
  _lseeki64 @331
  _ltoa=ntdll._ltoa @332
  _ltow=ntdll._ltow @333
  _makepath @334
  _matherr=MSVCRT__matherr @335
  _mbbtombc @336
  _mbbtype @337
  _mbccpy @338
  _mbclen @341
  _mbctolower @344
  _mbctoupper @346
  _mbctype=MSVCRT_mbctype @347 DATA
  _mbscat @349
  _mbschr @350
  _mbscmp @351
  _mbscoll @352
  _mbscpy @353
  _mbscspn @354
  _mbsdec @355
  _mbsdup=_strdup @356
  _mbsicmp @357
  _mbsicoll @358
  _mbsinc @359
  _mbslen @360
  _mbslwr @361
  _mbsnbcat @362
  _mbsnbcmp @363
  _mbsnbcnt @364
  _mbsnbcpy @366
  _mbsnbicmp @367
  _mbsnbset @369
  _mbsncat @370
  _mbsnccnt @371
  _mbsncmp @372
  _mbsncpy @374
  _mbsnextc @375
  _mbsnicmp @376
  _mbsninc @378
  _mbsnset @379
  _mbspbrk @380
  _mbsrchr @381
  _mbsrev @382
  _mbsset @383
  _mbsspn @384
  _mbsspnp @385
  _mbsstr @386
  _mbstok @387
  _mbstrlen @388
  _mbsupr @389
  _memccpy=ntdll._memccpy @390
  _memicmp=ntdll._memicmp @391
  _mkdir @392
  _mktemp @393
  _msize @394
  _nextafter @395
  _onexit=MSVCRT__onexit @396
  _open @397
  _open_osfhandle @398
  _osver=MSVCRT__osver @399 DATA
  _pclose=MSVCRT__pclose @403
  _pctype=MSVCRT__pctype @404 DATA
  _pgmptr=MSVCRT__pgmptr @405 DATA
  _pipe @406
  _popen=MSVCRT__popen @407
  _purecall @408
  _putch @409
  _putenv @410
  _putw=MSVCRT__putw @411
  _putws @412
  _read @413
  _rmdir @414
  _rmtmp @415
  _rotl @416
  _rotr @417
  _safe_fdiv @418
  _safe_fdivr @419
  _safe_fprem @420
  _safe_fprem1 @421
  _scalb @422
  _searchenv @423
  _seh_longjmp_unwind@4 @424
  _set_error_mode @425
  _set_sbh_threshold @426
  _seterrormode @427
  _setjmp=MSVCRT__setjmp @428
  _setjmp3=MSVCRT__setjmp3 @429
  _setmaxstdio @430
  _setmbcp @431
  _setmode @432
  _sleep @434
  _snprintf=MSVCRT__snprintf @435
  _snwprintf=MSVCRT__snwprintf @436
  _sopen=MSVCRT__sopen @437
  _spawnl @438
  _spawnle @439
  _spawnlp @440
  _spawnlpe @441
  _spawnv @442
  _spawnve @443
  _spawnvp @444
  _spawnvpe @445
  _splitpath=ntdll._splitpath @446
  _stat=MSVCRT__stat @447
  _stat64=MSVCRT__stat64 @448
  _stati64=MSVCRT__stati64 @449
  _statusfp @450
  _strcmpi=ntdll._strcmpi @451
  _strdate @452
  _strdup @453
  _strerror @454
  _stricmp=ntdll._stricmp @455
  _stricoll=MSVCRT__stricoll @456
  _strlwr=ntdll._strlwr @457
  _strnicmp=ntdll._strnicmp @459
  _strnset @461
  _strrev @462
  _strset @463
  _strtime @464
  _strupr=ntdll._strupr @465
  _swab=MSVCRT__swab @466
  _sys_errlist=MSVCRT__sys_errlist @467 DATA
  _sys_nerr=MSVCRT__sys_nerr @468 DATA
  _tell @469
  _telli64 @470
  _tempnam @471
  _timezone=MSVCRT___timezone @472 DATA
  _tolower=MSVCRT__tolower @473
  _toupper=MSVCRT__toupper @474
  _tzname=MSVCRT__tzname @475 DATA
  _tzset=MSVCRT__tzset @476
  _ui64toa=ntdll._ui64toa @477
  _ui64tow=ntdll._ui64tow @478
  _ultoa=ntdll._ultoa @479
  _ultow=ntdll._ultow @480
  _umask @481
  _ungetch @482
  _unlink @483
  _unloaddll @484
  _unlock @485
  _utime @486
  _vsnprintf=MSVCRT_vsnprintf @487
  _vsnwprintf=MSVCRT_vsnwprintf @488
  _waccess @489
  _wasctime=MSVCRT__wasctime @490
  _wchdir @491
  _wchmod @492
  _wcmdln=MSVCRT__wcmdln @493 DATA
  _wcreat @494
  _wcsdup @495
  _wcsicmp=ntdll._wcsicmp @496
  _wcsicoll @497
  _wcslwr=ntdll._wcslwr @498
  _wcsnicmp=ntdll._wcsnicmp @500
  _wcsnset @502
  _wcsrev @503
  _wcsset @504
  _wcsupr=ntdll._wcsupr @505
  _wctime=MSVCRT__wctime @506
  _wenviron @507 DATA
  _wfdopen=MSVCRT__wfdopen @516
  _wfindfirst=MSVCRT__wfindfirst @517
  _wfindfirsti64=MSVCRT__wfindfirsti64 @518
  _wfindnext=MSVCRT__wfindnext @519
  _wfindnexti64=MSVCRT__wfindnexti64 @520
  _wfopen=MSVCRT__wfopen @521
  _wfsopen=MSVCRT__wfsopen @523
  _wfullpath @524
  _wgetcwd @525
  _wgetdcwd @526
  _wgetenv @527
  _winmajor=MSVCRT__winmajor @528 DATA
  _winminor=MSVCRT__winminor @529 DATA
  _winver=MSVCRT__winver @530 DATA
  _wmakepath @531
  _wmkdir @532
  _wmktemp @533
  _wopen @534
  _wpgmptr=MSVCRT__wpgmptr @536 DATA
  _wpopen=MSVCRT__wpopen @537
  _wputenv @538
  _wremove @539
  _wrename @540
  _write @541
  _wrmdir @542
  _wsetlocale=MSVCRT__wsetlocale @544
  _wsopen=MSVCRT__wsopen @545
  _wsplitpath @554
  _wstat=MSVCRT__wstat @555
  _wstati64=MSVCRT__wstati64 @556
  _wstat64=MSVCRT__wstat64 @557
  _wstrdate @558
  _wstrtime @559
  _wtempnam @561
  _wtoi=ntdll._wtoi @563
  _wtoi64=ntdll._wtoi64 @564
  _wtol=ntdll._wtol @565
  _wunlink @566
  _wutime @567
  _y0 @568
  _y1 @569
  _yn @570
  abort=MSVCRT_abort @571
  abs=ntdll.abs @572
  acos=MSVCRT_acos @573
  asctime=MSVCRT_asctime @574
  asin=MSVCRT_asin @575
  atan=MSVCRT_atan @576
  atan2=MSVCRT_atan2 @577
  atexit=MSVCRT_atexit @578
  atof=MSVCRT_atof @579
  atoi=ntdll.atoi @580
  atol=ntdll.atol @581
  bsearch=ntdll.bsearch @582
  calloc=MSVCRT_calloc @583
  ceil=MSVCRT_ceil @584
  clearerr=MSVCRT_clearerr @585
  clock=MSVCRT_clock @586
  cos=MSVCRT_cos @587
  cosh=MSVCRT_cosh @588
  ctime=MSVCRT_ctime @589
  difftime=MSVCRT_difftime @590
  div=MSVCRT_div @591
  exit=MSVCRT_exit @592
  exp=MSVCRT_exp @593
  fabs=MSVCRT_fabs @594
  fclose=MSVCRT_fclose @595
  feof=MSVCRT_feof @596
  ferror=MSVCRT_ferror @597
  fflush=MSVCRT_fflush @598
  fgetc=MSVCRT_fgetc @599
  fgetpos=MSVCRT_fgetpos @600
  fgets=MSVCRT_fgets @601
  fgetwc=MSVCRT_fgetwc @602
  fgetws=MSVCRT_fgetws @603
  floor=MSVCRT_floor @604
  fmod=MSVCRT_fmod @605
  fopen=MSVCRT_fopen @606
  fprintf=MSVCRT_fprintf @607
  fputc=MSVCRT_fputc @608
  fputs=MSVCRT_fputs @609
  fputwc=MSVCRT_fputwc @610
  fputws=MSVCRT_fputws @611
  fread=MSVCRT_fread @612
  free=MSVCRT_free @613
  freopen=MSVCRT_freopen @614
  frexp=MSVCRT_frexp @615
  fscanf=MSVCRT_fscanf @616
  fseek=MSVCRT_fseek @617
  fsetpos=MSVCRT_fsetpos @618
  ftell=MSVCRT_ftell @619
  fwprintf=MSVCRT_fwprintf @620
  fwrite=MSVCRT_fwrite @621
  fwscanf=MSVCRT_fwscanf @622
  getc=MSVCRT_getc @623
  getchar=MSVCRT_getchar @624
  getenv=MSVCRT_getenv @625
  gets=MSVCRT_gets @626
  getwc=MSVCRT_getwc @627
  getwchar=MSVCRT_getwchar @628
  gmtime=MSVCRT_gmtime @629
  is_wctype=ntdll.iswctype @630
  isalnum=MSVCRT_isalnum @631
  isalpha=MSVCRT_isalpha @632
  iscntrl=MSVCRT_iscntrl @633
  isdigit=MSVCRT_isdigit @634
  isgraph=MSVCRT_isgraph @635
  isleadbyte=MSVCRT_isleadbyte @636
  islower=MSVCRT_islower @637
  isprint=MSVCRT_isprint @638
  ispunct=MSVCRT_ispunct @639
  isspace=MSVCRT_isspace @640
  isupper=MSVCRT_isupper @641
  iswalnum=MSVCRT_iswalnum @642
  iswalpha=ntdll.iswalpha @643
  iswascii=MSVCRT_iswascii @644
  iswcntrl=MSVCRT_iswcntrl @645
  iswctype=ntdll.iswctype @646
  iswdigit=MSVCRT_iswdigit @647
  iswgraph=MSVCRT_iswgraph @648
  iswlower=MSVCRT_iswlower @649
  iswprint=MSVCRT_iswprint @650
  iswpunct=MSVCRT_iswpunct @651
  iswspace=MSVCRT_iswspace @652
  iswupper=MSVCRT_iswupper @653
  iswxdigit=MSVCRT_iswxdigit @654
  isxdigit=MSVCRT_isxdigit @655
  labs=ntdll.labs @656
  ldexp=MSVCRT_ldexp @657
  ldiv=MSVCRT_ldiv @658
  localeconv=MSVCRT_localeconv @659
  localtime=MSVCRT_localtime @660
  log=MSVCRT_log @661
  log10=MSVCRT_log10 @662
  longjmp=MSVCRT_longjmp @663
  malloc=MSVCRT_malloc @664
  mblen=MSVCRT_mblen @665
  mbstowcs=ntdll.mbstowcs @666
  mbtowc=MSVCRT_mbtowc @667
  memchr=ntdll.memchr @668
  memcmp=ntdll.memcmp @669
  memcpy=ntdll.memcpy @670
  memmove=ntdll.memmove @671
  memset=ntdll.memset @672
  mktime=MSVCRT_mktime @673
  modf=MSVCRT_modf @674
  perror=MSVCRT_perror @675
  pow=MSVCRT_pow @676
  printf=MSVCRT_printf @677
  putc=MSVCRT_putc @678
  putchar=MSVCRT_putchar @679
  puts=MSVCRT_puts @680
  putwc=MSVCRT_fputwc @681
  putwchar=_fputwchar @682
  qsort=ntdll.qsort @683
  raise=MSVCRT_raise @684
  rand=MSVCRT_rand @685
  realloc=MSVCRT_realloc @686
  remove=MSVCRT_remove @687
  rename=MSVCRT_rename @688
  rewind=MSVCRT_rewind @689
  scanf=MSVCRT_scanf @690
  setbuf=MSVCRT_setbuf @691
  setlocale=MSVCRT_setlocale @692
  setvbuf=MSVCRT_setvbuf @693
  signal=MSVCRT_signal @694
  sin=MSVCRT_sin @695
  sinh=MSVCRT_sinh @696
  sprintf=MSVCRT_sprintf @697
  sqrt=MSVCRT_sqrt @698
  srand=MSVCRT_srand @699
  sscanf=MSVCRT_sscanf @700
  strcat=ntdll.strcat @701
  strchr=ntdll.strchr @702
  strcmp=ntdll.strcmp @703
  strcoll=MSVCRT_strcoll @704
  strcpy=ntdll.strcpy @705
  strcspn=ntdll.strcspn @706
  strerror=MSVCRT_strerror @707
  strftime=MSVCRT_strftime @708
  strlen=ntdll.strlen @709
  strncat=ntdll.strncat @710
  strncmp=ntdll.strncmp @711
  strncpy=ntdll.strncpy @712
  strpbrk=ntdll.strpbrk @713
  strrchr=ntdll.strrchr @714
  strspn=ntdll.strspn @715
  strstr=ntdll.strstr @716
  strtod=MSVCRT_strtod @717
  strtok=MSVCRT_strtok @718
  strtol=ntdll.strtol @719
  strtoul=ntdll.strtoul @720
  strxfrm=MSVCRT_strxfrm @721
  swprintf=MSVCRT_swprintf @722
  swscanf=MSVCRT_swscanf @723
  system=MSVCRT_system @724
  tan=MSVCRT_tan @725
  tanh=MSVCRT_tanh @726
  time=MSVCRT_time @727
  tmpfile=MSVCRT_tmpfile @728
  tmpnam=MSVCRT_tmpnam @729
  tolower=ntdll.tolower @730
  toupper=ntdll.toupper @731
  towlower=ntdll.towlower @732
  towupper=ntdll.towupper @733
  ungetc=MSVCRT_ungetc @734
  ungetwc=MSVCRT_ungetwc @735
  vfprintf=MSVCRT_vfprintf @736
  vfwprintf=MSVCRT_vfwprintf @737
  vprintf=MSVCRT_vprintf @738
  vsprintf=MSVCRT_vsprintf @739
  vswprintf=MSVCRT_vswprintf @740
  vwprintf=MSVCRT_vwprintf @741
  wcscat=ntdll.wcscat @742
  wcschr=ntdll.wcschr @743
  wcscmp=ntdll.wcscmp @744
  wcscoll=MSVCRT_wcscoll @745
  wcscpy=ntdll.wcscpy @746
  wcscspn=ntdll.wcscspn @747
  wcsftime=MSVCRT_wcsftime @748
  wcslen=ntdll.wcslen @749
  wcsncat=ntdll.wcsncat @750
  wcsncmp=ntdll.wcsncmp @751
  wcsncpy=ntdll.wcsncpy @752
  wcspbrk=MSVCRT_wcspbrk @753
  wcsrchr=ntdll.wcsrchr @754
  wcsspn=ntdll.wcsspn @755
  wcsstr=ntdll.wcsstr @756
  wcstod=MSVCRT_wcstod @757
  wcstok=MSVCRT_wcstok @758
  wcstol=ntdll.wcstol @759
  wcstombs=ntdll.wcstombs @760
  wcstoul=ntdll.wcstoul @761
  wctomb=MSVCRT_wctomb @763
  wprintf=MSVCRT_wprintf @764
  wscanf=MSVCRT_wscanf @765
