; File generated automatically from ./url.spec; do not edit!

LIBRARY url.dll

EXPORTS
  FileProtocolHandler@12=FileProtocolHandlerA@12 @7
  FileProtocolHandlerA@12 @8
  InetIsOffline@0 @9
  TelnetProtocolHandler@8=TelnetProtocolHandlerA@8 @18
  TelnetProtocolHandlerA@8 @19
