; File generated automatically from ./msi.spec; do not edit!

LIBRARY msi.dll

EXPORTS
  MsiAdvertiseProductA@16 @5
  MsiAdvertiseProductW@16 @6
  MsiCloseAllHandles@0 @7
  MsiCloseHandle@4 @8
  MsiCollectUserInfoA@4 @9
  MsiCollectUserInfoW@4 @10
  MsiConfigureFeatureA@12 @11
  MsiConfigureFeatureW@12 @14
  MsiConfigureProductA@12 @15
  MsiConfigureProductW@12 @16
  MsiCreateRecord@4 @17
  MsiDatabaseApplyTransformA@12 @18
  MsiDatabaseApplyTransformW@12 @19
  MsiDatabaseCommit@4 @20
  MsiDatabaseExportA@16 @21
  MsiDatabaseExportW@16 @22
  MsiDatabaseGenerateTransformA@20 @23
  MsiDatabaseGenerateTransformW@20 @24
  MsiDatabaseGetPrimaryKeysA@12 @25
  MsiDatabaseGetPrimaryKeysW@12 @26
  MsiDatabaseImportA@12 @27
  MsiDatabaseImportW@12 @28
  MsiDatabaseOpenViewA@12 @31
  MsiDatabaseOpenViewW@12 @32
  MsiDoActionA@8 @33
  MsiDoActionW@8 @34
  MsiEnableUIPreview@8 @35
  MsiEnumClientsA@12 @36
  MsiEnumClientsW@12 @37
  MsiEnumComponentQualifiersA@24 @38
  MsiEnumComponentQualifiersW@24 @39
  MsiEnumComponentsA@8 @40
  MsiEnumComponentsW@8 @41
  MsiEnumFeaturesA@16 @42
  MsiEnumFeaturesW@16 @43
  MsiEnumProductsA@8 @44
  MsiEnumProductsW@8 @45
  MsiEvaluateConditionA@8 @46
  MsiEvaluateConditionW@8 @47
  MsiGetLastErrorRecord@0 @48
  MsiGetActiveDatabase@4 @49
  MsiGetComponentStateA@16 @50
  MsiGetComponentStateW@16 @51
  MsiGetDatabaseState@4 @52
  MsiGetFeatureCostA@20 @53
  MsiGetFeatureCostW@20 @54
  MsiGetFeatureStateA@16 @57
  MsiGetFeatureStateW@16 @58
  MsiGetFeatureUsageA@16 @59
  MsiGetFeatureUsageW@16 @60
  MsiGetFeatureValidStatesA@12 @61
  MsiGetFeatureValidStatesW@12 @62
  MsiGetLanguage@4 @63
  MsiGetMode@8 @64
  MsiGetProductCodeA@8 @65
  MsiGetProductCodeW@8 @66
  MsiGetProductInfoA@16 @67
  MsiGetProductInfoW@16 @70
  MsiGetProductPropertyA@16 @71
  MsiGetProductPropertyW@16 @72
  MsiGetPropertyA@16 @73
  MsiGetPropertyW@16 @74
  MsiGetSourcePathA@16 @75
  MsiGetSourcePathW@16 @76
  MsiGetSummaryInformationA@16 @77
  MsiGetSummaryInformationW@16 @78
  MsiGetTargetPathA@16 @79
  MsiGetTargetPathW@16 @80
  MsiGetUserInfoA@28 @81
  MsiGetUserInfoW@28 @82
  MsiInstallProductA@8 @87
  MsiInstallProductW@8 @88
  MsiLocateComponentA@12 @89
  MsiLocateComponentW@12 @90
  MsiOpenDatabaseA@12 @91
  MsiOpenDatabaseW@12 @92
  MsiOpenPackageA@8 @93
  MsiOpenPackageW@8 @94
  MsiOpenProductA@8 @95
  MsiOpenProductW@8 @96
  MsiPreviewBillboardA@12 @97
  MsiPreviewBillboardW@12 @98
  MsiPreviewDialogA@8 @99
  MsiPreviewDialogW@8 @100
  MsiProcessMessage@12 @103
  MsiProvideComponentFromDescriptorA@16 @105
  MsiProvideComponentFromDescriptorW@16 @106
  MsiProvideQualifiedComponentA@20 @108
  MsiProvideQualifiedComponentW@20 @109
  MsiQueryFeatureStateA@8 @110
  MsiQueryFeatureStateW@8 @111
  MsiQueryProductStateA@4 @112
  MsiQueryProductStateW@4 @113
  MsiRecordDataSize@8 @114
  MsiRecordGetFieldCount@4 @115
  MsiRecordGetInteger@8 @116
  MsiRecordGetStringA@16 @117
  MsiRecordGetStringW@16 @118
  MsiRecordIsNull@8 @119
  MsiRecordReadStream@16 @120
  MsiRecordSetInteger@12 @121
  MsiRecordSetStreamA@12 @122
  MsiRecordSetStreamW@12 @123
  MsiRecordSetStringA@12 @124
  MsiRecordSetStringW@12 @125
  MsiReinstallFeatureA@12 @126
  MsiReinstallFeatureW@12 @129
  MsiReinstallProductA@8 @130
  MsiReinstallProductW@8 @131
  MsiSequenceA@12 @132
  MsiSequenceW@12 @133
  MsiSetComponentStateA@12 @134
  MsiSetComponentStateW@12 @135
  MsiSetExternalUIA@12 @136
  MsiSetExternalUIW@12 @137
  MsiSetFeatureStateA@12 @138
  MsiSetFeatureStateW@12 @139
  MsiSetInstallLevel@8 @140
  MsiSetInternalUI@8 @141
  MsiSetMode@12 @143
  MsiSetPropertyA@12 @144
  MsiSetPropertyW@12 @145
  MsiSetTargetPathA@12 @146
  MsiSetTargetPathW@12 @147
  MsiSummaryInfoGetPropertyA@28 @148
  MsiSummaryInfoGetPropertyCount@8 @149
  MsiSummaryInfoGetPropertyW@28 @150
  MsiSummaryInfoPersist@4 @151
  MsiSummaryInfoSetPropertyA@24 @152
  MsiSummaryInfoSetPropertyW@24 @153
  MsiUseFeatureA@8 @154
  MsiUseFeatureW@8 @155
  MsiVerifyPackageA@4 @156
  MsiVerifyPackageW@4 @157
  MsiViewClose@4 @158
  MsiViewExecute@8 @159
  MsiViewFetch@8 @160
  MsiViewGetErrorA@12 @161
  MsiViewGetErrorW@12 @162
  MsiViewModify@12 @163
  MsiDatabaseIsTablePersistentA@8 @164
  MsiDatabaseIsTablePersistentW@8 @165
  MsiViewGetColumnInfo@12 @166
  MsiRecordClearData@4 @167
  MsiEnableLogA@12 @168
  MsiEnableLogW@12 @169
  MsiFormatRecordA@16 @170
  MsiFormatRecordW@16 @171
  MsiGetComponentPathA@16 @172
  MsiGetComponentPathW@16 @173
  MsiApplyPatchA@16 @174
  MsiApplyPatchW@16 @175
  MsiAdvertiseScriptA@16 @176
  MsiAdvertiseScriptW@16 @177
  MsiEnumPatchesA@20 @180
  MsiEnumPatchesW@20 @181
  DllGetVersion@4 @182 PRIVATE
  MsiConfigureProductExA@16 @189
  MsiConfigureProductExW@16 @190
  MsiUseFeatureExA@16 @192
  MsiUseFeatureExW@16 @193
  MsiGetFileVersionA@20 @194
  MsiGetFileVersionW@20 @195
  MsiLoadStringA@20 @196
  MsiLoadStringW@20 @197
  MsiMessageBoxA@24 @198
  MsiMessageBoxW@24 @199
  MsiDecomposeDescriptorA@20 @200
  MsiDecomposeDescriptorW@20 @201
  MsiProvideQualifiedComponentExA@32 @202
  MsiProvideQualifiedComponentExW@32 @203
  MsiEnumRelatedProductsA@16 @204
  MsiEnumRelatedProductsW@16 @205
  MsiSourceListClearAllA@12 @208
  MsiSourceListClearAllW@12 @209
  MsiSourceListAddSourceA@16 @210
  MsiSourceListAddSourceW@16 @211
  MsiGetShortcutTargetA@16 @216
  MsiGetShortcutTargetW@16 @217
  MsiGetFileHashA@12 @218
  MsiGetFileHashW@12 @219
  MsiCreateAndVerifyInstallerDirectory@4 @222
  MsiGetFileSignatureInformationA@20 @223
  MsiGetFileSignatureInformationW@20 @224
  MsiProvideAssemblyA@24 @225
  MsiProvideAssemblyW@24 @226
  MsiAdvertiseProductExA@24 @227
  MsiAdvertiseProductExW@24 @228
  MsiOpenPackageExA@12 @231
  MsiOpenPackageExW@12 @232
  MsiEnumProductsExA@32 @245
  MsiEnumProductsExW@32 @246
  MsiQueryComponentStateA@20 @249
  DllCanUnloadNow@0 @282 PRIVATE
  DllGetClassObject@12 @283 PRIVATE
  DllRegisterServer@0 @284 PRIVATE
  DllUnregisterServer@0 @285 PRIVATE
