; File generated automatically from ./wintrust.spec; do not edit!

LIBRARY wintrust.dll

EXPORTS
  CryptCATAdminAcquireContext@12 @3
  CryptCATAdminAddCatalog@16 @4
  CryptCATAdminCalcHashFromFileHandle@16 @5
  CryptCATAdminEnumCatalogFromHash@20 @6
  CryptCATAdminReleaseCatalogContext@12 @8
  CryptCATAdminReleaseContext@8 @9
  CryptCATAdminRemoveCatalog@12 @10
  CryptCATClose@4 @21
  CryptCATEnumerateMember@8 @24
  CryptCATOpen@20 @29
  CryptSIPCreateIndirectData@12 @36
  CryptSIPGetSignedDataMsg@20 @39
  CryptSIPPutSignedDataMsg@20 @40
  CryptSIPRemoveSignedDataMsg@8 @41
  CryptSIPVerifyIndirectData@8 @42
  DllRegisterServer@0 @43 PRIVATE
  DllUnregisterServer@0 @44 PRIVATE
  SoftpubDllRegisterServer@0 @63
  SoftpubDllUnregisterServer@0 @64
  TrustIsCertificateSelfSigned@4 @74
  WTHelperGetProvSignerFromChain@16 @85
  WTHelperProvDataFromStateData@4 @88
  WinVerifyTrust@12 @111
  WinVerifyTrustEx@12 @112
  WintrustAddActionID@12 @113
  WintrustAddDefaultForUsage@8 @114
  WintrustGetRegPolicyFlags@4 @117
  WintrustLoadFunctionPointers@8 @118
  WintrustRemoveActionID@4 @119
  WintrustSetRegPolicyFlags@4 @120
  mscat32DllRegisterServer@0 @121
  mscat32DllUnregisterServer@0 @122
  mssip32DllRegisterServer@0 @123
  mssip32DllUnregisterServer@0 @124
