; File generated automatically from ./mlang.spec; do not edit!

LIBRARY mlang.dll

EXPORTS
  ConvertINetMultiByteToUnicode@24 @1
  ConvertINetString@28 @3
  ConvertINetUnicodeToMultiByte@24 @4
  DllCanUnloadNow@0 @5 PRIVATE
  DllGetClassObject@12 @6 PRIVATE
  DllRegisterServer@0 @7 PRIVATE
  DllUnregisterServer@0 @8 PRIVATE
  GetGlobalFontLinkObject@0 @9
  IsConvertINetStringAvailable@8 @10
  LcidToRfc1766A@12 @11
  LcidToRfc1766W@12 @12
