; File generated automatically from ./riched20.spec; do not edit!

LIBRARY riched20.dll

EXPORTS
  IID_IRichEditOle @2 DATA
  IID_IRichEditOleCallback @3 DATA
  CreateTextServices@12 @4
  IID_ITextServices @5 DATA
  IID_ITextHost @6 DATA
  IID_ITextHost2 @7 DATA
  REExtendedRegisterClass@0 @8
  RichEdit10ANSIWndProc@16 @9
  RichEditANSIWndProc@16 @10
