; File generated automatically from ./ole32.spec; do not edit!

LIBRARY ole32.dll

EXPORTS
  BindMoniker@16 @1
  CLIPFORMAT_UserFree@8 @2
  CLIPFORMAT_UserMarshal@12 @3
  CLIPFORMAT_UserSize@12 @4
  CLIPFORMAT_UserUnmarshal@12 @5
  CLSIDFromProgID@8 @6
  CLSIDFromString@8 @7
  CoAddRefServerProcess@0 @8
  CoAllowSetForegroundWindow@8 @9
  CoBuildVersion@0 @10
  CoCopyProxy@8 @11
  CoCreateFreeThreadedMarshaler@8 @12
  CoCreateGuid@4 @13
  CoCreateInstance@20 @14
  CoCreateInstanceEx@24 @15
  CoDisconnectObject@8 @16
  CoDosDateTimeToFileTime@12=kernel32.DosDateTimeToFileTime @17
  CoFileTimeNow@4 @18
  CoFileTimeToDosDateTime@12=kernel32.FileTimeToDosDateTime @19
  CoFreeAllLibraries@0 @20
  CoFreeLibrary@4 @21
  CoFreeUnusedLibraries@0 @22
  CoGetCallContext@8 @23
  CoGetClassObject@20 @25
  CoGetCurrentProcess@0 @27
  CoGetInterfaceAndReleaseStream@12 @30
  CoGetMalloc@8 @31
  CoGetMarshalSizeMax@24 @32
  CoGetObject@16 @33
  CoGetPSClsid@8 @34
  CoGetStandardMarshal@24 @35
  CoGetState@4 @36
  CoGetTreatAsClass@8 @38
  CoImpersonateClient@0 @39
  CoInitialize@4 @40
  CoInitializeEx@8 @41
  CoInitializeSecurity@36 @42
  CoInitializeWOW@8 @43
  CoIsHandlerConnected@4 @44
  CoIsOle1Class@4 @45
  CoLoadLibrary@8 @46
  CoLockObjectExternal@12 @47
  CoMarshalHresult@8 @48
  CoMarshalInterThreadInterfaceInStream@12 @49
  CoMarshalInterface@24 @50
  CoQueryClientBlanket@28 @52
  CoQueryProxyBlanket@32 @53
  CoRegisterChannelHook@8 @55
  CoRegisterClassObject@20 @56
  CoRegisterMallocSpy@4 @57
  CoRegisterMessageFilter@8 @58
  CoRegisterPSClsid@8 @59
  CoReleaseMarshalData@4 @62
  CoReleaseServerProcess@0 @63
  CoResumeClassObjects@0 @64
  CoRevertToSelf@0 @65
  CoRevokeClassObject@4 @66
  CoRevokeMallocSpy@0 @67
  CoSetProxyBlanket@32 @68
  CoSetState@4 @69
  CoSuspendClassObjects@0 @70
  CoTaskMemAlloc@4 @72
  CoTaskMemFree@4 @73
  CoTaskMemRealloc@8 @74
  CoTreatAsClass@8 @75
  CoUninitialize@0 @76
  CoUnmarshalHresult@8 @78
  CoUnmarshalInterface@12 @79
  CoWaitForMultipleHandles@20 @80
  CreateAntiMoniker@4 @81
  CreateBindCtx@8 @82
  CreateClassMoniker@8 @83
  CreateDataAdviseHolder@4 @84
  CreateDataCache@16 @85
  CreateErrorInfo@4 @86
  CreateFileMoniker@8 @87
  CreateGenericComposite@12 @88
  CreateILockBytesOnHGlobal@12 @89
  CreateItemMoniker@12 @90
  CreateOleAdviseHolder@4 @92
  CreateStreamOnHGlobal@12 @94
  DllDebugObjectRPCHook@8 @95
  DllGetClassObject@12 @96 PRIVATE
  DllRegisterServer@0 @98 PRIVATE
  DllUnregisterServer@0 @99 PRIVATE
  DoDragDrop@16 @100
  FmtIdToPropStgName@8 @102
  FreePropVariantArray@8 @103
  GetClassFile@8 @104
  GetConvertStg@4 @105
  GetErrorInfo@8 @107
  GetHGlobalFromILockBytes@8 @108
  GetHGlobalFromStream@8 @109
  GetRunningObjectTable@8 @111
  HACCEL_UserFree@8 @112
  HACCEL_UserMarshal@12 @113
  HACCEL_UserSize@12 @114
  HACCEL_UserUnmarshal@12 @115
  HBITMAP_UserFree@8 @116
  HBITMAP_UserMarshal@12 @117
  HBITMAP_UserSize@12 @118
  HBITMAP_UserUnmarshal@12 @119
  HDC_UserFree@8 @124
  HDC_UserMarshal@12 @125
  HDC_UserSize@12 @126
  HDC_UserUnmarshal@12 @127
  HENHMETAFILE_UserFree@8 @128
  HENHMETAFILE_UserMarshal@12 @129
  HENHMETAFILE_UserSize@12 @130
  HENHMETAFILE_UserUnmarshal@12 @131
  HGLOBAL_UserFree@8 @132
  HGLOBAL_UserMarshal@12 @133
  HGLOBAL_UserSize@12 @134
  HGLOBAL_UserUnmarshal@12 @135
  HMENU_UserFree@8 @136
  HMENU_UserMarshal@12 @137
  HMENU_UserSize@12 @138
  HMENU_UserUnmarshal@12 @139
  HMETAFILEPICT_UserFree@8 @140
  HMETAFILEPICT_UserMarshal@12 @141
  HMETAFILEPICT_UserSize@12 @142
  HMETAFILEPICT_UserUnmarshal@12 @143
  HMETAFILE_UserFree@8 @144
  HMETAFILE_UserMarshal@12 @145
  HMETAFILE_UserSize@12 @146
  HMETAFILE_UserUnmarshal@12 @147
  HPALETTE_UserFree@8 @148
  HPALETTE_UserMarshal@12 @149
  HPALETTE_UserSize@12 @150
  HPALETTE_UserUnmarshal@12 @151
  HWND_UserFree@8 @152
  HWND_UserMarshal@12 @153
  HWND_UserSize@12 @154
  HWND_UserUnmarshal@12 @155
  IIDFromString@8=CLSIDFromString@8 @156
  IsAccelerator@16 @158
  IsEqualGUID@8 @159
  IsValidInterface@4 @161
  MkParseDisplayName@16 @164
  MonikerCommonPrefixWith@12 @165
  OleBuildVersion@0 @167
  OleConvertIStorageToOLESTREAM@8 @168
  OleConvertOLESTREAMToIStorage@12 @170
  OleCreate@28 @172
  OleCreateDefaultHandler@16 @173
  OleCreateFromData@28 @176
  OleCreateFromFile@32 @178
  OleCreateLink@28 @180
  OleCreateLinkFromData@28 @182
  OleCreateLinkToFile@28 @184
  OleCreateMenuDescriptor@8 @186
  OleCreateStaticFromData@28 @187
  OleDestroyMenuDescriptor@4 @188
  OleDoAutoConvert@8 @189
  OleDraw@16 @190
  OleDuplicateData@12 @191
  OleFlushClipboard@0 @192
  OleGetAutoConvert@8 @193
  OleGetClipboard@4 @194
  OleGetIconOfClass@12 @195
  OleInitialize@4 @197
  OleInitializeWOW@8 @198
  OleIsCurrentClipboard@4 @199
  OleIsRunning@4 @200
  OleLoad@16 @201
  OleLoadFromStream@12 @202
  OleLockRunning@12 @203
  OleMetafilePictFromIconAndLabel@16 @204
  OleNoteObjectVisible@8 @205
  OleQueryCreateFromData@4 @206
  OleQueryLinkFromData@4 @207
  OleRegEnumFormatEtc@12 @208
  OleRegEnumVerbs@8 @209
  OleRegGetMiscStatus@12 @210
  OleRegGetUserType@12 @211
  OleRun@4 @212
  OleSave@12 @213
  OleSaveToStream@8 @214
  OleSetAutoConvert@8 @215
  OleSetClipboard@4 @216
  OleSetContainedObject@8 @217
  OleSetMenuDescriptor@20 @218
  OleTranslateAccelerator@12 @219
  OleUninitialize@0 @220
  ProgIDFromCLSID@8 @222
  PropStgNameToFmtId@8 @223
  PropSysAllocString@4 @224
  PropSysFreeString@4 @225
  PropVariantClear@4 @226
  PropVariantCopy@8 @227
  ReadClassStg@8 @228
  ReadClassStm@8 @229
  ReadFmtUserTypeStg@12 @230
  RegisterDragDrop@8 @233
  ReleaseStgMedium@4 @234
  RevokeDragDrop@4 @235
  SNB_UserFree@8 @236
  SNB_UserMarshal@12 @237
  SNB_UserSize@12 @238
  SNB_UserUnmarshal@12 @239
  STGMEDIUM_UserFree@8 @240
  STGMEDIUM_UserMarshal@12 @241
  STGMEDIUM_UserSize@12 @242
  STGMEDIUM_UserUnmarshal@12 @243
  SetConvertStg@8 @244
  SetErrorInfo@8 @246
  StgCreateDocfile@16 @247
  StgCreateDocfileOnILockBytes@16 @248
  StgCreatePropSetStg@12 @249
  StgCreateStorageEx@32 @250
  StgIsStorageFile@4 @253
  StgIsStorageILockBytes@4 @254
  StgOpenStorage@24 @256
  StgOpenStorageEx@32 @257
  StgOpenStorageOnILockBytes@24 @258
  StgSetTimes@16 @259
  StringFromCLSID@8 @260
  StringFromGUID2@12 @261
  StringFromIID@8=StringFromCLSID@8 @262
  WriteClassStg@8 @272
  WriteClassStm@8 @273
  WriteFmtUserTypeStg@12 @274
