; File generated automatically from ./gdiplus.spec; do not edit!

LIBRARY gdiplus.dll

EXPORTS
  GdipAlloc@4 @34
  GdipCreateFromHDC@8 @84
  GdipCreateFromHWND@8 @85
  GdipCreatePath@8 @109
  GdipCreatePen1@16 @114
  GdipCreateSolidFill@8 @122
  GdipDeleteBrush@4 @130
  GdipDeleteGraphics@4 @135
  GdipDeletePath@4 @137
  GdipDeletePen@4 @139
  GdipDrawArc@32 @145
  GdipDrawBezier@40 @147
  GdipDrawCurve2@20 @156
  GdipDrawLineI@24 @178
  GdipDrawLines@16 @179
  GdipDrawPie@32 @182
  GdipDrawRectangleI@24 @187
  GdipFillPie@32 @212
  GdipFree@4 @225
  GdipGetBrushType@8 @231
  GdiplusShutdown@4 @608
  GdiplusStartup@12 @609
