/*
 * DCI driver interface
 *
 * Copyright (C) 2005 Francois Gouget
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef _INC_DCIMAN
#define _INC_DCIMAN

#include <dciddi.h>

#ifdef __cplusplus
extern "C" {
#endif

HDC         WINAPI DCIOpenProvider(void);
void        WINAPI DCICloseProvider(HDC);
int         WINAPI DCICreatePrimary(HDC,LPDCISURFACEINFO*);

#ifdef __cplusplus
} /* extern "C" */
#endif

#endif /* _INC_DCIMAN */
