; File generated automatically from ./ntdll.spec; do not edit!

LIBRARY ntdll.dll

EXPORTS
  DbgBreakPoint@0 @19
  DbgPrint @20
  DbgPrintEx @21
  DbgUserBreakPoint@0 @26
  LdrAccessResource@16 @30
  LdrAddRefDll@8 @31
  LdrDisableThreadCalloutsForDll@4 @32
  LdrFindEntryForAddress@8 @34
  LdrFindResourceDirectory_U@16 @35
  LdrFindResource_U@16 @36
  LdrGetDllHandle@16 @38
  LdrGetProcedureAddress@16 @39
  LdrInitializeThunk@16 @41
  LdrLoadDll@16 @43
  LdrLockLoaderLock@12 @44
  LdrQueryProcessModuleInformation@12 @47
  LdrShutdownProcess@0 @50
  LdrShutdownThread@0 @51
  LdrUnloadDll@4 @53
  LdrUnlockLoaderLock@8 @54
  NlsAnsiCodePage @56 DATA
  NlsMbCodePageTag @57 DATA
  NlsMbOemCodePageTag @58 DATA
  NtAcceptConnectPort@24 @59
  NtAccessCheck@32 @60
  NtAccessCheckAndAuditAlarm@44 @61
  NtAddAtom@12 @62
  NtAdjustGroupsToken@24 @63
  NtAdjustPrivilegesToken@24 @64
  NtAlertResumeThread@8 @65
  NtAlertThread@4 @66
  NtAllocateLocallyUniqueId@4 @67
  NtAllocateUuids@12 @68
  NtAllocateVirtualMemory@24 @69
  NtCancelIoFile@8 @72
  NtCancelTimer@8 @73
  NtClearEvent@4 @74
  NtClose@4 @75
  NtCompleteConnectPort@4 @77
  NtConnectPort@32 @78
  NtCreateDirectoryObject@12 @80
  NtCreateEvent@20 @81
  NtCreateFile@44 @83
  NtCreateIoCompletion@16 @84
  NtCreateKey@28 @85
  NtCreateMailslotFile@32 @86
  NtCreateMutant@16 @87
  NtCreateNamedPipeFile@56 @88
  NtCreatePagingFile@16 @89
  NtCreatePort@20 @90
  NtCreateSection@28 @93
  NtCreateSemaphore@20 @94
  NtCreateSymbolicLinkObject@16 @95
  NtCreateTimer@16 @97
  NtCurrentTeb@0 @99
  NtDelayExecution@8 @100
  NtDeleteAtom@4 @101
  NtDeleteFile@4 @102
  NtDeleteKey@4 @103
  NtDeleteValueKey@8 @104
  NtDeviceIoControlFile@40 @105
  NtDisplayString@4 @106
  NtDuplicateObject@28 @107
  NtDuplicateToken@24 @108
  NtEnumerateKey@24 @110
  NtEnumerateValueKey@24 @111
  NtFindAtom@12 @113
  NtFlushBuffersFile@8 @114
  NtFlushInstructionCache@12 @115
  NtFlushKey@4 @116
  NtFlushVirtualMemory@16 @117
  NtFreeVirtualMemory@16 @119
  NtFsControlFile@40 @120
  NtGetContextThread@8 @121
  NtGetTickCount@0 @123
  NtInitiatePowerAction@16 @128
  NtListenPort@8 @129
  NtLoadDriver@4 @130
  NtLoadKey@8 @131
  NtLockFile@40 @132
  NtLockVirtualMemory@16 @133
  NtMapViewOfSection@40 @135
  NtNotifyChangeDirectoryFile@36 @136
  NtNotifyChangeKey@40 @137
  NtOpenDirectoryObject@12 @138
  NtOpenEvent@12 @139
  NtOpenFile@24 @141
  NtOpenIoCompletion@12 @142
  NtOpenKey@12 @143
  NtOpenMutant@12 @144
  NtOpenProcess@16 @146
  NtOpenProcessToken@12 @147
  NtOpenSection@12 @148
  NtOpenSemaphore@12 @149
  NtOpenSymbolicLinkObject@12 @150
  NtOpenThread@16 @151
  NtOpenThreadToken@16 @152
  NtOpenTimer@12 @153
  NtPowerInformation@20 @155
  NtPrivilegeCheck@12 @156
  NtProtectVirtualMemory@20 @159
  NtPulseEvent@8 @160
  NtQueryAttributesFile@8 @161
  NtQueryDefaultLocale@8 @162
  NtQueryDefaultUILanguage@4 @163
  NtQueryDirectoryFile@44 @164
  NtQueryDirectoryObject@28 @165
  NtQueryEvent@20 @167
  NtQueryFullAttributesFile@8 @168
  NtQueryInformationAtom@20 @169
  NtQueryInformationFile@20 @170
  NtQueryInformationProcess@20 @172
  NtQueryInformationThread@20 @173
  NtQueryInformationToken@20 @174
  NtQueryInstallUILanguage@4 @175
  NtQueryIoCompletion@20 @177
  NtQueryKey@20 @178
  NtQueryMultipleValueKey@24 @179
  NtQueryMutant@20 @180
  NtQueryObject@20 @181
  NtQueryPerformanceCounter@8 @183
  NtQuerySection@20 @184
  NtQuerySecurityObject@20 @185
  NtQuerySemaphore@20 @186
  NtQuerySymbolicLinkObject@12 @187
  NtQuerySystemInformation@16 @189
  NtQuerySystemTime@4 @190
  NtQueryTimer@20 @191
  NtQueryTimerResolution@12 @192
  NtQueryValueKey@24 @193
  NtQueryVirtualMemory@24 @194
  NtQueryVolumeInformationFile@20 @195
  NtQueueApcThread@20 @196
  NtRaiseException@12 @197
  NtReadFile@36 @199
  NtReadVirtualMemory@20 @202
  NtRegisterThreadTerminatePort@4 @204
  NtReleaseMutant@8 @205
  NtReleaseSemaphore@12 @207
  NtRemoveIoCompletion@20 @208
  NtReplaceKey@12 @209
  NtReplyWaitReceivePort@16 @211
  NtRequestWaitReplyPort@12 @215
  NtResetEvent@8 @216
  NtRestoreKey@12 @217
  NtResumeThread@8 @218
  NtSaveKey@8 @219
  NtSetContextThread@8 @221
  NtSetDefaultLocale@8 @223
  NtSetDefaultUILanguage@4 @224
  NtSetEvent@8 @226
  NtSetInformationFile@20 @230
  NtSetInformationKey@16 @231
  NtSetInformationObject@16 @232
  NtSetInformationProcess@16 @233
  NtSetInformationThread@16 @234
  NtSetInformationToken@16 @235
  NtSetIntervalProfile@8 @236
  NtSetIoCompletion@20 @237
  NtSetSecurityObject@12 @242
  NtSetSystemInformation@12 @244
  NtSetSystemTime@8 @246
  NtSetTimer@28 @247
  NtSetTimerResolution@12 @248
  NtSetValueKey@24 @249
  NtSetVolumeInformationFile@20 @250
  NtShutdownSystem@4 @251
  NtSignalAndWaitForSingleObject@16 @252
  NtSuspendThread@8 @255
  NtTerminateProcess@8 @257
  NtTerminateThread@8 @258
  NtUnloadDriver@4 @260
  NtUnloadKey@4 @261
  NtUnlockFile@20 @263
  NtUnlockVirtualMemory@16 @264
  NtUnmapViewOfSection@8 @265
  NtWaitForMultipleObjects@20 @268
  NtWaitForSingleObject@12 @270
  NtWriteFile@36 @273
  NtWriteVirtualMemory@20 @276
  NtYieldExecution@0 @277
  RtlAbsoluteToSelfRelativeSD@12 @283
  RtlAcquirePebLock@0 @284
  RtlAcquireResourceExclusive@8 @285
  RtlAcquireResourceShared@8 @286
  RtlAddAccessAllowedAce@16 @290
  RtlAddAccessAllowedAceEx@20 @291
  RtlAddAccessDeniedAce@16 @292
  RtlAddAccessDeniedAceEx@20 @293
  RtlAddAce@20 @294
  RtlAddAtomToAtomTable@12 @296
  RtlAddAuditAccessAce@24 @298
  RtlAddVectoredExceptionHandler@8 @299
  RtlAdjustPrivilege@16 @300
  RtlAllocateAndInitializeSid@44 @301
  RtlAllocateHandle@8 @302
  RtlAllocateHeap@12 @303
  RtlAnsiCharToUnicodeChar@4 @304
  RtlAnsiStringToUnicodeSize@4 @305
  RtlAnsiStringToUnicodeString@12 @306
  RtlAppendAsciizToString@8 @307
  RtlAppendStringToString@8 @308
  RtlAppendUnicodeStringToString@8 @309
  RtlAppendUnicodeToString@8 @310
  RtlAreAllAccessesGranted@8 @313
  RtlAreAnyAccessesGranted@8 @314
  RtlAreBitsClear@12 @315
  RtlAreBitsSet@12 @316
  RtlAssert@16 @317
  RtlCharToInteger@12 @319
  RtlCheckRegistryKey@8 @320
  RtlClearAllBits@4 @321
  RtlClearBits@12 @322
  RtlCompactHeap@8 @324
  RtlCompareMemory@12 @325
  RtlCompareMemoryUlong@12 @326
  RtlCompareString@12 @327
  RtlCompareUnicodeString@12 @328
  RtlComputeCrc32@12 @330
  RtlConvertLongToLargeInteger@4 @333
  RtlConvertSidToUnicodeString@12 @335
  RtlConvertUlongToLargeInteger@4 @337
  RtlCopyLuid@8 @338
  RtlCopyLuidAndAttributesArray@12 @339
  RtlCopySecurityDescriptor@8 @340
  RtlCopySid@12 @341
  RtlCopyString@8 @343
  RtlCopyUnicodeString@8 @344
  RtlCreateAcl@12 @345
  RtlCreateAtomTable@8 @347
  RtlCreateEnvironment@8 @348
  RtlCreateHeap@24 @349
  RtlCreateProcessParameters@40 @350
  RtlCreateQueryDebugBuffer@8 @352
  RtlCreateSecurityDescriptor@8 @354
  RtlCreateUnicodeString@8 @356
  RtlCreateUnicodeStringFromAsciiz@8 @357
  RtlCreateUserThread@40 @360
  RtlDeNormalizeProcessParams@4 @363
  RtlDecodePointer@4 @367
  RtlDeleteAce@8 @372
  RtlDeleteAtomFromAtomTable@8 @373
  RtlDeleteCriticalSection@4 @374
  RtlDeleteRegistryValue@12 @380
  RtlDeleteResource@4 @381
  RtlDeleteSecurityObject@4 @382
  RtlDestroyAtomTable@4 @383
  RtlDestroyEnvironment@4 @384
  RtlDestroyHandleTable@4 @385
  RtlDestroyHeap@4 @386
  RtlDestroyProcessParameters@4 @387
  RtlDestroyQueryDebugBuffer@4 @388
  RtlDetermineDosPathNameType_U@4 @389
  RtlDllShutdownInProgress@0 @390
  RtlDoesFileExists_U@4 @391
  RtlDosPathNameToNtPathName_U@16 @392
  RtlDosSearchPath_U@24 @393
  RtlDowncaseUnicodeChar@4 @394
  RtlDowncaseUnicodeString@12 @395
  RtlDumpResource@4 @396
  RtlDuplicateUnicodeString@12 @397
  RtlEmptyAtomTable@8 @398
  RtlEncodePointer@4 @399
  RtlEnlargedIntegerMultiply@8 @400
  RtlEnlargedUnsignedDivide@16 @401
  RtlEnlargedUnsignedMultiply@8 @402
  RtlEnterCriticalSection@4 @403
  RtlEqualComputerName@8 @408
  RtlEqualDomainName@8 @409
  RtlEqualLuid@8 @410
  RtlEqualPrefixSid@8 @411
  RtlEqualSid@8 @412
  RtlEqualString@12 @413
  RtlEqualUnicodeString@12 @414
  RtlEraseUnicodeString@4 @415
  RtlExitUserThread@4 @416
  RtlExpandEnvironmentStrings_U@16 @417
  RtlExtendedIntegerMultiply@12 @419
  RtlExtendedLargeIntegerDivide@16 @420
  RtlExtendedMagicDivide@20 @421
  RtlFillMemory@12 @422
  RtlFillMemoryUlong@12 @423
  RtlFindCharInUnicodeString@16 @427
  RtlFindClearBits@12 @428
  RtlFindClearBitsAndSet@12 @429
  RtlFindClearRuns@16 @430
  RtlFindLastBackwardRunClear@12 @431
  RtlFindLastBackwardRunSet@12 @432
  RtlFindLeastSignificantBit@8 @433
  RtlFindLongestRunClear@8 @434
  RtlFindLongestRunSet@8 @435
  RtlFindMessage@20 @436
  RtlFindMostSignificantBit@8 @437
  RtlFindNextForwardRunClear@12 @438
  RtlFindNextForwardRunSet@12 @439
  RtlFindSetBits@12 @441
  RtlFindSetBitsAndClear@12 @442
  RtlFindSetRuns@16 @443
  RtlFirstEntrySList@4 @444
  RtlFirstFreeAce@8 @445
  RtlFormatCurrentUserKeyPath@4 @447
  RtlFormatMessage@32 @448
  RtlFreeAnsiString@4 @449
  RtlFreeHandle@8 @450
  RtlFreeHeap@12 @451
  RtlFreeOemString@4 @452
  RtlFreeSid@4 @453
  RtlFreeUnicodeString@4 @454
  RtlGUIDFromString@8 @456
  RtlGetAce@12 @458
  RtlGetControlSecurityDescriptor@12 @461
  RtlGetCurrentDirectory_U@8 @462
  RtlGetCurrentPeb@0 @463
  RtlGetDaclSecurityDescriptor@16 @464
  RtlGetFullPathName_U@16 @466
  RtlGetGroupSecurityDescriptor@12 @467
  RtlGetLastNtStatus@0 @468
  RtlGetLastWin32Error@0 @469
  RtlGetLongestNtPathLength@0 @470
  RtlGetNtProductType@4 @472
  RtlGetNtVersionNumbers@12 @473
  RtlGetOwnerSecurityDescriptor@12 @474
  RtlGetProcessHeaps@8 @475
  RtlGetSaclSecurityDescriptor@16 @476
  RtlGetVersion@4 @478
  RtlIdentifierAuthoritySid@4 @480
  RtlImageDirectoryEntryToData@16 @481
  RtlImageNtHeader@4 @482
  RtlImageRvaToSection@12 @483
  RtlImageRvaToVa@16 @484
  RtlImpersonateSelf@4 @485
  RtlInitAnsiString@8 @486
  RtlInitAnsiStringEx@8 @487
  RtlInitString@8 @490
  RtlInitUnicodeString@8 @491
  RtlInitUnicodeStringEx@8 @492
  RtlInitializeBitMap@12 @493
  RtlInitializeCriticalSection@4 @495
  RtlInitializeCriticalSectionAndSpinCount@8 @496
  RtlInitializeGenericTable@20 @497
  RtlInitializeHandleTable@12 @498
  RtlInitializeResource@4 @500
  RtlInitializeSListHead@4 @501
  RtlInitializeSid@12 @502
  RtlInt64ToUnicodeString@16 @504
  RtlIntegerToChar@16 @505
  RtlIntegerToUnicodeString@12 @506
  RtlInterlockedFlushSList@4 @507
  RtlInterlockedPopEntrySList@4 @508
  RtlInterlockedPushEntrySList@8 @509
  RtlInterlockedPushListSList@16 @510
  RtlIpv4AddressToStringExW@16 @511
  RtlIpv4StringToAddressExW@16 @512
  RtlIsDosDeviceName_U@4 @513
  RtlIsNameLegalDOS8Dot3@12 @515
  RtlIsTextUnicode@12 @516
  RtlIsValidHandle@8 @517
  RtlIsValidIndexHandle@12 @518
  RtlLargeIntegerAdd@16 @519
  RtlLargeIntegerArithmeticShift@12 @520
  RtlLargeIntegerDivide@20 @521
  RtlLargeIntegerNegate@8 @522
  RtlLargeIntegerShiftLeft@12 @523
  RtlLargeIntegerShiftRight@12 @524
  RtlLargeIntegerSubtract@16 @525
  RtlLargeIntegerToChar@16 @526
  RtlLeaveCriticalSection@4 @527
  RtlLengthRequiredSid@4 @528
  RtlLengthSecurityDescriptor@4 @529
  RtlLengthSid@4 @530
  RtlLocalTimeToSystemTime@8 @531
  RtlLockHeap@4 @532
  RtlLookupAtomInAtomTable@12 @533
  RtlMakeSelfRelativeSD@12 @535
  RtlMapGenericMask@8 @536
  RtlMoveMemory@12 @537
  RtlMultiByteToUnicodeN@20 @538
  RtlMultiByteToUnicodeSize@12 @539
  RtlNewSecurityObject@24 @542
  RtlNormalizeProcessParams@4 @543
  RtlNtStatusToDosError@4 @544
  RtlNtStatusToDosErrorNoTeb@4 @545
  RtlNumberOfClearBits@4 @547
  RtlNumberOfSetBits@4 @548
  RtlOemStringToUnicodeSize@4 @549
  RtlOemStringToUnicodeString@12 @550
  RtlOemToUnicodeN@20 @551
  RtlOpenCurrentUser@8 @552
  RtlPcToFileHeader@8 @553
  RtlPinAtomInAtomTable@8 @554
  RtlPrefixString@12 @555
  RtlPrefixUnicodeString@12 @556
  RtlQueryAtomInAtomTable@24 @559
  RtlQueryDepthSList@4 @560
  RtlQueryEnvironmentVariable_U@12 @561
  RtlQueryInformationAcl@16 @563
  RtlQueryProcessDebugInformation@12 @568
  RtlQueryRegistryValues@20 @574
  RtlQueryTimeZoneInformation@4 @577
  RtlQueueWorkItem@12 @579
  RtlRaiseException@4 @580
  RtlRaiseStatus@4 @581
  RtlRandom@4 @582
  RtlReAllocateHeap@16 @584
  RtlReleasePebLock@0 @593
  RtlReleaseResource@4 @594
  RtlRemoveVectoredExceptionHandler@4 @596
  RtlRestoreLastWin32Error@4=RtlSetLastWin32Error@4 @598
  RtlSecondsSince1970ToTime@8 @602
  RtlSecondsSince1980ToTime@8 @603
  RtlSelfRelativeToAbsoluteSD@44 @604
  RtlSetAllBits@4 @605
  RtlSetBits@12 @606
  RtlSetCriticalSectionSpinCount@8 @607
  RtlSetCurrentDirectory_U@4 @608
  RtlSetCurrentEnvironment@8 @609
  RtlSetDaclSecurityDescriptor@16 @610
  RtlSetEnvironmentVariable@12 @611
  RtlSetGroupSecurityDescriptor@12 @612
  RtlSetLastWin32Error@4 @614
  RtlSetLastWin32ErrorAndNtStatusFromNtStatus@4 @615
  RtlSetOwnerSecurityDescriptor@12 @616
  RtlSetSaclSecurityDescriptor@16 @621
  RtlSetTimeZoneInformation@4 @623
  RtlSizeHeap@12 @627
  RtlStringFromGUID@8 @630
  RtlSubAuthorityCountSid@4 @631
  RtlSubAuthoritySid@8 @632
  RtlSystemTimeToLocalTime@8 @635
  RtlTimeFieldsToTime@8 @636
  RtlTimeToElapsedTimeFields@8 @637
  RtlTimeToSecondsSince1970@8 @638
  RtlTimeToSecondsSince1980@8 @639
  RtlTimeToTimeFields@8 @640
  RtlTryEnterCriticalSection@4 @641
  RtlUlongByteSwap=NTDLL_RtlUlongByteSwap @642
  RtlUlonglongByteSwap @643
  RtlUnicodeStringToAnsiSize@4 @644
  RtlUnicodeStringToAnsiString@12 @645
  RtlUnicodeStringToInteger@12 @647
  RtlUnicodeStringToOemSize@4 @648
  RtlUnicodeStringToOemString@12 @649
  RtlUnicodeToMultiByteN@20 @651
  RtlUnicodeToMultiByteSize@12 @652
  RtlUnicodeToOemN@20 @653
  RtlUniform@4 @654
  RtlUnlockHeap@4 @655
  RtlUnwind@16 @656
  RtlUpcaseUnicodeChar@4 @657
  RtlUpcaseUnicodeString@12 @658
  RtlUpcaseUnicodeStringToAnsiString@12 @659
  RtlUpcaseUnicodeStringToCountedOemString@12 @660
  RtlUpcaseUnicodeStringToOemString@12 @661
  RtlUpcaseUnicodeToMultiByteN@20 @663
  RtlUpcaseUnicodeToOemN@20 @664
  RtlUpperChar@4 @665
  RtlUpperString@8 @666
  RtlUshortByteSwap=NTDLL_RtlUshortByteSwap @668
  RtlValidAcl@4 @669
  RtlValidSecurityDescriptor@4 @670
  RtlValidSid@4 @671
  RtlValidateHeap@12 @672
  RtlVerifyVersionInfo@16 @674
  RtlWalkHeap@8 @676
  RtlWriteRegistryValue@24 @678
  RtlZeroMemory@8 @680
  RtlpNtCreateKey@28 @681
  RtlpNtEnumerateSubKey@12 @682
  RtlpNtMakeTemporaryKey@4 @683
  RtlpNtOpenKey@12 @684
  RtlpNtQueryValueKey@16 @685
  RtlpNtSetValueKey@16 @686
  RtlpUnWaitCriticalSection@4 @687
  RtlpWaitForCriticalSection@4 @688
  RtlxAnsiStringToUnicodeSize@4=RtlAnsiStringToUnicodeSize@4 @689
  RtlxOemStringToUnicodeSize@4=RtlOemStringToUnicodeSize@4 @690
  RtlxUnicodeStringToAnsiSize@4=RtlUnicodeStringToAnsiSize@4 @691
  RtlxUnicodeStringToOemSize@4=RtlUnicodeStringToOemSize@4 @692
  VerSetConditionMask@16 @693
  ZwAcceptConnectPort@24=NtAcceptConnectPort@24 @694
  ZwAccessCheck@32=NtAccessCheck@32 @695
  ZwAccessCheckAndAuditAlarm@44=NtAccessCheckAndAuditAlarm@44 @696
  ZwAddAtom@12=NtAddAtom@12 @697
  ZwAdjustGroupsToken@24=NtAdjustGroupsToken@24 @698
  ZwAdjustPrivilegesToken@24=NtAdjustPrivilegesToken@24 @699
  ZwAlertResumeThread@8=NtAlertResumeThread@8 @700
  ZwAlertThread@4=NtAlertThread@4 @701
  ZwAllocateLocallyUniqueId@4=NtAllocateLocallyUniqueId@4 @702
  ZwAllocateUuids@12=NtAllocateUuids@12 @703
  ZwAllocateVirtualMemory@24=NtAllocateVirtualMemory@24 @704
  ZwCancelIoFile@8=NtCancelIoFile@8 @707
  ZwCancelTimer@8=NtCancelTimer@8 @708
  ZwClearEvent@4=NtClearEvent@4 @709
  ZwClose@4=NtClose@4 @710
  ZwCompleteConnectPort@4=NtCompleteConnectPort@4 @712
  ZwConnectPort@32=NtConnectPort@32 @713
  ZwCreateDirectoryObject@12=NtCreateDirectoryObject@12 @715
  ZwCreateEvent@20=NtCreateEvent@20 @716
  ZwCreateFile@44=NtCreateFile@44 @718
  ZwCreateIoCompletion@16=NtCreateIoCompletion@16 @719
  ZwCreateKey@28=NtCreateKey@28 @720
  ZwCreateMailslotFile@32=NtCreateMailslotFile@32 @721
  ZwCreateMutant@16=NtCreateMutant@16 @722
  ZwCreateNamedPipeFile@56=NtCreateNamedPipeFile@56 @723
  ZwCreatePagingFile@16=NtCreatePagingFile@16 @724
  ZwCreatePort@20=NtCreatePort@20 @725
  ZwCreateSection@28=NtCreateSection@28 @728
  ZwCreateSemaphore@20=NtCreateSemaphore@20 @729
  ZwCreateSymbolicLinkObject@16=NtCreateSymbolicLinkObject@16 @730
  ZwCreateTimer@16=NtCreateTimer@16 @732
  ZwDelayExecution@8=NtDelayExecution@8 @734
  ZwDeleteAtom@4=NtDeleteAtom@4 @735
  ZwDeleteFile@4=NtDeleteFile@4 @736
  ZwDeleteKey@4=NtDeleteKey@4 @737
  ZwDeleteValueKey@8=NtDeleteValueKey@8 @738
  ZwDeviceIoControlFile@40=NtDeviceIoControlFile@40 @739
  ZwDisplayString@4=NtDisplayString@4 @740
  ZwDuplicateObject@28=NtDuplicateObject@28 @741
  ZwDuplicateToken@24=NtDuplicateToken@24 @742
  ZwEnumerateKey@24=NtEnumerateKey@24 @744
  ZwEnumerateValueKey@24=NtEnumerateValueKey@24 @745
  ZwFindAtom@12=NtFindAtom@12 @747
  ZwFlushBuffersFile@8=NtFlushBuffersFile@8 @748
  ZwFlushInstructionCache@12=NtFlushInstructionCache@12 @749
  ZwFlushKey@4=NtFlushKey@4 @750
  ZwFlushVirtualMemory@16=NtFlushVirtualMemory@16 @751
  ZwFreeVirtualMemory@16=NtFreeVirtualMemory@16 @753
  ZwFsControlFile@40=NtFsControlFile@40 @754
  ZwGetContextThread@8=NtGetContextThread@8 @755
  ZwGetTickCount@0=NtGetTickCount@0 @757
  ZwListenPort@8=NtListenPort@8 @761
  ZwLoadDriver@4=NtLoadDriver@4 @762
  ZwLoadKey@8=NtLoadKey@8 @763
  ZwLockFile@40=NtLockFile@40 @764
  ZwLockVirtualMemory@16=NtLockVirtualMemory@16 @765
  ZwMapViewOfSection@40=NtMapViewOfSection@40 @767
  ZwNotifyChangeDirectoryFile@36=NtNotifyChangeDirectoryFile@36 @768
  ZwNotifyChangeKey@40=NtNotifyChangeKey@40 @769
  ZwOpenDirectoryObject@12=NtOpenDirectoryObject@12 @770
  ZwOpenEvent@12=NtOpenEvent@12 @771
  ZwOpenFile@24=NtOpenFile@24 @773
  ZwOpenIoCompletion@12=NtOpenIoCompletion@12 @774
  ZwOpenKey@12=NtOpenKey@12 @775
  ZwOpenMutant@12=NtOpenMutant@12 @776
  ZwOpenProcess@16=NtOpenProcess@16 @778
  ZwOpenProcessToken@12=NtOpenProcessToken@12 @779
  ZwOpenSection@12=NtOpenSection@12 @780
  ZwOpenSemaphore@12=NtOpenSemaphore@12 @781
  ZwOpenSymbolicLinkObject@12=NtOpenSymbolicLinkObject@12 @782
  ZwOpenThread@16=NtOpenThread@16 @783
  ZwOpenThreadToken@16=NtOpenThreadToken@16 @784
  ZwOpenTimer@12=NtOpenTimer@12 @785
  ZwPrivilegeCheck@12=NtPrivilegeCheck@12 @787
  ZwProtectVirtualMemory@20=NtProtectVirtualMemory@20 @790
  ZwPulseEvent@8=NtPulseEvent@8 @791
  ZwQueryAttributesFile@8=NtQueryAttributesFile@8 @792
  ZwQueryDefaultLocale@8=NtQueryDefaultLocale@8 @793
  ZwQueryDefaultUILanguage@4=NtQueryDefaultUILanguage@4 @794
  ZwQueryDirectoryFile@44=NtQueryDirectoryFile@44 @795
  ZwQueryDirectoryObject@28=NtQueryDirectoryObject@28 @796
  ZwQueryEvent@20=NtQueryEvent@20 @798
  ZwQueryInformationAtom@20=NtQueryInformationAtom@20 @799
  ZwQueryInformationFile@20=NtQueryInformationFile@20 @800
  ZwQueryInformationProcess@20=NtQueryInformationProcess@20 @802
  ZwQueryInformationThread@20=NtQueryInformationThread@20 @803
  ZwQueryInformationToken@20=NtQueryInformationToken@20 @804
  ZwQueryInstallUILanguage@4=NtQueryInstallUILanguage@4 @805
  ZwQueryIoCompletion@20=NtQueryIoCompletion@20 @807
  ZwQueryKey@20=NtQueryKey@20 @808
  ZwQueryMutant@20=NtQueryMutant@20 @809
  ZwQueryObject@20=NtQueryObject@20 @810
  ZwQueryPerformanceCounter@8=NtQueryPerformanceCounter@8 @812
  ZwQuerySection@20=NtQuerySection@20 @813
  ZwQuerySecurityObject@20=NtQuerySecurityObject@20 @814
  ZwQuerySemaphore@20=NtQuerySemaphore@20 @815
  ZwQuerySymbolicLinkObject@12=NtQuerySymbolicLinkObject@12 @816
  ZwQuerySystemInformation@16=NtQuerySystemInformation@16 @818
  ZwQuerySystemTime@4=NtQuerySystemTime@4 @819
  ZwQueryTimer@20=NtQueryTimer@20 @820
  ZwQueryTimerResolution@12=NtQueryTimerResolution@12 @821
  ZwQueryValueKey@24=NtQueryValueKey@24 @822
  ZwQueryVirtualMemory@24=NtQueryVirtualMemory@24 @823
  ZwQueryVolumeInformationFile@20=NtQueryVolumeInformationFile@20 @824
  ZwRaiseException@12=NtRaiseException@12 @825
  ZwReadFile@36=NtReadFile@36 @827
  ZwReadVirtualMemory@20=NtReadVirtualMemory@20 @829
  ZwRegisterThreadTerminatePort@4=NtRegisterThreadTerminatePort@4 @831
  ZwReleaseMutant@8=NtReleaseMutant@8 @832
  ZwReleaseSemaphore@12=NtReleaseSemaphore@12 @834
  ZwRemoveIoCompletion@20=NtRemoveIoCompletion@20 @835
  ZwReplaceKey@12=NtReplaceKey@12 @836
  ZwReplyWaitReceivePort@16=NtReplyWaitReceivePort@16 @838
  ZwRequestWaitReplyPort@12=NtRequestWaitReplyPort@12 @841
  ZwResetEvent@8=NtResetEvent@8 @842
  ZwRestoreKey@12=NtRestoreKey@12 @843
  ZwResumeThread@8=NtResumeThread@8 @844
  ZwSaveKey@8=NtSaveKey@8 @845
  ZwSetContextThread@8=NtSetContextThread@8 @846
  ZwSetDefaultLocale@8=NtSetDefaultLocale@8 @848
  ZwSetDefaultUILanguage@4=NtSetDefaultUILanguage@4 @849
  ZwSetEvent@8=NtSetEvent@8 @851
  ZwSetInformationFile@20=NtSetInformationFile@20 @855
  ZwSetInformationKey@16=NtSetInformationKey@16 @856
  ZwSetInformationObject@16=NtSetInformationObject@16 @857
  ZwSetInformationProcess@16=NtSetInformationProcess@16 @858
  ZwSetInformationThread@16=NtSetInformationThread@16 @859
  ZwSetInformationToken@16=NtSetInformationToken@16 @860
  ZwSetIntervalProfile@8=NtSetIntervalProfile@8 @861
  ZwSetIoCompletion@20=NtSetIoCompletion@20 @862
  ZwSetSecurityObject@12=NtSetSecurityObject@12 @867
  ZwSetSystemInformation@12=NtSetSystemInformation@12 @869
  ZwSetSystemTime@8=NtSetSystemTime@8 @871
  ZwSetTimer@28=NtSetTimer@28 @872
  ZwSetTimerResolution@12=NtSetTimerResolution@12 @873
  ZwSetValueKey@24=NtSetValueKey@24 @874
  ZwSetVolumeInformationFile@20=NtSetVolumeInformationFile@20 @875
  ZwShutdownSystem@4=NtShutdownSystem@4 @876
  ZwSuspendThread@8=NtSuspendThread@8 @879
  ZwTerminateProcess@8=NtTerminateProcess@8 @881
  ZwTerminateThread@8=NtTerminateThread@8 @882
  ZwUnloadDriver@4=NtUnloadDriver@4 @884
  ZwUnloadKey@4=NtUnloadKey@4 @885
  ZwUnlockFile@20=NtUnlockFile@20 @887
  ZwUnlockVirtualMemory@16=NtUnlockVirtualMemory@16 @888
  ZwUnmapViewOfSection@8=NtUnmapViewOfSection@8 @889
  ZwWaitForMultipleObjects@20=NtWaitForMultipleObjects@20 @892
  ZwWaitForSingleObject@12=NtWaitForSingleObject@12 @894
  ZwWriteFile@36=NtWriteFile@36 @897
  ZwWriteVirtualMemory@20=NtWriteVirtualMemory@20 @899
  ZwYieldExecution@0=NtYieldExecution@0 @900
  _CIpow=NTDLL__CIpow @901 PRIVATE
  _alldiv@16 @902 PRIVATE
  _allmul@16 @903 PRIVATE
  _alloca_probe@0 @904 PRIVATE
  _allrem@16 @905 PRIVATE
  _atoi64 @906 PRIVATE
  _aulldiv@16 @907 PRIVATE
  _aullrem@16 @908 PRIVATE
  _chkstk@0 @909 PRIVATE
  _ftol=NTDLL__ftol @911 PRIVATE
  _i64toa @912 PRIVATE
  _i64tow @913 PRIVATE
  _itoa @914 PRIVATE
  _itow @915 PRIVATE
  _lfind @916 PRIVATE
  _ltoa @917 PRIVATE
  _ltow @918 PRIVATE
  _memccpy @919 PRIVATE
  _memicmp @920 PRIVATE
  _snprintf @921 PRIVATE
  _snwprintf @922 PRIVATE
  _splitpath @923 PRIVATE
  _strcmpi=_stricmp @924 PRIVATE
  _stricmp @925 PRIVATE
  _strlwr @926 PRIVATE
  _strnicmp @927 PRIVATE
  _strupr @928 PRIVATE
  _ui64toa @929 PRIVATE
  _ui64tow @930 PRIVATE
  _ultoa @931 PRIVATE
  _ultow @932 PRIVATE
  _vsnprintf @933 PRIVATE
  _vsnwprintf @934 PRIVATE
  _wcsicmp=NTDLL__wcsicmp @935 PRIVATE
  _wcslwr=NTDLL__wcslwr @936 PRIVATE
  _wcsnicmp=NTDLL__wcsnicmp @937 PRIVATE
  _wcsupr=NTDLL__wcsupr @938 PRIVATE
  _wtoi @939 PRIVATE
  _wtoi64 @940 PRIVATE
  _wtol @941 PRIVATE
  abs=NTDLL_abs @942 PRIVATE
  atan=NTDLL_atan @943 PRIVATE
  atoi=NTDLL_atoi @944 PRIVATE
  atol=NTDLL_atol @945 PRIVATE
  bsearch=NTDLL_bsearch @946 PRIVATE
  ceil=NTDLL_ceil @947 PRIVATE
  cos=NTDLL_cos @948 PRIVATE
  fabs=NTDLL_fabs @949 PRIVATE
  floor=NTDLL_floor @950 PRIVATE
  isalnum=NTDLL_isalnum @951 PRIVATE
  isalpha=NTDLL_isalpha @952 PRIVATE
  iscntrl=NTDLL_iscntrl @953 PRIVATE
  isdigit=NTDLL_isdigit @954 PRIVATE
  isgraph=NTDLL_isgraph @955 PRIVATE
  islower=NTDLL_islower @956 PRIVATE
  isprint=NTDLL_isprint @957 PRIVATE
  ispunct=NTDLL_ispunct @958 PRIVATE
  isspace=NTDLL_isspace @959 PRIVATE
  isupper=NTDLL_isupper @960 PRIVATE
  iswalpha=NTDLL_iswalpha @961 PRIVATE
  iswctype=NTDLL_iswctype @962 PRIVATE
  iswdigit=NTDLL_iswdigit @963 PRIVATE
  iswlower=NTDLL_iswlower @964 PRIVATE
  iswspace=NTDLL_iswspace @965 PRIVATE
  iswxdigit=NTDLL_iswxdigit @966 PRIVATE
  isxdigit=NTDLL_isxdigit @967 PRIVATE
  labs=NTDLL_labs @968 PRIVATE
  log=NTDLL_log @969 PRIVATE
  mbstowcs=NTDLL_mbstowcs @970 PRIVATE
  memchr=NTDLL_memchr @971 PRIVATE
  memcmp=NTDLL_memcmp @972 PRIVATE
  memcpy=NTDLL_memcpy @973 PRIVATE
  memmove=NTDLL_memmove @974 PRIVATE
  memset=NTDLL_memset @975 PRIVATE
  pow=NTDLL_pow @976 PRIVATE
  qsort=NTDLL_qsort @977 PRIVATE
  sin=NTDLL_sin @978 PRIVATE
  sprintf=NTDLL_sprintf @979 PRIVATE
  sqrt=NTDLL_sqrt @980 PRIVATE
  sscanf=NTDLL_sscanf @981 PRIVATE
  strcat=NTDLL_strcat @982 PRIVATE
  strchr=NTDLL_strchr @983 PRIVATE
  strcmp=NTDLL_strcmp @984 PRIVATE
  strcpy=NTDLL_strcpy @985 PRIVATE
  strcspn=NTDLL_strcspn @986 PRIVATE
  strlen=NTDLL_strlen @987 PRIVATE
  strncat=NTDLL_strncat @988 PRIVATE
  strncmp=NTDLL_strncmp @989 PRIVATE
  strncpy=NTDLL_strncpy @990 PRIVATE
  strpbrk=NTDLL_strpbrk @991 PRIVATE
  strrchr=NTDLL_strrchr @992 PRIVATE
  strspn=NTDLL_strspn @993 PRIVATE
  strstr=NTDLL_strstr @994 PRIVATE
  strtol=NTDLL_strtol @995 PRIVATE
  strtoul=NTDLL_strtoul @996 PRIVATE
  swprintf=NTDLL_swprintf @997 PRIVATE
  tan=NTDLL_tan @998 PRIVATE
  tolower=NTDLL_tolower @999 PRIVATE
  toupper=NTDLL_toupper @1000 PRIVATE
  towlower=NTDLL_towlower @1001 PRIVATE
  towupper=NTDLL_towupper @1002 PRIVATE
  vDbgPrintEx@16 @1003
  vDbgPrintExWithPrefix@20 @1004
  vsprintf=NTDLL_vsprintf @1005 PRIVATE
  wcscat=NTDLL_wcscat @1006 PRIVATE
  wcschr=NTDLL_wcschr @1007 PRIVATE
  wcscmp=NTDLL_wcscmp @1008 PRIVATE
  wcscpy=NTDLL_wcscpy @1009 PRIVATE
  wcscspn=NTDLL_wcscspn @1010 PRIVATE
  wcslen=NTDLL_wcslen @1011 PRIVATE
  wcsncat=NTDLL_wcsncat @1012 PRIVATE
  wcsncmp=NTDLL_wcsncmp @1013 PRIVATE
  wcsncpy=NTDLL_wcsncpy @1014 PRIVATE
  wcspbrk=NTDLL_wcspbrk @1015 PRIVATE
  wcsrchr=NTDLL_wcsrchr @1016 PRIVATE
  wcsspn=NTDLL_wcsspn @1017 PRIVATE
  wcsstr=NTDLL_wcsstr @1018 PRIVATE
  wcstok=NTDLL_wcstok @1019 PRIVATE
  wcstol=NTDLL_wcstol @1020 PRIVATE
  wcstombs=NTDLL_wcstombs @1021 PRIVATE
  wcstoul=NTDLL_wcstoul @1022 PRIVATE
  __wine_exception_handler @1023
  __wine_finally_handler @1024
  __wine_call_from_32_regs @1025
  __wine_enter_vm86 @1026
  wine_server_call @1027
  wine_server_fd_to_handle @1028
  wine_server_handle_to_fd @1029
  wine_server_release_fd @1030
  wine_server_send_fd @1031
  __wine_make_process_system @1032
  __wine_init_codepages @1033
  __wine_set_signal_handler @1034
  wine_nt_to_unix_file_name @1035
  wine_unix_to_nt_file_name @1036
  __wine_init_windows_dir @1037
