; File generated automatically from ./crypt32.spec; do not edit!

LIBRARY crypt32.dll

EXPORTS
  CertAddCRLContextToStore@16 @1
  CertAddCTLContextToStore@16 @2
  CertAddCertificateContextToStore@16 @3
  CertAddEncodedCRLToStore@24 @4
  CertAddEncodedCTLToStore@24 @5
  CertAddEncodedCertificateToStore@24 @6
  CertAddEnhancedKeyUsageIdentifier@8 @9
  CertAddSerializedElementToStore@32 @10
  CertAddStoreToCollection@16 @11
  CertAlgIdToOID@4 @12
  CertCloseStore@8 @13
  CertCompareCertificate@12 @14
  CertCompareCertificateName@12 @15
  CertCompareIntegerBlob@8 @16
  CertComparePublicKeyInfo@12 @17
  CertControlStore@16 @18
  CertCreateCRLContext@12 @19
  CertCreateCTLContext@12 @20
  CertCreateCertificateChainEngine@8 @21
  CertCreateCertificateContext@12 @22
  CertCreateSelfSignCertificate@32 @23
  CertDeleteCRLFromStore@4 @24
  CertDeleteCTLFromStore@4 @25
  CertDeleteCertificateFromStore@4 @26
  CertDuplicateCRLContext@4 @27
  CertDuplicateCTLContext@4 @28
  CertDuplicateCertificateContext@4 @29
  CertDuplicateStore@4 @30
  CertEnumCRLContextProperties@8 @31
  CertEnumCRLsInStore@8 @32
  CertEnumCTLContextProperties@8 @33
  CertEnumCTLsInStore@8 @34
  CertEnumCertificateContextProperties@8 @35
  CertEnumCertificatesInStore@8 @36
  CertEnumSystemStore@16 @37
  CertFindAttribute@12 @38
  CertFindCRLInStore@24 @39
  CertFindCertificateInStore@24 @41
  CertFindCertificateInCRL@20 @42
  CertFindExtension@12 @43
  CertFindRDNAttr@8 @44
  CertFreeCRLContext@4 @46
  CertFreeCTLContext@4 @47
  CertFreeCertificateChainEngine@4 @49
  CertFreeCertificateContext@4 @50
  CertGetCRLContextProperty@16 @51
  CertGetCRLFromStore@16 @52
  CertGetCTLContextProperty@16 @53
  CertGetCertificateChain@32 @54
  CertGetCertificateContextProperty@16 @55
  CertGetEnhancedKeyUsage@16 @56
  CertGetIssuerCertificateFromStore@16 @58
  CertGetNameStringA@24 @59
  CertGetNameStringW@24 @60
  CertGetPublicKeyLength@8 @61
  CertGetStoreProperty@16 @62
  CertGetSubjectCertificateFromStore@12 @63
  CertGetValidUsages@20 @64
  CertIsValidCRLForCertificate@16 @66
  CertNameToStrA@20 @67
  CertNameToStrW@20 @68
  CertOIDToAlgId@4 @69
  CertOpenStore@20 @70
  CertOpenSystemStoreA@8 @71
  CertOpenSystemStoreW@8 @72
  CertRDNValueToStrA@16 @73
  CertRDNValueToStrW@16 @74
  CertRemoveEnhancedKeyUsageIdentifier@8 @75
  CertRemoveStoreFromCollection@8 @76
  CertSaveStore@24 @77
  CertSerializeCRLStoreElement@16 @78
  CertSerializeCTLStoreElement@16 @79
  CertSerializeCertificateStoreElement@16 @80
  CertSetCRLContextProperty@16 @81
  CertSetCTLContextProperty@16 @82
  CertSetCertificateContextProperty@16 @83
  CertSetEnhancedKeyUsage@8 @84
  CertSetStoreProperty@16 @85
  CertStrToNameA@28 @86
  CertStrToNameW@28 @87
  CertVerifyCRLRevocation@16 @88
  CertVerifyCRLTimeValidity@8 @89
  CertVerifySubjectCertificateContext@12 @92
  CertVerifyTimeValidity@8 @93
  CertVerifyValidityNesting@8 @94
  CreateFileU@28=kernel32.CreateFileW @95
  CryptBinaryToStringA@20 @96
  CryptStringToBinaryA@28 @98
  CryptAcquireContextU@20=advapi32.CryptAcquireContextW @100
  CryptAcquireCertificatePrivateKey@24 @101
  CryptDecodeObject@28 @105
  CryptDecodeObjectEx@32 @106
  CryptEncodeObject@20 @109
  CryptEncodeObjectEx@28 @110
  CryptEnumOIDInfo@16 @113
  CryptExportPublicKeyInfo@20 @116
  CryptExportPublicKeyInfoEx@32 @117
  CryptFindLocalizedName@4 @118
  CryptFindOIDInfo@12 @119
  CryptFormatObject@36 @120
  CryptFreeOIDFunctionAddress@8 @121
  CryptGetDefaultOIDDllList@16 @123
  CryptGetDefaultOIDFunctionAddress@24 @124
  CryptGetOIDFunctionAddress@24 @127
  CryptGetOIDFunctionValue@28 @128
  CryptHashCertificate@28 @129
  CryptHashPublicKeyInfo@28 @131
  CryptImportPublicKeyInfo@16 @134
  CryptImportPublicKeyInfoEx@28 @135
  CryptInitOIDFunctionSet@8 @136
  CryptInstallOIDFunctionAddress@24 @137
  CryptMemAlloc@4 @139
  CryptMemFree@4 @140
  CryptMemRealloc@8 @141
  CryptMsgClose@4 @143
  CryptMsgDuplicate@4 @147
  CryptMsgGetParam@20 @150
  CryptMsgOpenToDecode@24 @151
  CryptMsgOpenToEncode@24 @152
  CryptMsgUpdate@16 @154
  CryptProtectData@28 @156
  CryptQueryObject@44 @157
  CryptRegisterDefaultOIDFunction@16 @158
  CryptRegisterOIDFunction@20 @159
  CryptSIPAddProvider@4 @161
  CryptSIPCreateIndirectData@12 @162
  CryptSIPGetSignedDataMsg@20 @163
  CryptSIPLoad@12 @164
  CryptSIPPutSignedDataMsg@20 @165
  CryptSIPRemoveProvider@4 @166
  CryptSIPRemoveSignedDataMsg@8 @167
  CryptSIPRetrieveSubjectGuid@12 @168
  CryptSIPVerifyIndirectData@8 @169
  CryptSetOIDFunctionValue@28 @171
  CryptSignAndEncodeCertificate@36 @173
  CryptSignCertificate@36 @175
  CryptUnprotectData@28 @179
  CryptUnregisterDefaultOIDFunction@12 @180
  CryptUnregisterOIDFunction@12 @181
  CryptVerifyCertificateSignature@20 @183
  CryptVerifyCertificateSignatureEx@32 @184
  CryptVerifyMessageSignature@28 @188
  I_CryptAllocTls@0 @191
  I_CryptCreateLruCache@8 @192
  I_CryptDetachTls@4 @194
  I_CryptFindLruEntryData@12 @195
  I_CryptFlushLruCache@12 @196
  I_CryptFreeLruCache@12 @197
  I_CryptFreeTls@8 @198
  I_CryptGetDefaultCryptProv@4 @199
  I_CryptGetOssGlobal@4 @201
  I_CryptGetTls@4 @202
  I_CryptInstallAsn1Module@12 @204
  I_CryptInstallOssGlobal@12 @205
  I_CryptReadTrustedPublisherDWORDValueFromRegistry@8 @206
  I_CryptSetTls@8 @208
  I_CryptUninstallAsn1Module@4 @209
