; File generated automatically from ./cfgmgr32.spec; do not edit!

LIBRARY cfgmgr32.dll

EXPORTS
  CM_Connect_MachineW@8=setupapi.CM_Connect_MachineW @11
  CM_Disconnect_Machine@4=setupapi.CM_Disconnect_Machine @26
  CM_Get_Device_IDA@16 @63
  CM_Get_Device_ID_ListA@16 @67
  CM_Get_Device_ID_Size@12 @75
  CMP_WaitNoPendingInstallEvents@4=setupapi.CMP_WaitNoPendingInstallEvents @180
