; File generated automatically from ./ws2_32.spec; do not edit!

LIBRARY ws2_32.dll

EXPORTS
  accept@12=WS_accept@12 @1
  bind@12=WS_bind@12 @2
  closesocket@4=WS_closesocket@4 @3
  connect@12=WS_connect@12 @4
  getpeername@12=WS_getpeername@12 @5
  getsockname@12=WS_getsockname@12 @6
  getsockopt@20=WS_getsockopt@20 @7
  htonl@4=WS_htonl@4 @8
  htons@4=WS_htons@4 @9
  ioctlsocket@12=WS_ioctlsocket@12 @10
  inet_addr@4=WS_inet_addr@4 @11
  inet_ntoa@4=WS_inet_ntoa@4 @12
  listen@8=WS_listen@8 @13
  ntohl@4=WS_ntohl@4 @14
  ntohs@4=WS_ntohs@4 @15
  recv@16=WS_recv@16 @16
  recvfrom@24=WS_recvfrom@24 @17
  select@20=WS_select@20 @18
  send@16=WS_send@16 @19
  sendto@24=WS_sendto@24 @20
  setsockopt@20=WS_setsockopt@20 @21
  shutdown@8=WS_shutdown@8 @22
  socket@12=WS_socket@12 @23
  gethostbyaddr@12=WS_gethostbyaddr@12 @51
  gethostbyname@4=WS_gethostbyname@4 @52
  getprotobyname@4=WS_getprotobyname@4 @53
  getprotobynumber@4=WS_getprotobynumber@4 @54
  getservbyname@8=WS_getservbyname@8 @55
  getservbyport@8=WS_getservbyport@8 @56
  gethostname@8=WS_gethostname@8 @57
  WSAAsyncSelect@16 @101
  WSAAsyncGetHostByAddr@28 @102
  WSAAsyncGetHostByName@20 @103
  WSAAsyncGetProtoByNumber@20 @104
  WSAAsyncGetProtoByName@20 @105
  WSAAsyncGetServByPort@24 @106
  WSAAsyncGetServByName@24 @107
  WSACancelAsyncRequest@4 @108
  WSASetBlockingHook@4 @109
  WSAUnhookBlockingHook@0 @110
  WSAGetLastError@0 @111
  WSASetLastError@4 @112
  WSACancelBlockingCall@0 @113
  WSAIsBlocking@0 @114
  WSAStartup@8 @115
  WSACleanup@0 @116
  __WSAFDIsSet@8 @151
  GetAddrInfoW@16 @24
  WSApSetPostRoutine@4 @25
  WPUCompleteOverlappedRequest@20 @26
  WSAAccept@20 @27
  WSAAddressToStringA@20 @28
  WSAAddressToStringW@20 @29
  WSACloseEvent@4 @30
  WSAConnect@28 @31
  WSACreateEvent@0 @32
  WSADuplicateSocketA@12 @33
  WSADuplicateSocketW@12 @34
  WSAEnumNameSpaceProvidersA@8 @35
  WSAEnumNameSpaceProvidersW@8 @36
  WSAEnumNetworkEvents@12 @37
  WSAEnumProtocolsA@12 @38
  WSAEnumProtocolsW@12 @39
  WSAEventSelect@12 @40
  WSAGetOverlappedResult@20 @41
  WSAGetQOSByName@12 @42
  WSAGetServiceClassInfoA@16 @43
  WSAGetServiceClassInfoW@16 @44
  WSAGetServiceClassNameByClassIdA@12 @45
  WSAGetServiceClassNameByClassIdW@12 @46
  WSAHtonl@12 @47
  WSAHtons@12 @48
  WSAInstallServiceClassA@4 @49
  WSAInstallServiceClassW@4 @50
  WSAIoctl@36 @58
  WSAJoinLeaf@32 @59
  WSALookupServiceBeginA@12 @60
  WSALookupServiceBeginW@12 @61
  WSALookupServiceEnd@4 @62
  WSALookupServiceNextA@16 @63
  WSALookupServiceNextW@16 @64
  WSANtohl@12 @66
  WSANtohs@12 @67
  WSAProviderConfigChange@12 @68
  WSARecv@28 @69
  WSARecvDisconnect@8 @70
  WSARecvFrom@36 @71
  WSARemoveServiceClass@4 @72
  WSAResetEvent@4=kernel32.ResetEvent @73
  WSASend@28 @74
  WSASendDisconnect@8 @75
  WSASendTo@36 @76
  WSASetEvent@4=kernel32.SetEvent @77
  WSASetServiceA@12 @78
  WSASetServiceW@12 @79
  WSASocketA@24 @80
  WSASocketW@24 @81
  WSAStringToAddressA@20 @82
  WSAStringToAddressW@20 @83
  WSAWaitForMultipleEvents@20=kernel32.WaitForMultipleObjectsEx @84
  WSCDeinstallProvider@8 @85
  WSCEnableNSProvider@8 @86
  WSCEnumProtocols@16 @87
  WSCGetProviderPath@16 @88
  WSCInstallNameSpace@20 @89
  WSCInstallProvider@20 @90
  WSCUnInstallNameSpace@4 @91
  WSCWriteProviderOrder@8 @94
  freeaddrinfo@4=WS_freeaddrinfo@4 @95
  getaddrinfo@16=WS_getaddrinfo@16 @96
  getnameinfo@28=WS_getnameinfo@28 @97
