; File generated automatically from ./oleacc.spec; do not edit!

LIBRARY oleacc.dll

EXPORTS
  AccessibleObjectFromWindow@16 @4
  CreateStdAccessibleObject@16 @5
  DllRegisterServer@0 @8 PRIVATE
  DllUnregisterServer@0 @9 PRIVATE
  LresultFromObject@12 @18
