; File generated automatically from ./rpcrt4.spec; do not edit!

LIBRARY rpcrt4.dll

EXPORTS
  CreateProxyFromTypeInfo@20 @1
  CStdStubBuffer_AddRef@4 @3
  CStdStubBuffer_Connect@8 @4
  CStdStubBuffer_CountRefs@4 @5
  CStdStubBuffer_DebugServerQueryInterface@8 @6
  CStdStubBuffer_DebugServerRelease@8 @7
  CStdStubBuffer_Disconnect@4 @8
  CStdStubBuffer_Invoke@12 @9
  CStdStubBuffer_IsIIDSupported@8 @10
  CStdStubBuffer_QueryInterface@12 @11
  DceErrorInqTextA@8 @13
  DceErrorInqTextW@8 @14
  DllRegisterServer@0 @15 PRIVATE
  IUnknown_AddRef_Proxy@4 @18
  IUnknown_QueryInterface_Proxy@12 @19
  IUnknown_Release_Proxy@4 @20
  I_RpcAllocate@4 @22
  I_RpcBindingSetAsync@8 @38
  I_RpcFree@4 @47
  I_RpcFreeBuffer@4 @48
  I_RpcGetBuffer@4 @51
  I_RpcMapWin32Status@4 @61
  I_RpcReceive@4 @73
  I_RpcSend@4 @75
  I_RpcSendReceive@4 @76
  I_RpcServerStartListening@4 @83
  I_RpcServerStopListening@0 @84
  I_RpcWindowProc@16 @123
  NDRCContextBinding@4 @139
  NDRCContextMarshall@8 @140
  NDRCContextUnmarshall@16 @141
  NDRSContextMarshall2@24 @142
  NDRSContextMarshall@12 @143
  NDRSContextMarshallEx@16 @144
  NDRSContextUnmarshall2@20 @145
  NDRSContextUnmarshall@8 @146
  NDRSContextUnmarshallEx@12 @147
  NdrAllocate@8 @149
  NdrByteCountPointerBufferSize@12 @152
  NdrByteCountPointerFree@12 @153
  NdrByteCountPointerMarshall@12 @154
  NdrByteCountPointerUnmarshall@16 @155
  NdrCStdStubBuffer2_Release@8 @156
  NdrCStdStubBuffer_Release@8 @157
  NdrClearOutParameters@12 @158
  NdrClientCall2 @159
  NdrClientCall=NdrClientCall2 @160
  NdrClientContextMarshall@12 @161
  NdrClientContextUnmarshall@12 @162
  NdrClientInitializeNew@16 @164
  NdrComplexArrayBufferSize@12 @165
  NdrComplexArrayFree@12 @166
  NdrComplexArrayMarshall@12 @167
  NdrComplexArrayMemorySize@8 @168
  NdrComplexArrayUnmarshall@16 @169
  NdrComplexStructBufferSize@12 @170
  NdrComplexStructFree@12 @171
  NdrComplexStructMarshall@12 @172
  NdrComplexStructMemorySize@8 @173
  NdrComplexStructUnmarshall@16 @174
  NdrConformantArrayBufferSize@12 @175
  NdrConformantArrayFree@12 @176
  NdrConformantArrayMarshall@12 @177
  NdrConformantArrayMemorySize@8 @178
  NdrConformantArrayUnmarshall@16 @179
  NdrConformantStringBufferSize@12 @180
  NdrConformantStringMarshall@12 @181
  NdrConformantStringMemorySize@8 @182
  NdrConformantStringUnmarshall@16 @183
  NdrConformantStructBufferSize@12 @184
  NdrConformantStructFree@12 @185
  NdrConformantStructMarshall@12 @186
  NdrConformantStructMemorySize@8 @187
  NdrConformantStructUnmarshall@16 @188
  NdrConformantVaryingArrayBufferSize@12 @189
  NdrConformantVaryingArrayFree@12 @190
  NdrConformantVaryingArrayMarshall@12 @191
  NdrConformantVaryingArrayMemorySize@8 @192
  NdrConformantVaryingArrayUnmarshall@16 @193
  NdrConformantVaryingStructBufferSize@12 @194
  NdrConformantVaryingStructFree@12 @195
  NdrConformantVaryingStructMarshall@12 @196
  NdrConformantVaryingStructMemorySize@8 @197
  NdrConformantVaryingStructUnmarshall@16 @198
  NdrContextHandleInitialize@8 @199
  NdrContextHandleSize@12 @200
  NdrConvert2@12 @201
  NdrConvert@8 @202
  NdrDllCanUnloadNow@4 @208
  NdrDllGetClassObject@24 @209
  NdrDllRegisterProxy@12 @210
  NdrDllUnregisterProxy@12 @211
  NdrEncapsulatedUnionBufferSize@12 @212
  NdrEncapsulatedUnionFree@12 @213
  NdrEncapsulatedUnionMarshall@12 @214
  NdrEncapsulatedUnionMemorySize@8 @215
  NdrEncapsulatedUnionUnmarshall@16 @216
  NdrFixedArrayBufferSize@12 @217
  NdrFixedArrayFree@12 @218
  NdrFixedArrayMarshall@12 @219
  NdrFixedArrayMemorySize@8 @220
  NdrFixedArrayUnmarshall@16 @221
  NdrFreeBuffer@4 @222
  NdrFullPointerFree@8 @223
  NdrFullPointerInsertRefId@12 @224
  NdrFullPointerQueryPointer@16 @225
  NdrFullPointerQueryRefId@16 @226
  NdrFullPointerXlatFree@4 @227
  NdrFullPointerXlatInit@8 @228
  NdrGetBuffer@12 @229
  NdrInterfacePointerBufferSize@12 @243
  NdrInterfacePointerFree@12 @244
  NdrInterfacePointerMarshall@12 @245
  NdrInterfacePointerMemorySize@8 @246
  NdrInterfacePointerUnmarshall@16 @247
  NdrMapCommAndFaultStatus@16 @249
  NdrNonConformantStringBufferSize@12 @263
  NdrNonConformantStringMarshall@12 @264
  NdrNonConformantStringMemorySize@8 @265
  NdrNonConformantStringUnmarshall@16 @266
  NdrNonEncapsulatedUnionBufferSize@12 @267
  NdrNonEncapsulatedUnionFree@12 @268
  NdrNonEncapsulatedUnionMarshall@12 @269
  NdrNonEncapsulatedUnionMemorySize@8 @270
  NdrNonEncapsulatedUnionUnmarshall@16 @271
  NdrOleAllocate@4 @274
  NdrOleFree@4 @275
  NdrPointerBufferSize@12 @286
  NdrPointerFree@12 @287
  NdrPointerMarshall@12 @288
  NdrPointerMemorySize@8 @289
  NdrPointerUnmarshall@16 @290
  NdrProxyErrorHandler@4 @291
  NdrProxyFreeBuffer@8 @292
  NdrProxyGetBuffer@8 @293
  NdrProxyInitialize@20 @294
  NdrProxySendReceive@8 @295
  NdrSendReceive@8 @304
  NdrServerCall2@4 @305
  NdrServerContextMarshall@12 @307
  NdrServerContextNewMarshall@16 @308
  NdrServerContextNewUnmarshall@8 @309
  NdrServerContextUnmarshall@4 @310
  NdrServerInitializeNew@12 @313
  NdrSimpleStructBufferSize@12 @318
  NdrSimpleStructFree@12 @319
  NdrSimpleStructMarshall@12 @320
  NdrSimpleStructMemorySize@8 @321
  NdrSimpleStructUnmarshall@16 @322
  NdrSimpleTypeMarshall@12 @323
  NdrSimpleTypeUnmarshall@12 @324
  NdrStubCall2@16 @325
  NdrStubForwardingFunction@16 @327
  NdrStubGetBuffer@12 @328
  NdrStubInitialize@16 @329
  NdrUserMarshalBufferSize@12 @337
  NdrUserMarshalFree@12 @338
  NdrUserMarshalMarshall@12 @339
  NdrUserMarshalMemorySize@8 @340
  NdrUserMarshalUnmarshall@16 @342
  NdrVaryingArrayBufferSize@12 @343
  NdrVaryingArrayFree@12 @344
  NdrVaryingArrayMarshall@12 @345
  NdrVaryingArrayMemorySize@8 @346
  NdrVaryingArrayUnmarshall@16 @347
  NdrXmitOrRepAsBufferSize@12 @348
  NdrXmitOrRepAsFree@12 @349
  NdrXmitOrRepAsMarshall@12 @350
  NdrXmitOrRepAsMemorySize@8 @351
  NdrXmitOrRepAsUnmarshall@16 @352
  RpcBindingCopy@8 @371
  RpcBindingFree@4 @372
  RpcBindingFromStringBindingA@8 @373
  RpcBindingFromStringBindingW@8 @374
  RpcBindingInqAuthInfoA@24 @379
  RpcBindingInqAuthInfoExA@32 @380
  RpcBindingInqAuthInfoExW@32 @381
  RpcBindingInqAuthInfoW@24 @382
  RpcBindingInqObject@8 @383
  RpcBindingSetAuthInfoA@24 @387
  RpcBindingSetAuthInfoExA@28 @388
  RpcBindingSetAuthInfoExW@28 @389
  RpcBindingSetAuthInfoW@24 @390
  RpcBindingSetObject@8 @391
  RpcBindingSetOption@12 @392
  RpcBindingToStringBindingA@8 @393
  RpcBindingToStringBindingW@8 @394
  RpcBindingVectorFree@4 @395
  RpcEpRegisterA@16 @402
  RpcEpResolveBinding@8 @406
  RpcEpUnregister@12 @407
  RpcImpersonateClient@4 @421
  RpcMgmtEnableIdleCleanup@0 @425
  RpcMgmtEpEltInqBegin@24 @426
  RpcMgmtInqIfIds@8 @433
  RpcMgmtIsServerListening@4 @438
  RpcMgmtSetComTimeout@8 @441
  RpcMgmtSetServerStackSize@4 @443
  RpcMgmtStopServerListening@4 @445
  RpcMgmtWaitServerListen@0 @446
  RpcNetworkIsProtseqValidA@4 @449
  RpcNetworkIsProtseqValidW@4 @450
  RpcObjectSetType@8 @455
  RpcRaiseException@4 @458
  RpcRevertToSelf@0 @460
  RpcRevertToSelfEx@4 @461
  RpcServerInqBindings@4 @462
  RpcServerListen@12 @468
  RpcServerRegisterAuthInfoA@16 @469
  RpcServerRegisterAuthInfoW@16 @470
  RpcServerRegisterIf2@28 @471
  RpcServerRegisterIf@12 @472
  RpcServerRegisterIfEx@24 @473
  RpcServerUnregisterIf@12 @475
  RpcServerUnregisterIfEx@12 @476
  RpcServerUseProtseqA@12 @481
  RpcServerUseProtseqEpA@16 @482
  RpcServerUseProtseqEpExA@20 @483
  RpcServerUseProtseqEpExW@20 @484
  RpcServerUseProtseqEpW@16 @485
  RpcServerUseProtseqW@12 @492
  RpcStringBindingComposeA@24 @517
  RpcStringBindingComposeW@24 @518
  RpcStringBindingParseA@24 @519
  RpcStringBindingParseW@24 @520
  RpcStringFreeA@4 @521
  RpcStringFreeW@4 @522
  TowerConstruct@24 @529
  TowerExplode@24 @530
  UuidCompare@12 @531
  UuidCreate@4 @532
  UuidCreateNil@4 @533
  UuidCreateSequential@4 @534
  UuidEqual@12 @535
  UuidFromStringA@8 @536
  UuidFromStringW@8 @537
  UuidHash@8 @538
  UuidIsNil@8 @539
  UuidToStringA@8 @540
  UuidToStringW@8 @541
