; File generated automatically from ./gdi32.spec; do not edit!

LIBRARY gdi32.dll

EXPORTS
  AbortDoc@4 @105
  AbortPath@4 @106
  AddFontMemResourceEx@16 @107
  AddFontResourceA@4 @108
  AddFontResourceExA@12 @109
  AddFontResourceExW@12 @110
  AddFontResourceW@4 @112
  AngleArc@24 @113
  AnimatePalette@16 @114
  Arc@36 @115
  ArcTo@36 @116
  BeginPath@4 @117
  BitBlt@36 @118
  CancelDC@4 @120
  ChoosePixelFormat@8 @122
  Chord@36 @123
  CloseEnhMetaFile@4 @124
  CloseFigure@4 @125
  CloseMetaFile@4 @126
  CombineRgn@16 @129
  CombineTransform@12 @130
  CopyEnhMetaFileA@8 @131
  CopyEnhMetaFileW@8 @132
  CopyMetaFileA@8 @133
  CopyMetaFileW@8 @134
  CreateBitmap@20 @135
  CreateBitmapIndirect@4 @136
  CreateBrushIndirect@4 @137
  CreateColorSpaceA@4 @138
  CreateColorSpaceW@4 @139
  CreateCompatibleBitmap@12 @140
  CreateCompatibleDC@4 @141
  CreateDCA@16 @142
  CreateDCW@16 @143
  CreateDIBPatternBrush@8 @144
  CreateDIBPatternBrushPt@8 @145
  CreateDIBSection@24 @146
  CreateDIBitmap@24 @147
  CreateDiscardableBitmap@12 @148
  CreateEllipticRgn@16 @149
  CreateEllipticRgnIndirect@4 @150
  CreateEnhMetaFileA@16 @151
  CreateEnhMetaFileW@16 @152
  CreateFontA@56 @153
  CreateFontIndirectA@4 @154
  CreateFontIndirectW@4 @155
  CreateFontW@56 @156
  CreateHalftonePalette@4 @157
  CreateHatchBrush@8 @158
  CreateICA@16 @159
  CreateICW@16 @160
  CreateMetaFileA@4 @161
  CreateMetaFileW@4 @162
  CreatePalette@4 @163
  CreatePatternBrush@4 @164
  CreatePen@12 @165
  CreatePenIndirect@4 @166
  CreatePolyPolygonRgn@16 @167
  CreatePolygonRgn@12 @168
  CreateRectRgn@16 @169
  CreateRectRgnIndirect@4 @170
  CreateRoundRectRgn@24 @171
  CreateScalableFontResourceA@16 @172
  CreateScalableFontResourceW@16 @173
  CreateSolidBrush@4 @174
  DPtoLP@12 @175
  DeleteColorSpace@4 @176
  DeleteDC@4 @177
  DeleteEnhMetaFile@4 @178
  DeleteMetaFile@4 @179
  DeleteObject@4 @180
  DescribePixelFormat@16 @181
  DrawEscape@16 @185
  Ellipse@20 @186
  EnableEUDC@4 @187
  EndDoc@4 @188
  EndPage@4 @189
  EndPath@4 @190
  EnumEnhMetaFile@20 @191
  EnumFontFamiliesA@16 @192
  EnumFontFamiliesExA@20 @193
  EnumFontFamiliesExW@20 @194
  EnumFontFamiliesW@16 @195
  EnumFontsA@16 @196
  EnumFontsW@16 @197
  EnumICMProfilesA@12 @198
  EnumICMProfilesW@12 @199
  EnumMetaFile@16 @200
  EnumObjects@16 @201
  EqualRgn@8 @202
  Escape@20 @203
  ExcludeClipRect@20 @204
  ExtCreatePen@20 @205
  ExtCreateRegion@12 @206
  ExtEscape@24 @207
  ExtFloodFill@20 @208
  ExtSelectClipRgn@12 @209
  ExtTextOutA@32 @210
  ExtTextOutW@32 @211
  FillPath@4 @212
  FillRgn@12 @213
  FixBrushOrgEx@16 @214
  FlattenPath@4 @215
  FloodFill@16 @216
  FontIsLinked@4 @217
  FrameRgn@20 @218
  GdiAlphaBlend@44 @220
  GdiComment@12 @223
  GdiConvertToDevmodeW@4 @233
  GdiFlush@0 @255
  GdiGetBatchLimit@0 @256
  GdiGetCharDimensions@12 @257
  GdiGetCodePage@4 @258
  GdiGradientFill@24 @263
  GdiIsMetaFileDC@4 @264
  GdiIsMetaPrintDC@4 @265
  GdiIsPlayMetafileDC@4 @266
  GdiSetBatchLimit@4 @272
  GdiTransparentBlt@44 @274
  GetArcDirection@4 @279
  GetAspectRatioFilterEx@8 @280
  GetBitmapBits@12 @281
  GetBitmapDimensionEx@8 @282
  GetBkColor@4 @283
  GetBkMode@4 @284
  GetBoundsRect@12 @285
  GetBrushOrgEx@8 @286
  GetCharABCWidthsA@16 @287
  GetCharABCWidthsFloatA@16 @288
  GetCharABCWidthsFloatW@16 @289
  GetCharABCWidthsI@20 @290
  GetCharABCWidthsW@16 @291
  GetCharWidth32A@16 @292
  GetCharWidth32W@16 @293
  GetCharWidthA@16=GetCharWidth32A@16 @294
  GetCharWidthFloatA@16 @295
  GetCharWidthFloatW@16 @296
  GetCharWidthI@20 @297
  GetCharWidthW@16=GetCharWidth32W@16 @298
  GetCharacterPlacementA@24 @300
  GetCharacterPlacementW@24 @301
  GetClipBox@8 @302
  GetClipRgn@8 @303
  GetColorAdjustment@8 @304
  GetColorSpace@4 @305
  GetCurrentObject@8 @306
  GetCurrentPositionEx@8 @307
  GetDCBrushColor@4 @308
  GetDCOrgEx@8 @309
  GetDCPenColor@4 @310
  GetDIBColorTable@16 @311
  GetDIBits@28 @312
  GetDeviceCaps@8 @313
  GetDeviceGammaRamp@8 @314
  GetEnhMetaFileA@4 @316
  GetEnhMetaFileBits@12 @317
  GetEnhMetaFileDescriptionA@12 @318
  GetEnhMetaFileDescriptionW@12 @319
  GetEnhMetaFileHeader@12 @320
  GetEnhMetaFilePaletteEntries@12 @321
  GetEnhMetaFileW@4 @322
  GetFontData@20 @323
  GetFontLanguageInfo@4 @324
  GetFontUnicodeRanges@8 @327
  GetGlyphIndicesA@20 @328
  GetGlyphIndicesW@20 @329
  GetGlyphOutlineA@28 @331
  GetGlyphOutlineW@28 @332
  GetGraphicsMode@4 @334
  GetICMProfileA@12 @335
  GetICMProfileW@12 @336
  GetKerningPairs@12=GetKerningPairsA@12 @337
  GetKerningPairsA@12 @338
  GetKerningPairsW@12 @339
  GetLayout@4 @340
  GetLogColorSpaceA@12 @341
  GetLogColorSpaceW@12 @342
  GetMapMode@4 @343
  GetMetaFileA@4 @344
  GetMetaFileBitsEx@12 @345
  GetMetaFileW@4 @346
  GetMetaRgn@8 @347
  GetMiterLimit@8 @348
  GetNearestColor@8 @349
  GetNearestPaletteIndex@8 @350
  GetObjectA@12 @351
  GetObjectType@4 @352
  GetObjectW@12 @353
  GetOutlineTextMetricsA@12 @354
  GetOutlineTextMetricsW@12 @355
  GetPaletteEntries@16 @356
  GetPath@16 @357
  GetPixel@12 @358
  GetPixelFormat@4 @359
  GetPolyFillMode@4 @360
  GetROP2@4 @361
  GetRandomRgn@12 @362
  GetRasterizerCaps@8 @363
  GetRegionData@12 @364
  GetRelAbs@8 @365
  GetRgnBox@8 @366
  GetStockObject@4 @367
  GetStretchBltMode@4 @368
  GetSystemPaletteEntries@16 @369
  GetSystemPaletteUse@4 @370
  GetTextAlign@4 @371
  GetTextCharacterExtra@4 @372
  GetTextCharset@4 @373
  GetTextCharsetInfo@12 @374
  GetTextColor@4 @375
  GetTextExtentExPointA@28 @376
  GetTextExtentExPointW@28 @377
  GetTextExtentPoint32A@16 @378
  GetTextExtentPoint32W@16 @379
  GetTextExtentPointA@16 @380
  GetTextExtentPointI@16 @381
  GetTextExtentPointW@16 @382
  GetTextFaceA@12 @383
  GetTextFaceW@12 @384
  GetTextMetricsA@8 @385
  GetTextMetricsW@8 @386
  GetTransform@12 @387
  GetViewportExtEx@8 @388
  GetViewportOrgEx@8 @389
  GetWinMetaFileBits@20 @390
  GetWindowExtEx@8 @391
  GetWindowOrgEx@8 @392
  GetWorldTransform@8 @393
  IntersectClipRect@20 @394
  InvertRgn@8 @395
  LPtoDP@12 @396
  LineDDA@24 @397
  LineTo@12 @398
  MaskBlt@48 @401
  ModifyWorldTransform@12 @402
  MoveToEx@16 @403
  OffsetClipRgn@12 @404
  OffsetRgn@12 @405
  OffsetViewportOrgEx@16 @406
  OffsetWindowOrgEx@16 @407
  PaintRgn@8 @408
  PatBlt@24 @409
  PathToRegion@4 @410
  Pie@36 @411
  PlayEnhMetaFile@12 @412
  PlayEnhMetaFileRecord@16 @413
  PlayMetaFile@8 @414
  PlayMetaFileRecord@16 @415
  PlgBlt@40 @416
  PolyBezier@12 @417
  PolyBezierTo@12 @418
  PolyDraw@16 @419
  PolyPolygon@16 @420
  PolyPolyline@16 @421
  PolyTextOutA@12 @422
  PolyTextOutW@12 @423
  Polygon@12 @424
  Polyline@12 @425
  PolylineTo@12 @426
  PtInRegion@12 @427
  PtVisible@12 @428
  RealizePalette@4 @429
  RectInRegion@8 @430
  RectVisible@8 @431
  Rectangle@20 @432
  RemoveFontResourceA@4 @433
  RemoveFontResourceExA@12 @434
  RemoveFontResourceExW@12 @435
  RemoveFontResourceW@4 @437
  ResetDCA@8 @438
  ResetDCW@8 @439
  ResizePalette@8 @440
  RestoreDC@8 @441
  RoundRect@28 @442
  SaveDC@4 @443
  ScaleViewportExtEx@24 @444
  ScaleWindowExtEx@24 @445
  SelectClipPath@8 @447
  SelectClipRgn@8 @448
  SelectObject@8 @450
  SelectPalette@12 @451
  SetAbortProc@8 @452
  SetArcDirection@8 @453
  SetBitmapBits@12 @454
  SetBitmapDimensionEx@16 @455
  SetBkColor@8 @456
  SetBkMode@8 @457
  SetBoundsRect@12 @458
  SetBrushOrgEx@16 @459
  SetColorAdjustment@8 @460
  SetColorSpace@8 @461
  SetDCBrushColor@8 @462
  SetDCPenColor@8 @463
  SetDIBColorTable@16 @464
  SetDIBits@28 @465
  SetDIBitsToDevice@48 @466
  SetDeviceGammaRamp@8 @467
  SetEnhMetaFileBits@8 @468
  SetGraphicsMode@8 @470
  SetICMMode@8 @471
  SetICMProfileA@8 @472
  SetICMProfileW@8 @473
  SetLayout@8 @474
  SetMagicColors@12 @475
  SetMapMode@8 @476
  SetMapperFlags@8 @477
  SetMetaFileBitsEx@8 @478
  SetMetaRgn@4 @479
  SetMiterLimit@12 @480
  SetObjectOwner@8 @481
  SetPaletteEntries@16 @482
  SetPixel@16 @483
  SetPixelFormat@12 @484
  SetPixelV@16 @485
  SetPolyFillMode@8 @486
  SetROP2@8 @487
  SetRectRgn@20 @488
  SetRelAbs@8 @489
  SetStretchBltMode@8 @490
  SetSystemPaletteUse@8 @491
  SetTextAlign@8 @492
  SetTextCharacterExtra@8 @493
  SetTextColor@8 @494
  SetTextJustification@12 @495
  SetViewportExtEx@16 @496
  SetViewportOrgEx@16 @497
  SetVirtualResolution@20 @498
  SetWinMetaFileBits@16 @499
  SetWindowExtEx@16 @500
  SetWindowOrgEx@16 @501
  SetWorldTransform@8 @502
  StartDocA@8 @503
  StartDocW@8 @504
  StartPage@4 @505
  StretchBlt@44 @506
  StretchDIBits@52 @507
  StrokeAndFillPath@4 @508
  StrokePath@4 @509
  SwapBuffers@4 @510
  TextOutA@20 @511
  TextOutW@20 @512
  TranslateCharsetInfo@12 @513
  UnrealizeObject@4 @515
  UpdateColors@4 @516
  UpdateICMRegKey@16=UpdateICMRegKeyA@16 @517
  UpdateICMRegKeyA@16 @518
  UpdateICMRegKeyW@16 @519
  WidenPath@4 @520
  pfnRealizePalette @522 DATA
  pfnSelectPalette @523 DATA
  wglCreateContext@4 @525
  wglDeleteContext@4 @526
  wglGetCurrentContext@0 @527
  wglGetCurrentDC@0 @528
  wglGetProcAddress@4 @529 PRIVATE
  wglMakeCurrent@8 @530
  wglShareLists@8 @531
  wglUseFontBitmapsA@16 @532
  wglUseFontBitmapsW@16 @533
  CloseJob16@4 @534
  DrvGetPrinterData16@24 @535
  DrvSetPrinterData16@20 @536
  OpenJob16@12 @537
  SelectVisRgn16@8 @538
  SetDCHook@12 @539
  SetHookFlags16@8 @540
  WriteSpool16@12 @541
  __wine_make_gdi_object_system @542
