; File generated automatically from ./winmm.spec; do not edit!

LIBRARY winmm.dll

EXPORTS
  CloseDriver@12 @2
  DefDriverProc@20 @5
  DriverCallback@28 @6
  DrvClose@12=CloseDriver@12 @7
  DrvDefDriverProc@20=DefDriverProc@20 @8
  DrvGetModuleHandle@4=GetDriverModuleHandle@4 @9
  DrvOpen@12=OpenDriver@12 @10
  DrvOpenA@12=OpenDriverA@12 @11
  DrvSendMessage@16=SendDriverMessage@16 @12
  GetDriverFlags@4 @13
  GetDriverModuleHandle@4 @14
  OpenDriver@12 @15
  OpenDriverA@12 @16
  PlaySound@12=PlaySoundA@12 @17
  PlaySoundA@12 @18
  PlaySoundW@12 @19
  SendDriverMessage@16 @20
  auxGetDevCapsA@12 @21
  auxGetDevCapsW@12 @22
  auxGetNumDevs@0 @23
  auxGetVolume@8 @24
  auxOutMessage@16 @25
  auxSetVolume@8 @26
  joyGetDevCapsA@12 @28
  joyGetDevCapsW@12 @29
  joyGetNumDevs@0 @30
  joyGetPos@8 @31
  joyGetPosEx@8 @32
  joyGetThreshold@8 @33
  joyReleaseCapture@4 @34
  joySetCapture@16 @35
  joySetThreshold@8 @36
  mciDriverNotify@12 @37
  mciDriverYield@4 @38
  mciExecute@4 @39
  mciFreeCommandResource@4 @40
  mciGetCreatorTask@4 @41
  mciGetDeviceIDA@4 @42
  mciGetDeviceIDFromElementIDA@8 @43
  mciGetDeviceIDFromElementIDW@8 @44
  mciGetDeviceIDW@4 @45
  mciGetDriverData@4 @46
  mciGetErrorStringA@12 @47
  mciGetErrorStringW@12 @48
  mciGetYieldProc@8 @49
  mciLoadCommandResource@12 @50
  mciSendCommandA@16 @51
  mciSendCommandW@16 @52
  mciSendStringA@16 @53
  mciSendStringW@16 @54
  mciSetDriverData@8 @55
  mciSetYieldProc@12 @56
  midiInAddBuffer@12 @59
  midiInClose@4 @60
  midiInGetDevCapsA@12 @61
  midiInGetDevCapsW@12 @62
  midiInGetErrorTextA@12=midiOutGetErrorTextA@12 @63
  midiInGetErrorTextW@12=midiOutGetErrorTextW@12 @64
  midiInGetID@8 @65
  midiInGetNumDevs@0 @66
  midiInMessage@16 @67
  midiInOpen@20 @68
  midiInPrepareHeader@12 @69
  midiInReset@4 @70
  midiInStart@4 @71
  midiInStop@4 @72
  midiInUnprepareHeader@12 @73
  midiOutCacheDrumPatches@16 @74
  midiOutCachePatches@16 @75
  midiOutClose@4 @76
  midiOutGetDevCapsA@12 @77
  midiOutGetDevCapsW@12 @78
  midiOutGetErrorTextA@12 @79
  midiOutGetErrorTextW@12 @80
  midiOutGetID@8 @81
  midiOutGetNumDevs@0 @82
  midiOutGetVolume@8 @83
  midiOutLongMsg@12 @84
  midiOutMessage@16 @85
  midiOutOpen@20 @86
  midiOutPrepareHeader@12 @87
  midiOutReset@4 @88
  midiOutSetVolume@8 @89
  midiOutShortMsg@8 @90
  midiOutUnprepareHeader@12 @91
  midiStreamClose@4 @92
  midiStreamOpen@24 @93
  midiStreamOut@12 @94
  midiStreamPause@4 @95
  midiStreamPosition@12 @96
  midiStreamProperty@12 @97
  midiStreamRestart@4 @98
  midiStreamStop@4 @99
  mixerClose@4 @100
  mixerGetControlDetailsA@12 @101
  mixerGetControlDetailsW@12 @102
  mixerGetDevCapsA@12 @103
  mixerGetDevCapsW@12 @104
  mixerGetID@12 @105
  mixerGetLineControlsA@12 @106
  mixerGetLineControlsW@12 @107
  mixerGetLineInfoA@12 @108
  mixerGetLineInfoW@12 @109
  mixerGetNumDevs@0 @110
  mixerMessage@16 @111
  mixerOpen@20 @112
  mixerSetControlDetails@12 @113
  mmGetCurrentTask@0 @114
  mmTaskBlock@4 @115
  mmTaskCreate@12 @116
  mmTaskSignal@4 @117
  mmTaskYield@0 @118
  mmioAdvance@12 @119
  mmioAscend@12 @120
  mmioClose@8 @121
  mmioCreateChunk@12 @122
  mmioDescend@16 @123
  mmioFlush@8 @124
  mmioGetInfo@12 @125
  mmioInstallIOProcA@12 @127
  mmioInstallIOProcW@12 @128
  mmioOpenA@12 @129
  mmioOpenW@12 @130
  mmioRead@12 @131
  mmioRenameA@16 @132
  mmioRenameW@16 @133
  mmioSeek@12 @134
  mmioSendMessage@16 @135
  mmioSetBuffer@16 @136
  mmioSetInfo@12 @137
  mmioStringToFOURCCA@8 @138
  mmioStringToFOURCCW@8 @139
  mmioWrite@12 @140
  mmsystemGetVersion@0 @141
  sndPlaySoundA@8 @142
  sndPlaySoundW@8 @143
  timeBeginPeriod@4 @144
  timeEndPeriod@4 @145
  timeGetDevCaps@8 @146
  timeGetSystemTime@8 @147
  timeGetTime@0 @148
  timeKillEvent@4 @149
  timeSetEvent@20 @150
  waveInAddBuffer@12 @151
  waveInClose@4 @152
  waveInGetDevCapsA@12 @153
  waveInGetDevCapsW@12 @154
  waveInGetErrorTextA@12=waveOutGetErrorTextA@12 @155
  waveInGetErrorTextW@12=waveOutGetErrorTextW@12 @156
  waveInGetID@8 @157
  waveInGetNumDevs@0 @158
  waveInGetPosition@12 @159
  waveInMessage@16 @160
  waveInOpen@24 @161
  waveInPrepareHeader@12 @162
  waveInReset@4 @163
  waveInStart@4 @164
  waveInStop@4 @165
  waveInUnprepareHeader@12 @166
  waveOutBreakLoop@4 @167
  waveOutClose@4 @168
  waveOutGetDevCapsA@12 @169
  waveOutGetDevCapsW@12 @170
  waveOutGetErrorTextA@12 @171
  waveOutGetErrorTextW@12 @172
  waveOutGetID@8 @173
  waveOutGetNumDevs@0 @174
  waveOutGetPitch@8 @175
  waveOutGetPlaybackRate@8 @176
  waveOutGetPosition@12 @177
  waveOutGetVolume@8 @178
  waveOutMessage@16 @179
  waveOutOpen@24 @180
  waveOutPause@4 @181
  waveOutPrepareHeader@12 @182
  waveOutReset@4 @183
  waveOutRestart@4 @184
  waveOutSetPitch@8 @185
  waveOutSetPlaybackRate@8 @186
  waveOutSetVolume@8 @187
  waveOutUnprepareHeader@12 @188
  waveOutWrite@12 @189
