; File generated automatically from ./advapi32.spec; do not edit!

LIBRARY advapi32.dll

EXPORTS
  A_SHAFinal@8 @1
  A_SHAInit@4 @2
  A_SHAUpdate@12 @3
  AbortSystemShutdownA@4 @4
  AbortSystemShutdownW@4 @5
  AccessCheck@32 @6
  AccessCheckAndAuditAlarmA@44 @7
  AccessCheckAndAuditAlarmW@44 @8
  AccessCheckByType@44 @9
  AddAccessAllowedAce@16 @10
  AddAccessAllowedAceEx@20 @11
  AddAccessDeniedAce@16 @12
  AddAccessDeniedAceEx@20 @13
  AddAce@20 @14
  AddAuditAccessAce@24 @15
  AdjustTokenGroups@24 @16
  AdjustTokenPrivileges@24 @17
  AllocateAndInitializeSid@44 @18
  AllocateLocallyUniqueId@4 @19
  AreAllAccessesGranted@8 @20
  AreAnyAccessesGranted@8 @21
  BackupEventLogA@8 @22
  BackupEventLogW@8 @23
  BuildExplicitAccessWithNameA@20 @24
  BuildExplicitAccessWithNameW@20 @25
  BuildSecurityDescriptorA@36 @26
  BuildSecurityDescriptorW@36 @27
  BuildTrusteeWithNameA@8 @28
  BuildTrusteeWithNameW@8 @29
  BuildTrusteeWithObjectsAndNameA@24 @30
  BuildTrusteeWithObjectsAndNameW@24 @31
  BuildTrusteeWithObjectsAndSidA@20 @32
  BuildTrusteeWithObjectsAndSidW@20 @33
  BuildTrusteeWithSidA@8 @34
  BuildTrusteeWithSidW@8 @35
  ChangeServiceConfig2A@12 @36
  ChangeServiceConfig2W@12 @37
  ChangeServiceConfigA@44 @38
  ChangeServiceConfigW@44 @39
  CheckTokenMembership@12 @40
  ClearEventLogA@8 @41
  ClearEventLogW@8 @42
  CloseEventLog@4 @43
  CloseServiceHandle@4 @44
  CommandLineFromMsiDescriptor@12 @45
  ControlService@12 @46
  ConvertSidToStringSidA@8 @47
  ConvertSidToStringSidW@8 @48
  ConvertStringSecurityDescriptorToSecurityDescriptorA@16 @49
  ConvertStringSecurityDescriptorToSecurityDescriptorW@16 @50
  ConvertStringSidToSidA@8 @51
  ConvertStringSidToSidW@8 @52
  CopySid@12 @53
  CreatePrivateObjectSecurity@24 @54
  CreateProcessAsUserA@44 @55
  CreateProcessAsUserW@44 @56
  CreateServiceA@52 @57
  CreateServiceW@52 @58
  CreateWellKnownSid@16 @59
  CryptAcquireContextA@20 @61
  CryptAcquireContextW@20 @62
  CryptContextAddRef@12 @63
  CryptCreateHash@20 @64
  CryptDecrypt@24 @65
  CryptDeriveKey@20 @66
  CryptDestroyHash@4 @67
  CryptDestroyKey@4 @68
  CryptDuplicateHash@16 @69
  CryptDuplicateKey@16 @70
  CryptEncrypt@28 @71
  CryptEnumProviderTypesA@24 @72
  CryptEnumProviderTypesW@24 @73
  CryptEnumProvidersA@24 @74
  CryptEnumProvidersW@24 @75
  CryptExportKey@24 @76
  CryptGenKey@16 @77
  CryptGenRandom@12 @78
  CryptGetDefaultProviderA@20 @79
  CryptGetDefaultProviderW@20 @80
  CryptGetHashParam@20 @81
  CryptGetKeyParam@20 @82
  CryptGetProvParam@20 @83
  CryptGetUserKey@12 @84
  CryptHashData@16 @85
  CryptHashSessionKey@12 @86
  CryptImportKey@24 @87
  CryptReleaseContext@8 @88
  CryptSetHashParam@16 @89
  CryptSetKeyParam@16 @90
  CryptSetProvParam@16 @91
  CryptSetProviderA@8 @92
  CryptSetProviderExA@16 @93
  CryptSetProviderExW@16 @94
  CryptSetProviderW@8 @95
  CryptSignHashA@24 @96
  CryptSignHashW@24 @97
  CryptVerifySignatureA@24 @98
  CryptVerifySignatureW@24 @99
  DecryptFileA@8 @100
  DecryptFileW@8 @101
  DeleteAce@8 @102
  DeleteService@4 @103
  DeregisterEventSource@4 @104
  DestroyPrivateObjectSecurity@4 @105
  DuplicateToken@12 @106
  DuplicateTokenEx@24 @107
  EncryptFileA@4 @112
  EncryptFileW@4 @113
  EnumDependentServicesA@24 @114
  EnumDependentServicesW@24 @115
  EnumServicesStatusA@32 @118
  EnumServicesStatusExA@40 @119
  EnumServicesStatusExW@40 @120
  EnumServicesStatusW@32 @121
  EqualPrefixSid@8 @122
  EqualSid@8 @123
  FileEncryptionStatusA@8 @124
  FileEncryptionStatusW@8 @125
  FindFirstFreeAce@8 @126
  FreeSid@4 @127
  GetAce@12 @128
  GetAclInformation@16 @129
  GetCurrentHwProfileA@4 @130
  GetCurrentHwProfileW@4 @131
  GetEffectiveRightsFromAclA@12 @132
  GetEffectiveRightsFromAclW@12 @133
  GetExplicitEntriesFromAclA@12 @134
  GetExplicitEntriesFromAclW@12 @135
  GetFileSecurityA@20 @136
  GetFileSecurityW@20 @137
  GetKernelObjectSecurity@20 @138
  GetLengthSid@4 @139
  GetNamedSecurityInfoA@32 @141
  GetNamedSecurityInfoW@32 @142
  GetNumberOfEventLogRecords@8 @143
  GetOldestEventLogRecord@8 @144
  GetPrivateObjectSecurity@20 @145
  GetSecurityDescriptorControl@12 @146
  GetSecurityDescriptorDacl@16 @147
  GetSecurityDescriptorGroup@12 @148
  GetSecurityDescriptorLength@4 @149
  GetSecurityDescriptorOwner@12 @150
  GetSecurityDescriptorSacl@16 @151
  GetSecurityInfo@32 @152
  GetSecurityInfoExW@36 @153
  GetServiceDisplayNameA@16 @154
  GetServiceDisplayNameW@16 @155
  GetServiceKeyNameA@16 @156
  GetServiceKeyNameW@16 @157
  GetSidIdentifierAuthority@4 @158
  GetSidLengthRequired@4 @159
  GetSidSubAuthority@8 @160
  GetSidSubAuthorityCount@4 @161
  GetTokenInformation@20 @163
  GetTrusteeFormA@4 @164
  GetTrusteeFormW@4 @165
  GetTrusteeNameA@4 @166
  GetTrusteeNameW@4 @167
  GetTrusteeTypeA@4 @168
  GetTrusteeTypeW@4 @169
  GetUserNameA@8 @170
  GetUserNameW@8 @171
  ImpersonateLoggedOnUser@4 @174
  ImpersonateNamedPipeClient@4 @175
  ImpersonateSelf@4 @176
  InitializeAcl@12 @177
  InitializeSecurityDescriptor@8 @178
  InitializeSid@12 @179
  InitiateSystemShutdownA@20 @180
  InitiateSystemShutdownExA@24 @181
  InitiateSystemShutdownExW@24 @182
  InitiateSystemShutdownW@20 @183
  IsTextUnicode@12 @186
  IsTokenRestricted@4 @187
  IsValidAcl@4 @188
  IsValidSecurityDescriptor@4 @189
  IsValidSid@4 @190
  IsWellKnownSid@8 @191
  LockServiceDatabase@4 @192
  LogonUserA@24 @193
  LogonUserW@24 @194
  LookupAccountNameA@28 @195
  LookupAccountNameW@28 @196
  LookupAccountSidA@28 @197
  LookupAccountSidW@28 @198
  LookupPrivilegeDisplayNameA@20 @199
  LookupPrivilegeDisplayNameW@20 @200
  LookupPrivilegeNameA@16 @201
  LookupPrivilegeNameW@16 @202
  LookupPrivilegeValueA@12 @203
  LookupPrivilegeValueW@12 @204
  LsaAddAccountRights@16 @205
  LsaClose@4 @207
  LsaCreateTrustedDomainEx@20 @211
  LsaDeleteTrustedDomain@8 @213
  LsaEnumerateAccountRights@16 @214
  LsaEnumerateAccountsWithUserRight@16 @216
  LsaEnumerateTrustedDomains@20 @219
  LsaEnumerateTrustedDomainsEx@20 @220
  LsaFreeMemory@4 @221
  LsaLookupNames2@24 @225
  LsaLookupNames@20 @226
  LsaLookupSids@20 @228
  LsaNtStatusToWinError@4 @229
  LsaOpenPolicy@16 @231
  LsaOpenTrustedDomainByName@16 @234
  LsaQueryInformationPolicy@12 @236
  LsaQueryTrustedDomainInfo@16 @238
  LsaQueryTrustedDomainInfoByName@16 @239
  LsaRegisterPolicyChangeNotification@8 @240
  LsaRemoveAccountRights@20 @241
  LsaRetrievePrivateData@12 @243
  LsaSetInformationPolicy@12 @244
  LsaSetTrustedDomainInfoByName@16 @248
  LsaSetTrustedDomainInformation@16 @249
  LsaStorePrivateData@12 @250
  LsaUnregisterPolicyChangeNotification@8 @251
  MD4Final@4 @252
  MD4Init@4 @253
  MD4Update@12 @254
  MD5Final@4 @255
  MD5Init@4 @256
  MD5Update@12 @257
  MakeAbsoluteSD@44 @258
  MakeSelfRelativeSD@12 @259
  MapGenericMask@8 @260
  NotifyBootConfigStatus@4 @261
  NotifyChangeEventLog@8 @262
  ObjectCloseAuditAlarmA@12 @263
  ObjectCloseAuditAlarmW@12 @264
  ObjectDeleteAuditAlarmW@12 @265
  ObjectOpenAuditAlarmA@48 @266
  ObjectOpenAuditAlarmW@48 @267
  ObjectPrivilegeAuditAlarmA@24 @268
  ObjectPrivilegeAuditAlarmW@24 @269
  OpenBackupEventLogA@8 @270
  OpenBackupEventLogW@8 @271
  OpenEventLogA@8 @272
  OpenEventLogW@8 @273
  OpenProcessToken@12 @274
  OpenSCManagerA@12 @275
  OpenSCManagerW@12 @276
  OpenServiceA@12 @277
  OpenServiceW@12 @278
  OpenThreadToken@16 @279
  PrivilegeCheck@12 @280
  PrivilegedServiceAuditAlarmA@20 @281
  PrivilegedServiceAuditAlarmW@20 @282
  QueryServiceConfigA@16 @283
  QueryServiceConfigW@16 @284
  QueryServiceLockStatusA@16 @285
  QueryServiceLockStatusW@16 @286
  QueryServiceObjectSecurity@20 @287
  QueryServiceStatus@8 @288
  QueryServiceStatusEx@20 @289
  QueryWindows31FilesMigration@4 @290
  ReadEventLogA@28 @291
  ReadEventLogW@28 @292
  RegCloseKey@4 @293
  RegConnectRegistryA@12 @294
  RegConnectRegistryW@12 @295
  RegCreateKeyA@12 @296
  RegCreateKeyExA@36 @297
  RegCreateKeyExW@36 @298
  RegCreateKeyW@12 @299
  RegDeleteKeyA@8 @300
  RegDeleteKeyW@8 @301
  RegDeleteTreeA@8 @302
  RegDeleteTreeW@8 @303
  RegDeleteValueA@8 @304
  RegDeleteValueW@8 @305
  RegDisablePredefinedCache@0 @306
  RegEnumKeyA@16 @307
  RegEnumKeyExA@32 @308
  RegEnumKeyExW@32 @309
  RegEnumKeyW@16 @310
  RegEnumValueA@32 @311
  RegEnumValueW@32 @312
  RegFlushKey@4 @313
  RegGetKeySecurity@16 @314
  RegGetValueA@28 @315
  RegGetValueW@28 @316
  RegLoadKeyA@12 @317
  RegLoadKeyW@12 @318
  RegLoadMUIStringA@28 @319
  RegLoadMUIStringW@28 @320
  RegNotifyChangeKeyValue@20 @321
  RegOpenCurrentUser@8 @322
  RegOpenKeyA@12 @323
  RegOpenKeyExA@20 @324
  RegOpenKeyExW@20 @325
  RegOpenKeyW@12 @326
  RegOpenUserClassesRoot@16 @327
  RegQueryInfoKeyA@48 @328
  RegQueryInfoKeyW@48 @329
  RegQueryMultipleValuesA@20 @330
  RegQueryMultipleValuesW@20 @331
  RegQueryValueA@16 @332
  RegQueryValueExA@24 @333
  RegQueryValueExW@24 @334
  RegQueryValueW@16 @335
  RegReplaceKeyA@16 @337
  RegReplaceKeyW@16 @338
  RegRestoreKeyA@12 @339
  RegRestoreKeyW@12 @340
  RegSaveKeyA@12 @341
  RegSaveKeyW@12 @342
  RegSetKeySecurity@12 @343
  RegSetValueA@20 @344
  RegSetValueExA@24 @345
  RegSetValueExW@24 @346
  RegSetValueW@20 @347
  RegUnLoadKeyA@8 @348
  RegUnLoadKeyW@8 @349
  RegisterEventSourceA@8 @350
  RegisterEventSourceW@8 @351
  RegisterServiceCtrlHandlerA@8 @352
  RegisterServiceCtrlHandlerExA@12 @353
  RegisterServiceCtrlHandlerExW@12 @354
  RegisterServiceCtrlHandlerW@8 @355
  RegisterTraceGuidsA@32 @356
  RegisterTraceGuidsW@32 @357
  ReportEventA@36 @358
  ReportEventW@36 @359
  RevertToSelf@0 @360
  SetAclInformation@16 @361
  SetEntriesInAclA@16 @362
  SetEntriesInAclW@16 @363
  SetFileSecurityA@12 @364
  SetFileSecurityW@12 @365
  SetKernelObjectSecurity@12 @366
  SetNamedSecurityInfoA@28 @367
  SetNamedSecurityInfoW@28 @368
  SetPrivateObjectSecurity@20 @369
  SetSecurityDescriptorControl@12 @370
  SetSecurityDescriptorDacl@16 @371
  SetSecurityDescriptorGroup@12 @372
  SetSecurityDescriptorOwner@12 @373
  SetSecurityDescriptorSacl@16 @374
  SetSecurityInfo@28 @375
  SetServiceBits@16 @376
  SetServiceObjectSecurity@12 @377
  SetServiceStatus@8 @378
  SetThreadToken@8 @379
  SetTokenInformation@16 @380
  StartServiceA@12 @381
  StartServiceCtrlDispatcherA@4 @382
  StartServiceCtrlDispatcherW@4 @383
  StartServiceW@12 @384
  SynchronizeWindows31FilesAndWindowsNTRegistry@16 @385
  SystemFunction001@12 @386
  SystemFunction002@12 @387
  SystemFunction003@8 @388
  SystemFunction004@12 @389
  SystemFunction005@12 @390
  SystemFunction006@8 @391
  SystemFunction007@8 @392
  SystemFunction008@12 @393
  SystemFunction009@12 @394
  SystemFunction010@12 @395
  SystemFunction011@12=SystemFunction010@12 @396
  SystemFunction012@12 @397
  SystemFunction013@12 @398
  SystemFunction014@12=SystemFunction012@12 @399
  SystemFunction015@12=SystemFunction013@12 @400
  SystemFunction016@12=SystemFunction012@12 @401
  SystemFunction017@12=SystemFunction013@12 @402
  SystemFunction018@12=SystemFunction012@12 @403
  SystemFunction019@12=SystemFunction013@12 @404
  SystemFunction020@12=SystemFunction012@12 @405
  SystemFunction021@12=SystemFunction013@12 @406
  SystemFunction022@12=SystemFunction012@12 @407
  SystemFunction023@12=SystemFunction013@12 @408
  SystemFunction024@12 @409
  SystemFunction025@12 @410
  SystemFunction026@12=SystemFunction024@12 @411
  SystemFunction027@12=SystemFunction025@12 @412
  SystemFunction030@8 @415
  SystemFunction031@8=SystemFunction030@8 @416
  SystemFunction032@8 @417
  SystemFunction035@4 @420
  SystemFunction036@8 @421
  SystemFunction040@12 @422
  SystemFunction041@12 @423
  UnlockServiceDatabase@4 @428
