/*** Autogenerated by WIDL 0.9.40 from mshtml.idl - Do not edit ***/
#include <rpc.h>
#include <rpcndr.h>

#ifndef __WIDL_MSHTML_H
#define __WIDL_MSHTML_H
#ifdef __cplusplus
extern "C" {
#endif
#include <ocidl.h>
#include <olectl.h>
#ifndef __IHTMLDocument2_FWD_DEFINED__
#define __IHTMLDocument2_FWD_DEFINED__
typedef interface IHTMLDocument2 IHTMLDocument2;
#endif

#ifndef __IHTMLStyleSheetsCollection_FWD_DEFINED__
#define __IHTMLStyleSheetsCollection_FWD_DEFINED__
typedef interface IHTMLStyleSheetsCollection IHTMLStyleSheetsCollection;
#endif

#ifndef __IHTMLFiltersCollection_FWD_DEFINED__
#define __IHTMLFiltersCollection_FWD_DEFINED__
typedef interface IHTMLFiltersCollection IHTMLFiltersCollection;
#endif

/*****************************************************************************
 * IHTMLFiltersCollection interface
 */
#ifndef __IHTMLFiltersCollection_INTERFACE_DEFINED__
#define __IHTMLFiltersCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLFiltersCollection, 0x3050f3ee, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLFiltersCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT *pvarIndex,
        VARIANT *pvarResult) = 0;

};
#else
typedef struct IHTMLFiltersCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLFiltersCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLFiltersCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLFiltersCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLFiltersCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLFiltersCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLFiltersCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLFiltersCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLFiltersCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLFiltersCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLFiltersCollection* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLFiltersCollection* This,
        VARIANT *pvarIndex,
        VARIANT *pvarResult);

    END_INTERFACE
} IHTMLFiltersCollectionVtbl;
interface IHTMLFiltersCollection {
    CONST_VTBL IHTMLFiltersCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLFiltersCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLFiltersCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLFiltersCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLFiltersCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLFiltersCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLFiltersCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLFiltersCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLFiltersCollection methods ***/
#define IHTMLFiltersCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLFiltersCollection_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLFiltersCollection_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLFiltersCollection_get_length_Proxy(
    IHTMLFiltersCollection* This,
    long *p);
void __RPC_STUB IHTMLFiltersCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFiltersCollection_get__newEnum_Proxy(
    IHTMLFiltersCollection* This,
    IUnknown **p);
void __RPC_STUB IHTMLFiltersCollection_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFiltersCollection_item_Proxy(
    IHTMLFiltersCollection* This,
    VARIANT *pvarIndex,
    VARIANT *pvarResult);
void __RPC_STUB IHTMLFiltersCollection_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLFiltersCollection_INTERFACE_DEFINED__ */


DEFINE_GUID(LIBID_MSHTML, 0x3050f1c5, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);

#ifndef __IHTMLStyle_FWD_DEFINED__
#define __IHTMLStyle_FWD_DEFINED__
typedef interface IHTMLStyle IHTMLStyle;
#endif

/*****************************************************************************
 * IHTMLStyle interface
 */
#ifndef __IHTMLStyle_INTERFACE_DEFINED__
#define __IHTMLStyle_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLStyle, 0x3050f25e, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLStyle : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_fontFamily(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontFamily(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontVariant(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontVariant(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontWeight(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontWeight(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontSize(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontSize(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_font(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_font(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_color(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_color(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_background(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_background(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundImage(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundRepeat(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundRepeat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundAttachment(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundAttachment(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPosition(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPositionX(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionX(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPositionY(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionY(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_wordSpacing(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_wordSpacing(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_letterSpacing(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_letterSpacing(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecoration(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecoration(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationNone(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationNone(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationUnderline(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationUnderline(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationOverline(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationOverline(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationLineThrough(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationLineThrough(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationBlink(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationBlink(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_verticalAlign(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_verticalAlign(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textTransform(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textTransform(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textAlign(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textAlign(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textIndent(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textIndent(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_lineHeight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lineHeight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginTop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginRight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginBottom(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginLeft(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_margin(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_margin(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingTop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingRight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingBottom(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingLeft(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_padding(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_padding(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_border(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_border(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTop(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTop(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRight(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRight(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottom(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottom(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeft(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeft(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderColor(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderColor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderWidth(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderWidth(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_width(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_height(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_styleFloat(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_styleFloat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_clear(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clear(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_display(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_display(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_visibility(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_visibility(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyleType(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStylePosition(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStylePosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyleImage(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_whiteSpace(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_whiteSpace(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_top(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_top(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_left(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_left(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_position(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_zIndex(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_zIndex(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_overflow(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_overflow(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pageBreakBefore(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakBefore(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pageBreakAfter(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakAfter(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cssText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cssText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pixelTop(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pixelTop(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pixelLeft(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pixelLeft(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pixelWidth(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pixelWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pixelHeight(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pixelHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_posTop(
        float v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_posTop(
        float *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_posLeft(
        float v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_posLeft(
        float *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_posWidth(
        float v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_posWidth(
        float *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_posHeight(
        float v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_posHeight(
        float *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cursor(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cursor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_clip(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clip(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_filter(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_filter(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE setAttribute(
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

};
#else
typedef struct IHTMLStyleVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLStyle* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLStyle* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLStyle* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLStyle* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLStyle* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLStyle* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLStyle* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLStyle methods ***/
    HRESULT (STDMETHODCALLTYPE *put_fontFamily)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontFamily)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontVariant)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontVariant)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontWeight)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontWeight)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontSize)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_fontSize)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_font)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_font)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_color)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_color)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_background)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_background)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundColor)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundColor)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundImage)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundImage)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundRepeat)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundRepeat)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundAttachment)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundAttachment)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPosition)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPosition)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPositionX)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionX)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPositionY)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionY)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_wordSpacing)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_wordSpacing)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_letterSpacing)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_letterSpacing)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecoration)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textDecoration)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationNone)(
        IHTMLStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationNone)(
        IHTMLStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationUnderline)(
        IHTMLStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationUnderline)(
        IHTMLStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationOverline)(
        IHTMLStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationOverline)(
        IHTMLStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationLineThrough)(
        IHTMLStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationLineThrough)(
        IHTMLStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationBlink)(
        IHTMLStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationBlink)(
        IHTMLStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_verticalAlign)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_verticalAlign)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textTransform)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textTransform)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textAlign)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textAlign)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textIndent)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_textIndent)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_lineHeight)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_lineHeight)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginTop)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginTop)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginRight)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginRight)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginBottom)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginBottom)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginLeft)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginLeft)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_margin)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_margin)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingTop)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingTop)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingRight)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingRight)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingBottom)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingBottom)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingLeft)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingLeft)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_padding)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_padding)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_border)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_border)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTop)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderTop)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRight)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderRight)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottom)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottom)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeft)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeft)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderColor)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderColor)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopColor)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopColor)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightColor)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightColor)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomColor)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomColor)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftColor)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftColor)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderWidth)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderWidth)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopWidth)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopWidth)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightWidth)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightWidth)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomWidth)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomWidth)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftWidth)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftWidth)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_width)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_height)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_styleFloat)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_styleFloat)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_clear)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_clear)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_display)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_display)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_visibility)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_visibility)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyleType)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyleType)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStylePosition)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStylePosition)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyleImage)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyleImage)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyle)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyle)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_whiteSpace)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_whiteSpace)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_top)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_top)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_left)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_left)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_position)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_zIndex)(
        IHTMLStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_zIndex)(
        IHTMLStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_overflow)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_overflow)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pageBreakBefore)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakBefore)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pageBreakAfter)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakAfter)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_cssText)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cssText)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pixelTop)(
        IHTMLStyle* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_pixelTop)(
        IHTMLStyle* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_pixelLeft)(
        IHTMLStyle* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_pixelLeft)(
        IHTMLStyle* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_pixelWidth)(
        IHTMLStyle* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_pixelWidth)(
        IHTMLStyle* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_pixelHeight)(
        IHTMLStyle* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_pixelHeight)(
        IHTMLStyle* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_posTop)(
        IHTMLStyle* This,
        float v);

    HRESULT (STDMETHODCALLTYPE *get_posTop)(
        IHTMLStyle* This,
        float *p);

    HRESULT (STDMETHODCALLTYPE *put_posLeft)(
        IHTMLStyle* This,
        float v);

    HRESULT (STDMETHODCALLTYPE *get_posLeft)(
        IHTMLStyle* This,
        float *p);

    HRESULT (STDMETHODCALLTYPE *put_posWidth)(
        IHTMLStyle* This,
        float v);

    HRESULT (STDMETHODCALLTYPE *get_posWidth)(
        IHTMLStyle* This,
        float *p);

    HRESULT (STDMETHODCALLTYPE *put_posHeight)(
        IHTMLStyle* This,
        float v);

    HRESULT (STDMETHODCALLTYPE *get_posHeight)(
        IHTMLStyle* This,
        float *p);

    HRESULT (STDMETHODCALLTYPE *put_cursor)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cursor)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_clip)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_clip)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_filter)(
        IHTMLStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_filter)(
        IHTMLStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *setAttribute)(
        IHTMLStyle* This,
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags);

    HRESULT (STDMETHODCALLTYPE *getAttribute)(
        IHTMLStyle* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue);

    HRESULT (STDMETHODCALLTYPE *removeAttribute)(
        IHTMLStyle* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLStyle* This,
        BSTR *String);

    END_INTERFACE
} IHTMLStyleVtbl;
interface IHTMLStyle {
    CONST_VTBL IHTMLStyleVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLStyle_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLStyle_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLStyle_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLStyle_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLStyle_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLStyle_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLStyle_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLStyle methods ***/
#define IHTMLStyle_put_fontFamily(p,a) (p)->lpVtbl->put_fontFamily(p,a)
#define IHTMLStyle_get_fontFamily(p,a) (p)->lpVtbl->get_fontFamily(p,a)
#define IHTMLStyle_put_fontStyle(p,a) (p)->lpVtbl->put_fontStyle(p,a)
#define IHTMLStyle_get_fontStyle(p,a) (p)->lpVtbl->get_fontStyle(p,a)
#define IHTMLStyle_put_fontVariant(p,a) (p)->lpVtbl->put_fontVariant(p,a)
#define IHTMLStyle_get_fontVariant(p,a) (p)->lpVtbl->get_fontVariant(p,a)
#define IHTMLStyle_put_fontWeight(p,a) (p)->lpVtbl->put_fontWeight(p,a)
#define IHTMLStyle_get_fontWeight(p,a) (p)->lpVtbl->get_fontWeight(p,a)
#define IHTMLStyle_put_fontSize(p,a) (p)->lpVtbl->put_fontSize(p,a)
#define IHTMLStyle_get_fontSize(p,a) (p)->lpVtbl->get_fontSize(p,a)
#define IHTMLStyle_put_font(p,a) (p)->lpVtbl->put_font(p,a)
#define IHTMLStyle_get_font(p,a) (p)->lpVtbl->get_font(p,a)
#define IHTMLStyle_put_color(p,a) (p)->lpVtbl->put_color(p,a)
#define IHTMLStyle_get_color(p,a) (p)->lpVtbl->get_color(p,a)
#define IHTMLStyle_put_background(p,a) (p)->lpVtbl->put_background(p,a)
#define IHTMLStyle_get_background(p,a) (p)->lpVtbl->get_background(p,a)
#define IHTMLStyle_put_backgroundColor(p,a) (p)->lpVtbl->put_backgroundColor(p,a)
#define IHTMLStyle_get_backgroundColor(p,a) (p)->lpVtbl->get_backgroundColor(p,a)
#define IHTMLStyle_put_backgroundImage(p,a) (p)->lpVtbl->put_backgroundImage(p,a)
#define IHTMLStyle_get_backgroundImage(p,a) (p)->lpVtbl->get_backgroundImage(p,a)
#define IHTMLStyle_put_backgroundRepeat(p,a) (p)->lpVtbl->put_backgroundRepeat(p,a)
#define IHTMLStyle_get_backgroundRepeat(p,a) (p)->lpVtbl->get_backgroundRepeat(p,a)
#define IHTMLStyle_put_backgroundAttachment(p,a) (p)->lpVtbl->put_backgroundAttachment(p,a)
#define IHTMLStyle_get_backgroundAttachment(p,a) (p)->lpVtbl->get_backgroundAttachment(p,a)
#define IHTMLStyle_put_backgroundPosition(p,a) (p)->lpVtbl->put_backgroundPosition(p,a)
#define IHTMLStyle_get_backgroundPosition(p,a) (p)->lpVtbl->get_backgroundPosition(p,a)
#define IHTMLStyle_put_backgroundPositionX(p,a) (p)->lpVtbl->put_backgroundPositionX(p,a)
#define IHTMLStyle_get_backgroundPositionX(p,a) (p)->lpVtbl->get_backgroundPositionX(p,a)
#define IHTMLStyle_put_backgroundPositionY(p,a) (p)->lpVtbl->put_backgroundPositionY(p,a)
#define IHTMLStyle_get_backgroundPositionY(p,a) (p)->lpVtbl->get_backgroundPositionY(p,a)
#define IHTMLStyle_put_wordSpacing(p,a) (p)->lpVtbl->put_wordSpacing(p,a)
#define IHTMLStyle_get_wordSpacing(p,a) (p)->lpVtbl->get_wordSpacing(p,a)
#define IHTMLStyle_put_letterSpacing(p,a) (p)->lpVtbl->put_letterSpacing(p,a)
#define IHTMLStyle_get_letterSpacing(p,a) (p)->lpVtbl->get_letterSpacing(p,a)
#define IHTMLStyle_put_textDecoration(p,a) (p)->lpVtbl->put_textDecoration(p,a)
#define IHTMLStyle_get_textDecoration(p,a) (p)->lpVtbl->get_textDecoration(p,a)
#define IHTMLStyle_put_textDecorationNone(p,a) (p)->lpVtbl->put_textDecorationNone(p,a)
#define IHTMLStyle_get_textDecorationNone(p,a) (p)->lpVtbl->get_textDecorationNone(p,a)
#define IHTMLStyle_put_textDecorationUnderline(p,a) (p)->lpVtbl->put_textDecorationUnderline(p,a)
#define IHTMLStyle_get_textDecorationUnderline(p,a) (p)->lpVtbl->get_textDecorationUnderline(p,a)
#define IHTMLStyle_put_textDecorationOverline(p,a) (p)->lpVtbl->put_textDecorationOverline(p,a)
#define IHTMLStyle_get_textDecorationOverline(p,a) (p)->lpVtbl->get_textDecorationOverline(p,a)
#define IHTMLStyle_put_textDecorationLineThrough(p,a) (p)->lpVtbl->put_textDecorationLineThrough(p,a)
#define IHTMLStyle_get_textDecorationLineThrough(p,a) (p)->lpVtbl->get_textDecorationLineThrough(p,a)
#define IHTMLStyle_put_textDecorationBlink(p,a) (p)->lpVtbl->put_textDecorationBlink(p,a)
#define IHTMLStyle_get_textDecorationBlink(p,a) (p)->lpVtbl->get_textDecorationBlink(p,a)
#define IHTMLStyle_put_verticalAlign(p,a) (p)->lpVtbl->put_verticalAlign(p,a)
#define IHTMLStyle_get_verticalAlign(p,a) (p)->lpVtbl->get_verticalAlign(p,a)
#define IHTMLStyle_put_textTransform(p,a) (p)->lpVtbl->put_textTransform(p,a)
#define IHTMLStyle_get_textTransform(p,a) (p)->lpVtbl->get_textTransform(p,a)
#define IHTMLStyle_put_textAlign(p,a) (p)->lpVtbl->put_textAlign(p,a)
#define IHTMLStyle_get_textAlign(p,a) (p)->lpVtbl->get_textAlign(p,a)
#define IHTMLStyle_put_textIndent(p,a) (p)->lpVtbl->put_textIndent(p,a)
#define IHTMLStyle_get_textIndent(p,a) (p)->lpVtbl->get_textIndent(p,a)
#define IHTMLStyle_put_lineHeight(p,a) (p)->lpVtbl->put_lineHeight(p,a)
#define IHTMLStyle_get_lineHeight(p,a) (p)->lpVtbl->get_lineHeight(p,a)
#define IHTMLStyle_put_marginTop(p,a) (p)->lpVtbl->put_marginTop(p,a)
#define IHTMLStyle_get_marginTop(p,a) (p)->lpVtbl->get_marginTop(p,a)
#define IHTMLStyle_put_marginRight(p,a) (p)->lpVtbl->put_marginRight(p,a)
#define IHTMLStyle_get_marginRight(p,a) (p)->lpVtbl->get_marginRight(p,a)
#define IHTMLStyle_put_marginBottom(p,a) (p)->lpVtbl->put_marginBottom(p,a)
#define IHTMLStyle_get_marginBottom(p,a) (p)->lpVtbl->get_marginBottom(p,a)
#define IHTMLStyle_put_marginLeft(p,a) (p)->lpVtbl->put_marginLeft(p,a)
#define IHTMLStyle_get_marginLeft(p,a) (p)->lpVtbl->get_marginLeft(p,a)
#define IHTMLStyle_put_margin(p,a) (p)->lpVtbl->put_margin(p,a)
#define IHTMLStyle_get_margin(p,a) (p)->lpVtbl->get_margin(p,a)
#define IHTMLStyle_put_paddingTop(p,a) (p)->lpVtbl->put_paddingTop(p,a)
#define IHTMLStyle_get_paddingTop(p,a) (p)->lpVtbl->get_paddingTop(p,a)
#define IHTMLStyle_put_paddingRight(p,a) (p)->lpVtbl->put_paddingRight(p,a)
#define IHTMLStyle_get_paddingRight(p,a) (p)->lpVtbl->get_paddingRight(p,a)
#define IHTMLStyle_put_paddingBottom(p,a) (p)->lpVtbl->put_paddingBottom(p,a)
#define IHTMLStyle_get_paddingBottom(p,a) (p)->lpVtbl->get_paddingBottom(p,a)
#define IHTMLStyle_put_paddingLeft(p,a) (p)->lpVtbl->put_paddingLeft(p,a)
#define IHTMLStyle_get_paddingLeft(p,a) (p)->lpVtbl->get_paddingLeft(p,a)
#define IHTMLStyle_put_padding(p,a) (p)->lpVtbl->put_padding(p,a)
#define IHTMLStyle_get_padding(p,a) (p)->lpVtbl->get_padding(p,a)
#define IHTMLStyle_put_border(p,a) (p)->lpVtbl->put_border(p,a)
#define IHTMLStyle_get_border(p,a) (p)->lpVtbl->get_border(p,a)
#define IHTMLStyle_put_borderTop(p,a) (p)->lpVtbl->put_borderTop(p,a)
#define IHTMLStyle_get_borderTop(p,a) (p)->lpVtbl->get_borderTop(p,a)
#define IHTMLStyle_put_borderRight(p,a) (p)->lpVtbl->put_borderRight(p,a)
#define IHTMLStyle_get_borderRight(p,a) (p)->lpVtbl->get_borderRight(p,a)
#define IHTMLStyle_put_borderBottom(p,a) (p)->lpVtbl->put_borderBottom(p,a)
#define IHTMLStyle_get_borderBottom(p,a) (p)->lpVtbl->get_borderBottom(p,a)
#define IHTMLStyle_put_borderLeft(p,a) (p)->lpVtbl->put_borderLeft(p,a)
#define IHTMLStyle_get_borderLeft(p,a) (p)->lpVtbl->get_borderLeft(p,a)
#define IHTMLStyle_put_borderColor(p,a) (p)->lpVtbl->put_borderColor(p,a)
#define IHTMLStyle_get_borderColor(p,a) (p)->lpVtbl->get_borderColor(p,a)
#define IHTMLStyle_put_borderTopColor(p,a) (p)->lpVtbl->put_borderTopColor(p,a)
#define IHTMLStyle_get_borderTopColor(p,a) (p)->lpVtbl->get_borderTopColor(p,a)
#define IHTMLStyle_put_borderRightColor(p,a) (p)->lpVtbl->put_borderRightColor(p,a)
#define IHTMLStyle_get_borderRightColor(p,a) (p)->lpVtbl->get_borderRightColor(p,a)
#define IHTMLStyle_put_borderBottomColor(p,a) (p)->lpVtbl->put_borderBottomColor(p,a)
#define IHTMLStyle_get_borderBottomColor(p,a) (p)->lpVtbl->get_borderBottomColor(p,a)
#define IHTMLStyle_put_borderLeftColor(p,a) (p)->lpVtbl->put_borderLeftColor(p,a)
#define IHTMLStyle_get_borderLeftColor(p,a) (p)->lpVtbl->get_borderLeftColor(p,a)
#define IHTMLStyle_put_borderWidth(p,a) (p)->lpVtbl->put_borderWidth(p,a)
#define IHTMLStyle_get_borderWidth(p,a) (p)->lpVtbl->get_borderWidth(p,a)
#define IHTMLStyle_put_borderTopWidth(p,a) (p)->lpVtbl->put_borderTopWidth(p,a)
#define IHTMLStyle_get_borderTopWidth(p,a) (p)->lpVtbl->get_borderTopWidth(p,a)
#define IHTMLStyle_put_borderRightWidth(p,a) (p)->lpVtbl->put_borderRightWidth(p,a)
#define IHTMLStyle_get_borderRightWidth(p,a) (p)->lpVtbl->get_borderRightWidth(p,a)
#define IHTMLStyle_put_borderBottomWidth(p,a) (p)->lpVtbl->put_borderBottomWidth(p,a)
#define IHTMLStyle_get_borderBottomWidth(p,a) (p)->lpVtbl->get_borderBottomWidth(p,a)
#define IHTMLStyle_put_borderLeftWidth(p,a) (p)->lpVtbl->put_borderLeftWidth(p,a)
#define IHTMLStyle_get_borderLeftWidth(p,a) (p)->lpVtbl->get_borderLeftWidth(p,a)
#define IHTMLStyle_put_borderStyle(p,a) (p)->lpVtbl->put_borderStyle(p,a)
#define IHTMLStyle_get_borderStyle(p,a) (p)->lpVtbl->get_borderStyle(p,a)
#define IHTMLStyle_put_borderTopStyle(p,a) (p)->lpVtbl->put_borderTopStyle(p,a)
#define IHTMLStyle_get_borderTopStyle(p,a) (p)->lpVtbl->get_borderTopStyle(p,a)
#define IHTMLStyle_put_borderRightStyle(p,a) (p)->lpVtbl->put_borderRightStyle(p,a)
#define IHTMLStyle_get_borderRightStyle(p,a) (p)->lpVtbl->get_borderRightStyle(p,a)
#define IHTMLStyle_put_borderBottomStyle(p,a) (p)->lpVtbl->put_borderBottomStyle(p,a)
#define IHTMLStyle_get_borderBottomStyle(p,a) (p)->lpVtbl->get_borderBottomStyle(p,a)
#define IHTMLStyle_put_borderLeftStyle(p,a) (p)->lpVtbl->put_borderLeftStyle(p,a)
#define IHTMLStyle_get_borderLeftStyle(p,a) (p)->lpVtbl->get_borderLeftStyle(p,a)
#define IHTMLStyle_put_width(p,a) (p)->lpVtbl->put_width(p,a)
#define IHTMLStyle_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLStyle_put_height(p,a) (p)->lpVtbl->put_height(p,a)
#define IHTMLStyle_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLStyle_put_styleFloat(p,a) (p)->lpVtbl->put_styleFloat(p,a)
#define IHTMLStyle_get_styleFloat(p,a) (p)->lpVtbl->get_styleFloat(p,a)
#define IHTMLStyle_put_clear(p,a) (p)->lpVtbl->put_clear(p,a)
#define IHTMLStyle_get_clear(p,a) (p)->lpVtbl->get_clear(p,a)
#define IHTMLStyle_put_display(p,a) (p)->lpVtbl->put_display(p,a)
#define IHTMLStyle_get_display(p,a) (p)->lpVtbl->get_display(p,a)
#define IHTMLStyle_put_visibility(p,a) (p)->lpVtbl->put_visibility(p,a)
#define IHTMLStyle_get_visibility(p,a) (p)->lpVtbl->get_visibility(p,a)
#define IHTMLStyle_put_listStyleType(p,a) (p)->lpVtbl->put_listStyleType(p,a)
#define IHTMLStyle_get_listStyleType(p,a) (p)->lpVtbl->get_listStyleType(p,a)
#define IHTMLStyle_put_listStylePosition(p,a) (p)->lpVtbl->put_listStylePosition(p,a)
#define IHTMLStyle_get_listStylePosition(p,a) (p)->lpVtbl->get_listStylePosition(p,a)
#define IHTMLStyle_put_listStyleImage(p,a) (p)->lpVtbl->put_listStyleImage(p,a)
#define IHTMLStyle_get_listStyleImage(p,a) (p)->lpVtbl->get_listStyleImage(p,a)
#define IHTMLStyle_put_listStyle(p,a) (p)->lpVtbl->put_listStyle(p,a)
#define IHTMLStyle_get_listStyle(p,a) (p)->lpVtbl->get_listStyle(p,a)
#define IHTMLStyle_put_whiteSpace(p,a) (p)->lpVtbl->put_whiteSpace(p,a)
#define IHTMLStyle_get_whiteSpace(p,a) (p)->lpVtbl->get_whiteSpace(p,a)
#define IHTMLStyle_put_top(p,a) (p)->lpVtbl->put_top(p,a)
#define IHTMLStyle_get_top(p,a) (p)->lpVtbl->get_top(p,a)
#define IHTMLStyle_put_left(p,a) (p)->lpVtbl->put_left(p,a)
#define IHTMLStyle_get_left(p,a) (p)->lpVtbl->get_left(p,a)
#define IHTMLStyle_get_position(p,a) (p)->lpVtbl->get_position(p,a)
#define IHTMLStyle_put_zIndex(p,a) (p)->lpVtbl->put_zIndex(p,a)
#define IHTMLStyle_get_zIndex(p,a) (p)->lpVtbl->get_zIndex(p,a)
#define IHTMLStyle_put_overflow(p,a) (p)->lpVtbl->put_overflow(p,a)
#define IHTMLStyle_get_overflow(p,a) (p)->lpVtbl->get_overflow(p,a)
#define IHTMLStyle_put_pageBreakBefore(p,a) (p)->lpVtbl->put_pageBreakBefore(p,a)
#define IHTMLStyle_get_pageBreakBefore(p,a) (p)->lpVtbl->get_pageBreakBefore(p,a)
#define IHTMLStyle_put_pageBreakAfter(p,a) (p)->lpVtbl->put_pageBreakAfter(p,a)
#define IHTMLStyle_get_pageBreakAfter(p,a) (p)->lpVtbl->get_pageBreakAfter(p,a)
#define IHTMLStyle_put_cssText(p,a) (p)->lpVtbl->put_cssText(p,a)
#define IHTMLStyle_get_cssText(p,a) (p)->lpVtbl->get_cssText(p,a)
#define IHTMLStyle_put_pixelTop(p,a) (p)->lpVtbl->put_pixelTop(p,a)
#define IHTMLStyle_get_pixelTop(p,a) (p)->lpVtbl->get_pixelTop(p,a)
#define IHTMLStyle_put_pixelLeft(p,a) (p)->lpVtbl->put_pixelLeft(p,a)
#define IHTMLStyle_get_pixelLeft(p,a) (p)->lpVtbl->get_pixelLeft(p,a)
#define IHTMLStyle_put_pixelWidth(p,a) (p)->lpVtbl->put_pixelWidth(p,a)
#define IHTMLStyle_get_pixelWidth(p,a) (p)->lpVtbl->get_pixelWidth(p,a)
#define IHTMLStyle_put_pixelHeight(p,a) (p)->lpVtbl->put_pixelHeight(p,a)
#define IHTMLStyle_get_pixelHeight(p,a) (p)->lpVtbl->get_pixelHeight(p,a)
#define IHTMLStyle_put_posTop(p,a) (p)->lpVtbl->put_posTop(p,a)
#define IHTMLStyle_get_posTop(p,a) (p)->lpVtbl->get_posTop(p,a)
#define IHTMLStyle_put_posLeft(p,a) (p)->lpVtbl->put_posLeft(p,a)
#define IHTMLStyle_get_posLeft(p,a) (p)->lpVtbl->get_posLeft(p,a)
#define IHTMLStyle_put_posWidth(p,a) (p)->lpVtbl->put_posWidth(p,a)
#define IHTMLStyle_get_posWidth(p,a) (p)->lpVtbl->get_posWidth(p,a)
#define IHTMLStyle_put_posHeight(p,a) (p)->lpVtbl->put_posHeight(p,a)
#define IHTMLStyle_get_posHeight(p,a) (p)->lpVtbl->get_posHeight(p,a)
#define IHTMLStyle_put_cursor(p,a) (p)->lpVtbl->put_cursor(p,a)
#define IHTMLStyle_get_cursor(p,a) (p)->lpVtbl->get_cursor(p,a)
#define IHTMLStyle_put_clip(p,a) (p)->lpVtbl->put_clip(p,a)
#define IHTMLStyle_get_clip(p,a) (p)->lpVtbl->get_clip(p,a)
#define IHTMLStyle_put_filter(p,a) (p)->lpVtbl->put_filter(p,a)
#define IHTMLStyle_get_filter(p,a) (p)->lpVtbl->get_filter(p,a)
#define IHTMLStyle_setAttribute(p,a,b,c) (p)->lpVtbl->setAttribute(p,a,b,c)
#define IHTMLStyle_getAttribute(p,a,b,c) (p)->lpVtbl->getAttribute(p,a,b,c)
#define IHTMLStyle_removeAttribute(p,a,b,c) (p)->lpVtbl->removeAttribute(p,a,b,c)
#define IHTMLStyle_toString(p,a) (p)->lpVtbl->toString(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLStyle_put_fontFamily_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_fontFamily_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_fontFamily_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_fontFamily_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_fontStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_fontStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_fontStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_fontStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_fontVariant_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_fontVariant_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_fontVariant_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_fontVariant_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_fontWeight_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_fontWeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_fontWeight_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_fontWeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_fontSize_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_fontSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_fontSize_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_fontSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_font_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_font_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_font_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_font_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_color_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_color_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_color_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_color_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_background_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_background_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundColor_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_backgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundColor_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_backgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundImage_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_backgroundImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundImage_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_backgroundImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundRepeat_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_backgroundRepeat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundRepeat_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_backgroundRepeat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundAttachment_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_backgroundAttachment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundAttachment_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_backgroundAttachment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundPosition_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_backgroundPosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundPosition_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_backgroundPosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundPositionX_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_backgroundPositionX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundPositionX_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_backgroundPositionX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_backgroundPositionY_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_backgroundPositionY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_backgroundPositionY_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_backgroundPositionY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_wordSpacing_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_wordSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_wordSpacing_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_wordSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_letterSpacing_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_letterSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_letterSpacing_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_letterSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecoration_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecoration_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecorationNone_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyle_put_textDecorationNone_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecorationNone_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyle_get_textDecorationNone_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecorationUnderline_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyle_put_textDecorationUnderline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecorationUnderline_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyle_get_textDecorationUnderline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecorationOverline_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyle_put_textDecorationOverline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecorationOverline_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyle_get_textDecorationOverline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecorationLineThrough_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyle_put_textDecorationLineThrough_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecorationLineThrough_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyle_get_textDecorationLineThrough_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textDecorationBlink_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyle_put_textDecorationBlink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textDecorationBlink_Proxy(
    IHTMLStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyle_get_textDecorationBlink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_verticalAlign_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_verticalAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_verticalAlign_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_verticalAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textTransform_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_textTransform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textTransform_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_textTransform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textAlign_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_textAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textAlign_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_textAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_textIndent_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_textIndent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_textIndent_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_textIndent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_lineHeight_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_lineHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_lineHeight_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_lineHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_marginTop_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_marginTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_marginTop_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_marginTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_marginRight_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_marginRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_marginRight_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_marginRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_marginBottom_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_marginBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_marginBottom_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_marginBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_marginLeft_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_marginLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_marginLeft_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_marginLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_margin_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_margin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_margin_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_margin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_paddingTop_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_paddingTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_paddingTop_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_paddingTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_paddingRight_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_paddingRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_paddingRight_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_paddingRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_paddingBottom_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_paddingBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_paddingBottom_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_paddingBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_paddingLeft_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_paddingLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_paddingLeft_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_paddingLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_padding_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_padding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_padding_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_padding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_border_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_border_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderTop_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderTop_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderRight_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderRight_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderBottom_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderBottom_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderLeft_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderLeft_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderColor_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderColor_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderTopColor_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderTopColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderTopColor_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderTopColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderRightColor_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderRightColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderRightColor_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderRightColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderBottomColor_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderBottomColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderBottomColor_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderBottomColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderLeftColor_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderLeftColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderLeftColor_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderLeftColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderWidth_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderWidth_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderTopWidth_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderTopWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderTopWidth_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderTopWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderRightWidth_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderRightWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderRightWidth_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderRightWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderBottomWidth_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderBottomWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderBottomWidth_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderBottomWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderLeftWidth_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_borderLeftWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderLeftWidth_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_borderLeftWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderTopStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderTopStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderTopStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderTopStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderRightStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderRightStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderRightStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderRightStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderBottomStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderBottomStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderBottomStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderBottomStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_borderLeftStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_borderLeftStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_borderLeftStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_borderLeftStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_width_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_width_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_height_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_height_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_styleFloat_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_styleFloat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_styleFloat_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_styleFloat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_clear_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_clear_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_display_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_display_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_display_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_display_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_visibility_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_visibility_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_visibility_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_visibility_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_listStyleType_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_listStyleType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_listStyleType_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_listStyleType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_listStylePosition_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_listStylePosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_listStylePosition_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_listStylePosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_listStyleImage_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_listStyleImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_listStyleImage_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_listStyleImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_listStyle_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_listStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_listStyle_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_listStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_whiteSpace_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_whiteSpace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_whiteSpace_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_whiteSpace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_top_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_top_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_left_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_left_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_position_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_position_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_zIndex_Proxy(
    IHTMLStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLStyle_put_zIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_zIndex_Proxy(
    IHTMLStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLStyle_get_zIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_overflow_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_overflow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_overflow_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_overflow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pageBreakBefore_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_pageBreakBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pageBreakBefore_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_pageBreakBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pageBreakAfter_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_pageBreakAfter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pageBreakAfter_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_pageBreakAfter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_cssText_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_cssText_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pixelTop_Proxy(
    IHTMLStyle* This,
    long v);
void __RPC_STUB IHTMLStyle_put_pixelTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pixelTop_Proxy(
    IHTMLStyle* This,
    long *p);
void __RPC_STUB IHTMLStyle_get_pixelTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pixelLeft_Proxy(
    IHTMLStyle* This,
    long v);
void __RPC_STUB IHTMLStyle_put_pixelLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pixelLeft_Proxy(
    IHTMLStyle* This,
    long *p);
void __RPC_STUB IHTMLStyle_get_pixelLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pixelWidth_Proxy(
    IHTMLStyle* This,
    long v);
void __RPC_STUB IHTMLStyle_put_pixelWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pixelWidth_Proxy(
    IHTMLStyle* This,
    long *p);
void __RPC_STUB IHTMLStyle_get_pixelWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_pixelHeight_Proxy(
    IHTMLStyle* This,
    long v);
void __RPC_STUB IHTMLStyle_put_pixelHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_pixelHeight_Proxy(
    IHTMLStyle* This,
    long *p);
void __RPC_STUB IHTMLStyle_get_pixelHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_posTop_Proxy(
    IHTMLStyle* This,
    float v);
void __RPC_STUB IHTMLStyle_put_posTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_posTop_Proxy(
    IHTMLStyle* This,
    float *p);
void __RPC_STUB IHTMLStyle_get_posTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_posLeft_Proxy(
    IHTMLStyle* This,
    float v);
void __RPC_STUB IHTMLStyle_put_posLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_posLeft_Proxy(
    IHTMLStyle* This,
    float *p);
void __RPC_STUB IHTMLStyle_get_posLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_posWidth_Proxy(
    IHTMLStyle* This,
    float v);
void __RPC_STUB IHTMLStyle_put_posWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_posWidth_Proxy(
    IHTMLStyle* This,
    float *p);
void __RPC_STUB IHTMLStyle_get_posWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_posHeight_Proxy(
    IHTMLStyle* This,
    float v);
void __RPC_STUB IHTMLStyle_put_posHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_posHeight_Proxy(
    IHTMLStyle* This,
    float *p);
void __RPC_STUB IHTMLStyle_get_posHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_cursor_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_cursor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_cursor_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_cursor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_clip_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_clip_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_clip_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_clip_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_put_filter_Proxy(
    IHTMLStyle* This,
    BSTR v);
void __RPC_STUB IHTMLStyle_put_filter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_get_filter_Proxy(
    IHTMLStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLStyle_get_filter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_setAttribute_Proxy(
    IHTMLStyle* This,
    BSTR strAttributeName,
    VARIANT AttributeValue,
    LONG lFlags);
void __RPC_STUB IHTMLStyle_setAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_getAttribute_Proxy(
    IHTMLStyle* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT *AttributeValue);
void __RPC_STUB IHTMLStyle_getAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_removeAttribute_Proxy(
    IHTMLStyle* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT_BOOL *pfSuccess);
void __RPC_STUB IHTMLStyle_removeAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyle_toString_Proxy(
    IHTMLStyle* This,
    BSTR *String);
void __RPC_STUB IHTMLStyle_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLStyle_INTERFACE_DEFINED__ */

#ifndef __IHTMLRuleStyle_FWD_DEFINED__
#define __IHTMLRuleStyle_FWD_DEFINED__
typedef interface IHTMLRuleStyle IHTMLRuleStyle;
#endif

/*****************************************************************************
 * IHTMLRuleStyle interface
 */
#ifndef __IHTMLRuleStyle_INTERFACE_DEFINED__
#define __IHTMLRuleStyle_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLRuleStyle, 0x3050f3cf, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLRuleStyle : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_fontFamily(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontFamily(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontVariant(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontVariant(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontWeight(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontWeight(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fontSize(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontSize(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_font(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_font(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_color(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_color(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_background(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_background(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundImage(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundRepeat(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundRepeat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundAttachment(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundAttachment(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPosition(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPositionX(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionX(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_backgroundPositionY(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionY(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_wordSpacing(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_wordSpacing(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_letterSpacing(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_letterSpacing(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecoration(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecoration(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationNone(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationNone(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationUnderline(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationUnderline(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationOverline(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationOverline(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationLineThrough(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationLineThrough(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationBlink(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationBlink(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_verticalAlign(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_verticalAlign(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textTransform(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textTransform(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textAlign(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textAlign(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textIndent(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textIndent(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_lineHeight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lineHeight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginTop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginRight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginBottom(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_marginLeft(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_margin(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_margin(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingTop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingRight(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingBottom(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_paddingLeft(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_padding(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_padding(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_border(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_border(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTop(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTop(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRight(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRight(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottom(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottom(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeft(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeft(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderColor(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderColor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderWidth(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderWidth(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftWidth(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderTopStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderRightStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderBottomStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_borderLeftStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_width(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_height(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_styleFloat(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_styleFloat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_clear(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clear(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_display(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_display(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_visibility(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_visibility(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyleType(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStylePosition(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStylePosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyleImage(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_listStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_whiteSpace(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_whiteSpace(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_top(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_top(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_left(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_left(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_position(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_zIndex(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_zIndex(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_overflow(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_overflow(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pageBreakBefore(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakBefore(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pageBreakAfter(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakAfter(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cssText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cssText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cursor(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cursor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_clip(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clip(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_filter(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_filter(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE setAttribute(
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess) = 0;

};
#else
typedef struct IHTMLRuleStyleVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLRuleStyle* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLRuleStyle* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLRuleStyle* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLRuleStyle* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLRuleStyle* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLRuleStyle* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLRuleStyle* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLRuleStyle methods ***/
    HRESULT (STDMETHODCALLTYPE *put_fontFamily)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontFamily)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontVariant)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontVariant)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontWeight)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_fontWeight)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_fontSize)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_fontSize)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_font)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_font)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_color)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_color)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_background)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_background)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundColor)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundColor)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundImage)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundImage)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundRepeat)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundRepeat)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundAttachment)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundAttachment)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPosition)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPosition)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPositionX)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionX)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_backgroundPositionY)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionY)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_wordSpacing)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_wordSpacing)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_letterSpacing)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_letterSpacing)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecoration)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textDecoration)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationNone)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationNone)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationUnderline)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationUnderline)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationOverline)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationOverline)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationLineThrough)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationLineThrough)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationBlink)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationBlink)(
        IHTMLRuleStyle* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_verticalAlign)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_verticalAlign)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textTransform)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textTransform)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textAlign)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textAlign)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textIndent)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_textIndent)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_lineHeight)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_lineHeight)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginTop)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginTop)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginRight)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginRight)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginBottom)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginBottom)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_marginLeft)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_marginLeft)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_margin)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_margin)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingTop)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingTop)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingRight)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingRight)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingBottom)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingBottom)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_paddingLeft)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_paddingLeft)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_padding)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_padding)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_border)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_border)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTop)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderTop)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRight)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderRight)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottom)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottom)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeft)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeft)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderColor)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderColor)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopColor)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopColor)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightColor)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightColor)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomColor)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomColor)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftColor)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftColor)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderWidth)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderWidth)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopWidth)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopWidth)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightWidth)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightWidth)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomWidth)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomWidth)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftWidth)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftWidth)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_borderStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderTopStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderTopStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderRightStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderRightStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderBottomStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_borderLeftStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_width)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_height)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_styleFloat)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_styleFloat)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_clear)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_clear)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_display)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_display)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_visibility)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_visibility)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyleType)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyleType)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStylePosition)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStylePosition)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyleImage)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyleImage)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_listStyle)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_listStyle)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_whiteSpace)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_whiteSpace)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_top)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_top)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_left)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_left)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_position)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_zIndex)(
        IHTMLRuleStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_zIndex)(
        IHTMLRuleStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_overflow)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_overflow)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pageBreakBefore)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakBefore)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pageBreakAfter)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakAfter)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_cssText)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cssText)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_cursor)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cursor)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_clip)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_clip)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_filter)(
        IHTMLRuleStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_filter)(
        IHTMLRuleStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *setAttribute)(
        IHTMLRuleStyle* This,
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags);

    HRESULT (STDMETHODCALLTYPE *getAttribute)(
        IHTMLRuleStyle* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue);

    HRESULT (STDMETHODCALLTYPE *removeAttribute)(
        IHTMLRuleStyle* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess);

    END_INTERFACE
} IHTMLRuleStyleVtbl;
interface IHTMLRuleStyle {
    CONST_VTBL IHTMLRuleStyleVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLRuleStyle_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLRuleStyle_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLRuleStyle_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLRuleStyle_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLRuleStyle_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLRuleStyle_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLRuleStyle_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLRuleStyle methods ***/
#define IHTMLRuleStyle_put_fontFamily(p,a) (p)->lpVtbl->put_fontFamily(p,a)
#define IHTMLRuleStyle_get_fontFamily(p,a) (p)->lpVtbl->get_fontFamily(p,a)
#define IHTMLRuleStyle_put_fontStyle(p,a) (p)->lpVtbl->put_fontStyle(p,a)
#define IHTMLRuleStyle_get_fontStyle(p,a) (p)->lpVtbl->get_fontStyle(p,a)
#define IHTMLRuleStyle_put_fontVariant(p,a) (p)->lpVtbl->put_fontVariant(p,a)
#define IHTMLRuleStyle_get_fontVariant(p,a) (p)->lpVtbl->get_fontVariant(p,a)
#define IHTMLRuleStyle_put_fontWeight(p,a) (p)->lpVtbl->put_fontWeight(p,a)
#define IHTMLRuleStyle_get_fontWeight(p,a) (p)->lpVtbl->get_fontWeight(p,a)
#define IHTMLRuleStyle_put_fontSize(p,a) (p)->lpVtbl->put_fontSize(p,a)
#define IHTMLRuleStyle_get_fontSize(p,a) (p)->lpVtbl->get_fontSize(p,a)
#define IHTMLRuleStyle_put_font(p,a) (p)->lpVtbl->put_font(p,a)
#define IHTMLRuleStyle_get_font(p,a) (p)->lpVtbl->get_font(p,a)
#define IHTMLRuleStyle_put_color(p,a) (p)->lpVtbl->put_color(p,a)
#define IHTMLRuleStyle_get_color(p,a) (p)->lpVtbl->get_color(p,a)
#define IHTMLRuleStyle_put_background(p,a) (p)->lpVtbl->put_background(p,a)
#define IHTMLRuleStyle_get_background(p,a) (p)->lpVtbl->get_background(p,a)
#define IHTMLRuleStyle_put_backgroundColor(p,a) (p)->lpVtbl->put_backgroundColor(p,a)
#define IHTMLRuleStyle_get_backgroundColor(p,a) (p)->lpVtbl->get_backgroundColor(p,a)
#define IHTMLRuleStyle_put_backgroundImage(p,a) (p)->lpVtbl->put_backgroundImage(p,a)
#define IHTMLRuleStyle_get_backgroundImage(p,a) (p)->lpVtbl->get_backgroundImage(p,a)
#define IHTMLRuleStyle_put_backgroundRepeat(p,a) (p)->lpVtbl->put_backgroundRepeat(p,a)
#define IHTMLRuleStyle_get_backgroundRepeat(p,a) (p)->lpVtbl->get_backgroundRepeat(p,a)
#define IHTMLRuleStyle_put_backgroundAttachment(p,a) (p)->lpVtbl->put_backgroundAttachment(p,a)
#define IHTMLRuleStyle_get_backgroundAttachment(p,a) (p)->lpVtbl->get_backgroundAttachment(p,a)
#define IHTMLRuleStyle_put_backgroundPosition(p,a) (p)->lpVtbl->put_backgroundPosition(p,a)
#define IHTMLRuleStyle_get_backgroundPosition(p,a) (p)->lpVtbl->get_backgroundPosition(p,a)
#define IHTMLRuleStyle_put_backgroundPositionX(p,a) (p)->lpVtbl->put_backgroundPositionX(p,a)
#define IHTMLRuleStyle_get_backgroundPositionX(p,a) (p)->lpVtbl->get_backgroundPositionX(p,a)
#define IHTMLRuleStyle_put_backgroundPositionY(p,a) (p)->lpVtbl->put_backgroundPositionY(p,a)
#define IHTMLRuleStyle_get_backgroundPositionY(p,a) (p)->lpVtbl->get_backgroundPositionY(p,a)
#define IHTMLRuleStyle_put_wordSpacing(p,a) (p)->lpVtbl->put_wordSpacing(p,a)
#define IHTMLRuleStyle_get_wordSpacing(p,a) (p)->lpVtbl->get_wordSpacing(p,a)
#define IHTMLRuleStyle_put_letterSpacing(p,a) (p)->lpVtbl->put_letterSpacing(p,a)
#define IHTMLRuleStyle_get_letterSpacing(p,a) (p)->lpVtbl->get_letterSpacing(p,a)
#define IHTMLRuleStyle_put_textDecoration(p,a) (p)->lpVtbl->put_textDecoration(p,a)
#define IHTMLRuleStyle_get_textDecoration(p,a) (p)->lpVtbl->get_textDecoration(p,a)
#define IHTMLRuleStyle_put_textDecorationNone(p,a) (p)->lpVtbl->put_textDecorationNone(p,a)
#define IHTMLRuleStyle_get_textDecorationNone(p,a) (p)->lpVtbl->get_textDecorationNone(p,a)
#define IHTMLRuleStyle_put_textDecorationUnderline(p,a) (p)->lpVtbl->put_textDecorationUnderline(p,a)
#define IHTMLRuleStyle_get_textDecorationUnderline(p,a) (p)->lpVtbl->get_textDecorationUnderline(p,a)
#define IHTMLRuleStyle_put_textDecorationOverline(p,a) (p)->lpVtbl->put_textDecorationOverline(p,a)
#define IHTMLRuleStyle_get_textDecorationOverline(p,a) (p)->lpVtbl->get_textDecorationOverline(p,a)
#define IHTMLRuleStyle_put_textDecorationLineThrough(p,a) (p)->lpVtbl->put_textDecorationLineThrough(p,a)
#define IHTMLRuleStyle_get_textDecorationLineThrough(p,a) (p)->lpVtbl->get_textDecorationLineThrough(p,a)
#define IHTMLRuleStyle_put_textDecorationBlink(p,a) (p)->lpVtbl->put_textDecorationBlink(p,a)
#define IHTMLRuleStyle_get_textDecorationBlink(p,a) (p)->lpVtbl->get_textDecorationBlink(p,a)
#define IHTMLRuleStyle_put_verticalAlign(p,a) (p)->lpVtbl->put_verticalAlign(p,a)
#define IHTMLRuleStyle_get_verticalAlign(p,a) (p)->lpVtbl->get_verticalAlign(p,a)
#define IHTMLRuleStyle_put_textTransform(p,a) (p)->lpVtbl->put_textTransform(p,a)
#define IHTMLRuleStyle_get_textTransform(p,a) (p)->lpVtbl->get_textTransform(p,a)
#define IHTMLRuleStyle_put_textAlign(p,a) (p)->lpVtbl->put_textAlign(p,a)
#define IHTMLRuleStyle_get_textAlign(p,a) (p)->lpVtbl->get_textAlign(p,a)
#define IHTMLRuleStyle_put_textIndent(p,a) (p)->lpVtbl->put_textIndent(p,a)
#define IHTMLRuleStyle_get_textIndent(p,a) (p)->lpVtbl->get_textIndent(p,a)
#define IHTMLRuleStyle_put_lineHeight(p,a) (p)->lpVtbl->put_lineHeight(p,a)
#define IHTMLRuleStyle_get_lineHeight(p,a) (p)->lpVtbl->get_lineHeight(p,a)
#define IHTMLRuleStyle_put_marginTop(p,a) (p)->lpVtbl->put_marginTop(p,a)
#define IHTMLRuleStyle_get_marginTop(p,a) (p)->lpVtbl->get_marginTop(p,a)
#define IHTMLRuleStyle_put_marginRight(p,a) (p)->lpVtbl->put_marginRight(p,a)
#define IHTMLRuleStyle_get_marginRight(p,a) (p)->lpVtbl->get_marginRight(p,a)
#define IHTMLRuleStyle_put_marginBottom(p,a) (p)->lpVtbl->put_marginBottom(p,a)
#define IHTMLRuleStyle_get_marginBottom(p,a) (p)->lpVtbl->get_marginBottom(p,a)
#define IHTMLRuleStyle_put_marginLeft(p,a) (p)->lpVtbl->put_marginLeft(p,a)
#define IHTMLRuleStyle_get_marginLeft(p,a) (p)->lpVtbl->get_marginLeft(p,a)
#define IHTMLRuleStyle_put_margin(p,a) (p)->lpVtbl->put_margin(p,a)
#define IHTMLRuleStyle_get_margin(p,a) (p)->lpVtbl->get_margin(p,a)
#define IHTMLRuleStyle_put_paddingTop(p,a) (p)->lpVtbl->put_paddingTop(p,a)
#define IHTMLRuleStyle_get_paddingTop(p,a) (p)->lpVtbl->get_paddingTop(p,a)
#define IHTMLRuleStyle_put_paddingRight(p,a) (p)->lpVtbl->put_paddingRight(p,a)
#define IHTMLRuleStyle_get_paddingRight(p,a) (p)->lpVtbl->get_paddingRight(p,a)
#define IHTMLRuleStyle_put_paddingBottom(p,a) (p)->lpVtbl->put_paddingBottom(p,a)
#define IHTMLRuleStyle_get_paddingBottom(p,a) (p)->lpVtbl->get_paddingBottom(p,a)
#define IHTMLRuleStyle_put_paddingLeft(p,a) (p)->lpVtbl->put_paddingLeft(p,a)
#define IHTMLRuleStyle_get_paddingLeft(p,a) (p)->lpVtbl->get_paddingLeft(p,a)
#define IHTMLRuleStyle_put_padding(p,a) (p)->lpVtbl->put_padding(p,a)
#define IHTMLRuleStyle_get_padding(p,a) (p)->lpVtbl->get_padding(p,a)
#define IHTMLRuleStyle_put_border(p,a) (p)->lpVtbl->put_border(p,a)
#define IHTMLRuleStyle_get_border(p,a) (p)->lpVtbl->get_border(p,a)
#define IHTMLRuleStyle_put_borderTop(p,a) (p)->lpVtbl->put_borderTop(p,a)
#define IHTMLRuleStyle_get_borderTop(p,a) (p)->lpVtbl->get_borderTop(p,a)
#define IHTMLRuleStyle_put_borderRight(p,a) (p)->lpVtbl->put_borderRight(p,a)
#define IHTMLRuleStyle_get_borderRight(p,a) (p)->lpVtbl->get_borderRight(p,a)
#define IHTMLRuleStyle_put_borderBottom(p,a) (p)->lpVtbl->put_borderBottom(p,a)
#define IHTMLRuleStyle_get_borderBottom(p,a) (p)->lpVtbl->get_borderBottom(p,a)
#define IHTMLRuleStyle_put_borderLeft(p,a) (p)->lpVtbl->put_borderLeft(p,a)
#define IHTMLRuleStyle_get_borderLeft(p,a) (p)->lpVtbl->get_borderLeft(p,a)
#define IHTMLRuleStyle_put_borderColor(p,a) (p)->lpVtbl->put_borderColor(p,a)
#define IHTMLRuleStyle_get_borderColor(p,a) (p)->lpVtbl->get_borderColor(p,a)
#define IHTMLRuleStyle_put_borderTopColor(p,a) (p)->lpVtbl->put_borderTopColor(p,a)
#define IHTMLRuleStyle_get_borderTopColor(p,a) (p)->lpVtbl->get_borderTopColor(p,a)
#define IHTMLRuleStyle_put_borderRightColor(p,a) (p)->lpVtbl->put_borderRightColor(p,a)
#define IHTMLRuleStyle_get_borderRightColor(p,a) (p)->lpVtbl->get_borderRightColor(p,a)
#define IHTMLRuleStyle_put_borderBottomColor(p,a) (p)->lpVtbl->put_borderBottomColor(p,a)
#define IHTMLRuleStyle_get_borderBottomColor(p,a) (p)->lpVtbl->get_borderBottomColor(p,a)
#define IHTMLRuleStyle_put_borderLeftColor(p,a) (p)->lpVtbl->put_borderLeftColor(p,a)
#define IHTMLRuleStyle_get_borderLeftColor(p,a) (p)->lpVtbl->get_borderLeftColor(p,a)
#define IHTMLRuleStyle_put_borderWidth(p,a) (p)->lpVtbl->put_borderWidth(p,a)
#define IHTMLRuleStyle_get_borderWidth(p,a) (p)->lpVtbl->get_borderWidth(p,a)
#define IHTMLRuleStyle_put_borderTopWidth(p,a) (p)->lpVtbl->put_borderTopWidth(p,a)
#define IHTMLRuleStyle_get_borderTopWidth(p,a) (p)->lpVtbl->get_borderTopWidth(p,a)
#define IHTMLRuleStyle_put_borderRightWidth(p,a) (p)->lpVtbl->put_borderRightWidth(p,a)
#define IHTMLRuleStyle_get_borderRightWidth(p,a) (p)->lpVtbl->get_borderRightWidth(p,a)
#define IHTMLRuleStyle_put_borderBottomWidth(p,a) (p)->lpVtbl->put_borderBottomWidth(p,a)
#define IHTMLRuleStyle_get_borderBottomWidth(p,a) (p)->lpVtbl->get_borderBottomWidth(p,a)
#define IHTMLRuleStyle_put_borderLeftWidth(p,a) (p)->lpVtbl->put_borderLeftWidth(p,a)
#define IHTMLRuleStyle_get_borderLeftWidth(p,a) (p)->lpVtbl->get_borderLeftWidth(p,a)
#define IHTMLRuleStyle_put_borderStyle(p,a) (p)->lpVtbl->put_borderStyle(p,a)
#define IHTMLRuleStyle_get_borderStyle(p,a) (p)->lpVtbl->get_borderStyle(p,a)
#define IHTMLRuleStyle_put_borderTopStyle(p,a) (p)->lpVtbl->put_borderTopStyle(p,a)
#define IHTMLRuleStyle_get_borderTopStyle(p,a) (p)->lpVtbl->get_borderTopStyle(p,a)
#define IHTMLRuleStyle_put_borderRightStyle(p,a) (p)->lpVtbl->put_borderRightStyle(p,a)
#define IHTMLRuleStyle_get_borderRightStyle(p,a) (p)->lpVtbl->get_borderRightStyle(p,a)
#define IHTMLRuleStyle_put_borderBottomStyle(p,a) (p)->lpVtbl->put_borderBottomStyle(p,a)
#define IHTMLRuleStyle_get_borderBottomStyle(p,a) (p)->lpVtbl->get_borderBottomStyle(p,a)
#define IHTMLRuleStyle_put_borderLeftStyle(p,a) (p)->lpVtbl->put_borderLeftStyle(p,a)
#define IHTMLRuleStyle_get_borderLeftStyle(p,a) (p)->lpVtbl->get_borderLeftStyle(p,a)
#define IHTMLRuleStyle_put_width(p,a) (p)->lpVtbl->put_width(p,a)
#define IHTMLRuleStyle_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLRuleStyle_put_height(p,a) (p)->lpVtbl->put_height(p,a)
#define IHTMLRuleStyle_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLRuleStyle_put_styleFloat(p,a) (p)->lpVtbl->put_styleFloat(p,a)
#define IHTMLRuleStyle_get_styleFloat(p,a) (p)->lpVtbl->get_styleFloat(p,a)
#define IHTMLRuleStyle_put_clear(p,a) (p)->lpVtbl->put_clear(p,a)
#define IHTMLRuleStyle_get_clear(p,a) (p)->lpVtbl->get_clear(p,a)
#define IHTMLRuleStyle_put_display(p,a) (p)->lpVtbl->put_display(p,a)
#define IHTMLRuleStyle_get_display(p,a) (p)->lpVtbl->get_display(p,a)
#define IHTMLRuleStyle_put_visibility(p,a) (p)->lpVtbl->put_visibility(p,a)
#define IHTMLRuleStyle_get_visibility(p,a) (p)->lpVtbl->get_visibility(p,a)
#define IHTMLRuleStyle_put_listStyleType(p,a) (p)->lpVtbl->put_listStyleType(p,a)
#define IHTMLRuleStyle_get_listStyleType(p,a) (p)->lpVtbl->get_listStyleType(p,a)
#define IHTMLRuleStyle_put_listStylePosition(p,a) (p)->lpVtbl->put_listStylePosition(p,a)
#define IHTMLRuleStyle_get_listStylePosition(p,a) (p)->lpVtbl->get_listStylePosition(p,a)
#define IHTMLRuleStyle_put_listStyleImage(p,a) (p)->lpVtbl->put_listStyleImage(p,a)
#define IHTMLRuleStyle_get_listStyleImage(p,a) (p)->lpVtbl->get_listStyleImage(p,a)
#define IHTMLRuleStyle_put_listStyle(p,a) (p)->lpVtbl->put_listStyle(p,a)
#define IHTMLRuleStyle_get_listStyle(p,a) (p)->lpVtbl->get_listStyle(p,a)
#define IHTMLRuleStyle_put_whiteSpace(p,a) (p)->lpVtbl->put_whiteSpace(p,a)
#define IHTMLRuleStyle_get_whiteSpace(p,a) (p)->lpVtbl->get_whiteSpace(p,a)
#define IHTMLRuleStyle_put_top(p,a) (p)->lpVtbl->put_top(p,a)
#define IHTMLRuleStyle_get_top(p,a) (p)->lpVtbl->get_top(p,a)
#define IHTMLRuleStyle_put_left(p,a) (p)->lpVtbl->put_left(p,a)
#define IHTMLRuleStyle_get_left(p,a) (p)->lpVtbl->get_left(p,a)
#define IHTMLRuleStyle_get_position(p,a) (p)->lpVtbl->get_position(p,a)
#define IHTMLRuleStyle_put_zIndex(p,a) (p)->lpVtbl->put_zIndex(p,a)
#define IHTMLRuleStyle_get_zIndex(p,a) (p)->lpVtbl->get_zIndex(p,a)
#define IHTMLRuleStyle_put_overflow(p,a) (p)->lpVtbl->put_overflow(p,a)
#define IHTMLRuleStyle_get_overflow(p,a) (p)->lpVtbl->get_overflow(p,a)
#define IHTMLRuleStyle_put_pageBreakBefore(p,a) (p)->lpVtbl->put_pageBreakBefore(p,a)
#define IHTMLRuleStyle_get_pageBreakBefore(p,a) (p)->lpVtbl->get_pageBreakBefore(p,a)
#define IHTMLRuleStyle_put_pageBreakAfter(p,a) (p)->lpVtbl->put_pageBreakAfter(p,a)
#define IHTMLRuleStyle_get_pageBreakAfter(p,a) (p)->lpVtbl->get_pageBreakAfter(p,a)
#define IHTMLRuleStyle_put_cssText(p,a) (p)->lpVtbl->put_cssText(p,a)
#define IHTMLRuleStyle_get_cssText(p,a) (p)->lpVtbl->get_cssText(p,a)
#define IHTMLRuleStyle_put_cursor(p,a) (p)->lpVtbl->put_cursor(p,a)
#define IHTMLRuleStyle_get_cursor(p,a) (p)->lpVtbl->get_cursor(p,a)
#define IHTMLRuleStyle_put_clip(p,a) (p)->lpVtbl->put_clip(p,a)
#define IHTMLRuleStyle_get_clip(p,a) (p)->lpVtbl->get_clip(p,a)
#define IHTMLRuleStyle_put_filter(p,a) (p)->lpVtbl->put_filter(p,a)
#define IHTMLRuleStyle_get_filter(p,a) (p)->lpVtbl->get_filter(p,a)
#define IHTMLRuleStyle_setAttribute(p,a,b,c) (p)->lpVtbl->setAttribute(p,a,b,c)
#define IHTMLRuleStyle_getAttribute(p,a,b,c) (p)->lpVtbl->getAttribute(p,a,b,c)
#define IHTMLRuleStyle_removeAttribute(p,a,b,c) (p)->lpVtbl->removeAttribute(p,a,b,c)
#endif

#endif

HRESULT CALLBACK IHTMLRuleStyle_put_fontFamily_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_fontFamily_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_fontFamily_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_fontFamily_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_fontStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_fontStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_fontStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_fontStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_fontVariant_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_fontVariant_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_fontVariant_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_fontVariant_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_fontWeight_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_fontWeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_fontWeight_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_fontWeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_fontSize_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_fontSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_fontSize_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_fontSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_font_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_font_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_font_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_font_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_color_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_color_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_color_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_color_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_background_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_background_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundImage_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundImage_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundRepeat_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundRepeat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundRepeat_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundRepeat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundAttachment_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundAttachment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundAttachment_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundAttachment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundPosition_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundPosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundPosition_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundPosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundPositionX_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundPositionX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundPositionX_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundPositionX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_backgroundPositionY_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_backgroundPositionY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_backgroundPositionY_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_backgroundPositionY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_wordSpacing_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_wordSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_wordSpacing_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_wordSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_letterSpacing_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_letterSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_letterSpacing_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_letterSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecoration_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecoration_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecorationNone_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLRuleStyle_put_textDecorationNone_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecorationNone_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecorationNone_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecorationUnderline_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLRuleStyle_put_textDecorationUnderline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecorationUnderline_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecorationUnderline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecorationOverline_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLRuleStyle_put_textDecorationOverline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecorationOverline_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecorationOverline_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecorationLineThrough_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLRuleStyle_put_textDecorationLineThrough_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecorationLineThrough_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecorationLineThrough_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textDecorationBlink_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLRuleStyle_put_textDecorationBlink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textDecorationBlink_Proxy(
    IHTMLRuleStyle* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLRuleStyle_get_textDecorationBlink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_verticalAlign_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_verticalAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_verticalAlign_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_verticalAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textTransform_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_textTransform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textTransform_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_textTransform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textAlign_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_textAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textAlign_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_textAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_textIndent_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_textIndent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_textIndent_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_textIndent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_lineHeight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_lineHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_lineHeight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_lineHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_marginTop_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_marginTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_marginTop_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_marginTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_marginRight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_marginRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_marginRight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_marginRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_marginBottom_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_marginBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_marginBottom_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_marginBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_marginLeft_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_marginLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_marginLeft_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_marginLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_margin_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_margin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_margin_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_margin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_paddingTop_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_paddingTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_paddingTop_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_paddingTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_paddingRight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_paddingRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_paddingRight_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_paddingRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_paddingBottom_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_paddingBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_paddingBottom_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_paddingBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_paddingLeft_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_paddingLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_paddingLeft_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_paddingLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_padding_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_padding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_padding_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_padding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_border_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_border_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderTop_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderTop_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderRight_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderRight_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderBottom_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderBottom_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderLeft_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderLeft_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderColor_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderColor_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderTopColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderTopColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderTopColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderTopColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderRightColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderRightColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderRightColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderRightColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderBottomColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderBottomColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderBottomColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderBottomColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderLeftColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderLeftColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderLeftColor_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderLeftColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderWidth_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderWidth_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderTopWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderTopWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderTopWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderTopWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderRightWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderRightWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderRightWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderRightWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderBottomWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderBottomWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderBottomWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderBottomWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderLeftWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_borderLeftWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderLeftWidth_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_borderLeftWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderTopStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderTopStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderTopStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderTopStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderRightStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderRightStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderRightStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderRightStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderBottomStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderBottomStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderBottomStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderBottomStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_borderLeftStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_borderLeftStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_borderLeftStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_borderLeftStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_width_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_width_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_height_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_height_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_styleFloat_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_styleFloat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_styleFloat_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_styleFloat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_clear_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_clear_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_display_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_display_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_display_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_display_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_visibility_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_visibility_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_visibility_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_visibility_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_listStyleType_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_listStyleType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_listStyleType_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_listStyleType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_listStylePosition_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_listStylePosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_listStylePosition_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_listStylePosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_listStyleImage_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_listStyleImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_listStyleImage_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_listStyleImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_listStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_listStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_listStyle_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_listStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_whiteSpace_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_whiteSpace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_whiteSpace_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_whiteSpace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_top_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_top_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_left_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_left_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_position_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_position_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_zIndex_Proxy(
    IHTMLRuleStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRuleStyle_put_zIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_zIndex_Proxy(
    IHTMLRuleStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRuleStyle_get_zIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_overflow_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_overflow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_overflow_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_overflow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_pageBreakBefore_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_pageBreakBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_pageBreakBefore_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_pageBreakBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_pageBreakAfter_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_pageBreakAfter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_pageBreakAfter_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_pageBreakAfter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_cssText_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_cssText_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_cursor_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_cursor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_cursor_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_cursor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_clip_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_clip_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_clip_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_clip_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_put_filter_Proxy(
    IHTMLRuleStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRuleStyle_put_filter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_get_filter_Proxy(
    IHTMLRuleStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRuleStyle_get_filter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_setAttribute_Proxy(
    IHTMLRuleStyle* This,
    BSTR strAttributeName,
    VARIANT AttributeValue,
    LONG lFlags);
void __RPC_STUB IHTMLRuleStyle_setAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_getAttribute_Proxy(
    IHTMLRuleStyle* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT *AttributeValue);
void __RPC_STUB IHTMLRuleStyle_getAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRuleStyle_removeAttribute_Proxy(
    IHTMLRuleStyle* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT_BOOL *pfSuccess);
void __RPC_STUB IHTMLRuleStyle_removeAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLRuleStyle_INTERFACE_DEFINED__ */

#ifndef __IHTMLRenderStyle_FWD_DEFINED__
#define __IHTMLRenderStyle_FWD_DEFINED__
typedef interface IHTMLRenderStyle IHTMLRenderStyle;
#endif

/*****************************************************************************
 * IHTMLRenderStyle interface
 */
#ifndef __IHTMLRenderStyle_INTERFACE_DEFINED__
#define __IHTMLRenderStyle_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLRenderStyle, 0x3050f6ae, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLRenderStyle : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_textLineThroughStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textLineThroughStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textUnderlineStyle(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textUnderlineStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textEffect(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textEffect(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textBackgroundColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textBackgroundColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecorationColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecorationColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_renderingPriority(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_renderingPriority(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultTextSelection(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultTextSelection(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_textDecoration(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecoration(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLRenderStyleVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLRenderStyle* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLRenderStyle* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLRenderStyle* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLRenderStyle* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLRenderStyle* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLRenderStyle* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLRenderStyle* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLRenderStyle methods ***/
    HRESULT (STDMETHODCALLTYPE *put_textLineThroughStyle)(
        IHTMLRenderStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textLineThroughStyle)(
        IHTMLRenderStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textUnderlineStyle)(
        IHTMLRenderStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textUnderlineStyle)(
        IHTMLRenderStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textEffect)(
        IHTMLRenderStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textEffect)(
        IHTMLRenderStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textColor)(
        IHTMLRenderStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_textColor)(
        IHTMLRenderStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textBackgroundColor)(
        IHTMLRenderStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_textBackgroundColor)(
        IHTMLRenderStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecorationColor)(
        IHTMLRenderStyle* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_textDecorationColor)(
        IHTMLRenderStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_renderingPriority)(
        IHTMLRenderStyle* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_renderingPriority)(
        IHTMLRenderStyle* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_defaultTextSelection)(
        IHTMLRenderStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_defaultTextSelection)(
        IHTMLRenderStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_textDecoration)(
        IHTMLRenderStyle* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_textDecoration)(
        IHTMLRenderStyle* This,
        BSTR *p);

    END_INTERFACE
} IHTMLRenderStyleVtbl;
interface IHTMLRenderStyle {
    CONST_VTBL IHTMLRenderStyleVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLRenderStyle_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLRenderStyle_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLRenderStyle_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLRenderStyle_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLRenderStyle_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLRenderStyle_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLRenderStyle_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLRenderStyle methods ***/
#define IHTMLRenderStyle_put_textLineThroughStyle(p,a) (p)->lpVtbl->put_textLineThroughStyle(p,a)
#define IHTMLRenderStyle_get_textLineThroughStyle(p,a) (p)->lpVtbl->get_textLineThroughStyle(p,a)
#define IHTMLRenderStyle_put_textUnderlineStyle(p,a) (p)->lpVtbl->put_textUnderlineStyle(p,a)
#define IHTMLRenderStyle_get_textUnderlineStyle(p,a) (p)->lpVtbl->get_textUnderlineStyle(p,a)
#define IHTMLRenderStyle_put_textEffect(p,a) (p)->lpVtbl->put_textEffect(p,a)
#define IHTMLRenderStyle_get_textEffect(p,a) (p)->lpVtbl->get_textEffect(p,a)
#define IHTMLRenderStyle_put_textColor(p,a) (p)->lpVtbl->put_textColor(p,a)
#define IHTMLRenderStyle_get_textColor(p,a) (p)->lpVtbl->get_textColor(p,a)
#define IHTMLRenderStyle_put_textBackgroundColor(p,a) (p)->lpVtbl->put_textBackgroundColor(p,a)
#define IHTMLRenderStyle_get_textBackgroundColor(p,a) (p)->lpVtbl->get_textBackgroundColor(p,a)
#define IHTMLRenderStyle_put_textDecorationColor(p,a) (p)->lpVtbl->put_textDecorationColor(p,a)
#define IHTMLRenderStyle_get_textDecorationColor(p,a) (p)->lpVtbl->get_textDecorationColor(p,a)
#define IHTMLRenderStyle_put_renderingPriority(p,a) (p)->lpVtbl->put_renderingPriority(p,a)
#define IHTMLRenderStyle_get_renderingPriority(p,a) (p)->lpVtbl->get_renderingPriority(p,a)
#define IHTMLRenderStyle_put_defaultTextSelection(p,a) (p)->lpVtbl->put_defaultTextSelection(p,a)
#define IHTMLRenderStyle_get_defaultTextSelection(p,a) (p)->lpVtbl->get_defaultTextSelection(p,a)
#define IHTMLRenderStyle_put_textDecoration(p,a) (p)->lpVtbl->put_textDecoration(p,a)
#define IHTMLRenderStyle_get_textDecoration(p,a) (p)->lpVtbl->get_textDecoration(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLRenderStyle_put_textLineThroughStyle_Proxy(
    IHTMLRenderStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRenderStyle_put_textLineThroughStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textLineThroughStyle_Proxy(
    IHTMLRenderStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRenderStyle_get_textLineThroughStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textUnderlineStyle_Proxy(
    IHTMLRenderStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRenderStyle_put_textUnderlineStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textUnderlineStyle_Proxy(
    IHTMLRenderStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRenderStyle_get_textUnderlineStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textEffect_Proxy(
    IHTMLRenderStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRenderStyle_put_textEffect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textEffect_Proxy(
    IHTMLRenderStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRenderStyle_get_textEffect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRenderStyle_put_textColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRenderStyle_get_textColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textBackgroundColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRenderStyle_put_textBackgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textBackgroundColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRenderStyle_get_textBackgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textDecorationColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT v);
void __RPC_STUB IHTMLRenderStyle_put_textDecorationColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textDecorationColor_Proxy(
    IHTMLRenderStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLRenderStyle_get_textDecorationColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_renderingPriority_Proxy(
    IHTMLRenderStyle* This,
    long v);
void __RPC_STUB IHTMLRenderStyle_put_renderingPriority_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_renderingPriority_Proxy(
    IHTMLRenderStyle* This,
    long *p);
void __RPC_STUB IHTMLRenderStyle_get_renderingPriority_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_defaultTextSelection_Proxy(
    IHTMLRenderStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRenderStyle_put_defaultTextSelection_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_defaultTextSelection_Proxy(
    IHTMLRenderStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRenderStyle_get_defaultTextSelection_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_put_textDecoration_Proxy(
    IHTMLRenderStyle* This,
    BSTR v);
void __RPC_STUB IHTMLRenderStyle_put_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRenderStyle_get_textDecoration_Proxy(
    IHTMLRenderStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLRenderStyle_get_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLRenderStyle_INTERFACE_DEFINED__ */

#ifndef __IHTMLCurrentStyle_FWD_DEFINED__
#define __IHTMLCurrentStyle_FWD_DEFINED__
typedef interface IHTMLCurrentStyle IHTMLCurrentStyle;
#endif

/*****************************************************************************
 * IHTMLCurrentStyle interface
 */
#ifndef __IHTMLCurrentStyle_INTERFACE_DEFINED__
#define __IHTMLCurrentStyle_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLCurrentStyle, 0x3050f3db, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLCurrentStyle : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_position(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_styleFloat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_color(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontFamily(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontVariant(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontWeight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontSize(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionX(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundPositionY(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundRepeat(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderTopWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderRightWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderBottomWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderLeftWidth(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_left(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_top(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_paddingBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textAlign(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textDecoration(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_display(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_visibility(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_zIndex(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_letterSpacing(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lineHeight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textIndent(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_verticalAlign(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_backgroundAttachment(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_marginLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clear(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStylePosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_listStyleImage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clipTop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clipRight(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clipBottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clipLeft(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_overflow(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakBefore(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pageBreakAfter(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cursor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_tableLayout(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderCollapse(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_direction(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_behavior(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_unicodeBidi(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_right(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bottom(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_imeMode(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rubyAlign(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rubyPosition(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rubyOverhang(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textAutospace(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lineBreak(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_wordBreak(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textJustify(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textJustifyTrim(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textKashida(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_blockDirection(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_layoutGridChar(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_layoutGridLine(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_layoutGridMode(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_layoutGridType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderStyle(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderColor(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_borderWidth(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_padding(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_margin(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_accelerator(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_overflowX(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_overflowY(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_textTransform(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLCurrentStyleVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLCurrentStyle* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLCurrentStyle* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLCurrentStyle* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLCurrentStyle* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLCurrentStyle* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLCurrentStyle* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLCurrentStyle* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLCurrentStyle methods ***/
    HRESULT (STDMETHODCALLTYPE *get_position)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_styleFloat)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_color)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundColor)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_fontFamily)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fontStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fontVariant)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fontWeight)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_fontSize)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundImage)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionX)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundPositionY)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundRepeat)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftColor)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderTopColor)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderRightColor)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomColor)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderTopStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderRightStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderTopWidth)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderRightWidth)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderBottomWidth)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_borderLeftWidth)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_left)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_top)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_paddingLeft)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_paddingTop)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_paddingRight)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_paddingBottom)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_textAlign)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textDecoration)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_display)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_visibility)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_zIndex)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_letterSpacing)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_lineHeight)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_textIndent)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_verticalAlign)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_backgroundAttachment)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_marginTop)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_marginRight)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_marginBottom)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_marginLeft)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_clear)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_listStyleType)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_listStylePosition)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_listStyleImage)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_clipTop)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_clipRight)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_clipBottom)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_clipLeft)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_overflow)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakBefore)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_pageBreakAfter)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_cursor)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_tableLayout)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderCollapse)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_direction)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_behavior)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *getAttribute)(
        IHTMLCurrentStyle* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue);

    HRESULT (STDMETHODCALLTYPE *get_unicodeBidi)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_right)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_bottom)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_imeMode)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_rubyAlign)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_rubyPosition)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_rubyOverhang)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textAutospace)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_lineBreak)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_wordBreak)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textJustify)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textJustifyTrim)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textKashida)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_blockDirection)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_layoutGridChar)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_layoutGridLine)(
        IHTMLCurrentStyle* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_layoutGridMode)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_layoutGridType)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderStyle)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderColor)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_borderWidth)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_padding)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_margin)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_accelerator)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_overflowX)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_overflowY)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_textTransform)(
        IHTMLCurrentStyle* This,
        BSTR *p);

    END_INTERFACE
} IHTMLCurrentStyleVtbl;
interface IHTMLCurrentStyle {
    CONST_VTBL IHTMLCurrentStyleVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLCurrentStyle_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLCurrentStyle_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLCurrentStyle_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLCurrentStyle_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLCurrentStyle_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLCurrentStyle_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLCurrentStyle_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLCurrentStyle methods ***/
#define IHTMLCurrentStyle_get_position(p,a) (p)->lpVtbl->get_position(p,a)
#define IHTMLCurrentStyle_get_styleFloat(p,a) (p)->lpVtbl->get_styleFloat(p,a)
#define IHTMLCurrentStyle_get_color(p,a) (p)->lpVtbl->get_color(p,a)
#define IHTMLCurrentStyle_get_backgroundColor(p,a) (p)->lpVtbl->get_backgroundColor(p,a)
#define IHTMLCurrentStyle_get_fontFamily(p,a) (p)->lpVtbl->get_fontFamily(p,a)
#define IHTMLCurrentStyle_get_fontStyle(p,a) (p)->lpVtbl->get_fontStyle(p,a)
#define IHTMLCurrentStyle_get_fontVariant(p,a) (p)->lpVtbl->get_fontVariant(p,a)
#define IHTMLCurrentStyle_get_fontWeight(p,a) (p)->lpVtbl->get_fontWeight(p,a)
#define IHTMLCurrentStyle_get_fontSize(p,a) (p)->lpVtbl->get_fontSize(p,a)
#define IHTMLCurrentStyle_get_backgroundImage(p,a) (p)->lpVtbl->get_backgroundImage(p,a)
#define IHTMLCurrentStyle_get_backgroundPositionX(p,a) (p)->lpVtbl->get_backgroundPositionX(p,a)
#define IHTMLCurrentStyle_get_backgroundPositionY(p,a) (p)->lpVtbl->get_backgroundPositionY(p,a)
#define IHTMLCurrentStyle_get_backgroundRepeat(p,a) (p)->lpVtbl->get_backgroundRepeat(p,a)
#define IHTMLCurrentStyle_get_borderLeftColor(p,a) (p)->lpVtbl->get_borderLeftColor(p,a)
#define IHTMLCurrentStyle_get_borderTopColor(p,a) (p)->lpVtbl->get_borderTopColor(p,a)
#define IHTMLCurrentStyle_get_borderRightColor(p,a) (p)->lpVtbl->get_borderRightColor(p,a)
#define IHTMLCurrentStyle_get_borderBottomColor(p,a) (p)->lpVtbl->get_borderBottomColor(p,a)
#define IHTMLCurrentStyle_get_borderTopStyle(p,a) (p)->lpVtbl->get_borderTopStyle(p,a)
#define IHTMLCurrentStyle_get_borderRightStyle(p,a) (p)->lpVtbl->get_borderRightStyle(p,a)
#define IHTMLCurrentStyle_get_borderBottomStyle(p,a) (p)->lpVtbl->get_borderBottomStyle(p,a)
#define IHTMLCurrentStyle_get_borderLeftStyle(p,a) (p)->lpVtbl->get_borderLeftStyle(p,a)
#define IHTMLCurrentStyle_get_borderTopWidth(p,a) (p)->lpVtbl->get_borderTopWidth(p,a)
#define IHTMLCurrentStyle_get_borderRightWidth(p,a) (p)->lpVtbl->get_borderRightWidth(p,a)
#define IHTMLCurrentStyle_get_borderBottomWidth(p,a) (p)->lpVtbl->get_borderBottomWidth(p,a)
#define IHTMLCurrentStyle_get_borderLeftWidth(p,a) (p)->lpVtbl->get_borderLeftWidth(p,a)
#define IHTMLCurrentStyle_get_left(p,a) (p)->lpVtbl->get_left(p,a)
#define IHTMLCurrentStyle_get_top(p,a) (p)->lpVtbl->get_top(p,a)
#define IHTMLCurrentStyle_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLCurrentStyle_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLCurrentStyle_get_paddingLeft(p,a) (p)->lpVtbl->get_paddingLeft(p,a)
#define IHTMLCurrentStyle_get_paddingTop(p,a) (p)->lpVtbl->get_paddingTop(p,a)
#define IHTMLCurrentStyle_get_paddingRight(p,a) (p)->lpVtbl->get_paddingRight(p,a)
#define IHTMLCurrentStyle_get_paddingBottom(p,a) (p)->lpVtbl->get_paddingBottom(p,a)
#define IHTMLCurrentStyle_get_textAlign(p,a) (p)->lpVtbl->get_textAlign(p,a)
#define IHTMLCurrentStyle_get_textDecoration(p,a) (p)->lpVtbl->get_textDecoration(p,a)
#define IHTMLCurrentStyle_get_display(p,a) (p)->lpVtbl->get_display(p,a)
#define IHTMLCurrentStyle_get_visibility(p,a) (p)->lpVtbl->get_visibility(p,a)
#define IHTMLCurrentStyle_get_zIndex(p,a) (p)->lpVtbl->get_zIndex(p,a)
#define IHTMLCurrentStyle_get_letterSpacing(p,a) (p)->lpVtbl->get_letterSpacing(p,a)
#define IHTMLCurrentStyle_get_lineHeight(p,a) (p)->lpVtbl->get_lineHeight(p,a)
#define IHTMLCurrentStyle_get_textIndent(p,a) (p)->lpVtbl->get_textIndent(p,a)
#define IHTMLCurrentStyle_get_verticalAlign(p,a) (p)->lpVtbl->get_verticalAlign(p,a)
#define IHTMLCurrentStyle_get_backgroundAttachment(p,a) (p)->lpVtbl->get_backgroundAttachment(p,a)
#define IHTMLCurrentStyle_get_marginTop(p,a) (p)->lpVtbl->get_marginTop(p,a)
#define IHTMLCurrentStyle_get_marginRight(p,a) (p)->lpVtbl->get_marginRight(p,a)
#define IHTMLCurrentStyle_get_marginBottom(p,a) (p)->lpVtbl->get_marginBottom(p,a)
#define IHTMLCurrentStyle_get_marginLeft(p,a) (p)->lpVtbl->get_marginLeft(p,a)
#define IHTMLCurrentStyle_get_clear(p,a) (p)->lpVtbl->get_clear(p,a)
#define IHTMLCurrentStyle_get_listStyleType(p,a) (p)->lpVtbl->get_listStyleType(p,a)
#define IHTMLCurrentStyle_get_listStylePosition(p,a) (p)->lpVtbl->get_listStylePosition(p,a)
#define IHTMLCurrentStyle_get_listStyleImage(p,a) (p)->lpVtbl->get_listStyleImage(p,a)
#define IHTMLCurrentStyle_get_clipTop(p,a) (p)->lpVtbl->get_clipTop(p,a)
#define IHTMLCurrentStyle_get_clipRight(p,a) (p)->lpVtbl->get_clipRight(p,a)
#define IHTMLCurrentStyle_get_clipBottom(p,a) (p)->lpVtbl->get_clipBottom(p,a)
#define IHTMLCurrentStyle_get_clipLeft(p,a) (p)->lpVtbl->get_clipLeft(p,a)
#define IHTMLCurrentStyle_get_overflow(p,a) (p)->lpVtbl->get_overflow(p,a)
#define IHTMLCurrentStyle_get_pageBreakBefore(p,a) (p)->lpVtbl->get_pageBreakBefore(p,a)
#define IHTMLCurrentStyle_get_pageBreakAfter(p,a) (p)->lpVtbl->get_pageBreakAfter(p,a)
#define IHTMLCurrentStyle_get_cursor(p,a) (p)->lpVtbl->get_cursor(p,a)
#define IHTMLCurrentStyle_get_tableLayout(p,a) (p)->lpVtbl->get_tableLayout(p,a)
#define IHTMLCurrentStyle_get_borderCollapse(p,a) (p)->lpVtbl->get_borderCollapse(p,a)
#define IHTMLCurrentStyle_get_direction(p,a) (p)->lpVtbl->get_direction(p,a)
#define IHTMLCurrentStyle_get_behavior(p,a) (p)->lpVtbl->get_behavior(p,a)
#define IHTMLCurrentStyle_getAttribute(p,a,b,c) (p)->lpVtbl->getAttribute(p,a,b,c)
#define IHTMLCurrentStyle_get_unicodeBidi(p,a) (p)->lpVtbl->get_unicodeBidi(p,a)
#define IHTMLCurrentStyle_get_right(p,a) (p)->lpVtbl->get_right(p,a)
#define IHTMLCurrentStyle_get_bottom(p,a) (p)->lpVtbl->get_bottom(p,a)
#define IHTMLCurrentStyle_get_imeMode(p,a) (p)->lpVtbl->get_imeMode(p,a)
#define IHTMLCurrentStyle_get_rubyAlign(p,a) (p)->lpVtbl->get_rubyAlign(p,a)
#define IHTMLCurrentStyle_get_rubyPosition(p,a) (p)->lpVtbl->get_rubyPosition(p,a)
#define IHTMLCurrentStyle_get_rubyOverhang(p,a) (p)->lpVtbl->get_rubyOverhang(p,a)
#define IHTMLCurrentStyle_get_textAutospace(p,a) (p)->lpVtbl->get_textAutospace(p,a)
#define IHTMLCurrentStyle_get_lineBreak(p,a) (p)->lpVtbl->get_lineBreak(p,a)
#define IHTMLCurrentStyle_get_wordBreak(p,a) (p)->lpVtbl->get_wordBreak(p,a)
#define IHTMLCurrentStyle_get_textJustify(p,a) (p)->lpVtbl->get_textJustify(p,a)
#define IHTMLCurrentStyle_get_textJustifyTrim(p,a) (p)->lpVtbl->get_textJustifyTrim(p,a)
#define IHTMLCurrentStyle_get_textKashida(p,a) (p)->lpVtbl->get_textKashida(p,a)
#define IHTMLCurrentStyle_get_blockDirection(p,a) (p)->lpVtbl->get_blockDirection(p,a)
#define IHTMLCurrentStyle_get_layoutGridChar(p,a) (p)->lpVtbl->get_layoutGridChar(p,a)
#define IHTMLCurrentStyle_get_layoutGridLine(p,a) (p)->lpVtbl->get_layoutGridLine(p,a)
#define IHTMLCurrentStyle_get_layoutGridMode(p,a) (p)->lpVtbl->get_layoutGridMode(p,a)
#define IHTMLCurrentStyle_get_layoutGridType(p,a) (p)->lpVtbl->get_layoutGridType(p,a)
#define IHTMLCurrentStyle_get_borderStyle(p,a) (p)->lpVtbl->get_borderStyle(p,a)
#define IHTMLCurrentStyle_get_borderColor(p,a) (p)->lpVtbl->get_borderColor(p,a)
#define IHTMLCurrentStyle_get_borderWidth(p,a) (p)->lpVtbl->get_borderWidth(p,a)
#define IHTMLCurrentStyle_get_padding(p,a) (p)->lpVtbl->get_padding(p,a)
#define IHTMLCurrentStyle_get_margin(p,a) (p)->lpVtbl->get_margin(p,a)
#define IHTMLCurrentStyle_get_accelerator(p,a) (p)->lpVtbl->get_accelerator(p,a)
#define IHTMLCurrentStyle_get_overflowX(p,a) (p)->lpVtbl->get_overflowX(p,a)
#define IHTMLCurrentStyle_get_overflowY(p,a) (p)->lpVtbl->get_overflowY(p,a)
#define IHTMLCurrentStyle_get_textTransform(p,a) (p)->lpVtbl->get_textTransform(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLCurrentStyle_get_position_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_position_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_styleFloat_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_styleFloat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_color_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_color_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundColor_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_fontFamily_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_fontFamily_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_fontStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_fontStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_fontVariant_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_fontVariant_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_fontWeight_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_fontWeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_fontSize_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_fontSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundImage_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundPositionX_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundPositionX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundPositionY_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundPositionY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundRepeat_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundRepeat_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderLeftColor_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderLeftColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderTopColor_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderTopColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderRightColor_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderRightColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderBottomColor_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderBottomColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderTopStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderTopStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderRightStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderRightStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderBottomStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderBottomStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderLeftStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderLeftStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderTopWidth_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderTopWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderRightWidth_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderRightWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderBottomWidth_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderBottomWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderLeftWidth_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderLeftWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_left_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_top_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_width_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_height_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_paddingLeft_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_paddingLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_paddingTop_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_paddingTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_paddingRight_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_paddingRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_paddingBottom_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_paddingBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textAlign_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textDecoration_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textDecoration_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_display_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_display_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_visibility_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_visibility_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_zIndex_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_zIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_letterSpacing_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_letterSpacing_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_lineHeight_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_lineHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textIndent_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_textIndent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_verticalAlign_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_verticalAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_backgroundAttachment_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_backgroundAttachment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_marginTop_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_marginTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_marginRight_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_marginRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_marginBottom_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_marginBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_marginLeft_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_marginLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_clear_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_listStyleType_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_listStyleType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_listStylePosition_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_listStylePosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_listStyleImage_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_listStyleImage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_clipTop_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_clipTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_clipRight_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_clipRight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_clipBottom_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_clipBottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_clipLeft_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_clipLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_overflow_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_overflow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_pageBreakBefore_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_pageBreakBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_pageBreakAfter_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_pageBreakAfter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_cursor_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_cursor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_tableLayout_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_tableLayout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderCollapse_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderCollapse_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_direction_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_direction_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_behavior_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_behavior_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_getAttribute_Proxy(
    IHTMLCurrentStyle* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT *AttributeValue);
void __RPC_STUB IHTMLCurrentStyle_getAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_unicodeBidi_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_unicodeBidi_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_right_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_right_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_bottom_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_bottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_imeMode_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_imeMode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_rubyAlign_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_rubyAlign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_rubyPosition_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_rubyPosition_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_rubyOverhang_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_rubyOverhang_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textAutospace_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textAutospace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_lineBreak_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_lineBreak_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_wordBreak_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_wordBreak_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textJustify_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textJustify_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textJustifyTrim_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textJustifyTrim_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textKashida_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_textKashida_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_blockDirection_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_blockDirection_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_layoutGridChar_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_layoutGridChar_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_layoutGridLine_Proxy(
    IHTMLCurrentStyle* This,
    VARIANT *p);
void __RPC_STUB IHTMLCurrentStyle_get_layoutGridLine_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_layoutGridMode_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_layoutGridMode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_layoutGridType_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_layoutGridType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderStyle_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderColor_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_borderWidth_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_borderWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_padding_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_padding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_margin_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_margin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_accelerator_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_accelerator_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_overflowX_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_overflowX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_overflowY_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_overflowY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLCurrentStyle_get_textTransform_Proxy(
    IHTMLCurrentStyle* This,
    BSTR *p);
void __RPC_STUB IHTMLCurrentStyle_get_textTransform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLCurrentStyle_INTERFACE_DEFINED__ */

#ifndef __IHTMLRect_FWD_DEFINED__
#define __IHTMLRect_FWD_DEFINED__
typedef interface IHTMLRect IHTMLRect;
#endif

/*****************************************************************************
 * IHTMLRect interface
 */
#ifndef __IHTMLRect_INTERFACE_DEFINED__
#define __IHTMLRect_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLRect, 0x3050f4a3, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLRect : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_left(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_left(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_top(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_top(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_right(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_right(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bottom(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bottom(
        long *p) = 0;

};
#else
typedef struct IHTMLRectVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLRect* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLRect* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLRect* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLRect* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLRect* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLRect* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLRect* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLRect methods ***/
    HRESULT (STDMETHODCALLTYPE *put_left)(
        IHTMLRect* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_left)(
        IHTMLRect* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_top)(
        IHTMLRect* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_top)(
        IHTMLRect* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_right)(
        IHTMLRect* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_right)(
        IHTMLRect* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_bottom)(
        IHTMLRect* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_bottom)(
        IHTMLRect* This,
        long *p);

    END_INTERFACE
} IHTMLRectVtbl;
interface IHTMLRect {
    CONST_VTBL IHTMLRectVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLRect_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLRect_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLRect_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLRect_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLRect_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLRect_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLRect_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLRect methods ***/
#define IHTMLRect_put_left(p,a) (p)->lpVtbl->put_left(p,a)
#define IHTMLRect_get_left(p,a) (p)->lpVtbl->get_left(p,a)
#define IHTMLRect_put_top(p,a) (p)->lpVtbl->put_top(p,a)
#define IHTMLRect_get_top(p,a) (p)->lpVtbl->get_top(p,a)
#define IHTMLRect_put_right(p,a) (p)->lpVtbl->put_right(p,a)
#define IHTMLRect_get_right(p,a) (p)->lpVtbl->get_right(p,a)
#define IHTMLRect_put_bottom(p,a) (p)->lpVtbl->put_bottom(p,a)
#define IHTMLRect_get_bottom(p,a) (p)->lpVtbl->get_bottom(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLRect_put_left_Proxy(
    IHTMLRect* This,
    long v);
void __RPC_STUB IHTMLRect_put_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_get_left_Proxy(
    IHTMLRect* This,
    long *p);
void __RPC_STUB IHTMLRect_get_left_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_put_top_Proxy(
    IHTMLRect* This,
    long v);
void __RPC_STUB IHTMLRect_put_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_get_top_Proxy(
    IHTMLRect* This,
    long *p);
void __RPC_STUB IHTMLRect_get_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_put_right_Proxy(
    IHTMLRect* This,
    long v);
void __RPC_STUB IHTMLRect_put_right_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_get_right_Proxy(
    IHTMLRect* This,
    long *p);
void __RPC_STUB IHTMLRect_get_right_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_put_bottom_Proxy(
    IHTMLRect* This,
    long v);
void __RPC_STUB IHTMLRect_put_bottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRect_get_bottom_Proxy(
    IHTMLRect* This,
    long *p);
void __RPC_STUB IHTMLRect_get_bottom_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLRect_INTERFACE_DEFINED__ */

#ifndef __IHTMLRectCollection_FWD_DEFINED__
#define __IHTMLRectCollection_FWD_DEFINED__
typedef interface IHTMLRectCollection IHTMLRectCollection;
#endif

/*****************************************************************************
 * IHTMLRectCollection interface
 */
#ifndef __IHTMLRectCollection_INTERFACE_DEFINED__
#define __IHTMLRectCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLRectCollection, 0x3050f4a4, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLRectCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT *pvarIndex,
        VARIANT *pvarResult) = 0;

};
#else
typedef struct IHTMLRectCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLRectCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLRectCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLRectCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLRectCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLRectCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLRectCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLRectCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLRectCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLRectCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLRectCollection* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLRectCollection* This,
        VARIANT *pvarIndex,
        VARIANT *pvarResult);

    END_INTERFACE
} IHTMLRectCollectionVtbl;
interface IHTMLRectCollection {
    CONST_VTBL IHTMLRectCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLRectCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLRectCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLRectCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLRectCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLRectCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLRectCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLRectCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLRectCollection methods ***/
#define IHTMLRectCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLRectCollection_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLRectCollection_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLRectCollection_get_length_Proxy(
    IHTMLRectCollection* This,
    long *p);
void __RPC_STUB IHTMLRectCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRectCollection_get__newEnum_Proxy(
    IHTMLRectCollection* This,
    IUnknown **p);
void __RPC_STUB IHTMLRectCollection_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLRectCollection_item_Proxy(
    IHTMLRectCollection* This,
    VARIANT *pvarIndex,
    VARIANT *pvarResult);
void __RPC_STUB IHTMLRectCollection_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLRectCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLDOMNode_FWD_DEFINED__
#define __IHTMLDOMNode_FWD_DEFINED__
typedef interface IHTMLDOMNode IHTMLDOMNode;
#endif

/*****************************************************************************
 * IHTMLDOMNode interface
 */
#ifndef __IHTMLDOMNode_INTERFACE_DEFINED__
#define __IHTMLDOMNode_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDOMNode, 0x3050f5da, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDOMNode : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_nodeType(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentNode(
        IHTMLDOMNode **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE hasChildNodes(
        VARIANT_BOOL *fChildren) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_childNodes(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_attributes(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE insertBefore(
        IHTMLDOMNode *newChild,
        VARIANT refChild,
        IHTMLDOMNode **node) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeChild(
        IHTMLDOMNode *oldChild,
        IHTMLDOMNode **node) = 0;

    virtual HRESULT STDMETHODCALLTYPE replaceChild(
        IHTMLDOMNode *newChild,
        IHTMLDOMNode *oldChild,
        IHTMLDOMNode **node) = 0;

    virtual HRESULT STDMETHODCALLTYPE cloneNode(
        VARIANT_BOOL fDeep,
        IHTMLDOMNode **clonedNode) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeNode(
        VARIANT_BOOL fDeep,
        IHTMLDOMNode **removed) = 0;

    virtual HRESULT STDMETHODCALLTYPE swapNode(
        IHTMLDOMNode *otherNode,
        IHTMLDOMNode **swappedNode) = 0;

    virtual HRESULT STDMETHODCALLTYPE replaceNode(
        IHTMLDOMNode *replacement,
        IHTMLDOMNode **replaced) = 0;

    virtual HRESULT STDMETHODCALLTYPE appendChild(
        IHTMLDOMNode *newChild,
        IHTMLDOMNode **node) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nodeName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_nodeValue(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nodeValue(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_firstChild(
        IHTMLDOMNode **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lastChild(
        IHTMLDOMNode **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_previousSibling(
        IHTMLDOMNode **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nextSibling(
        IHTMLDOMNode **p) = 0;

};
#else
typedef struct IHTMLDOMNodeVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDOMNode* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDOMNode* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDOMNode* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDOMNode* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDOMNode* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDOMNode* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDOMNode* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDOMNode methods ***/
    HRESULT (STDMETHODCALLTYPE *get_nodeType)(
        IHTMLDOMNode* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_parentNode)(
        IHTMLDOMNode* This,
        IHTMLDOMNode **p);

    HRESULT (STDMETHODCALLTYPE *hasChildNodes)(
        IHTMLDOMNode* This,
        VARIANT_BOOL *fChildren);

    HRESULT (STDMETHODCALLTYPE *get_childNodes)(
        IHTMLDOMNode* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *get_attributes)(
        IHTMLDOMNode* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *insertBefore)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *newChild,
        VARIANT refChild,
        IHTMLDOMNode **node);

    HRESULT (STDMETHODCALLTYPE *removeChild)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *oldChild,
        IHTMLDOMNode **node);

    HRESULT (STDMETHODCALLTYPE *replaceChild)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *newChild,
        IHTMLDOMNode *oldChild,
        IHTMLDOMNode **node);

    HRESULT (STDMETHODCALLTYPE *cloneNode)(
        IHTMLDOMNode* This,
        VARIANT_BOOL fDeep,
        IHTMLDOMNode **clonedNode);

    HRESULT (STDMETHODCALLTYPE *removeNode)(
        IHTMLDOMNode* This,
        VARIANT_BOOL fDeep,
        IHTMLDOMNode **removed);

    HRESULT (STDMETHODCALLTYPE *swapNode)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *otherNode,
        IHTMLDOMNode **swappedNode);

    HRESULT (STDMETHODCALLTYPE *replaceNode)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *replacement,
        IHTMLDOMNode **replaced);

    HRESULT (STDMETHODCALLTYPE *appendChild)(
        IHTMLDOMNode* This,
        IHTMLDOMNode *newChild,
        IHTMLDOMNode **node);

    HRESULT (STDMETHODCALLTYPE *get_nodeName)(
        IHTMLDOMNode* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_nodeValue)(
        IHTMLDOMNode* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_nodeValue)(
        IHTMLDOMNode* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_firstChild)(
        IHTMLDOMNode* This,
        IHTMLDOMNode **p);

    HRESULT (STDMETHODCALLTYPE *get_lastChild)(
        IHTMLDOMNode* This,
        IHTMLDOMNode **p);

    HRESULT (STDMETHODCALLTYPE *get_previousSibling)(
        IHTMLDOMNode* This,
        IHTMLDOMNode **p);

    HRESULT (STDMETHODCALLTYPE *get_nextSibling)(
        IHTMLDOMNode* This,
        IHTMLDOMNode **p);

    END_INTERFACE
} IHTMLDOMNodeVtbl;
interface IHTMLDOMNode {
    CONST_VTBL IHTMLDOMNodeVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDOMNode_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDOMNode_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDOMNode_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDOMNode_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDOMNode_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDOMNode_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDOMNode_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDOMNode methods ***/
#define IHTMLDOMNode_get_nodeType(p,a) (p)->lpVtbl->get_nodeType(p,a)
#define IHTMLDOMNode_get_parentNode(p,a) (p)->lpVtbl->get_parentNode(p,a)
#define IHTMLDOMNode_hasChildNodes(p,a) (p)->lpVtbl->hasChildNodes(p,a)
#define IHTMLDOMNode_get_childNodes(p,a) (p)->lpVtbl->get_childNodes(p,a)
#define IHTMLDOMNode_get_attributes(p,a) (p)->lpVtbl->get_attributes(p,a)
#define IHTMLDOMNode_insertBefore(p,a,b,c) (p)->lpVtbl->insertBefore(p,a,b,c)
#define IHTMLDOMNode_removeChild(p,a,b) (p)->lpVtbl->removeChild(p,a,b)
#define IHTMLDOMNode_replaceChild(p,a,b,c) (p)->lpVtbl->replaceChild(p,a,b,c)
#define IHTMLDOMNode_cloneNode(p,a,b) (p)->lpVtbl->cloneNode(p,a,b)
#define IHTMLDOMNode_removeNode(p,a,b) (p)->lpVtbl->removeNode(p,a,b)
#define IHTMLDOMNode_swapNode(p,a,b) (p)->lpVtbl->swapNode(p,a,b)
#define IHTMLDOMNode_replaceNode(p,a,b) (p)->lpVtbl->replaceNode(p,a,b)
#define IHTMLDOMNode_appendChild(p,a,b) (p)->lpVtbl->appendChild(p,a,b)
#define IHTMLDOMNode_get_nodeName(p,a) (p)->lpVtbl->get_nodeName(p,a)
#define IHTMLDOMNode_put_nodeValue(p,a) (p)->lpVtbl->put_nodeValue(p,a)
#define IHTMLDOMNode_get_nodeValue(p,a) (p)->lpVtbl->get_nodeValue(p,a)
#define IHTMLDOMNode_get_firstChild(p,a) (p)->lpVtbl->get_firstChild(p,a)
#define IHTMLDOMNode_get_lastChild(p,a) (p)->lpVtbl->get_lastChild(p,a)
#define IHTMLDOMNode_get_previousSibling(p,a) (p)->lpVtbl->get_previousSibling(p,a)
#define IHTMLDOMNode_get_nextSibling(p,a) (p)->lpVtbl->get_nextSibling(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDOMNode_get_nodeType_Proxy(
    IHTMLDOMNode* This,
    long *p);
void __RPC_STUB IHTMLDOMNode_get_nodeType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_parentNode_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDOMNode_get_parentNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_hasChildNodes_Proxy(
    IHTMLDOMNode* This,
    VARIANT_BOOL *fChildren);
void __RPC_STUB IHTMLDOMNode_hasChildNodes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_childNodes_Proxy(
    IHTMLDOMNode* This,
    IDispatch **p);
void __RPC_STUB IHTMLDOMNode_get_childNodes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_attributes_Proxy(
    IHTMLDOMNode* This,
    IDispatch **p);
void __RPC_STUB IHTMLDOMNode_get_attributes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_insertBefore_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *newChild,
    VARIANT refChild,
    IHTMLDOMNode **node);
void __RPC_STUB IHTMLDOMNode_insertBefore_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_removeChild_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *oldChild,
    IHTMLDOMNode **node);
void __RPC_STUB IHTMLDOMNode_removeChild_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_replaceChild_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *newChild,
    IHTMLDOMNode *oldChild,
    IHTMLDOMNode **node);
void __RPC_STUB IHTMLDOMNode_replaceChild_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_cloneNode_Proxy(
    IHTMLDOMNode* This,
    VARIANT_BOOL fDeep,
    IHTMLDOMNode **clonedNode);
void __RPC_STUB IHTMLDOMNode_cloneNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_removeNode_Proxy(
    IHTMLDOMNode* This,
    VARIANT_BOOL fDeep,
    IHTMLDOMNode **removed);
void __RPC_STUB IHTMLDOMNode_removeNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_swapNode_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *otherNode,
    IHTMLDOMNode **swappedNode);
void __RPC_STUB IHTMLDOMNode_swapNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_replaceNode_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *replacement,
    IHTMLDOMNode **replaced);
void __RPC_STUB IHTMLDOMNode_replaceNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_appendChild_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode *newChild,
    IHTMLDOMNode **node);
void __RPC_STUB IHTMLDOMNode_appendChild_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_nodeName_Proxy(
    IHTMLDOMNode* This,
    BSTR *p);
void __RPC_STUB IHTMLDOMNode_get_nodeName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_put_nodeValue_Proxy(
    IHTMLDOMNode* This,
    VARIANT v);
void __RPC_STUB IHTMLDOMNode_put_nodeValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_nodeValue_Proxy(
    IHTMLDOMNode* This,
    VARIANT *p);
void __RPC_STUB IHTMLDOMNode_get_nodeValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_firstChild_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDOMNode_get_firstChild_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_lastChild_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDOMNode_get_lastChild_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_previousSibling_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDOMNode_get_previousSibling_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMNode_get_nextSibling_Proxy(
    IHTMLDOMNode* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDOMNode_get_nextSibling_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDOMNode_INTERFACE_DEFINED__ */

#ifndef __IHTMLDOMNode2_FWD_DEFINED__
#define __IHTMLDOMNode2_FWD_DEFINED__
typedef interface IHTMLDOMNode2 IHTMLDOMNode2;
#endif

/*****************************************************************************
 * IHTMLDOMNode2 interface
 */
#ifndef __IHTMLDOMNode2_INTERFACE_DEFINED__
#define __IHTMLDOMNode2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDOMNode2, 0x3050f80b, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDOMNode2 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_ownerDocument(
        IDispatch **p) = 0;

};
#else
typedef struct IHTMLDOMNode2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDOMNode2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDOMNode2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDOMNode2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDOMNode2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDOMNode2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDOMNode2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDOMNode2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDOMNode2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_ownerDocument)(
        IHTMLDOMNode2* This,
        IDispatch **p);

    END_INTERFACE
} IHTMLDOMNode2Vtbl;
interface IHTMLDOMNode2 {
    CONST_VTBL IHTMLDOMNode2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDOMNode2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDOMNode2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDOMNode2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDOMNode2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDOMNode2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDOMNode2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDOMNode2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDOMNode2 methods ***/
#define IHTMLDOMNode2_get_ownerDocument(p,a) (p)->lpVtbl->get_ownerDocument(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDOMNode2_get_ownerDocument_Proxy(
    IHTMLDOMNode2* This,
    IDispatch **p);
void __RPC_STUB IHTMLDOMNode2_get_ownerDocument_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDOMNode2_INTERFACE_DEFINED__ */

#ifndef __IHTMLDOMAttribute_FWD_DEFINED__
#define __IHTMLDOMAttribute_FWD_DEFINED__
typedef interface IHTMLDOMAttribute IHTMLDOMAttribute;
#endif

/*****************************************************************************
 * IHTMLDOMAttribute interface
 */
#ifndef __IHTMLDOMAttribute_INTERFACE_DEFINED__
#define __IHTMLDOMAttribute_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDOMAttribute, 0x3050f4b0, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDOMAttribute : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_nodeName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_nodeValue(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nodeValue(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_specified(
        VARIANT_BOOL *p) = 0;

};
#else
typedef struct IHTMLDOMAttributeVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDOMAttribute* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDOMAttribute* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDOMAttribute* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDOMAttribute* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDOMAttribute* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDOMAttribute* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDOMAttribute* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDOMAttribute methods ***/
    HRESULT (STDMETHODCALLTYPE *get_nodeName)(
        IHTMLDOMAttribute* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_nodeValue)(
        IHTMLDOMAttribute* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_nodeValue)(
        IHTMLDOMAttribute* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_specified)(
        IHTMLDOMAttribute* This,
        VARIANT_BOOL *p);

    END_INTERFACE
} IHTMLDOMAttributeVtbl;
interface IHTMLDOMAttribute {
    CONST_VTBL IHTMLDOMAttributeVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDOMAttribute_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDOMAttribute_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDOMAttribute_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDOMAttribute_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDOMAttribute_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDOMAttribute_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDOMAttribute_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDOMAttribute methods ***/
#define IHTMLDOMAttribute_get_nodeName(p,a) (p)->lpVtbl->get_nodeName(p,a)
#define IHTMLDOMAttribute_put_nodeValue(p,a) (p)->lpVtbl->put_nodeValue(p,a)
#define IHTMLDOMAttribute_get_nodeValue(p,a) (p)->lpVtbl->get_nodeValue(p,a)
#define IHTMLDOMAttribute_get_specified(p,a) (p)->lpVtbl->get_specified(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDOMAttribute_get_nodeName_Proxy(
    IHTMLDOMAttribute* This,
    BSTR *p);
void __RPC_STUB IHTMLDOMAttribute_get_nodeName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMAttribute_put_nodeValue_Proxy(
    IHTMLDOMAttribute* This,
    VARIANT v);
void __RPC_STUB IHTMLDOMAttribute_put_nodeValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMAttribute_get_nodeValue_Proxy(
    IHTMLDOMAttribute* This,
    VARIANT *p);
void __RPC_STUB IHTMLDOMAttribute_get_nodeValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDOMAttribute_get_specified_Proxy(
    IHTMLDOMAttribute* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLDOMAttribute_get_specified_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDOMAttribute_INTERFACE_DEFINED__ */

#ifndef __IHTMLDOMImplementation_FWD_DEFINED__
#define __IHTMLDOMImplementation_FWD_DEFINED__
typedef interface IHTMLDOMImplementation IHTMLDOMImplementation;
#endif

/*****************************************************************************
 * IHTMLDOMImplementation interface
 */
#ifndef __IHTMLDOMImplementation_INTERFACE_DEFINED__
#define __IHTMLDOMImplementation_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDOMImplementation, 0x3050f80d, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDOMImplementation : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE hasFeature(
        BSTR bstrfeature,
        VARIANT version,
        VARIANT_BOOL *pfHasFeature) = 0;

};
#else
typedef struct IHTMLDOMImplementationVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDOMImplementation* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDOMImplementation* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDOMImplementation* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDOMImplementation* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDOMImplementation* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDOMImplementation* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDOMImplementation* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDOMImplementation methods ***/
    HRESULT (STDMETHODCALLTYPE *hasFeature)(
        IHTMLDOMImplementation* This,
        BSTR bstrfeature,
        VARIANT version,
        VARIANT_BOOL *pfHasFeature);

    END_INTERFACE
} IHTMLDOMImplementationVtbl;
interface IHTMLDOMImplementation {
    CONST_VTBL IHTMLDOMImplementationVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDOMImplementation_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDOMImplementation_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDOMImplementation_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDOMImplementation_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDOMImplementation_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDOMImplementation_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDOMImplementation_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDOMImplementation methods ***/
#define IHTMLDOMImplementation_hasFeature(p,a,b,c) (p)->lpVtbl->hasFeature(p,a,b,c)
#endif

#endif

HRESULT CALLBACK IHTMLDOMImplementation_hasFeature_Proxy(
    IHTMLDOMImplementation* This,
    BSTR bstrfeature,
    VARIANT version,
    VARIANT_BOOL *pfHasFeature);
void __RPC_STUB IHTMLDOMImplementation_hasFeature_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDOMImplementation_INTERFACE_DEFINED__ */

#ifndef __IHTMLElementCollection_FWD_DEFINED__
#define __IHTMLElementCollection_FWD_DEFINED__
typedef interface IHTMLElementCollection IHTMLElementCollection;
#endif

#ifndef __IHTMLElement_FWD_DEFINED__
#define __IHTMLElement_FWD_DEFINED__
typedef interface IHTMLElement IHTMLElement;
#endif

/*****************************************************************************
 * IHTMLElement interface
 */
#ifndef __IHTMLElement_INTERFACE_DEFINED__
#define __IHTMLElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLElement, 0x3050f1ff, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE setAttribute(
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeAttribute(
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_className(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_className(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_id(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_id(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_tagName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_style(
        IHTMLStyle **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onhelp(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onhelp(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onclick(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onclick(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondblclick(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondblclick(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeydown(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeydown(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeyup(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeyup(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeypress(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeypress(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseout(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseout(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseover(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseover(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmousemove(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmousemove(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmousedown(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmousedown(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseup(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseup(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_document(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_title(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_title(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_language(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_language(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselectstart(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselectstart(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE scrollIntoView(
        VARIANT varargStart) = 0;

    virtual HRESULT STDMETHODCALLTYPE contains(
        IHTMLElement *pChild,
        VARIANT_BOOL *pfResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_sourceIndex(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_recordNumber(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_lang(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lang(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetLeft(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetTop(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetParent(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_innerHTML(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_innerHTML(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_innerText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_innerText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_outerHTML(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_outerHTML(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_outerText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_outerText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE insertAdjacentHTML(
        BSTR where,
        BSTR html) = 0;

    virtual HRESULT STDMETHODCALLTYPE insertAdjacentText(
        BSTR where,
        BSTR text) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentTextEdit(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_isTextEdit(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE click(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_filters(
        IHTMLFiltersCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragstart(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragstart(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onafterupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onafterupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onerrorupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onerrorupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowexit(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowexit(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowenter(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowenter(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondatasetchanged(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondatasetchanged(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondataavailable(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondataavailable(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondatasetcomplete(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondatasetcomplete(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onfilterchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onfilterchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_children(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_all(
        IDispatch **p) = 0;

};
#else
typedef struct IHTMLElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLElement methods ***/
    HRESULT (STDMETHODCALLTYPE *setAttribute)(
        IHTMLElement* This,
        BSTR strAttributeName,
        VARIANT AttributeValue,
        LONG lFlags);

    HRESULT (STDMETHODCALLTYPE *getAttribute)(
        IHTMLElement* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT *AttributeValue);

    HRESULT (STDMETHODCALLTYPE *removeAttribute)(
        IHTMLElement* This,
        BSTR strAttributeName,
        LONG lFlags,
        VARIANT_BOOL *pfSuccess);

    HRESULT (STDMETHODCALLTYPE *put_className)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_className)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_id)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_id)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_tagName)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_parentElement)(
        IHTMLElement* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_style)(
        IHTMLElement* This,
        IHTMLStyle **p);

    HRESULT (STDMETHODCALLTYPE *put_onhelp)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onhelp)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onclick)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onclick)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondblclick)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondblclick)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeydown)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeydown)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeyup)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeyup)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeypress)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeypress)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseout)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseout)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseover)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseover)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmousemove)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmousemove)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmousedown)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmousedown)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseup)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseup)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_document)(
        IHTMLElement* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *put_title)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_title)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_language)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_language)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onselectstart)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselectstart)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *scrollIntoView)(
        IHTMLElement* This,
        VARIANT varargStart);

    HRESULT (STDMETHODCALLTYPE *contains)(
        IHTMLElement* This,
        IHTMLElement *pChild,
        VARIANT_BOOL *pfResult);

    HRESULT (STDMETHODCALLTYPE *get_sourceIndex)(
        IHTMLElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_recordNumber)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_lang)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_lang)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetLeft)(
        IHTMLElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetTop)(
        IHTMLElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetWidth)(
        IHTMLElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetHeight)(
        IHTMLElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetParent)(
        IHTMLElement* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *put_innerHTML)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_innerHTML)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_innerText)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_innerText)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_outerHTML)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_outerHTML)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_outerText)(
        IHTMLElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_outerText)(
        IHTMLElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *insertAdjacentHTML)(
        IHTMLElement* This,
        BSTR where,
        BSTR html);

    HRESULT (STDMETHODCALLTYPE *insertAdjacentText)(
        IHTMLElement* This,
        BSTR where,
        BSTR text);

    HRESULT (STDMETHODCALLTYPE *get_parentTextEdit)(
        IHTMLElement* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_isTextEdit)(
        IHTMLElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *click)(
        IHTMLElement* This);

    HRESULT (STDMETHODCALLTYPE *get_filters)(
        IHTMLElement* This,
        IHTMLFiltersCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_ondragstart)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragstart)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLElement* This,
        BSTR *String);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeupdate)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeupdate)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onafterupdate)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onafterupdate)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onerrorupdate)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onerrorupdate)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowexit)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowexit)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowenter)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowenter)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondatasetchanged)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondatasetchanged)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondataavailable)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondataavailable)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondatasetcomplete)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondatasetcomplete)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onfilterchange)(
        IHTMLElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onfilterchange)(
        IHTMLElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_children)(
        IHTMLElement* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *get_all)(
        IHTMLElement* This,
        IDispatch **p);

    END_INTERFACE
} IHTMLElementVtbl;
interface IHTMLElement {
    CONST_VTBL IHTMLElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLElement methods ***/
#define IHTMLElement_setAttribute(p,a,b,c) (p)->lpVtbl->setAttribute(p,a,b,c)
#define IHTMLElement_getAttribute(p,a,b,c) (p)->lpVtbl->getAttribute(p,a,b,c)
#define IHTMLElement_removeAttribute(p,a,b,c) (p)->lpVtbl->removeAttribute(p,a,b,c)
#define IHTMLElement_put_className(p,a) (p)->lpVtbl->put_className(p,a)
#define IHTMLElement_get_className(p,a) (p)->lpVtbl->get_className(p,a)
#define IHTMLElement_put_id(p,a) (p)->lpVtbl->put_id(p,a)
#define IHTMLElement_get_id(p,a) (p)->lpVtbl->get_id(p,a)
#define IHTMLElement_get_tagName(p,a) (p)->lpVtbl->get_tagName(p,a)
#define IHTMLElement_get_parentElement(p,a) (p)->lpVtbl->get_parentElement(p,a)
#define IHTMLElement_get_style(p,a) (p)->lpVtbl->get_style(p,a)
#define IHTMLElement_put_onhelp(p,a) (p)->lpVtbl->put_onhelp(p,a)
#define IHTMLElement_get_onhelp(p,a) (p)->lpVtbl->get_onhelp(p,a)
#define IHTMLElement_put_onclick(p,a) (p)->lpVtbl->put_onclick(p,a)
#define IHTMLElement_get_onclick(p,a) (p)->lpVtbl->get_onclick(p,a)
#define IHTMLElement_put_ondblclick(p,a) (p)->lpVtbl->put_ondblclick(p,a)
#define IHTMLElement_get_ondblclick(p,a) (p)->lpVtbl->get_ondblclick(p,a)
#define IHTMLElement_put_onkeydown(p,a) (p)->lpVtbl->put_onkeydown(p,a)
#define IHTMLElement_get_onkeydown(p,a) (p)->lpVtbl->get_onkeydown(p,a)
#define IHTMLElement_put_onkeyup(p,a) (p)->lpVtbl->put_onkeyup(p,a)
#define IHTMLElement_get_onkeyup(p,a) (p)->lpVtbl->get_onkeyup(p,a)
#define IHTMLElement_put_onkeypress(p,a) (p)->lpVtbl->put_onkeypress(p,a)
#define IHTMLElement_get_onkeypress(p,a) (p)->lpVtbl->get_onkeypress(p,a)
#define IHTMLElement_put_onmouseout(p,a) (p)->lpVtbl->put_onmouseout(p,a)
#define IHTMLElement_get_onmouseout(p,a) (p)->lpVtbl->get_onmouseout(p,a)
#define IHTMLElement_put_onmouseover(p,a) (p)->lpVtbl->put_onmouseover(p,a)
#define IHTMLElement_get_onmouseover(p,a) (p)->lpVtbl->get_onmouseover(p,a)
#define IHTMLElement_put_onmousemove(p,a) (p)->lpVtbl->put_onmousemove(p,a)
#define IHTMLElement_get_onmousemove(p,a) (p)->lpVtbl->get_onmousemove(p,a)
#define IHTMLElement_put_onmousedown(p,a) (p)->lpVtbl->put_onmousedown(p,a)
#define IHTMLElement_get_onmousedown(p,a) (p)->lpVtbl->get_onmousedown(p,a)
#define IHTMLElement_put_onmouseup(p,a) (p)->lpVtbl->put_onmouseup(p,a)
#define IHTMLElement_get_onmouseup(p,a) (p)->lpVtbl->get_onmouseup(p,a)
#define IHTMLElement_get_document(p,a) (p)->lpVtbl->get_document(p,a)
#define IHTMLElement_put_title(p,a) (p)->lpVtbl->put_title(p,a)
#define IHTMLElement_get_title(p,a) (p)->lpVtbl->get_title(p,a)
#define IHTMLElement_put_language(p,a) (p)->lpVtbl->put_language(p,a)
#define IHTMLElement_get_language(p,a) (p)->lpVtbl->get_language(p,a)
#define IHTMLElement_put_onselectstart(p,a) (p)->lpVtbl->put_onselectstart(p,a)
#define IHTMLElement_get_onselectstart(p,a) (p)->lpVtbl->get_onselectstart(p,a)
#define IHTMLElement_scrollIntoView(p,a) (p)->lpVtbl->scrollIntoView(p,a)
#define IHTMLElement_contains(p,a,b) (p)->lpVtbl->contains(p,a,b)
#define IHTMLElement_get_sourceIndex(p,a) (p)->lpVtbl->get_sourceIndex(p,a)
#define IHTMLElement_get_recordNumber(p,a) (p)->lpVtbl->get_recordNumber(p,a)
#define IHTMLElement_put_lang(p,a) (p)->lpVtbl->put_lang(p,a)
#define IHTMLElement_get_lang(p,a) (p)->lpVtbl->get_lang(p,a)
#define IHTMLElement_get_offsetLeft(p,a) (p)->lpVtbl->get_offsetLeft(p,a)
#define IHTMLElement_get_offsetTop(p,a) (p)->lpVtbl->get_offsetTop(p,a)
#define IHTMLElement_get_offsetWidth(p,a) (p)->lpVtbl->get_offsetWidth(p,a)
#define IHTMLElement_get_offsetHeight(p,a) (p)->lpVtbl->get_offsetHeight(p,a)
#define IHTMLElement_get_offsetParent(p,a) (p)->lpVtbl->get_offsetParent(p,a)
#define IHTMLElement_put_innerHTML(p,a) (p)->lpVtbl->put_innerHTML(p,a)
#define IHTMLElement_get_innerHTML(p,a) (p)->lpVtbl->get_innerHTML(p,a)
#define IHTMLElement_put_innerText(p,a) (p)->lpVtbl->put_innerText(p,a)
#define IHTMLElement_get_innerText(p,a) (p)->lpVtbl->get_innerText(p,a)
#define IHTMLElement_put_outerHTML(p,a) (p)->lpVtbl->put_outerHTML(p,a)
#define IHTMLElement_get_outerHTML(p,a) (p)->lpVtbl->get_outerHTML(p,a)
#define IHTMLElement_put_outerText(p,a) (p)->lpVtbl->put_outerText(p,a)
#define IHTMLElement_get_outerText(p,a) (p)->lpVtbl->get_outerText(p,a)
#define IHTMLElement_insertAdjacentHTML(p,a,b) (p)->lpVtbl->insertAdjacentHTML(p,a,b)
#define IHTMLElement_insertAdjacentText(p,a,b) (p)->lpVtbl->insertAdjacentText(p,a,b)
#define IHTMLElement_get_parentTextEdit(p,a) (p)->lpVtbl->get_parentTextEdit(p,a)
#define IHTMLElement_get_isTextEdit(p,a) (p)->lpVtbl->get_isTextEdit(p,a)
#define IHTMLElement_click(p) (p)->lpVtbl->click(p)
#define IHTMLElement_get_filters(p,a) (p)->lpVtbl->get_filters(p,a)
#define IHTMLElement_put_ondragstart(p,a) (p)->lpVtbl->put_ondragstart(p,a)
#define IHTMLElement_get_ondragstart(p,a) (p)->lpVtbl->get_ondragstart(p,a)
#define IHTMLElement_toString(p,a) (p)->lpVtbl->toString(p,a)
#define IHTMLElement_put_onbeforeupdate(p,a) (p)->lpVtbl->put_onbeforeupdate(p,a)
#define IHTMLElement_get_onbeforeupdate(p,a) (p)->lpVtbl->get_onbeforeupdate(p,a)
#define IHTMLElement_put_onafterupdate(p,a) (p)->lpVtbl->put_onafterupdate(p,a)
#define IHTMLElement_get_onafterupdate(p,a) (p)->lpVtbl->get_onafterupdate(p,a)
#define IHTMLElement_put_onerrorupdate(p,a) (p)->lpVtbl->put_onerrorupdate(p,a)
#define IHTMLElement_get_onerrorupdate(p,a) (p)->lpVtbl->get_onerrorupdate(p,a)
#define IHTMLElement_put_onrowexit(p,a) (p)->lpVtbl->put_onrowexit(p,a)
#define IHTMLElement_get_onrowexit(p,a) (p)->lpVtbl->get_onrowexit(p,a)
#define IHTMLElement_put_onrowenter(p,a) (p)->lpVtbl->put_onrowenter(p,a)
#define IHTMLElement_get_onrowenter(p,a) (p)->lpVtbl->get_onrowenter(p,a)
#define IHTMLElement_put_ondatasetchanged(p,a) (p)->lpVtbl->put_ondatasetchanged(p,a)
#define IHTMLElement_get_ondatasetchanged(p,a) (p)->lpVtbl->get_ondatasetchanged(p,a)
#define IHTMLElement_put_ondataavailable(p,a) (p)->lpVtbl->put_ondataavailable(p,a)
#define IHTMLElement_get_ondataavailable(p,a) (p)->lpVtbl->get_ondataavailable(p,a)
#define IHTMLElement_put_ondatasetcomplete(p,a) (p)->lpVtbl->put_ondatasetcomplete(p,a)
#define IHTMLElement_get_ondatasetcomplete(p,a) (p)->lpVtbl->get_ondatasetcomplete(p,a)
#define IHTMLElement_put_onfilterchange(p,a) (p)->lpVtbl->put_onfilterchange(p,a)
#define IHTMLElement_get_onfilterchange(p,a) (p)->lpVtbl->get_onfilterchange(p,a)
#define IHTMLElement_get_children(p,a) (p)->lpVtbl->get_children(p,a)
#define IHTMLElement_get_all(p,a) (p)->lpVtbl->get_all(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLElement_setAttribute_Proxy(
    IHTMLElement* This,
    BSTR strAttributeName,
    VARIANT AttributeValue,
    LONG lFlags);
void __RPC_STUB IHTMLElement_setAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_getAttribute_Proxy(
    IHTMLElement* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT *AttributeValue);
void __RPC_STUB IHTMLElement_getAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_removeAttribute_Proxy(
    IHTMLElement* This,
    BSTR strAttributeName,
    LONG lFlags,
    VARIANT_BOOL *pfSuccess);
void __RPC_STUB IHTMLElement_removeAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_className_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_className_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_className_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_className_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_id_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_id_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_id_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_id_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_tagName_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_tagName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_parentElement_Proxy(
    IHTMLElement* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLElement_get_parentElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_style_Proxy(
    IHTMLElement* This,
    IHTMLStyle **p);
void __RPC_STUB IHTMLElement_get_style_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onhelp_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onhelp_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onclick_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onclick_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_ondblclick_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_ondblclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_ondblclick_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_ondblclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onkeydown_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onkeydown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onkeydown_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onkeydown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onkeyup_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onkeyup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onkeyup_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onkeyup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onkeypress_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onkeypress_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onkeypress_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onkeypress_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onmouseout_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onmouseout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onmouseout_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onmouseout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onmouseover_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onmouseover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onmouseover_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onmouseover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onmousemove_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onmousemove_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onmousemove_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onmousemove_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onmousedown_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onmousedown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onmousedown_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onmousedown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onmouseup_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onmouseup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onmouseup_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onmouseup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_document_Proxy(
    IHTMLElement* This,
    IDispatch **p);
void __RPC_STUB IHTMLElement_get_document_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_title_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_title_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_language_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_language_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_language_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_language_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onselectstart_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onselectstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onselectstart_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onselectstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_scrollIntoView_Proxy(
    IHTMLElement* This,
    VARIANT varargStart);
void __RPC_STUB IHTMLElement_scrollIntoView_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_contains_Proxy(
    IHTMLElement* This,
    IHTMLElement *pChild,
    VARIANT_BOOL *pfResult);
void __RPC_STUB IHTMLElement_contains_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_sourceIndex_Proxy(
    IHTMLElement* This,
    long *p);
void __RPC_STUB IHTMLElement_get_sourceIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_recordNumber_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_recordNumber_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_lang_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_lang_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_lang_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_lang_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_offsetLeft_Proxy(
    IHTMLElement* This,
    long *p);
void __RPC_STUB IHTMLElement_get_offsetLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_offsetTop_Proxy(
    IHTMLElement* This,
    long *p);
void __RPC_STUB IHTMLElement_get_offsetTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_offsetWidth_Proxy(
    IHTMLElement* This,
    long *p);
void __RPC_STUB IHTMLElement_get_offsetWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_offsetHeight_Proxy(
    IHTMLElement* This,
    long *p);
void __RPC_STUB IHTMLElement_get_offsetHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_offsetParent_Proxy(
    IHTMLElement* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLElement_get_offsetParent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_innerHTML_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_innerHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_innerHTML_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_innerHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_innerText_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_innerText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_innerText_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_innerText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_outerHTML_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_outerHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_outerHTML_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_outerHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_outerText_Proxy(
    IHTMLElement* This,
    BSTR v);
void __RPC_STUB IHTMLElement_put_outerText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_outerText_Proxy(
    IHTMLElement* This,
    BSTR *p);
void __RPC_STUB IHTMLElement_get_outerText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_insertAdjacentHTML_Proxy(
    IHTMLElement* This,
    BSTR where,
    BSTR html);
void __RPC_STUB IHTMLElement_insertAdjacentHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_insertAdjacentText_Proxy(
    IHTMLElement* This,
    BSTR where,
    BSTR text);
void __RPC_STUB IHTMLElement_insertAdjacentText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_parentTextEdit_Proxy(
    IHTMLElement* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLElement_get_parentTextEdit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_isTextEdit_Proxy(
    IHTMLElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLElement_get_isTextEdit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_click_Proxy(
    IHTMLElement* This);
void __RPC_STUB IHTMLElement_click_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_filters_Proxy(
    IHTMLElement* This,
    IHTMLFiltersCollection **p);
void __RPC_STUB IHTMLElement_get_filters_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_ondragstart_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_ondragstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_ondragstart_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_ondragstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_toString_Proxy(
    IHTMLElement* This,
    BSTR *String);
void __RPC_STUB IHTMLElement_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onbeforeupdate_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onbeforeupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onbeforeupdate_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onbeforeupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onafterupdate_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onafterupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onafterupdate_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onafterupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onerrorupdate_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onerrorupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onerrorupdate_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onerrorupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onrowexit_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onrowexit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onrowexit_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onrowexit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onrowenter_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onrowenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onrowenter_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onrowenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_ondatasetchanged_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_ondatasetchanged_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_ondatasetchanged_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_ondatasetchanged_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_ondataavailable_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_ondataavailable_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_ondataavailable_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_ondataavailable_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_ondatasetcomplete_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_ondatasetcomplete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_ondatasetcomplete_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_ondatasetcomplete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_put_onfilterchange_Proxy(
    IHTMLElement* This,
    VARIANT v);
void __RPC_STUB IHTMLElement_put_onfilterchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_onfilterchange_Proxy(
    IHTMLElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement_get_onfilterchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_children_Proxy(
    IHTMLElement* This,
    IDispatch **p);
void __RPC_STUB IHTMLElement_get_children_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement_get_all_Proxy(
    IHTMLElement* This,
    IDispatch **p);
void __RPC_STUB IHTMLElement_get_all_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLElement2_FWD_DEFINED__
#define __IHTMLElement2_FWD_DEFINED__
typedef interface IHTMLElement2 IHTMLElement2;
#endif

/*****************************************************************************
 * IHTMLElement2 interface
 */
#ifndef __IHTMLElement2_INTERFACE_DEFINED__
#define __IHTMLElement2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLElement2, 0x3050f434, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLElement2 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_scopeName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE setCapture(
        VARIANT_BOOL containerCapture) = 0;

    virtual HRESULT STDMETHODCALLTYPE releaseCapture(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onlosecapture(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onlosecapture(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE componentFromPoint(
        long x,
        long y,
        BSTR *component) = 0;

    virtual HRESULT STDMETHODCALLTYPE doScroll(
        VARIANT component) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onscroll(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onscroll(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondrag(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondrag(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragend(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragend(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragenter(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragenter(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragover(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragover(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragleave(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragleave(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondrop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondrop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforecut(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforecut(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncut(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncut(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforecopy(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforecopy(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncopy(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncopy(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforepaste(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforepaste(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onpaste(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onpaste(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_currentStyle(
        IHTMLCurrentStyle **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onpropertychange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onpropertychange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE getClientRects(
        IHTMLRectCollection **pRectCol) = 0;

    virtual HRESULT STDMETHODCALLTYPE getBoundingClientRect(
        IHTMLRect **pRect) = 0;

    virtual HRESULT STDMETHODCALLTYPE setExpression(
        BSTR propname,
        BSTR expression,
        BSTR language) = 0;

    virtual HRESULT STDMETHODCALLTYPE getExpression(
        BSTR propname,
        VARIANT *expression) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeExpression(
        BSTR propname,
        VARIANT_BOOL *pfSuccess) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_tabIndex(
        short v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_tabIndex(
        short *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE focus(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_accessKey(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_accessKey(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onblur(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onblur(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onfocus(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onfocus(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onresize(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onresize(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE blur(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE addFilter(
        IUnknown *pUnk) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeFilter(
        IUnknown *pUnk) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientTop(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientLeft(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE attachEvent(
        BSTR event,
        IDispatch *pDisp,
        VARIANT_BOOL *pfResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE detachEvent(
        BSTR event,
        IDispatch *pDisp) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyState(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onreadystatechange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onreadystatechange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowsdelete(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowsdelete(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowsinserted(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowsinserted(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncellchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncellchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_dir(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_dir(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createControlRange(
        IDispatch **range) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_scrollTop(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollTop(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_scrollLeft(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollLeft(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE clearAttributes(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE mergeAttributes(
        IHTMLElement *mergeThis) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncontextmenu(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncontextmenu(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE insertAdjacentElement(
        BSTR where,
        IHTMLElement *insertedElement,
        IHTMLElement **inserted) = 0;

    virtual HRESULT STDMETHODCALLTYPE applyElement(
        IHTMLElement *apply,
        BSTR where,
        IHTMLElement **applied) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAdjacentText(
        BSTR where,
        BSTR *text) = 0;

    virtual HRESULT STDMETHODCALLTYPE replaceAdjacentText(
        BSTR where,
        BSTR newText,
        BSTR *oldText) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_canHaveChildren(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE addBehavior(
        BSTR bstrUrl,
        VARIANT *pvarFactory,
        long *pCookie) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeBehavior(
        long cookie,
        VARIANT_BOOL *pfResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_runtimeStyle(
        IHTMLStyle **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_behaviorUrns(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_tagUrn(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_tagUrn(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeeditfocus(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeeditfocus(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyStateValue(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE getElementsByTagName(
        BSTR v,
        IHTMLElementCollection **pelColl) = 0;

};
#else
typedef struct IHTMLElement2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLElement2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLElement2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLElement2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLElement2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLElement2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLElement2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLElement2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLElement2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_scopeName)(
        IHTMLElement2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *setCapture)(
        IHTMLElement2* This,
        VARIANT_BOOL containerCapture);

    HRESULT (STDMETHODCALLTYPE *releaseCapture)(
        IHTMLElement2* This);

    HRESULT (STDMETHODCALLTYPE *put_onlosecapture)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onlosecapture)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *componentFromPoint)(
        IHTMLElement2* This,
        long x,
        long y,
        BSTR *component);

    HRESULT (STDMETHODCALLTYPE *doScroll)(
        IHTMLElement2* This,
        VARIANT component);

    HRESULT (STDMETHODCALLTYPE *put_onscroll)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onscroll)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondrag)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondrag)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondragend)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragend)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondragenter)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragenter)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondragover)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragover)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondragleave)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragleave)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondrop)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondrop)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforecut)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforecut)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_oncut)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncut)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforecopy)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforecopy)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_oncopy)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncopy)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforepaste)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforepaste)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onpaste)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onpaste)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_currentStyle)(
        IHTMLElement2* This,
        IHTMLCurrentStyle **p);

    HRESULT (STDMETHODCALLTYPE *put_onpropertychange)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onpropertychange)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *getClientRects)(
        IHTMLElement2* This,
        IHTMLRectCollection **pRectCol);

    HRESULT (STDMETHODCALLTYPE *getBoundingClientRect)(
        IHTMLElement2* This,
        IHTMLRect **pRect);

    HRESULT (STDMETHODCALLTYPE *setExpression)(
        IHTMLElement2* This,
        BSTR propname,
        BSTR expression,
        BSTR language);

    HRESULT (STDMETHODCALLTYPE *getExpression)(
        IHTMLElement2* This,
        BSTR propname,
        VARIANT *expression);

    HRESULT (STDMETHODCALLTYPE *removeExpression)(
        IHTMLElement2* This,
        BSTR propname,
        VARIANT_BOOL *pfSuccess);

    HRESULT (STDMETHODCALLTYPE *put_tabIndex)(
        IHTMLElement2* This,
        short v);

    HRESULT (STDMETHODCALLTYPE *get_tabIndex)(
        IHTMLElement2* This,
        short *p);

    HRESULT (STDMETHODCALLTYPE *focus)(
        IHTMLElement2* This);

    HRESULT (STDMETHODCALLTYPE *put_accessKey)(
        IHTMLElement2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_accessKey)(
        IHTMLElement2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onblur)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onblur)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onfocus)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onfocus)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onresize)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onresize)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *blur)(
        IHTMLElement2* This);

    HRESULT (STDMETHODCALLTYPE *addFilter)(
        IHTMLElement2* This,
        IUnknown *pUnk);

    HRESULT (STDMETHODCALLTYPE *removeFilter)(
        IHTMLElement2* This,
        IUnknown *pUnk);

    HRESULT (STDMETHODCALLTYPE *get_clientHeight)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_clientWidth)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_clientTop)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_clientLeft)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *attachEvent)(
        IHTMLElement2* This,
        BSTR event,
        IDispatch *pDisp,
        VARIANT_BOOL *pfResult);

    HRESULT (STDMETHODCALLTYPE *detachEvent)(
        IHTMLElement2* This,
        BSTR event,
        IDispatch *pDisp);

    HRESULT (STDMETHODCALLTYPE *get_readyState)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onreadystatechange)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onreadystatechange)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowsdelete)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowsdelete)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowsinserted)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowsinserted)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_oncellchange)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncellchange)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_dir)(
        IHTMLElement2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_dir)(
        IHTMLElement2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *createControlRange)(
        IHTMLElement2* This,
        IDispatch **range);

    HRESULT (STDMETHODCALLTYPE *get_scrollHeight)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_scrollWidth)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_scrollTop)(
        IHTMLElement2* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_scrollTop)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_scrollLeft)(
        IHTMLElement2* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_scrollLeft)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *clearAttributes)(
        IHTMLElement2* This);

    HRESULT (STDMETHODCALLTYPE *mergeAttributes)(
        IHTMLElement2* This,
        IHTMLElement *mergeThis);

    HRESULT (STDMETHODCALLTYPE *put_oncontextmenu)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncontextmenu)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *insertAdjacentElement)(
        IHTMLElement2* This,
        BSTR where,
        IHTMLElement *insertedElement,
        IHTMLElement **inserted);

    HRESULT (STDMETHODCALLTYPE *applyElement)(
        IHTMLElement2* This,
        IHTMLElement *apply,
        BSTR where,
        IHTMLElement **applied);

    HRESULT (STDMETHODCALLTYPE *getAdjacentText)(
        IHTMLElement2* This,
        BSTR where,
        BSTR *text);

    HRESULT (STDMETHODCALLTYPE *replaceAdjacentText)(
        IHTMLElement2* This,
        BSTR where,
        BSTR newText,
        BSTR *oldText);

    HRESULT (STDMETHODCALLTYPE *get_canHaveChildren)(
        IHTMLElement2* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *addBehavior)(
        IHTMLElement2* This,
        BSTR bstrUrl,
        VARIANT *pvarFactory,
        long *pCookie);

    HRESULT (STDMETHODCALLTYPE *removeBehavior)(
        IHTMLElement2* This,
        long cookie,
        VARIANT_BOOL *pfResult);

    HRESULT (STDMETHODCALLTYPE *get_runtimeStyle)(
        IHTMLElement2* This,
        IHTMLStyle **p);

    HRESULT (STDMETHODCALLTYPE *get_behaviorUrns)(
        IHTMLElement2* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *put_tagUrn)(
        IHTMLElement2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_tagUrn)(
        IHTMLElement2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeeditfocus)(
        IHTMLElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeeditfocus)(
        IHTMLElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_readyStateValue)(
        IHTMLElement2* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *getElementsByTagName)(
        IHTMLElement2* This,
        BSTR v,
        IHTMLElementCollection **pelColl);

    END_INTERFACE
} IHTMLElement2Vtbl;
interface IHTMLElement2 {
    CONST_VTBL IHTMLElement2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLElement2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLElement2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLElement2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLElement2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLElement2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLElement2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLElement2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLElement2 methods ***/
#define IHTMLElement2_get_scopeName(p,a) (p)->lpVtbl->get_scopeName(p,a)
#define IHTMLElement2_setCapture(p,a) (p)->lpVtbl->setCapture(p,a)
#define IHTMLElement2_releaseCapture(p) (p)->lpVtbl->releaseCapture(p)
#define IHTMLElement2_put_onlosecapture(p,a) (p)->lpVtbl->put_onlosecapture(p,a)
#define IHTMLElement2_get_onlosecapture(p,a) (p)->lpVtbl->get_onlosecapture(p,a)
#define IHTMLElement2_componentFromPoint(p,a,b,c) (p)->lpVtbl->componentFromPoint(p,a,b,c)
#define IHTMLElement2_doScroll(p,a) (p)->lpVtbl->doScroll(p,a)
#define IHTMLElement2_put_onscroll(p,a) (p)->lpVtbl->put_onscroll(p,a)
#define IHTMLElement2_get_onscroll(p,a) (p)->lpVtbl->get_onscroll(p,a)
#define IHTMLElement2_put_ondrag(p,a) (p)->lpVtbl->put_ondrag(p,a)
#define IHTMLElement2_get_ondrag(p,a) (p)->lpVtbl->get_ondrag(p,a)
#define IHTMLElement2_put_ondragend(p,a) (p)->lpVtbl->put_ondragend(p,a)
#define IHTMLElement2_get_ondragend(p,a) (p)->lpVtbl->get_ondragend(p,a)
#define IHTMLElement2_put_ondragenter(p,a) (p)->lpVtbl->put_ondragenter(p,a)
#define IHTMLElement2_get_ondragenter(p,a) (p)->lpVtbl->get_ondragenter(p,a)
#define IHTMLElement2_put_ondragover(p,a) (p)->lpVtbl->put_ondragover(p,a)
#define IHTMLElement2_get_ondragover(p,a) (p)->lpVtbl->get_ondragover(p,a)
#define IHTMLElement2_put_ondragleave(p,a) (p)->lpVtbl->put_ondragleave(p,a)
#define IHTMLElement2_get_ondragleave(p,a) (p)->lpVtbl->get_ondragleave(p,a)
#define IHTMLElement2_put_ondrop(p,a) (p)->lpVtbl->put_ondrop(p,a)
#define IHTMLElement2_get_ondrop(p,a) (p)->lpVtbl->get_ondrop(p,a)
#define IHTMLElement2_put_onbeforecut(p,a) (p)->lpVtbl->put_onbeforecut(p,a)
#define IHTMLElement2_get_onbeforecut(p,a) (p)->lpVtbl->get_onbeforecut(p,a)
#define IHTMLElement2_put_oncut(p,a) (p)->lpVtbl->put_oncut(p,a)
#define IHTMLElement2_get_oncut(p,a) (p)->lpVtbl->get_oncut(p,a)
#define IHTMLElement2_put_onbeforecopy(p,a) (p)->lpVtbl->put_onbeforecopy(p,a)
#define IHTMLElement2_get_onbeforecopy(p,a) (p)->lpVtbl->get_onbeforecopy(p,a)
#define IHTMLElement2_put_oncopy(p,a) (p)->lpVtbl->put_oncopy(p,a)
#define IHTMLElement2_get_oncopy(p,a) (p)->lpVtbl->get_oncopy(p,a)
#define IHTMLElement2_put_onbeforepaste(p,a) (p)->lpVtbl->put_onbeforepaste(p,a)
#define IHTMLElement2_get_onbeforepaste(p,a) (p)->lpVtbl->get_onbeforepaste(p,a)
#define IHTMLElement2_put_onpaste(p,a) (p)->lpVtbl->put_onpaste(p,a)
#define IHTMLElement2_get_onpaste(p,a) (p)->lpVtbl->get_onpaste(p,a)
#define IHTMLElement2_get_currentStyle(p,a) (p)->lpVtbl->get_currentStyle(p,a)
#define IHTMLElement2_put_onpropertychange(p,a) (p)->lpVtbl->put_onpropertychange(p,a)
#define IHTMLElement2_get_onpropertychange(p,a) (p)->lpVtbl->get_onpropertychange(p,a)
#define IHTMLElement2_getClientRects(p,a) (p)->lpVtbl->getClientRects(p,a)
#define IHTMLElement2_getBoundingClientRect(p,a) (p)->lpVtbl->getBoundingClientRect(p,a)
#define IHTMLElement2_setExpression(p,a,b,c) (p)->lpVtbl->setExpression(p,a,b,c)
#define IHTMLElement2_getExpression(p,a,b) (p)->lpVtbl->getExpression(p,a,b)
#define IHTMLElement2_removeExpression(p,a,b) (p)->lpVtbl->removeExpression(p,a,b)
#define IHTMLElement2_put_tabIndex(p,a) (p)->lpVtbl->put_tabIndex(p,a)
#define IHTMLElement2_get_tabIndex(p,a) (p)->lpVtbl->get_tabIndex(p,a)
#define IHTMLElement2_focus(p) (p)->lpVtbl->focus(p)
#define IHTMLElement2_put_accessKey(p,a) (p)->lpVtbl->put_accessKey(p,a)
#define IHTMLElement2_get_accessKey(p,a) (p)->lpVtbl->get_accessKey(p,a)
#define IHTMLElement2_put_onblur(p,a) (p)->lpVtbl->put_onblur(p,a)
#define IHTMLElement2_get_onblur(p,a) (p)->lpVtbl->get_onblur(p,a)
#define IHTMLElement2_put_onfocus(p,a) (p)->lpVtbl->put_onfocus(p,a)
#define IHTMLElement2_get_onfocus(p,a) (p)->lpVtbl->get_onfocus(p,a)
#define IHTMLElement2_put_onresize(p,a) (p)->lpVtbl->put_onresize(p,a)
#define IHTMLElement2_get_onresize(p,a) (p)->lpVtbl->get_onresize(p,a)
#define IHTMLElement2_blur(p) (p)->lpVtbl->blur(p)
#define IHTMLElement2_addFilter(p,a) (p)->lpVtbl->addFilter(p,a)
#define IHTMLElement2_removeFilter(p,a) (p)->lpVtbl->removeFilter(p,a)
#define IHTMLElement2_get_clientHeight(p,a) (p)->lpVtbl->get_clientHeight(p,a)
#define IHTMLElement2_get_clientWidth(p,a) (p)->lpVtbl->get_clientWidth(p,a)
#define IHTMLElement2_get_clientTop(p,a) (p)->lpVtbl->get_clientTop(p,a)
#define IHTMLElement2_get_clientLeft(p,a) (p)->lpVtbl->get_clientLeft(p,a)
#define IHTMLElement2_attachEvent(p,a,b,c) (p)->lpVtbl->attachEvent(p,a,b,c)
#define IHTMLElement2_detachEvent(p,a,b) (p)->lpVtbl->detachEvent(p,a,b)
#define IHTMLElement2_get_readyState(p,a) (p)->lpVtbl->get_readyState(p,a)
#define IHTMLElement2_put_onreadystatechange(p,a) (p)->lpVtbl->put_onreadystatechange(p,a)
#define IHTMLElement2_get_onreadystatechange(p,a) (p)->lpVtbl->get_onreadystatechange(p,a)
#define IHTMLElement2_put_onrowsdelete(p,a) (p)->lpVtbl->put_onrowsdelete(p,a)
#define IHTMLElement2_get_onrowsdelete(p,a) (p)->lpVtbl->get_onrowsdelete(p,a)
#define IHTMLElement2_put_onrowsinserted(p,a) (p)->lpVtbl->put_onrowsinserted(p,a)
#define IHTMLElement2_get_onrowsinserted(p,a) (p)->lpVtbl->get_onrowsinserted(p,a)
#define IHTMLElement2_put_oncellchange(p,a) (p)->lpVtbl->put_oncellchange(p,a)
#define IHTMLElement2_get_oncellchange(p,a) (p)->lpVtbl->get_oncellchange(p,a)
#define IHTMLElement2_put_dir(p,a) (p)->lpVtbl->put_dir(p,a)
#define IHTMLElement2_get_dir(p,a) (p)->lpVtbl->get_dir(p,a)
#define IHTMLElement2_createControlRange(p,a) (p)->lpVtbl->createControlRange(p,a)
#define IHTMLElement2_get_scrollHeight(p,a) (p)->lpVtbl->get_scrollHeight(p,a)
#define IHTMLElement2_get_scrollWidth(p,a) (p)->lpVtbl->get_scrollWidth(p,a)
#define IHTMLElement2_put_scrollTop(p,a) (p)->lpVtbl->put_scrollTop(p,a)
#define IHTMLElement2_get_scrollTop(p,a) (p)->lpVtbl->get_scrollTop(p,a)
#define IHTMLElement2_put_scrollLeft(p,a) (p)->lpVtbl->put_scrollLeft(p,a)
#define IHTMLElement2_get_scrollLeft(p,a) (p)->lpVtbl->get_scrollLeft(p,a)
#define IHTMLElement2_clearAttributes(p) (p)->lpVtbl->clearAttributes(p)
#define IHTMLElement2_mergeAttributes(p,a) (p)->lpVtbl->mergeAttributes(p,a)
#define IHTMLElement2_put_oncontextmenu(p,a) (p)->lpVtbl->put_oncontextmenu(p,a)
#define IHTMLElement2_get_oncontextmenu(p,a) (p)->lpVtbl->get_oncontextmenu(p,a)
#define IHTMLElement2_insertAdjacentElement(p,a,b,c) (p)->lpVtbl->insertAdjacentElement(p,a,b,c)
#define IHTMLElement2_applyElement(p,a,b,c) (p)->lpVtbl->applyElement(p,a,b,c)
#define IHTMLElement2_getAdjacentText(p,a,b) (p)->lpVtbl->getAdjacentText(p,a,b)
#define IHTMLElement2_replaceAdjacentText(p,a,b,c) (p)->lpVtbl->replaceAdjacentText(p,a,b,c)
#define IHTMLElement2_get_canHaveChildren(p,a) (p)->lpVtbl->get_canHaveChildren(p,a)
#define IHTMLElement2_addBehavior(p,a,b,c) (p)->lpVtbl->addBehavior(p,a,b,c)
#define IHTMLElement2_removeBehavior(p,a,b) (p)->lpVtbl->removeBehavior(p,a,b)
#define IHTMLElement2_get_runtimeStyle(p,a) (p)->lpVtbl->get_runtimeStyle(p,a)
#define IHTMLElement2_get_behaviorUrns(p,a) (p)->lpVtbl->get_behaviorUrns(p,a)
#define IHTMLElement2_put_tagUrn(p,a) (p)->lpVtbl->put_tagUrn(p,a)
#define IHTMLElement2_get_tagUrn(p,a) (p)->lpVtbl->get_tagUrn(p,a)
#define IHTMLElement2_put_onbeforeeditfocus(p,a) (p)->lpVtbl->put_onbeforeeditfocus(p,a)
#define IHTMLElement2_get_onbeforeeditfocus(p,a) (p)->lpVtbl->get_onbeforeeditfocus(p,a)
#define IHTMLElement2_get_readyStateValue(p,a) (p)->lpVtbl->get_readyStateValue(p,a)
#define IHTMLElement2_getElementsByTagName(p,a,b) (p)->lpVtbl->getElementsByTagName(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLElement2_get_scopeName_Proxy(
    IHTMLElement2* This,
    BSTR *p);
void __RPC_STUB IHTMLElement2_get_scopeName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_setCapture_Proxy(
    IHTMLElement2* This,
    VARIANT_BOOL containerCapture);
void __RPC_STUB IHTMLElement2_setCapture_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_releaseCapture_Proxy(
    IHTMLElement2* This);
void __RPC_STUB IHTMLElement2_releaseCapture_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onlosecapture_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onlosecapture_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onlosecapture_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onlosecapture_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_componentFromPoint_Proxy(
    IHTMLElement2* This,
    long x,
    long y,
    BSTR *component);
void __RPC_STUB IHTMLElement2_componentFromPoint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_doScroll_Proxy(
    IHTMLElement2* This,
    VARIANT component);
void __RPC_STUB IHTMLElement2_doScroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onscroll_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onscroll_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondrag_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondrag_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondrag_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondrag_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondragend_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondragend_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondragend_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondragend_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondragenter_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondragenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondragenter_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondragenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondragover_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondragover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondragover_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondragover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondragleave_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondragleave_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondragleave_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondragleave_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_ondrop_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_ondrop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_ondrop_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_ondrop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onbeforecut_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onbeforecut_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onbeforecut_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onbeforecut_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_oncut_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_oncut_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_oncut_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_oncut_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onbeforecopy_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onbeforecopy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onbeforecopy_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onbeforecopy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_oncopy_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_oncopy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_oncopy_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_oncopy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onbeforepaste_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onbeforepaste_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onbeforepaste_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onbeforepaste_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onpaste_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onpaste_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onpaste_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onpaste_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_currentStyle_Proxy(
    IHTMLElement2* This,
    IHTMLCurrentStyle **p);
void __RPC_STUB IHTMLElement2_get_currentStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onpropertychange_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onpropertychange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onpropertychange_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onpropertychange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_getClientRects_Proxy(
    IHTMLElement2* This,
    IHTMLRectCollection **pRectCol);
void __RPC_STUB IHTMLElement2_getClientRects_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_getBoundingClientRect_Proxy(
    IHTMLElement2* This,
    IHTMLRect **pRect);
void __RPC_STUB IHTMLElement2_getBoundingClientRect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_setExpression_Proxy(
    IHTMLElement2* This,
    BSTR propname,
    BSTR expression,
    BSTR language);
void __RPC_STUB IHTMLElement2_setExpression_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_getExpression_Proxy(
    IHTMLElement2* This,
    BSTR propname,
    VARIANT *expression);
void __RPC_STUB IHTMLElement2_getExpression_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_removeExpression_Proxy(
    IHTMLElement2* This,
    BSTR propname,
    VARIANT_BOOL *pfSuccess);
void __RPC_STUB IHTMLElement2_removeExpression_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_tabIndex_Proxy(
    IHTMLElement2* This,
    short v);
void __RPC_STUB IHTMLElement2_put_tabIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_tabIndex_Proxy(
    IHTMLElement2* This,
    short *p);
void __RPC_STUB IHTMLElement2_get_tabIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_focus_Proxy(
    IHTMLElement2* This);
void __RPC_STUB IHTMLElement2_focus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_accessKey_Proxy(
    IHTMLElement2* This,
    BSTR v);
void __RPC_STUB IHTMLElement2_put_accessKey_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_accessKey_Proxy(
    IHTMLElement2* This,
    BSTR *p);
void __RPC_STUB IHTMLElement2_get_accessKey_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onblur_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onblur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onblur_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onblur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onfocus_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onfocus_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onresize_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onresize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onresize_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onresize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_blur_Proxy(
    IHTMLElement2* This);
void __RPC_STUB IHTMLElement2_blur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_addFilter_Proxy(
    IHTMLElement2* This,
    IUnknown *pUnk);
void __RPC_STUB IHTMLElement2_addFilter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_removeFilter_Proxy(
    IHTMLElement2* This,
    IUnknown *pUnk);
void __RPC_STUB IHTMLElement2_removeFilter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_clientHeight_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_clientHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_clientWidth_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_clientWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_clientTop_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_clientTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_clientLeft_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_clientLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_attachEvent_Proxy(
    IHTMLElement2* This,
    BSTR event,
    IDispatch *pDisp,
    VARIANT_BOOL *pfResult);
void __RPC_STUB IHTMLElement2_attachEvent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_detachEvent_Proxy(
    IHTMLElement2* This,
    BSTR event,
    IDispatch *pDisp);
void __RPC_STUB IHTMLElement2_detachEvent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_readyState_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_readyState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onreadystatechange_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onreadystatechange_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onrowsdelete_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onrowsdelete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onrowsdelete_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onrowsdelete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onrowsinserted_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onrowsinserted_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onrowsinserted_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onrowsinserted_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_oncellchange_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_oncellchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_oncellchange_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_oncellchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_dir_Proxy(
    IHTMLElement2* This,
    BSTR v);
void __RPC_STUB IHTMLElement2_put_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_dir_Proxy(
    IHTMLElement2* This,
    BSTR *p);
void __RPC_STUB IHTMLElement2_get_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_createControlRange_Proxy(
    IHTMLElement2* This,
    IDispatch **range);
void __RPC_STUB IHTMLElement2_createControlRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_scrollHeight_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_scrollHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_scrollWidth_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_scrollWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_scrollTop_Proxy(
    IHTMLElement2* This,
    long v);
void __RPC_STUB IHTMLElement2_put_scrollTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_scrollTop_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_scrollTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_scrollLeft_Proxy(
    IHTMLElement2* This,
    long v);
void __RPC_STUB IHTMLElement2_put_scrollLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_scrollLeft_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_scrollLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_clearAttributes_Proxy(
    IHTMLElement2* This);
void __RPC_STUB IHTMLElement2_clearAttributes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_mergeAttributes_Proxy(
    IHTMLElement2* This,
    IHTMLElement *mergeThis);
void __RPC_STUB IHTMLElement2_mergeAttributes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_oncontextmenu_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_oncontextmenu_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_oncontextmenu_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_oncontextmenu_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_insertAdjacentElement_Proxy(
    IHTMLElement2* This,
    BSTR where,
    IHTMLElement *insertedElement,
    IHTMLElement **inserted);
void __RPC_STUB IHTMLElement2_insertAdjacentElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_applyElement_Proxy(
    IHTMLElement2* This,
    IHTMLElement *apply,
    BSTR where,
    IHTMLElement **applied);
void __RPC_STUB IHTMLElement2_applyElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_getAdjacentText_Proxy(
    IHTMLElement2* This,
    BSTR where,
    BSTR *text);
void __RPC_STUB IHTMLElement2_getAdjacentText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_replaceAdjacentText_Proxy(
    IHTMLElement2* This,
    BSTR where,
    BSTR newText,
    BSTR *oldText);
void __RPC_STUB IHTMLElement2_replaceAdjacentText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_canHaveChildren_Proxy(
    IHTMLElement2* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLElement2_get_canHaveChildren_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_addBehavior_Proxy(
    IHTMLElement2* This,
    BSTR bstrUrl,
    VARIANT *pvarFactory,
    long *pCookie);
void __RPC_STUB IHTMLElement2_addBehavior_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_removeBehavior_Proxy(
    IHTMLElement2* This,
    long cookie,
    VARIANT_BOOL *pfResult);
void __RPC_STUB IHTMLElement2_removeBehavior_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_runtimeStyle_Proxy(
    IHTMLElement2* This,
    IHTMLStyle **p);
void __RPC_STUB IHTMLElement2_get_runtimeStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_behaviorUrns_Proxy(
    IHTMLElement2* This,
    IDispatch **p);
void __RPC_STUB IHTMLElement2_get_behaviorUrns_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_tagUrn_Proxy(
    IHTMLElement2* This,
    BSTR v);
void __RPC_STUB IHTMLElement2_put_tagUrn_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_tagUrn_Proxy(
    IHTMLElement2* This,
    BSTR *p);
void __RPC_STUB IHTMLElement2_get_tagUrn_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_put_onbeforeeditfocus_Proxy(
    IHTMLElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLElement2_put_onbeforeeditfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_onbeforeeditfocus_Proxy(
    IHTMLElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLElement2_get_onbeforeeditfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_get_readyStateValue_Proxy(
    IHTMLElement2* This,
    long *p);
void __RPC_STUB IHTMLElement2_get_readyStateValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElement2_getElementsByTagName_Proxy(
    IHTMLElement2* This,
    BSTR v,
    IHTMLElementCollection **pelColl);
void __RPC_STUB IHTMLElement2_getElementsByTagName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLElement2_INTERFACE_DEFINED__ */

#ifndef __IHTMLStyleSheetRule_FWD_DEFINED__
#define __IHTMLStyleSheetRule_FWD_DEFINED__
typedef interface IHTMLStyleSheetRule IHTMLStyleSheetRule;
#endif

/*****************************************************************************
 * IHTMLStyleSheetRule interface
 */
#ifndef __IHTMLStyleSheetRule_INTERFACE_DEFINED__
#define __IHTMLStyleSheetRule_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLStyleSheetRule, 0x3050f357, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLStyleSheetRule : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_selectorText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_selectorText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_style(
        IHTMLRuleStyle **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readOnly(
        VARIANT_BOOL *p) = 0;

};
#else
typedef struct IHTMLStyleSheetRuleVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLStyleSheetRule* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLStyleSheetRule* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLStyleSheetRule* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLStyleSheetRule* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLStyleSheetRule* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLStyleSheetRule* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLStyleSheetRule* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLStyleSheetRule methods ***/
    HRESULT (STDMETHODCALLTYPE *put_selectorText)(
        IHTMLStyleSheetRule* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_selectorText)(
        IHTMLStyleSheetRule* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_style)(
        IHTMLStyleSheetRule* This,
        IHTMLRuleStyle **p);

    HRESULT (STDMETHODCALLTYPE *get_readOnly)(
        IHTMLStyleSheetRule* This,
        VARIANT_BOOL *p);

    END_INTERFACE
} IHTMLStyleSheetRuleVtbl;
interface IHTMLStyleSheetRule {
    CONST_VTBL IHTMLStyleSheetRuleVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLStyleSheetRule_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLStyleSheetRule_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLStyleSheetRule_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLStyleSheetRule_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLStyleSheetRule_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLStyleSheetRule_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLStyleSheetRule_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLStyleSheetRule methods ***/
#define IHTMLStyleSheetRule_put_selectorText(p,a) (p)->lpVtbl->put_selectorText(p,a)
#define IHTMLStyleSheetRule_get_selectorText(p,a) (p)->lpVtbl->get_selectorText(p,a)
#define IHTMLStyleSheetRule_get_style(p,a) (p)->lpVtbl->get_style(p,a)
#define IHTMLStyleSheetRule_get_readOnly(p,a) (p)->lpVtbl->get_readOnly(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLStyleSheetRule_put_selectorText_Proxy(
    IHTMLStyleSheetRule* This,
    BSTR v);
void __RPC_STUB IHTMLStyleSheetRule_put_selectorText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetRule_get_selectorText_Proxy(
    IHTMLStyleSheetRule* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheetRule_get_selectorText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetRule_get_style_Proxy(
    IHTMLStyleSheetRule* This,
    IHTMLRuleStyle **p);
void __RPC_STUB IHTMLStyleSheetRule_get_style_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetRule_get_readOnly_Proxy(
    IHTMLStyleSheetRule* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyleSheetRule_get_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLStyleSheetRule_INTERFACE_DEFINED__ */

#ifndef __IHTMLStyleSheetRulesCollection_FWD_DEFINED__
#define __IHTMLStyleSheetRulesCollection_FWD_DEFINED__
typedef interface IHTMLStyleSheetRulesCollection IHTMLStyleSheetRulesCollection;
#endif

/*****************************************************************************
 * IHTMLStyleSheetRulesCollection interface
 */
#ifndef __IHTMLStyleSheetRulesCollection_INTERFACE_DEFINED__
#define __IHTMLStyleSheetRulesCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLStyleSheetRulesCollection, 0x3050f2e5, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLStyleSheetRulesCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        long index,
        IHTMLStyleSheetRule **ppHTMLStyleSheetRule) = 0;

};
#else
typedef struct IHTMLStyleSheetRulesCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLStyleSheetRulesCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLStyleSheetRulesCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLStyleSheetRulesCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLStyleSheetRulesCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLStyleSheetRulesCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLStyleSheetRulesCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLStyleSheetRulesCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLStyleSheetRulesCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLStyleSheetRulesCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLStyleSheetRulesCollection* This,
        long index,
        IHTMLStyleSheetRule **ppHTMLStyleSheetRule);

    END_INTERFACE
} IHTMLStyleSheetRulesCollectionVtbl;
interface IHTMLStyleSheetRulesCollection {
    CONST_VTBL IHTMLStyleSheetRulesCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLStyleSheetRulesCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLStyleSheetRulesCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLStyleSheetRulesCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLStyleSheetRulesCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLStyleSheetRulesCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLStyleSheetRulesCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLStyleSheetRulesCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLStyleSheetRulesCollection methods ***/
#define IHTMLStyleSheetRulesCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLStyleSheetRulesCollection_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLStyleSheetRulesCollection_get_length_Proxy(
    IHTMLStyleSheetRulesCollection* This,
    long *p);
void __RPC_STUB IHTMLStyleSheetRulesCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetRulesCollection_item_Proxy(
    IHTMLStyleSheetRulesCollection* This,
    long index,
    IHTMLStyleSheetRule **ppHTMLStyleSheetRule);
void __RPC_STUB IHTMLStyleSheetRulesCollection_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLStyleSheetRulesCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLStyleSheet_FWD_DEFINED__
#define __IHTMLStyleSheet_FWD_DEFINED__
typedef interface IHTMLStyleSheet IHTMLStyleSheet;
#endif

/*****************************************************************************
 * IHTMLStyleSheet interface
 */
#ifndef __IHTMLStyleSheet_INTERFACE_DEFINED__
#define __IHTMLStyleSheet_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLStyleSheet, 0x3050f2e3, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLStyleSheet : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_title(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_title(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentStyleSheet(
        IHTMLStyleSheet **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_owningElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_disabled(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_disabled(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readOnly(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_imports(
        IHTMLStyleSheetsCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_href(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_href(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_id(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE addImport(
        BSTR bstrURL,
        long lIndex,
        long *plIndex) = 0;

    virtual HRESULT STDMETHODCALLTYPE addRule(
        BSTR bstrSelector,
        BSTR bstrStyle,
        long lIndex,
        long *plNewIndex) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeImport(
        long lIndex) = 0;

    virtual HRESULT STDMETHODCALLTYPE removeRule(
        long lIndex) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_media(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_media(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cssText(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cssText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rules(
        IHTMLStyleSheetRulesCollection **p) = 0;

};
#else
typedef struct IHTMLStyleSheetVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLStyleSheet* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLStyleSheet* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLStyleSheet* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLStyleSheet* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLStyleSheet* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLStyleSheet* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLStyleSheet* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLStyleSheet methods ***/
    HRESULT (STDMETHODCALLTYPE *put_title)(
        IHTMLStyleSheet* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_title)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_parentStyleSheet)(
        IHTMLStyleSheet* This,
        IHTMLStyleSheet **p);

    HRESULT (STDMETHODCALLTYPE *get_owningElement)(
        IHTMLStyleSheet* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *put_disabled)(
        IHTMLStyleSheet* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_disabled)(
        IHTMLStyleSheet* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_readOnly)(
        IHTMLStyleSheet* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_imports)(
        IHTMLStyleSheet* This,
        IHTMLStyleSheetsCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_href)(
        IHTMLStyleSheet* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_href)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_id)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *addImport)(
        IHTMLStyleSheet* This,
        BSTR bstrURL,
        long lIndex,
        long *plIndex);

    HRESULT (STDMETHODCALLTYPE *addRule)(
        IHTMLStyleSheet* This,
        BSTR bstrSelector,
        BSTR bstrStyle,
        long lIndex,
        long *plNewIndex);

    HRESULT (STDMETHODCALLTYPE *removeImport)(
        IHTMLStyleSheet* This,
        long lIndex);

    HRESULT (STDMETHODCALLTYPE *removeRule)(
        IHTMLStyleSheet* This,
        long lIndex);

    HRESULT (STDMETHODCALLTYPE *put_media)(
        IHTMLStyleSheet* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_media)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_cssText)(
        IHTMLStyleSheet* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cssText)(
        IHTMLStyleSheet* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_rules)(
        IHTMLStyleSheet* This,
        IHTMLStyleSheetRulesCollection **p);

    END_INTERFACE
} IHTMLStyleSheetVtbl;
interface IHTMLStyleSheet {
    CONST_VTBL IHTMLStyleSheetVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLStyleSheet_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLStyleSheet_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLStyleSheet_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLStyleSheet_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLStyleSheet_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLStyleSheet_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLStyleSheet_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLStyleSheet methods ***/
#define IHTMLStyleSheet_put_title(p,a) (p)->lpVtbl->put_title(p,a)
#define IHTMLStyleSheet_get_title(p,a) (p)->lpVtbl->get_title(p,a)
#define IHTMLStyleSheet_get_parentStyleSheet(p,a) (p)->lpVtbl->get_parentStyleSheet(p,a)
#define IHTMLStyleSheet_get_owningElement(p,a) (p)->lpVtbl->get_owningElement(p,a)
#define IHTMLStyleSheet_put_disabled(p,a) (p)->lpVtbl->put_disabled(p,a)
#define IHTMLStyleSheet_get_disabled(p,a) (p)->lpVtbl->get_disabled(p,a)
#define IHTMLStyleSheet_get_readOnly(p,a) (p)->lpVtbl->get_readOnly(p,a)
#define IHTMLStyleSheet_get_imports(p,a) (p)->lpVtbl->get_imports(p,a)
#define IHTMLStyleSheet_put_href(p,a) (p)->lpVtbl->put_href(p,a)
#define IHTMLStyleSheet_get_href(p,a) (p)->lpVtbl->get_href(p,a)
#define IHTMLStyleSheet_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#define IHTMLStyleSheet_get_id(p,a) (p)->lpVtbl->get_id(p,a)
#define IHTMLStyleSheet_addImport(p,a,b,c) (p)->lpVtbl->addImport(p,a,b,c)
#define IHTMLStyleSheet_addRule(p,a,b,c,d) (p)->lpVtbl->addRule(p,a,b,c,d)
#define IHTMLStyleSheet_removeImport(p,a) (p)->lpVtbl->removeImport(p,a)
#define IHTMLStyleSheet_removeRule(p,a) (p)->lpVtbl->removeRule(p,a)
#define IHTMLStyleSheet_put_media(p,a) (p)->lpVtbl->put_media(p,a)
#define IHTMLStyleSheet_get_media(p,a) (p)->lpVtbl->get_media(p,a)
#define IHTMLStyleSheet_put_cssText(p,a) (p)->lpVtbl->put_cssText(p,a)
#define IHTMLStyleSheet_get_cssText(p,a) (p)->lpVtbl->get_cssText(p,a)
#define IHTMLStyleSheet_get_rules(p,a) (p)->lpVtbl->get_rules(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLStyleSheet_put_title_Proxy(
    IHTMLStyleSheet* This,
    BSTR v);
void __RPC_STUB IHTMLStyleSheet_put_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_title_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_parentStyleSheet_Proxy(
    IHTMLStyleSheet* This,
    IHTMLStyleSheet **p);
void __RPC_STUB IHTMLStyleSheet_get_parentStyleSheet_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_owningElement_Proxy(
    IHTMLStyleSheet* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLStyleSheet_get_owningElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_put_disabled_Proxy(
    IHTMLStyleSheet* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLStyleSheet_put_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_disabled_Proxy(
    IHTMLStyleSheet* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyleSheet_get_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_readOnly_Proxy(
    IHTMLStyleSheet* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLStyleSheet_get_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_imports_Proxy(
    IHTMLStyleSheet* This,
    IHTMLStyleSheetsCollection **p);
void __RPC_STUB IHTMLStyleSheet_get_imports_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_put_href_Proxy(
    IHTMLStyleSheet* This,
    BSTR v);
void __RPC_STUB IHTMLStyleSheet_put_href_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_href_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_href_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_type_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_id_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_id_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_addImport_Proxy(
    IHTMLStyleSheet* This,
    BSTR bstrURL,
    long lIndex,
    long *plIndex);
void __RPC_STUB IHTMLStyleSheet_addImport_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_addRule_Proxy(
    IHTMLStyleSheet* This,
    BSTR bstrSelector,
    BSTR bstrStyle,
    long lIndex,
    long *plNewIndex);
void __RPC_STUB IHTMLStyleSheet_addRule_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_removeImport_Proxy(
    IHTMLStyleSheet* This,
    long lIndex);
void __RPC_STUB IHTMLStyleSheet_removeImport_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_removeRule_Proxy(
    IHTMLStyleSheet* This,
    long lIndex);
void __RPC_STUB IHTMLStyleSheet_removeRule_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_put_media_Proxy(
    IHTMLStyleSheet* This,
    BSTR v);
void __RPC_STUB IHTMLStyleSheet_put_media_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_media_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_media_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_put_cssText_Proxy(
    IHTMLStyleSheet* This,
    BSTR v);
void __RPC_STUB IHTMLStyleSheet_put_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_cssText_Proxy(
    IHTMLStyleSheet* This,
    BSTR *p);
void __RPC_STUB IHTMLStyleSheet_get_cssText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheet_get_rules_Proxy(
    IHTMLStyleSheet* This,
    IHTMLStyleSheetRulesCollection **p);
void __RPC_STUB IHTMLStyleSheet_get_rules_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLStyleSheet_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IHTMLStyleSheetsCollection interface
 */
#ifndef __IHTMLStyleSheetsCollection_INTERFACE_DEFINED__
#define __IHTMLStyleSheetsCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLStyleSheetsCollection, 0x3050f37e, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLStyleSheetsCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT *pvarIndex,
        VARIANT *pvarResult) = 0;

};
#else
typedef struct IHTMLStyleSheetsCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLStyleSheetsCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLStyleSheetsCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLStyleSheetsCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLStyleSheetsCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLStyleSheetsCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLStyleSheetsCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLStyleSheetsCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLStyleSheetsCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLStyleSheetsCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLStyleSheetsCollection* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLStyleSheetsCollection* This,
        VARIANT *pvarIndex,
        VARIANT *pvarResult);

    END_INTERFACE
} IHTMLStyleSheetsCollectionVtbl;
interface IHTMLStyleSheetsCollection {
    CONST_VTBL IHTMLStyleSheetsCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLStyleSheetsCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLStyleSheetsCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLStyleSheetsCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLStyleSheetsCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLStyleSheetsCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLStyleSheetsCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLStyleSheetsCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLStyleSheetsCollection methods ***/
#define IHTMLStyleSheetsCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLStyleSheetsCollection_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLStyleSheetsCollection_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLStyleSheetsCollection_get_length_Proxy(
    IHTMLStyleSheetsCollection* This,
    long *p);
void __RPC_STUB IHTMLStyleSheetsCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetsCollection_get__newEnum_Proxy(
    IHTMLStyleSheetsCollection* This,
    IUnknown **p);
void __RPC_STUB IHTMLStyleSheetsCollection_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLStyleSheetsCollection_item_Proxy(
    IHTMLStyleSheetsCollection* This,
    VARIANT *pvarIndex,
    VARIANT *pvarResult);
void __RPC_STUB IHTMLStyleSheetsCollection_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLStyleSheetsCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLTxtRange_FWD_DEFINED__
#define __IHTMLTxtRange_FWD_DEFINED__
typedef interface IHTMLTxtRange IHTMLTxtRange;
#endif

/*****************************************************************************
 * IHTMLTxtRange interface
 */
#ifndef __IHTMLTxtRange_INTERFACE_DEFINED__
#define __IHTMLTxtRange_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLTxtRange, 0x3050f220, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLTxtRange : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_htmlText(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_text(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_text(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE parentElement(
        IHTMLElement **parent) = 0;

    virtual HRESULT STDMETHODCALLTYPE duplicate(
        IHTMLTxtRange **Duplicate) = 0;

    virtual HRESULT STDMETHODCALLTYPE inRange(
        IHTMLTxtRange *Range,
        VARIANT_BOOL *InRange) = 0;

    virtual HRESULT STDMETHODCALLTYPE isEqual(
        IHTMLTxtRange *Range,
        VARIANT_BOOL *IsEqual) = 0;

    virtual HRESULT STDMETHODCALLTYPE scrollIntoView(
        VARIANT_BOOL fStart) = 0;

    virtual HRESULT STDMETHODCALLTYPE collapse(
        VARIANT_BOOL Start) = 0;

    virtual HRESULT STDMETHODCALLTYPE expand(
        BSTR Unit,
        VARIANT_BOOL *Success) = 0;

    virtual HRESULT STDMETHODCALLTYPE move(
        BSTR Unit,
        long Count,
        long *ActualCount) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveStart(
        BSTR Unit,
        long Count,
        long *ActualCount) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveEnd(
        BSTR Unit,
        long Count,
        long *ActualCount) = 0;

    virtual HRESULT STDMETHODCALLTYPE select(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE pasteHTML(
        BSTR html) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveToElementText(
        IHTMLElement *element) = 0;

    virtual HRESULT STDMETHODCALLTYPE setEndPoint(
        BSTR how,
        IHTMLTxtRange *SourceRange) = 0;

    virtual HRESULT STDMETHODCALLTYPE compareEndPoints(
        BSTR how,
        IHTMLTxtRange *SourceRange,
        long *ret) = 0;

    virtual HRESULT STDMETHODCALLTYPE findText(
        BSTR String,
        long count,
        long Flags,
        VARIANT_BOOL *Success) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveToPoint(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE getBookmark(
        BSTR *Boolmark) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveToBookmark(
        BSTR Bookmark,
        VARIANT_BOOL *Success) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandSupported(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandEnabled(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandState(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandIndeterm(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandText(
        BSTR cmdID,
        BSTR *pcmdText) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandValue(
        BSTR cmdID,
        VARIANT *pcmdValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE execCommand(
        BSTR cmdID,
        VARIANT_BOOL showUI,
        VARIANT value,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE execCommandShowHelp(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

};
#else
typedef struct IHTMLTxtRangeVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLTxtRange* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLTxtRange* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLTxtRange* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLTxtRange* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLTxtRange* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLTxtRange* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLTxtRange* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLTxtRange methods ***/
    HRESULT (STDMETHODCALLTYPE *get_htmlText)(
        IHTMLTxtRange* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_text)(
        IHTMLTxtRange* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_text)(
        IHTMLTxtRange* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *parentElement)(
        IHTMLTxtRange* This,
        IHTMLElement **parent);

    HRESULT (STDMETHODCALLTYPE *duplicate)(
        IHTMLTxtRange* This,
        IHTMLTxtRange **Duplicate);

    HRESULT (STDMETHODCALLTYPE *inRange)(
        IHTMLTxtRange* This,
        IHTMLTxtRange *Range,
        VARIANT_BOOL *InRange);

    HRESULT (STDMETHODCALLTYPE *isEqual)(
        IHTMLTxtRange* This,
        IHTMLTxtRange *Range,
        VARIANT_BOOL *IsEqual);

    HRESULT (STDMETHODCALLTYPE *scrollIntoView)(
        IHTMLTxtRange* This,
        VARIANT_BOOL fStart);

    HRESULT (STDMETHODCALLTYPE *collapse)(
        IHTMLTxtRange* This,
        VARIANT_BOOL Start);

    HRESULT (STDMETHODCALLTYPE *expand)(
        IHTMLTxtRange* This,
        BSTR Unit,
        VARIANT_BOOL *Success);

    HRESULT (STDMETHODCALLTYPE *move)(
        IHTMLTxtRange* This,
        BSTR Unit,
        long Count,
        long *ActualCount);

    HRESULT (STDMETHODCALLTYPE *moveStart)(
        IHTMLTxtRange* This,
        BSTR Unit,
        long Count,
        long *ActualCount);

    HRESULT (STDMETHODCALLTYPE *moveEnd)(
        IHTMLTxtRange* This,
        BSTR Unit,
        long Count,
        long *ActualCount);

    HRESULT (STDMETHODCALLTYPE *select)(
        IHTMLTxtRange* This);

    HRESULT (STDMETHODCALLTYPE *pasteHTML)(
        IHTMLTxtRange* This,
        BSTR html);

    HRESULT (STDMETHODCALLTYPE *moveToElementText)(
        IHTMLTxtRange* This,
        IHTMLElement *element);

    HRESULT (STDMETHODCALLTYPE *setEndPoint)(
        IHTMLTxtRange* This,
        BSTR how,
        IHTMLTxtRange *SourceRange);

    HRESULT (STDMETHODCALLTYPE *compareEndPoints)(
        IHTMLTxtRange* This,
        BSTR how,
        IHTMLTxtRange *SourceRange,
        long *ret);

    HRESULT (STDMETHODCALLTYPE *findText)(
        IHTMLTxtRange* This,
        BSTR String,
        long count,
        long Flags,
        VARIANT_BOOL *Success);

    HRESULT (STDMETHODCALLTYPE *moveToPoint)(
        IHTMLTxtRange* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *getBookmark)(
        IHTMLTxtRange* This,
        BSTR *Boolmark);

    HRESULT (STDMETHODCALLTYPE *moveToBookmark)(
        IHTMLTxtRange* This,
        BSTR Bookmark,
        VARIANT_BOOL *Success);

    HRESULT (STDMETHODCALLTYPE *queryCommandSupported)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandEnabled)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandState)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandIndeterm)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandText)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        BSTR *pcmdText);

    HRESULT (STDMETHODCALLTYPE *queryCommandValue)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT *pcmdValue);

    HRESULT (STDMETHODCALLTYPE *execCommand)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL showUI,
        VARIANT value,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *execCommandShowHelp)(
        IHTMLTxtRange* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    END_INTERFACE
} IHTMLTxtRangeVtbl;
interface IHTMLTxtRange {
    CONST_VTBL IHTMLTxtRangeVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLTxtRange_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLTxtRange_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLTxtRange_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLTxtRange_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLTxtRange_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLTxtRange_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLTxtRange_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLTxtRange methods ***/
#define IHTMLTxtRange_get_htmlText(p,a) (p)->lpVtbl->get_htmlText(p,a)
#define IHTMLTxtRange_put_text(p,a) (p)->lpVtbl->put_text(p,a)
#define IHTMLTxtRange_get_text(p,a) (p)->lpVtbl->get_text(p,a)
#define IHTMLTxtRange_parentElement(p,a) (p)->lpVtbl->parentElement(p,a)
#define IHTMLTxtRange_duplicate(p,a) (p)->lpVtbl->duplicate(p,a)
#define IHTMLTxtRange_inRange(p,a,b) (p)->lpVtbl->inRange(p,a,b)
#define IHTMLTxtRange_isEqual(p,a,b) (p)->lpVtbl->isEqual(p,a,b)
#define IHTMLTxtRange_scrollIntoView(p,a) (p)->lpVtbl->scrollIntoView(p,a)
#define IHTMLTxtRange_collapse(p,a) (p)->lpVtbl->collapse(p,a)
#define IHTMLTxtRange_expand(p,a,b) (p)->lpVtbl->expand(p,a,b)
#define IHTMLTxtRange_move(p,a,b,c) (p)->lpVtbl->move(p,a,b,c)
#define IHTMLTxtRange_moveStart(p,a,b,c) (p)->lpVtbl->moveStart(p,a,b,c)
#define IHTMLTxtRange_moveEnd(p,a,b,c) (p)->lpVtbl->moveEnd(p,a,b,c)
#define IHTMLTxtRange_select(p) (p)->lpVtbl->select(p)
#define IHTMLTxtRange_pasteHTML(p,a) (p)->lpVtbl->pasteHTML(p,a)
#define IHTMLTxtRange_moveToElementText(p,a) (p)->lpVtbl->moveToElementText(p,a)
#define IHTMLTxtRange_setEndPoint(p,a,b) (p)->lpVtbl->setEndPoint(p,a,b)
#define IHTMLTxtRange_compareEndPoints(p,a,b,c) (p)->lpVtbl->compareEndPoints(p,a,b,c)
#define IHTMLTxtRange_findText(p,a,b,c,d) (p)->lpVtbl->findText(p,a,b,c,d)
#define IHTMLTxtRange_moveToPoint(p,a,b) (p)->lpVtbl->moveToPoint(p,a,b)
#define IHTMLTxtRange_getBookmark(p,a) (p)->lpVtbl->getBookmark(p,a)
#define IHTMLTxtRange_moveToBookmark(p,a,b) (p)->lpVtbl->moveToBookmark(p,a,b)
#define IHTMLTxtRange_queryCommandSupported(p,a,b) (p)->lpVtbl->queryCommandSupported(p,a,b)
#define IHTMLTxtRange_queryCommandEnabled(p,a,b) (p)->lpVtbl->queryCommandEnabled(p,a,b)
#define IHTMLTxtRange_queryCommandState(p,a,b) (p)->lpVtbl->queryCommandState(p,a,b)
#define IHTMLTxtRange_queryCommandIndeterm(p,a,b) (p)->lpVtbl->queryCommandIndeterm(p,a,b)
#define IHTMLTxtRange_queryCommandText(p,a,b) (p)->lpVtbl->queryCommandText(p,a,b)
#define IHTMLTxtRange_queryCommandValue(p,a,b) (p)->lpVtbl->queryCommandValue(p,a,b)
#define IHTMLTxtRange_execCommand(p,a,b,c,d) (p)->lpVtbl->execCommand(p,a,b,c,d)
#define IHTMLTxtRange_execCommandShowHelp(p,a,b) (p)->lpVtbl->execCommandShowHelp(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLTxtRange_get_htmlText_Proxy(
    IHTMLTxtRange* This,
    BSTR *p);
void __RPC_STUB IHTMLTxtRange_get_htmlText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_put_text_Proxy(
    IHTMLTxtRange* This,
    BSTR v);
void __RPC_STUB IHTMLTxtRange_put_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_get_text_Proxy(
    IHTMLTxtRange* This,
    BSTR *p);
void __RPC_STUB IHTMLTxtRange_get_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_parentElement_Proxy(
    IHTMLTxtRange* This,
    IHTMLElement **parent);
void __RPC_STUB IHTMLTxtRange_parentElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_duplicate_Proxy(
    IHTMLTxtRange* This,
    IHTMLTxtRange **Duplicate);
void __RPC_STUB IHTMLTxtRange_duplicate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_inRange_Proxy(
    IHTMLTxtRange* This,
    IHTMLTxtRange *Range,
    VARIANT_BOOL *InRange);
void __RPC_STUB IHTMLTxtRange_inRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_isEqual_Proxy(
    IHTMLTxtRange* This,
    IHTMLTxtRange *Range,
    VARIANT_BOOL *IsEqual);
void __RPC_STUB IHTMLTxtRange_isEqual_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_scrollIntoView_Proxy(
    IHTMLTxtRange* This,
    VARIANT_BOOL fStart);
void __RPC_STUB IHTMLTxtRange_scrollIntoView_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_collapse_Proxy(
    IHTMLTxtRange* This,
    VARIANT_BOOL Start);
void __RPC_STUB IHTMLTxtRange_collapse_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_expand_Proxy(
    IHTMLTxtRange* This,
    BSTR Unit,
    VARIANT_BOOL *Success);
void __RPC_STUB IHTMLTxtRange_expand_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_move_Proxy(
    IHTMLTxtRange* This,
    BSTR Unit,
    long Count,
    long *ActualCount);
void __RPC_STUB IHTMLTxtRange_move_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_moveStart_Proxy(
    IHTMLTxtRange* This,
    BSTR Unit,
    long Count,
    long *ActualCount);
void __RPC_STUB IHTMLTxtRange_moveStart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_moveEnd_Proxy(
    IHTMLTxtRange* This,
    BSTR Unit,
    long Count,
    long *ActualCount);
void __RPC_STUB IHTMLTxtRange_moveEnd_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_select_Proxy(
    IHTMLTxtRange* This);
void __RPC_STUB IHTMLTxtRange_select_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_pasteHTML_Proxy(
    IHTMLTxtRange* This,
    BSTR html);
void __RPC_STUB IHTMLTxtRange_pasteHTML_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_moveToElementText_Proxy(
    IHTMLTxtRange* This,
    IHTMLElement *element);
void __RPC_STUB IHTMLTxtRange_moveToElementText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_setEndPoint_Proxy(
    IHTMLTxtRange* This,
    BSTR how,
    IHTMLTxtRange *SourceRange);
void __RPC_STUB IHTMLTxtRange_setEndPoint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_compareEndPoints_Proxy(
    IHTMLTxtRange* This,
    BSTR how,
    IHTMLTxtRange *SourceRange,
    long *ret);
void __RPC_STUB IHTMLTxtRange_compareEndPoints_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_findText_Proxy(
    IHTMLTxtRange* This,
    BSTR String,
    long count,
    long Flags,
    VARIANT_BOOL *Success);
void __RPC_STUB IHTMLTxtRange_findText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_moveToPoint_Proxy(
    IHTMLTxtRange* This,
    long x,
    long y);
void __RPC_STUB IHTMLTxtRange_moveToPoint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_getBookmark_Proxy(
    IHTMLTxtRange* This,
    BSTR *Boolmark);
void __RPC_STUB IHTMLTxtRange_getBookmark_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_moveToBookmark_Proxy(
    IHTMLTxtRange* This,
    BSTR Bookmark,
    VARIANT_BOOL *Success);
void __RPC_STUB IHTMLTxtRange_moveToBookmark_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandSupported_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_queryCommandSupported_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandEnabled_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_queryCommandEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandState_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_queryCommandState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandIndeterm_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_queryCommandIndeterm_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandText_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    BSTR *pcmdText);
void __RPC_STUB IHTMLTxtRange_queryCommandText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_queryCommandValue_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT *pcmdValue);
void __RPC_STUB IHTMLTxtRange_queryCommandValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_execCommand_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL showUI,
    VARIANT value,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_execCommand_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTxtRange_execCommandShowHelp_Proxy(
    IHTMLTxtRange* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLTxtRange_execCommandShowHelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLTxtRange_INTERFACE_DEFINED__ */

#ifndef __IHTMLFormElement_FWD_DEFINED__
#define __IHTMLFormElement_FWD_DEFINED__
typedef interface IHTMLFormElement IHTMLFormElement;
#endif

/*****************************************************************************
 * IHTMLFormElement interface
 */
#ifndef __IHTMLFormElement_INTERFACE_DEFINED__
#define __IHTMLFormElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLFormElement, 0x3050f1f7, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLFormElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_action(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_action(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_dir(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_dir(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_encoding(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_encoding(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_method(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_method(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_elements(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_target(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_target(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onsubmit(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onsubmit(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onreset(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onreset(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE submit(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE reset(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_length(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp) = 0;

    virtual HRESULT STDMETHODCALLTYPE tags(
        VARIANT tagName,
        IDispatch **pdisp) = 0;

};
#else
typedef struct IHTMLFormElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLFormElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLFormElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLFormElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLFormElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLFormElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLFormElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLFormElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLFormElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_action)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_action)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_dir)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_dir)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_encoding)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_encoding)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_method)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_method)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_elements)(
        IHTMLFormElement* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *put_target)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_target)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLFormElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLFormElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onsubmit)(
        IHTMLFormElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onsubmit)(
        IHTMLFormElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onreset)(
        IHTMLFormElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onreset)(
        IHTMLFormElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *submit)(
        IHTMLFormElement* This);

    HRESULT (STDMETHODCALLTYPE *reset)(
        IHTMLFormElement* This);

    HRESULT (STDMETHODCALLTYPE *put_length)(
        IHTMLFormElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLFormElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLFormElement* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLFormElement* This,
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp);

    HRESULT (STDMETHODCALLTYPE *tags)(
        IHTMLFormElement* This,
        VARIANT tagName,
        IDispatch **pdisp);

    END_INTERFACE
} IHTMLFormElementVtbl;
interface IHTMLFormElement {
    CONST_VTBL IHTMLFormElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLFormElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLFormElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLFormElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLFormElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLFormElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLFormElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLFormElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLFormElement methods ***/
#define IHTMLFormElement_put_action(p,a) (p)->lpVtbl->put_action(p,a)
#define IHTMLFormElement_get_action(p,a) (p)->lpVtbl->get_action(p,a)
#define IHTMLFormElement_put_dir(p,a) (p)->lpVtbl->put_dir(p,a)
#define IHTMLFormElement_get_dir(p,a) (p)->lpVtbl->get_dir(p,a)
#define IHTMLFormElement_put_encoding(p,a) (p)->lpVtbl->put_encoding(p,a)
#define IHTMLFormElement_get_encoding(p,a) (p)->lpVtbl->get_encoding(p,a)
#define IHTMLFormElement_put_method(p,a) (p)->lpVtbl->put_method(p,a)
#define IHTMLFormElement_get_method(p,a) (p)->lpVtbl->get_method(p,a)
#define IHTMLFormElement_get_elements(p,a) (p)->lpVtbl->get_elements(p,a)
#define IHTMLFormElement_put_target(p,a) (p)->lpVtbl->put_target(p,a)
#define IHTMLFormElement_get_target(p,a) (p)->lpVtbl->get_target(p,a)
#define IHTMLFormElement_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLFormElement_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLFormElement_put_onsubmit(p,a) (p)->lpVtbl->put_onsubmit(p,a)
#define IHTMLFormElement_get_onsubmit(p,a) (p)->lpVtbl->get_onsubmit(p,a)
#define IHTMLFormElement_put_onreset(p,a) (p)->lpVtbl->put_onreset(p,a)
#define IHTMLFormElement_get_onreset(p,a) (p)->lpVtbl->get_onreset(p,a)
#define IHTMLFormElement_submit(p) (p)->lpVtbl->submit(p)
#define IHTMLFormElement_reset(p) (p)->lpVtbl->reset(p)
#define IHTMLFormElement_put_length(p,a) (p)->lpVtbl->put_length(p,a)
#define IHTMLFormElement_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLFormElement_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLFormElement_item(p,a,b,c) (p)->lpVtbl->item(p,a,b,c)
#define IHTMLFormElement_tags(p,a,b) (p)->lpVtbl->tags(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLFormElement_put_action_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_action_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_action_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_action_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_dir_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_dir_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_encoding_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_encoding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_encoding_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_encoding_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_method_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_method_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_method_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_method_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_elements_Proxy(
    IHTMLFormElement* This,
    IDispatch **p);
void __RPC_STUB IHTMLFormElement_get_elements_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_target_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_target_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_target_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_target_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_name_Proxy(
    IHTMLFormElement* This,
    BSTR v);
void __RPC_STUB IHTMLFormElement_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_name_Proxy(
    IHTMLFormElement* This,
    BSTR *p);
void __RPC_STUB IHTMLFormElement_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_onsubmit_Proxy(
    IHTMLFormElement* This,
    VARIANT v);
void __RPC_STUB IHTMLFormElement_put_onsubmit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_onsubmit_Proxy(
    IHTMLFormElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLFormElement_get_onsubmit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_onreset_Proxy(
    IHTMLFormElement* This,
    VARIANT v);
void __RPC_STUB IHTMLFormElement_put_onreset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_onreset_Proxy(
    IHTMLFormElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLFormElement_get_onreset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_submit_Proxy(
    IHTMLFormElement* This);
void __RPC_STUB IHTMLFormElement_submit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_reset_Proxy(
    IHTMLFormElement* This);
void __RPC_STUB IHTMLFormElement_reset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_put_length_Proxy(
    IHTMLFormElement* This,
    long v);
void __RPC_STUB IHTMLFormElement_put_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get_length_Proxy(
    IHTMLFormElement* This,
    long *p);
void __RPC_STUB IHTMLFormElement_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_get__newEnum_Proxy(
    IHTMLFormElement* This,
    IUnknown **p);
void __RPC_STUB IHTMLFormElement_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_item_Proxy(
    IHTMLFormElement* This,
    VARIANT name,
    VARIANT index,
    IDispatch **pdisp);
void __RPC_STUB IHTMLFormElement_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFormElement_tags_Proxy(
    IHTMLFormElement* This,
    VARIANT tagName,
    IDispatch **pdisp);
void __RPC_STUB IHTMLFormElement_tags_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLFormElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLTextContainer_FWD_DEFINED__
#define __IHTMLTextContainer_FWD_DEFINED__
typedef interface IHTMLTextContainer IHTMLTextContainer;
#endif

/*****************************************************************************
 * IHTMLTextContainer interface
 */
#ifndef __IHTMLTextContainer_INTERFACE_DEFINED__
#define __IHTMLTextContainer_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLTextContainer, 0x3050f230, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLTextContainer : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE createControlRange(
        IDispatch **range) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_scrollTop(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollTop(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_scrollLeft(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scrollLeft(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onscroll(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onscroll(
        VARIANT *p) = 0;

};
#else
typedef struct IHTMLTextContainerVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLTextContainer* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLTextContainer* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLTextContainer* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLTextContainer* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLTextContainer* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLTextContainer* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLTextContainer* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLTextContainer methods ***/
    HRESULT (STDMETHODCALLTYPE *createControlRange)(
        IHTMLTextContainer* This,
        IDispatch **range);

    HRESULT (STDMETHODCALLTYPE *get_scrollHeight)(
        IHTMLTextContainer* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_scrollWidth)(
        IHTMLTextContainer* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_scrollTop)(
        IHTMLTextContainer* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_scrollTop)(
        IHTMLTextContainer* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_scrollLeft)(
        IHTMLTextContainer* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_scrollLeft)(
        IHTMLTextContainer* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_onscroll)(
        IHTMLTextContainer* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onscroll)(
        IHTMLTextContainer* This,
        VARIANT *p);

    END_INTERFACE
} IHTMLTextContainerVtbl;
interface IHTMLTextContainer {
    CONST_VTBL IHTMLTextContainerVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLTextContainer_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLTextContainer_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLTextContainer_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLTextContainer_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLTextContainer_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLTextContainer_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLTextContainer_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLTextContainer methods ***/
#define IHTMLTextContainer_createControlRange(p,a) (p)->lpVtbl->createControlRange(p,a)
#define IHTMLTextContainer_get_scrollHeight(p,a) (p)->lpVtbl->get_scrollHeight(p,a)
#define IHTMLTextContainer_get_scrollWidth(p,a) (p)->lpVtbl->get_scrollWidth(p,a)
#define IHTMLTextContainer_put_scrollTop(p,a) (p)->lpVtbl->put_scrollTop(p,a)
#define IHTMLTextContainer_get_scrollTop(p,a) (p)->lpVtbl->get_scrollTop(p,a)
#define IHTMLTextContainer_put_scrollLeft(p,a) (p)->lpVtbl->put_scrollLeft(p,a)
#define IHTMLTextContainer_get_scrollLeft(p,a) (p)->lpVtbl->get_scrollLeft(p,a)
#define IHTMLTextContainer_put_onscroll(p,a) (p)->lpVtbl->put_onscroll(p,a)
#define IHTMLTextContainer_get_onscroll(p,a) (p)->lpVtbl->get_onscroll(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLTextContainer_createControlRange_Proxy(
    IHTMLTextContainer* This,
    IDispatch **range);
void __RPC_STUB IHTMLTextContainer_createControlRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_get_scrollHeight_Proxy(
    IHTMLTextContainer* This,
    long *p);
void __RPC_STUB IHTMLTextContainer_get_scrollHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_get_scrollWidth_Proxy(
    IHTMLTextContainer* This,
    long *p);
void __RPC_STUB IHTMLTextContainer_get_scrollWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_put_scrollTop_Proxy(
    IHTMLTextContainer* This,
    long v);
void __RPC_STUB IHTMLTextContainer_put_scrollTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_get_scrollTop_Proxy(
    IHTMLTextContainer* This,
    long *p);
void __RPC_STUB IHTMLTextContainer_get_scrollTop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_put_scrollLeft_Proxy(
    IHTMLTextContainer* This,
    long v);
void __RPC_STUB IHTMLTextContainer_put_scrollLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_get_scrollLeft_Proxy(
    IHTMLTextContainer* This,
    long *p);
void __RPC_STUB IHTMLTextContainer_get_scrollLeft_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_put_onscroll_Proxy(
    IHTMLTextContainer* This,
    VARIANT v);
void __RPC_STUB IHTMLTextContainer_put_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextContainer_get_onscroll_Proxy(
    IHTMLTextContainer* This,
    VARIANT *p);
void __RPC_STUB IHTMLTextContainer_get_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLTextContainer_INTERFACE_DEFINED__ */

#ifndef __IHTMLImgElement_FWD_DEFINED__
#define __IHTMLImgElement_FWD_DEFINED__
typedef interface IHTMLImgElement IHTMLImgElement;
#endif

/*****************************************************************************
 * IHTMLImgElement interface
 */
#ifndef __IHTMLImgElement_INTERFACE_DEFINED__
#define __IHTMLImgElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLImgElement, 0x3050f240, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLImgElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_isMap(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_isMap(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_useMap(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_useMap(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_mimeType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileSize(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileCreatedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileModifiedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileUpdatedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_protocol(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_href(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nameProp(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_border(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_border(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vspace(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vspace(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_hspace(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_hspace(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_alt(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_alt(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_src(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_src(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_lowsrc(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lowsrc(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vrml(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vrml(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_dynsrc(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_dynsrc(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyState(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_complete(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_loop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_loop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_align(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_align(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onerror(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onerror(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onabort(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onabort(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_width(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_height(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_start(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_start(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLImgElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLImgElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLImgElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLImgElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLImgElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLImgElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLImgElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLImgElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLImgElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_isMap)(
        IHTMLImgElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_isMap)(
        IHTMLImgElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_useMap)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_useMap)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_mimeType)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileSize)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileCreatedDate)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileModifiedDate)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileUpdatedDate)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_protocol)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_href)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_nameProp)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_border)(
        IHTMLImgElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_border)(
        IHTMLImgElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_vspace)(
        IHTMLImgElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_vspace)(
        IHTMLImgElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_hspace)(
        IHTMLImgElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_hspace)(
        IHTMLImgElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_alt)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_alt)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_src)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_src)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_lowsrc)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_lowsrc)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_vrml)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_vrml)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_dynsrc)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_dynsrc)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_readyState)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_complete)(
        IHTMLImgElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_loop)(
        IHTMLImgElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_loop)(
        IHTMLImgElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_align)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_align)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onload)(
        IHTMLImgElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onload)(
        IHTMLImgElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onerror)(
        IHTMLImgElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onerror)(
        IHTMLImgElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onabort)(
        IHTMLImgElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onabort)(
        IHTMLImgElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLImgElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_width)(
        IHTMLImgElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLImgElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_height)(
        IHTMLImgElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLImgElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_start)(
        IHTMLImgElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_start)(
        IHTMLImgElement* This,
        BSTR *p);

    END_INTERFACE
} IHTMLImgElementVtbl;
interface IHTMLImgElement {
    CONST_VTBL IHTMLImgElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLImgElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLImgElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLImgElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLImgElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLImgElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLImgElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLImgElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLImgElement methods ***/
#define IHTMLImgElement_put_isMap(p,a) (p)->lpVtbl->put_isMap(p,a)
#define IHTMLImgElement_get_isMap(p,a) (p)->lpVtbl->get_isMap(p,a)
#define IHTMLImgElement_put_useMap(p,a) (p)->lpVtbl->put_useMap(p,a)
#define IHTMLImgElement_get_useMap(p,a) (p)->lpVtbl->get_useMap(p,a)
#define IHTMLImgElement_get_mimeType(p,a) (p)->lpVtbl->get_mimeType(p,a)
#define IHTMLImgElement_get_fileSize(p,a) (p)->lpVtbl->get_fileSize(p,a)
#define IHTMLImgElement_get_fileCreatedDate(p,a) (p)->lpVtbl->get_fileCreatedDate(p,a)
#define IHTMLImgElement_get_fileModifiedDate(p,a) (p)->lpVtbl->get_fileModifiedDate(p,a)
#define IHTMLImgElement_get_fileUpdatedDate(p,a) (p)->lpVtbl->get_fileUpdatedDate(p,a)
#define IHTMLImgElement_get_protocol(p,a) (p)->lpVtbl->get_protocol(p,a)
#define IHTMLImgElement_get_href(p,a) (p)->lpVtbl->get_href(p,a)
#define IHTMLImgElement_get_nameProp(p,a) (p)->lpVtbl->get_nameProp(p,a)
#define IHTMLImgElement_put_border(p,a) (p)->lpVtbl->put_border(p,a)
#define IHTMLImgElement_get_border(p,a) (p)->lpVtbl->get_border(p,a)
#define IHTMLImgElement_put_vspace(p,a) (p)->lpVtbl->put_vspace(p,a)
#define IHTMLImgElement_get_vspace(p,a) (p)->lpVtbl->get_vspace(p,a)
#define IHTMLImgElement_put_hspace(p,a) (p)->lpVtbl->put_hspace(p,a)
#define IHTMLImgElement_get_hspace(p,a) (p)->lpVtbl->get_hspace(p,a)
#define IHTMLImgElement_put_alt(p,a) (p)->lpVtbl->put_alt(p,a)
#define IHTMLImgElement_get_alt(p,a) (p)->lpVtbl->get_alt(p,a)
#define IHTMLImgElement_put_src(p,a) (p)->lpVtbl->put_src(p,a)
#define IHTMLImgElement_get_src(p,a) (p)->lpVtbl->get_src(p,a)
#define IHTMLImgElement_put_lowsrc(p,a) (p)->lpVtbl->put_lowsrc(p,a)
#define IHTMLImgElement_get_lowsrc(p,a) (p)->lpVtbl->get_lowsrc(p,a)
#define IHTMLImgElement_put_vrml(p,a) (p)->lpVtbl->put_vrml(p,a)
#define IHTMLImgElement_get_vrml(p,a) (p)->lpVtbl->get_vrml(p,a)
#define IHTMLImgElement_put_dynsrc(p,a) (p)->lpVtbl->put_dynsrc(p,a)
#define IHTMLImgElement_get_dynsrc(p,a) (p)->lpVtbl->get_dynsrc(p,a)
#define IHTMLImgElement_get_readyState(p,a) (p)->lpVtbl->get_readyState(p,a)
#define IHTMLImgElement_get_complete(p,a) (p)->lpVtbl->get_complete(p,a)
#define IHTMLImgElement_put_loop(p,a) (p)->lpVtbl->put_loop(p,a)
#define IHTMLImgElement_get_loop(p,a) (p)->lpVtbl->get_loop(p,a)
#define IHTMLImgElement_put_align(p,a) (p)->lpVtbl->put_align(p,a)
#define IHTMLImgElement_get_align(p,a) (p)->lpVtbl->get_align(p,a)
#define IHTMLImgElement_put_onload(p,a) (p)->lpVtbl->put_onload(p,a)
#define IHTMLImgElement_get_onload(p,a) (p)->lpVtbl->get_onload(p,a)
#define IHTMLImgElement_put_onerror(p,a) (p)->lpVtbl->put_onerror(p,a)
#define IHTMLImgElement_get_onerror(p,a) (p)->lpVtbl->get_onerror(p,a)
#define IHTMLImgElement_put_onabort(p,a) (p)->lpVtbl->put_onabort(p,a)
#define IHTMLImgElement_get_onabort(p,a) (p)->lpVtbl->get_onabort(p,a)
#define IHTMLImgElement_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLImgElement_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLImgElement_put_width(p,a) (p)->lpVtbl->put_width(p,a)
#define IHTMLImgElement_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLImgElement_put_height(p,a) (p)->lpVtbl->put_height(p,a)
#define IHTMLImgElement_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLImgElement_put_start(p,a) (p)->lpVtbl->put_start(p,a)
#define IHTMLImgElement_get_start(p,a) (p)->lpVtbl->get_start(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLImgElement_put_isMap_Proxy(
    IHTMLImgElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLImgElement_put_isMap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_isMap_Proxy(
    IHTMLImgElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLImgElement_get_isMap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_useMap_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_useMap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_useMap_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_useMap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_mimeType_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_mimeType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_fileSize_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_fileSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_fileCreatedDate_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_fileCreatedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_fileModifiedDate_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_fileModifiedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_fileUpdatedDate_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_fileUpdatedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_protocol_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_protocol_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_href_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_href_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_nameProp_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_nameProp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_border_Proxy(
    IHTMLImgElement* This,
    VARIANT v);
void __RPC_STUB IHTMLImgElement_put_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_border_Proxy(
    IHTMLImgElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLImgElement_get_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_vspace_Proxy(
    IHTMLImgElement* This,
    long v);
void __RPC_STUB IHTMLImgElement_put_vspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_vspace_Proxy(
    IHTMLImgElement* This,
    long *p);
void __RPC_STUB IHTMLImgElement_get_vspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_hspace_Proxy(
    IHTMLImgElement* This,
    long v);
void __RPC_STUB IHTMLImgElement_put_hspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_hspace_Proxy(
    IHTMLImgElement* This,
    long *p);
void __RPC_STUB IHTMLImgElement_get_hspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_alt_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_alt_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_alt_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_alt_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_src_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_src_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_src_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_src_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_lowsrc_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_lowsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_lowsrc_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_lowsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_vrml_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_vrml_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_vrml_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_vrml_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_dynsrc_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_dynsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_dynsrc_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_dynsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_readyState_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_readyState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_complete_Proxy(
    IHTMLImgElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLImgElement_get_complete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_loop_Proxy(
    IHTMLImgElement* This,
    VARIANT v);
void __RPC_STUB IHTMLImgElement_put_loop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_loop_Proxy(
    IHTMLImgElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLImgElement_get_loop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_align_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_align_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_align_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_align_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_onload_Proxy(
    IHTMLImgElement* This,
    VARIANT v);
void __RPC_STUB IHTMLImgElement_put_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_onload_Proxy(
    IHTMLImgElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLImgElement_get_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_onerror_Proxy(
    IHTMLImgElement* This,
    VARIANT v);
void __RPC_STUB IHTMLImgElement_put_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_onerror_Proxy(
    IHTMLImgElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLImgElement_get_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_onabort_Proxy(
    IHTMLImgElement* This,
    VARIANT v);
void __RPC_STUB IHTMLImgElement_put_onabort_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_onabort_Proxy(
    IHTMLImgElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLImgElement_get_onabort_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_name_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_name_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_width_Proxy(
    IHTMLImgElement* This,
    long v);
void __RPC_STUB IHTMLImgElement_put_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_width_Proxy(
    IHTMLImgElement* This,
    long *p);
void __RPC_STUB IHTMLImgElement_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_height_Proxy(
    IHTMLImgElement* This,
    long v);
void __RPC_STUB IHTMLImgElement_put_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_height_Proxy(
    IHTMLImgElement* This,
    long *p);
void __RPC_STUB IHTMLImgElement_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_put_start_Proxy(
    IHTMLImgElement* This,
    BSTR v);
void __RPC_STUB IHTMLImgElement_put_start_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLImgElement_get_start_Proxy(
    IHTMLImgElement* This,
    BSTR *p);
void __RPC_STUB IHTMLImgElement_get_start_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLImgElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLImageElementFactory_FWD_DEFINED__
#define __IHTMLImageElementFactory_FWD_DEFINED__
typedef interface IHTMLImageElementFactory IHTMLImageElementFactory;
#endif

/*****************************************************************************
 * IHTMLImageElementFactory interface
 */
#ifndef __IHTMLImageElementFactory_INTERFACE_DEFINED__
#define __IHTMLImageElementFactory_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLImageElementFactory, 0x3050f38e, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0xa0,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLImageElementFactory : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE create(
        VARIANT width,
        VARIANT height,
        IHTMLImgElement **elem) = 0;

};
#else
typedef struct IHTMLImageElementFactoryVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLImageElementFactory* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLImageElementFactory* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLImageElementFactory* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLImageElementFactory* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLImageElementFactory* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLImageElementFactory* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLImageElementFactory* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLImageElementFactory methods ***/
    HRESULT (STDMETHODCALLTYPE *create)(
        IHTMLImageElementFactory* This,
        VARIANT width,
        VARIANT height,
        IHTMLImgElement **elem);

    END_INTERFACE
} IHTMLImageElementFactoryVtbl;
interface IHTMLImageElementFactory {
    CONST_VTBL IHTMLImageElementFactoryVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLImageElementFactory_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLImageElementFactory_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLImageElementFactory_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLImageElementFactory_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLImageElementFactory_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLImageElementFactory_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLImageElementFactory_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLImageElementFactory methods ***/
#define IHTMLImageElementFactory_create(p,a,b,c) (p)->lpVtbl->create(p,a,b,c)
#endif

#endif

HRESULT CALLBACK IHTMLImageElementFactory_create_Proxy(
    IHTMLImageElementFactory* This,
    VARIANT width,
    VARIANT height,
    IHTMLImgElement **elem);
void __RPC_STUB IHTMLImageElementFactory_create_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLImageElementFactory_INTERFACE_DEFINED__ */

#ifndef __IHTMLBodyElement_FWD_DEFINED__
#define __IHTMLBodyElement_FWD_DEFINED__
typedef interface IHTMLBodyElement IHTMLBodyElement;
#endif

/*****************************************************************************
 * IHTMLBodyElement interface
 */
#ifndef __IHTMLBodyElement_INTERFACE_DEFINED__
#define __IHTMLBodyElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLBodyElement, 0x3050f1d8, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLBodyElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_background(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_background(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bgProperties(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bgProperties(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_leftMargin(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_leftMargin(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_topMargin(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_topMargin(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_rightMargin(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rightMargin(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bottomMargin(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bottomMargin(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_noWrap(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_noWrap(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bgColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bgColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_text(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_text(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_link(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_link(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vLink(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vLink(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_aLink(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_aLink(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onunload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onunload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_scroll(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scroll(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselect(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselect(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeunload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeunload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createTextRange(
        IHTMLTxtRange **range) = 0;

};
#else
typedef struct IHTMLBodyElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLBodyElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLBodyElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLBodyElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLBodyElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLBodyElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLBodyElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLBodyElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLBodyElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_background)(
        IHTMLBodyElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_background)(
        IHTMLBodyElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_bgProperties)(
        IHTMLBodyElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_bgProperties)(
        IHTMLBodyElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_leftMargin)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_leftMargin)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_topMargin)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_topMargin)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_rightMargin)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_rightMargin)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_bottomMargin)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_bottomMargin)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_noWrap)(
        IHTMLBodyElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_noWrap)(
        IHTMLBodyElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_bgColor)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_bgColor)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_text)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_text)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_link)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_link)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_vLink)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_vLink)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_aLink)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_aLink)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onload)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onload)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onunload)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onunload)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_scroll)(
        IHTMLBodyElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_scroll)(
        IHTMLBodyElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onselect)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselect)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeunload)(
        IHTMLBodyElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeunload)(
        IHTMLBodyElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *createTextRange)(
        IHTMLBodyElement* This,
        IHTMLTxtRange **range);

    END_INTERFACE
} IHTMLBodyElementVtbl;
interface IHTMLBodyElement {
    CONST_VTBL IHTMLBodyElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLBodyElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLBodyElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLBodyElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLBodyElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLBodyElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLBodyElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLBodyElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLBodyElement methods ***/
#define IHTMLBodyElement_put_background(p,a) (p)->lpVtbl->put_background(p,a)
#define IHTMLBodyElement_get_background(p,a) (p)->lpVtbl->get_background(p,a)
#define IHTMLBodyElement_put_bgProperties(p,a) (p)->lpVtbl->put_bgProperties(p,a)
#define IHTMLBodyElement_get_bgProperties(p,a) (p)->lpVtbl->get_bgProperties(p,a)
#define IHTMLBodyElement_put_leftMargin(p,a) (p)->lpVtbl->put_leftMargin(p,a)
#define IHTMLBodyElement_get_leftMargin(p,a) (p)->lpVtbl->get_leftMargin(p,a)
#define IHTMLBodyElement_put_topMargin(p,a) (p)->lpVtbl->put_topMargin(p,a)
#define IHTMLBodyElement_get_topMargin(p,a) (p)->lpVtbl->get_topMargin(p,a)
#define IHTMLBodyElement_put_rightMargin(p,a) (p)->lpVtbl->put_rightMargin(p,a)
#define IHTMLBodyElement_get_rightMargin(p,a) (p)->lpVtbl->get_rightMargin(p,a)
#define IHTMLBodyElement_put_bottomMargin(p,a) (p)->lpVtbl->put_bottomMargin(p,a)
#define IHTMLBodyElement_get_bottomMargin(p,a) (p)->lpVtbl->get_bottomMargin(p,a)
#define IHTMLBodyElement_put_noWrap(p,a) (p)->lpVtbl->put_noWrap(p,a)
#define IHTMLBodyElement_get_noWrap(p,a) (p)->lpVtbl->get_noWrap(p,a)
#define IHTMLBodyElement_put_bgColor(p,a) (p)->lpVtbl->put_bgColor(p,a)
#define IHTMLBodyElement_get_bgColor(p,a) (p)->lpVtbl->get_bgColor(p,a)
#define IHTMLBodyElement_put_text(p,a) (p)->lpVtbl->put_text(p,a)
#define IHTMLBodyElement_get_text(p,a) (p)->lpVtbl->get_text(p,a)
#define IHTMLBodyElement_put_link(p,a) (p)->lpVtbl->put_link(p,a)
#define IHTMLBodyElement_get_link(p,a) (p)->lpVtbl->get_link(p,a)
#define IHTMLBodyElement_put_vLink(p,a) (p)->lpVtbl->put_vLink(p,a)
#define IHTMLBodyElement_get_vLink(p,a) (p)->lpVtbl->get_vLink(p,a)
#define IHTMLBodyElement_put_aLink(p,a) (p)->lpVtbl->put_aLink(p,a)
#define IHTMLBodyElement_get_aLink(p,a) (p)->lpVtbl->get_aLink(p,a)
#define IHTMLBodyElement_put_onload(p,a) (p)->lpVtbl->put_onload(p,a)
#define IHTMLBodyElement_get_onload(p,a) (p)->lpVtbl->get_onload(p,a)
#define IHTMLBodyElement_put_onunload(p,a) (p)->lpVtbl->put_onunload(p,a)
#define IHTMLBodyElement_get_onunload(p,a) (p)->lpVtbl->get_onunload(p,a)
#define IHTMLBodyElement_put_scroll(p,a) (p)->lpVtbl->put_scroll(p,a)
#define IHTMLBodyElement_get_scroll(p,a) (p)->lpVtbl->get_scroll(p,a)
#define IHTMLBodyElement_put_onselect(p,a) (p)->lpVtbl->put_onselect(p,a)
#define IHTMLBodyElement_get_onselect(p,a) (p)->lpVtbl->get_onselect(p,a)
#define IHTMLBodyElement_put_onbeforeunload(p,a) (p)->lpVtbl->put_onbeforeunload(p,a)
#define IHTMLBodyElement_get_onbeforeunload(p,a) (p)->lpVtbl->get_onbeforeunload(p,a)
#define IHTMLBodyElement_createTextRange(p,a) (p)->lpVtbl->createTextRange(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLBodyElement_put_background_Proxy(
    IHTMLBodyElement* This,
    BSTR v);
void __RPC_STUB IHTMLBodyElement_put_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_background_Proxy(
    IHTMLBodyElement* This,
    BSTR *p);
void __RPC_STUB IHTMLBodyElement_get_background_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_bgProperties_Proxy(
    IHTMLBodyElement* This,
    BSTR v);
void __RPC_STUB IHTMLBodyElement_put_bgProperties_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_bgProperties_Proxy(
    IHTMLBodyElement* This,
    BSTR *p);
void __RPC_STUB IHTMLBodyElement_get_bgProperties_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_leftMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_leftMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_leftMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_leftMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_topMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_topMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_topMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_topMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_rightMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_rightMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_rightMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_rightMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_bottomMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_bottomMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_bottomMargin_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_bottomMargin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_noWrap_Proxy(
    IHTMLBodyElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLBodyElement_put_noWrap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_noWrap_Proxy(
    IHTMLBodyElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLBodyElement_get_noWrap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_bgColor_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_bgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_bgColor_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_bgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_text_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_text_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_link_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_link_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_link_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_link_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_vLink_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_vLink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_vLink_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_vLink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_aLink_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_aLink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_aLink_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_aLink_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_onload_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_onload_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_onunload_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_onunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_onunload_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_onunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_scroll_Proxy(
    IHTMLBodyElement* This,
    BSTR v);
void __RPC_STUB IHTMLBodyElement_put_scroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_scroll_Proxy(
    IHTMLBodyElement* This,
    BSTR *p);
void __RPC_STUB IHTMLBodyElement_get_scroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_onselect_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_onselect_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_put_onbeforeunload_Proxy(
    IHTMLBodyElement* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement_put_onbeforeunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_get_onbeforeunload_Proxy(
    IHTMLBodyElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement_get_onbeforeunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement_createTextRange_Proxy(
    IHTMLBodyElement* This,
    IHTMLTxtRange **range);
void __RPC_STUB IHTMLBodyElement_createTextRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLBodyElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLBodyElement2_FWD_DEFINED__
#define __IHTMLBodyElement2_FWD_DEFINED__
typedef interface IHTMLBodyElement2 IHTMLBodyElement2;
#endif

/*****************************************************************************
 * IHTMLBodyElement2 interface
 */
#ifndef __IHTMLBodyElement2_INTERFACE_DEFINED__
#define __IHTMLBodyElement2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLBodyElement2, 0x3050f5c5, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLBodyElement2 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_onbeforeprint(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeprint(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onafterprint(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onafterprint(
        VARIANT *p) = 0;

};
#else
typedef struct IHTMLBodyElement2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLBodyElement2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLBodyElement2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLBodyElement2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLBodyElement2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLBodyElement2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLBodyElement2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLBodyElement2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLBodyElement2 methods ***/
    HRESULT (STDMETHODCALLTYPE *put_onbeforeprint)(
        IHTMLBodyElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeprint)(
        IHTMLBodyElement2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onafterprint)(
        IHTMLBodyElement2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onafterprint)(
        IHTMLBodyElement2* This,
        VARIANT *p);

    END_INTERFACE
} IHTMLBodyElement2Vtbl;
interface IHTMLBodyElement2 {
    CONST_VTBL IHTMLBodyElement2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLBodyElement2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLBodyElement2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLBodyElement2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLBodyElement2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLBodyElement2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLBodyElement2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLBodyElement2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLBodyElement2 methods ***/
#define IHTMLBodyElement2_put_onbeforeprint(p,a) (p)->lpVtbl->put_onbeforeprint(p,a)
#define IHTMLBodyElement2_get_onbeforeprint(p,a) (p)->lpVtbl->get_onbeforeprint(p,a)
#define IHTMLBodyElement2_put_onafterprint(p,a) (p)->lpVtbl->put_onafterprint(p,a)
#define IHTMLBodyElement2_get_onafterprint(p,a) (p)->lpVtbl->get_onafterprint(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLBodyElement2_put_onbeforeprint_Proxy(
    IHTMLBodyElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement2_put_onbeforeprint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement2_get_onbeforeprint_Proxy(
    IHTMLBodyElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement2_get_onbeforeprint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement2_put_onafterprint_Proxy(
    IHTMLBodyElement2* This,
    VARIANT v);
void __RPC_STUB IHTMLBodyElement2_put_onafterprint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLBodyElement2_get_onafterprint_Proxy(
    IHTMLBodyElement2* This,
    VARIANT *p);
void __RPC_STUB IHTMLBodyElement2_get_onafterprint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLBodyElement2_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IHTMLElementCollection interface
 */
#ifndef __IHTMLElementCollection_INTERFACE_DEFINED__
#define __IHTMLElementCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLElementCollection, 0x3050f21f, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLElementCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_length(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp) = 0;

    virtual HRESULT STDMETHODCALLTYPE tags(
        VARIANT tagName,
        IDispatch **pdisp) = 0;

};
#else
typedef struct IHTMLElementCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLElementCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLElementCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLElementCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLElementCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLElementCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLElementCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLElementCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLElementCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLElementCollection* This,
        BSTR *String);

    HRESULT (STDMETHODCALLTYPE *put_length)(
        IHTMLElementCollection* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLElementCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLElementCollection* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLElementCollection* This,
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp);

    HRESULT (STDMETHODCALLTYPE *tags)(
        IHTMLElementCollection* This,
        VARIANT tagName,
        IDispatch **pdisp);

    END_INTERFACE
} IHTMLElementCollectionVtbl;
interface IHTMLElementCollection {
    CONST_VTBL IHTMLElementCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLElementCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLElementCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLElementCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLElementCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLElementCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLElementCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLElementCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLElementCollection methods ***/
#define IHTMLElementCollection_toString(p,a) (p)->lpVtbl->toString(p,a)
#define IHTMLElementCollection_put_length(p,a) (p)->lpVtbl->put_length(p,a)
#define IHTMLElementCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLElementCollection_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLElementCollection_item(p,a,b,c) (p)->lpVtbl->item(p,a,b,c)
#define IHTMLElementCollection_tags(p,a,b) (p)->lpVtbl->tags(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLElementCollection_toString_Proxy(
    IHTMLElementCollection* This,
    BSTR *String);
void __RPC_STUB IHTMLElementCollection_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElementCollection_put_length_Proxy(
    IHTMLElementCollection* This,
    long v);
void __RPC_STUB IHTMLElementCollection_put_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElementCollection_get_length_Proxy(
    IHTMLElementCollection* This,
    long *p);
void __RPC_STUB IHTMLElementCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElementCollection_get__newEnum_Proxy(
    IHTMLElementCollection* This,
    IUnknown **p);
void __RPC_STUB IHTMLElementCollection_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElementCollection_item_Proxy(
    IHTMLElementCollection* This,
    VARIANT name,
    VARIANT index,
    IDispatch **pdisp);
void __RPC_STUB IHTMLElementCollection_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLElementCollection_tags_Proxy(
    IHTMLElementCollection* This,
    VARIANT tagName,
    IDispatch **pdisp);
void __RPC_STUB IHTMLElementCollection_tags_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLElementCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLSelectElement_FWD_DEFINED__
#define __IHTMLSelectElement_FWD_DEFINED__
typedef interface IHTMLSelectElement IHTMLSelectElement;
#endif

/*****************************************************************************
 * IHTMLSelectElement interface
 */
#ifndef __IHTMLSelectElement_INTERFACE_DEFINED__
#define __IHTMLSelectElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLSelectElement, 0x3050f244, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLSelectElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_size(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_size(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_multiple(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_multiple(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_options(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_selectedIndex(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_selectedIndex(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_value(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_value(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_disabled(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_disabled(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_form(
        IHTMLFormElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE add(
        IHTMLElement *element,
        VARIANT before) = 0;

    virtual HRESULT STDMETHODCALLTYPE remove(
        long index) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_length(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp) = 0;

    virtual HRESULT STDMETHODCALLTYPE tags(
        VARIANT tagName,
        IDispatch **pdisp) = 0;

};
#else
typedef struct IHTMLSelectElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLSelectElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLSelectElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLSelectElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLSelectElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLSelectElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLSelectElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLSelectElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLSelectElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_size)(
        IHTMLSelectElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_size)(
        IHTMLSelectElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_multiple)(
        IHTMLSelectElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_multiple)(
        IHTMLSelectElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLSelectElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLSelectElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_options)(
        IHTMLSelectElement* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *put_onchange)(
        IHTMLSelectElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onchange)(
        IHTMLSelectElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_selectedIndex)(
        IHTMLSelectElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_selectedIndex)(
        IHTMLSelectElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLSelectElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_value)(
        IHTMLSelectElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_value)(
        IHTMLSelectElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_disabled)(
        IHTMLSelectElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_disabled)(
        IHTMLSelectElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_form)(
        IHTMLSelectElement* This,
        IHTMLFormElement **p);

    HRESULT (STDMETHODCALLTYPE *add)(
        IHTMLSelectElement* This,
        IHTMLElement *element,
        VARIANT before);

    HRESULT (STDMETHODCALLTYPE *remove)(
        IHTMLSelectElement* This,
        long index);

    HRESULT (STDMETHODCALLTYPE *put_length)(
        IHTMLSelectElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLSelectElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLSelectElement* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLSelectElement* This,
        VARIANT name,
        VARIANT index,
        IDispatch **pdisp);

    HRESULT (STDMETHODCALLTYPE *tags)(
        IHTMLSelectElement* This,
        VARIANT tagName,
        IDispatch **pdisp);

    END_INTERFACE
} IHTMLSelectElementVtbl;
interface IHTMLSelectElement {
    CONST_VTBL IHTMLSelectElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLSelectElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLSelectElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLSelectElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLSelectElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLSelectElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLSelectElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLSelectElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLSelectElement methods ***/
#define IHTMLSelectElement_put_size(p,a) (p)->lpVtbl->put_size(p,a)
#define IHTMLSelectElement_get_size(p,a) (p)->lpVtbl->get_size(p,a)
#define IHTMLSelectElement_put_multiple(p,a) (p)->lpVtbl->put_multiple(p,a)
#define IHTMLSelectElement_get_multiple(p,a) (p)->lpVtbl->get_multiple(p,a)
#define IHTMLSelectElement_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLSelectElement_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLSelectElement_get_options(p,a) (p)->lpVtbl->get_options(p,a)
#define IHTMLSelectElement_put_onchange(p,a) (p)->lpVtbl->put_onchange(p,a)
#define IHTMLSelectElement_get_onchange(p,a) (p)->lpVtbl->get_onchange(p,a)
#define IHTMLSelectElement_put_selectedIndex(p,a) (p)->lpVtbl->put_selectedIndex(p,a)
#define IHTMLSelectElement_get_selectedIndex(p,a) (p)->lpVtbl->get_selectedIndex(p,a)
#define IHTMLSelectElement_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#define IHTMLSelectElement_put_value(p,a) (p)->lpVtbl->put_value(p,a)
#define IHTMLSelectElement_get_value(p,a) (p)->lpVtbl->get_value(p,a)
#define IHTMLSelectElement_put_disabled(p,a) (p)->lpVtbl->put_disabled(p,a)
#define IHTMLSelectElement_get_disabled(p,a) (p)->lpVtbl->get_disabled(p,a)
#define IHTMLSelectElement_get_form(p,a) (p)->lpVtbl->get_form(p,a)
#define IHTMLSelectElement_add(p,a,b) (p)->lpVtbl->add(p,a,b)
#define IHTMLSelectElement_remove(p,a) (p)->lpVtbl->remove(p,a)
#define IHTMLSelectElement_put_length(p,a) (p)->lpVtbl->put_length(p,a)
#define IHTMLSelectElement_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLSelectElement_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLSelectElement_item(p,a,b,c) (p)->lpVtbl->item(p,a,b,c)
#define IHTMLSelectElement_tags(p,a,b) (p)->lpVtbl->tags(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLSelectElement_put_size_Proxy(
    IHTMLSelectElement* This,
    long v);
void __RPC_STUB IHTMLSelectElement_put_size_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_size_Proxy(
    IHTMLSelectElement* This,
    long *p);
void __RPC_STUB IHTMLSelectElement_get_size_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_multiple_Proxy(
    IHTMLSelectElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLSelectElement_put_multiple_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_multiple_Proxy(
    IHTMLSelectElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLSelectElement_get_multiple_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_name_Proxy(
    IHTMLSelectElement* This,
    BSTR v);
void __RPC_STUB IHTMLSelectElement_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_name_Proxy(
    IHTMLSelectElement* This,
    BSTR *p);
void __RPC_STUB IHTMLSelectElement_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_options_Proxy(
    IHTMLSelectElement* This,
    IDispatch **p);
void __RPC_STUB IHTMLSelectElement_get_options_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_onchange_Proxy(
    IHTMLSelectElement* This,
    VARIANT v);
void __RPC_STUB IHTMLSelectElement_put_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_onchange_Proxy(
    IHTMLSelectElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLSelectElement_get_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_selectedIndex_Proxy(
    IHTMLSelectElement* This,
    long v);
void __RPC_STUB IHTMLSelectElement_put_selectedIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_selectedIndex_Proxy(
    IHTMLSelectElement* This,
    long *p);
void __RPC_STUB IHTMLSelectElement_get_selectedIndex_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_type_Proxy(
    IHTMLSelectElement* This,
    BSTR *p);
void __RPC_STUB IHTMLSelectElement_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_value_Proxy(
    IHTMLSelectElement* This,
    BSTR v);
void __RPC_STUB IHTMLSelectElement_put_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_value_Proxy(
    IHTMLSelectElement* This,
    BSTR *p);
void __RPC_STUB IHTMLSelectElement_get_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_disabled_Proxy(
    IHTMLSelectElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLSelectElement_put_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_disabled_Proxy(
    IHTMLSelectElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLSelectElement_get_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_form_Proxy(
    IHTMLSelectElement* This,
    IHTMLFormElement **p);
void __RPC_STUB IHTMLSelectElement_get_form_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_add_Proxy(
    IHTMLSelectElement* This,
    IHTMLElement *element,
    VARIANT before);
void __RPC_STUB IHTMLSelectElement_add_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_remove_Proxy(
    IHTMLSelectElement* This,
    long index);
void __RPC_STUB IHTMLSelectElement_remove_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_put_length_Proxy(
    IHTMLSelectElement* This,
    long v);
void __RPC_STUB IHTMLSelectElement_put_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get_length_Proxy(
    IHTMLSelectElement* This,
    long *p);
void __RPC_STUB IHTMLSelectElement_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_get__newEnum_Proxy(
    IHTMLSelectElement* This,
    IUnknown **p);
void __RPC_STUB IHTMLSelectElement_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_item_Proxy(
    IHTMLSelectElement* This,
    VARIANT name,
    VARIANT index,
    IDispatch **pdisp);
void __RPC_STUB IHTMLSelectElement_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectElement_tags_Proxy(
    IHTMLSelectElement* This,
    VARIANT tagName,
    IDispatch **pdisp);
void __RPC_STUB IHTMLSelectElement_tags_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLSelectElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLSelectionObject_FWD_DEFINED__
#define __IHTMLSelectionObject_FWD_DEFINED__
typedef interface IHTMLSelectionObject IHTMLSelectionObject;
#endif

/*****************************************************************************
 * IHTMLSelectionObject interface
 */
#ifndef __IHTMLSelectionObject_INTERFACE_DEFINED__
#define __IHTMLSelectionObject_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLSelectionObject, 0x3050f25a, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLSelectionObject : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE createRange(
        IDispatch **range) = 0;

    virtual HRESULT STDMETHODCALLTYPE empty(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE clear(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLSelectionObjectVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLSelectionObject* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLSelectionObject* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLSelectionObject* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLSelectionObject* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLSelectionObject* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLSelectionObject* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLSelectionObject* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLSelectionObject methods ***/
    HRESULT (STDMETHODCALLTYPE *createRange)(
        IHTMLSelectionObject* This,
        IDispatch **range);

    HRESULT (STDMETHODCALLTYPE *empty)(
        IHTMLSelectionObject* This);

    HRESULT (STDMETHODCALLTYPE *clear)(
        IHTMLSelectionObject* This);

    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLSelectionObject* This,
        BSTR *p);

    END_INTERFACE
} IHTMLSelectionObjectVtbl;
interface IHTMLSelectionObject {
    CONST_VTBL IHTMLSelectionObjectVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLSelectionObject_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLSelectionObject_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLSelectionObject_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLSelectionObject_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLSelectionObject_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLSelectionObject_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLSelectionObject_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLSelectionObject methods ***/
#define IHTMLSelectionObject_createRange(p,a) (p)->lpVtbl->createRange(p,a)
#define IHTMLSelectionObject_empty(p) (p)->lpVtbl->empty(p)
#define IHTMLSelectionObject_clear(p) (p)->lpVtbl->clear(p)
#define IHTMLSelectionObject_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLSelectionObject_createRange_Proxy(
    IHTMLSelectionObject* This,
    IDispatch **range);
void __RPC_STUB IHTMLSelectionObject_createRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectionObject_empty_Proxy(
    IHTMLSelectionObject* This);
void __RPC_STUB IHTMLSelectionObject_empty_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectionObject_clear_Proxy(
    IHTMLSelectionObject* This);
void __RPC_STUB IHTMLSelectionObject_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLSelectionObject_get_type_Proxy(
    IHTMLSelectionObject* This,
    BSTR *p);
void __RPC_STUB IHTMLSelectionObject_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLSelectionObject_INTERFACE_DEFINED__ */

#ifndef __IHTMLOptionElement_FWD_DEFINED__
#define __IHTMLOptionElement_FWD_DEFINED__
typedef interface IHTMLOptionElement IHTMLOptionElement;
#endif

/*****************************************************************************
 * IHTMLOptionElement interface
 */
#ifndef __IHTMLOptionElement_INTERFACE_DEFINED__
#define __IHTMLOptionElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLOptionElement, 0x3050f211, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLOptionElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_selected(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_selected(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_value(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_value(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultSelected(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultSelected(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_index(
        LONG v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_index(
        LONG *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_text(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_text(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_form(
        IHTMLFormElement **p) = 0;

};
#else
typedef struct IHTMLOptionElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLOptionElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLOptionElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLOptionElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLOptionElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLOptionElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLOptionElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLOptionElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLOptionElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_selected)(
        IHTMLOptionElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_selected)(
        IHTMLOptionElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_value)(
        IHTMLOptionElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_value)(
        IHTMLOptionElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_defaultSelected)(
        IHTMLOptionElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_defaultSelected)(
        IHTMLOptionElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_index)(
        IHTMLOptionElement* This,
        LONG v);

    HRESULT (STDMETHODCALLTYPE *get_index)(
        IHTMLOptionElement* This,
        LONG *p);

    HRESULT (STDMETHODCALLTYPE *put_text)(
        IHTMLOptionElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_text)(
        IHTMLOptionElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_form)(
        IHTMLOptionElement* This,
        IHTMLFormElement **p);

    END_INTERFACE
} IHTMLOptionElementVtbl;
interface IHTMLOptionElement {
    CONST_VTBL IHTMLOptionElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLOptionElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLOptionElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLOptionElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLOptionElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLOptionElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLOptionElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLOptionElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLOptionElement methods ***/
#define IHTMLOptionElement_put_selected(p,a) (p)->lpVtbl->put_selected(p,a)
#define IHTMLOptionElement_get_selected(p,a) (p)->lpVtbl->get_selected(p,a)
#define IHTMLOptionElement_put_value(p,a) (p)->lpVtbl->put_value(p,a)
#define IHTMLOptionElement_get_value(p,a) (p)->lpVtbl->get_value(p,a)
#define IHTMLOptionElement_put_defaultSelected(p,a) (p)->lpVtbl->put_defaultSelected(p,a)
#define IHTMLOptionElement_get_defaultSelected(p,a) (p)->lpVtbl->get_defaultSelected(p,a)
#define IHTMLOptionElement_put_index(p,a) (p)->lpVtbl->put_index(p,a)
#define IHTMLOptionElement_get_index(p,a) (p)->lpVtbl->get_index(p,a)
#define IHTMLOptionElement_put_text(p,a) (p)->lpVtbl->put_text(p,a)
#define IHTMLOptionElement_get_text(p,a) (p)->lpVtbl->get_text(p,a)
#define IHTMLOptionElement_get_form(p,a) (p)->lpVtbl->get_form(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLOptionElement_put_selected_Proxy(
    IHTMLOptionElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLOptionElement_put_selected_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_selected_Proxy(
    IHTMLOptionElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLOptionElement_get_selected_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_put_value_Proxy(
    IHTMLOptionElement* This,
    BSTR v);
void __RPC_STUB IHTMLOptionElement_put_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_value_Proxy(
    IHTMLOptionElement* This,
    BSTR *p);
void __RPC_STUB IHTMLOptionElement_get_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_put_defaultSelected_Proxy(
    IHTMLOptionElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLOptionElement_put_defaultSelected_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_defaultSelected_Proxy(
    IHTMLOptionElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLOptionElement_get_defaultSelected_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_put_index_Proxy(
    IHTMLOptionElement* This,
    LONG v);
void __RPC_STUB IHTMLOptionElement_put_index_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_index_Proxy(
    IHTMLOptionElement* This,
    LONG *p);
void __RPC_STUB IHTMLOptionElement_get_index_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_put_text_Proxy(
    IHTMLOptionElement* This,
    BSTR v);
void __RPC_STUB IHTMLOptionElement_put_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_text_Proxy(
    IHTMLOptionElement* This,
    BSTR *p);
void __RPC_STUB IHTMLOptionElement_get_text_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOptionElement_get_form_Proxy(
    IHTMLOptionElement* This,
    IHTMLFormElement **p);
void __RPC_STUB IHTMLOptionElement_get_form_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLOptionElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLOptionElementFactory_FWD_DEFINED__
#define __IHTMLOptionElementFactory_FWD_DEFINED__
typedef interface IHTMLOptionElementFactory IHTMLOptionElementFactory;
#endif

/*****************************************************************************
 * IHTMLOptionElementFactory interface
 */
#ifndef __IHTMLOptionElementFactory_INTERFACE_DEFINED__
#define __IHTMLOptionElementFactory_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLOptionElementFactory, 0x3050f38c, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLOptionElementFactory : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE create(
        VARIANT text,
        VARIANT value,
        VARIANT defaultselected,
        VARIANT selected,
        IHTMLOptionElement **optelem) = 0;

};
#else
typedef struct IHTMLOptionElementFactoryVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLOptionElementFactory* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLOptionElementFactory* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLOptionElementFactory* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLOptionElementFactory* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLOptionElementFactory* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLOptionElementFactory* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLOptionElementFactory* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLOptionElementFactory methods ***/
    HRESULT (STDMETHODCALLTYPE *create)(
        IHTMLOptionElementFactory* This,
        VARIANT text,
        VARIANT value,
        VARIANT defaultselected,
        VARIANT selected,
        IHTMLOptionElement **optelem);

    END_INTERFACE
} IHTMLOptionElementFactoryVtbl;
interface IHTMLOptionElementFactory {
    CONST_VTBL IHTMLOptionElementFactoryVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLOptionElementFactory_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLOptionElementFactory_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLOptionElementFactory_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLOptionElementFactory_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLOptionElementFactory_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLOptionElementFactory_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLOptionElementFactory_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLOptionElementFactory methods ***/
#define IHTMLOptionElementFactory_create(p,a,b,c,d,e) (p)->lpVtbl->create(p,a,b,c,d,e)
#endif

#endif

HRESULT CALLBACK IHTMLOptionElementFactory_create_Proxy(
    IHTMLOptionElementFactory* This,
    VARIANT text,
    VARIANT value,
    VARIANT defaultselected,
    VARIANT selected,
    IHTMLOptionElement **optelem);
void __RPC_STUB IHTMLOptionElementFactory_create_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLOptionElementFactory_INTERFACE_DEFINED__ */

#ifndef __IHTMLInputElement_FWD_DEFINED__
#define __IHTMLInputElement_FWD_DEFINED__
typedef interface IHTMLInputElement IHTMLInputElement;
#endif

/*****************************************************************************
 * IHTMLInputElement interface
 */
#ifndef __IHTMLInputElement_INTERFACE_DEFINED__
#define __IHTMLInputElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLInputElement, 0x3050f5d2, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLInputElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_type(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_value(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_value(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_status(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_status(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_disabled(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_disabled(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_form(
        IHTMLFormElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_size(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_size(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_maxLength(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_maxLength(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE select(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselect(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselect(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultValue(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultValue(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_readOnly(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readOnly(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createTextRange(
        IHTMLTxtRange **range) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_indeterminate(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_indeterminate(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultChecked(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultChecked(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_checked(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_checked(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_border(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_border(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vspace(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vspace(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_hspace(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_hspace(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_alt(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_alt(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_src(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_src(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_lowsrc(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lowsrc(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vrml(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vrml(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_dynsrc(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_dynsrc(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyState(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_complete(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_loop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_loop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_align(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_align(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onerror(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onerror(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onabort(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onabort(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_width(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_height(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_start(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_start(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLInputElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLInputElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLInputElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLInputElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLInputElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLInputElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLInputElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLInputElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLInputElement methods ***/
    HRESULT (STDMETHODCALLTYPE *put_type)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_value)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_value)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_status)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_status)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_disabled)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_disabled)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_form)(
        IHTMLInputElement* This,
        IHTMLFormElement **p);

    HRESULT (STDMETHODCALLTYPE *put_size)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_size)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_maxLength)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_maxLength)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *select)(
        IHTMLInputElement* This);

    HRESULT (STDMETHODCALLTYPE *put_onchange)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onchange)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onselect)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselect)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_defaultValue)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_defaultValue)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_readOnly)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_readOnly)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *createTextRange)(
        IHTMLInputElement* This,
        IHTMLTxtRange **range);

    HRESULT (STDMETHODCALLTYPE *put_indeterminate)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_indeterminate)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_defaultChecked)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_defaultChecked)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_checked)(
        IHTMLInputElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_checked)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_border)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_border)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_vspace)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_vspace)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_hspace)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_hspace)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_alt)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_alt)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_src)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_src)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_lowsrc)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_lowsrc)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_vrml)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_vrml)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_dynsrc)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_dynsrc)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_readyState)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_complete)(
        IHTMLInputElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_loop)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_loop)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_align)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_align)(
        IHTMLInputElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_onload)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onload)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onerror)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onerror)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onabort)(
        IHTMLInputElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onabort)(
        IHTMLInputElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_width)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_height)(
        IHTMLInputElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLInputElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_start)(
        IHTMLInputElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_start)(
        IHTMLInputElement* This,
        BSTR *p);

    END_INTERFACE
} IHTMLInputElementVtbl;
interface IHTMLInputElement {
    CONST_VTBL IHTMLInputElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLInputElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLInputElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLInputElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLInputElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLInputElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLInputElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLInputElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLInputElement methods ***/
#define IHTMLInputElement_put_type(p,a) (p)->lpVtbl->put_type(p,a)
#define IHTMLInputElement_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#define IHTMLInputElement_put_value(p,a) (p)->lpVtbl->put_value(p,a)
#define IHTMLInputElement_get_value(p,a) (p)->lpVtbl->get_value(p,a)
#define IHTMLInputElement_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLInputElement_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLInputElement_put_status(p,a) (p)->lpVtbl->put_status(p,a)
#define IHTMLInputElement_get_status(p,a) (p)->lpVtbl->get_status(p,a)
#define IHTMLInputElement_put_disabled(p,a) (p)->lpVtbl->put_disabled(p,a)
#define IHTMLInputElement_get_disabled(p,a) (p)->lpVtbl->get_disabled(p,a)
#define IHTMLInputElement_get_form(p,a) (p)->lpVtbl->get_form(p,a)
#define IHTMLInputElement_put_size(p,a) (p)->lpVtbl->put_size(p,a)
#define IHTMLInputElement_get_size(p,a) (p)->lpVtbl->get_size(p,a)
#define IHTMLInputElement_put_maxLength(p,a) (p)->lpVtbl->put_maxLength(p,a)
#define IHTMLInputElement_get_maxLength(p,a) (p)->lpVtbl->get_maxLength(p,a)
#define IHTMLInputElement_select(p) (p)->lpVtbl->select(p)
#define IHTMLInputElement_put_onchange(p,a) (p)->lpVtbl->put_onchange(p,a)
#define IHTMLInputElement_get_onchange(p,a) (p)->lpVtbl->get_onchange(p,a)
#define IHTMLInputElement_put_onselect(p,a) (p)->lpVtbl->put_onselect(p,a)
#define IHTMLInputElement_get_onselect(p,a) (p)->lpVtbl->get_onselect(p,a)
#define IHTMLInputElement_put_defaultValue(p,a) (p)->lpVtbl->put_defaultValue(p,a)
#define IHTMLInputElement_get_defaultValue(p,a) (p)->lpVtbl->get_defaultValue(p,a)
#define IHTMLInputElement_put_readOnly(p,a) (p)->lpVtbl->put_readOnly(p,a)
#define IHTMLInputElement_get_readOnly(p,a) (p)->lpVtbl->get_readOnly(p,a)
#define IHTMLInputElement_createTextRange(p,a) (p)->lpVtbl->createTextRange(p,a)
#define IHTMLInputElement_put_indeterminate(p,a) (p)->lpVtbl->put_indeterminate(p,a)
#define IHTMLInputElement_get_indeterminate(p,a) (p)->lpVtbl->get_indeterminate(p,a)
#define IHTMLInputElement_put_defaultChecked(p,a) (p)->lpVtbl->put_defaultChecked(p,a)
#define IHTMLInputElement_get_defaultChecked(p,a) (p)->lpVtbl->get_defaultChecked(p,a)
#define IHTMLInputElement_put_checked(p,a) (p)->lpVtbl->put_checked(p,a)
#define IHTMLInputElement_get_checked(p,a) (p)->lpVtbl->get_checked(p,a)
#define IHTMLInputElement_put_border(p,a) (p)->lpVtbl->put_border(p,a)
#define IHTMLInputElement_get_border(p,a) (p)->lpVtbl->get_border(p,a)
#define IHTMLInputElement_put_vspace(p,a) (p)->lpVtbl->put_vspace(p,a)
#define IHTMLInputElement_get_vspace(p,a) (p)->lpVtbl->get_vspace(p,a)
#define IHTMLInputElement_put_hspace(p,a) (p)->lpVtbl->put_hspace(p,a)
#define IHTMLInputElement_get_hspace(p,a) (p)->lpVtbl->get_hspace(p,a)
#define IHTMLInputElement_put_alt(p,a) (p)->lpVtbl->put_alt(p,a)
#define IHTMLInputElement_get_alt(p,a) (p)->lpVtbl->get_alt(p,a)
#define IHTMLInputElement_put_src(p,a) (p)->lpVtbl->put_src(p,a)
#define IHTMLInputElement_get_src(p,a) (p)->lpVtbl->get_src(p,a)
#define IHTMLInputElement_put_lowsrc(p,a) (p)->lpVtbl->put_lowsrc(p,a)
#define IHTMLInputElement_get_lowsrc(p,a) (p)->lpVtbl->get_lowsrc(p,a)
#define IHTMLInputElement_put_vrml(p,a) (p)->lpVtbl->put_vrml(p,a)
#define IHTMLInputElement_get_vrml(p,a) (p)->lpVtbl->get_vrml(p,a)
#define IHTMLInputElement_put_dynsrc(p,a) (p)->lpVtbl->put_dynsrc(p,a)
#define IHTMLInputElement_get_dynsrc(p,a) (p)->lpVtbl->get_dynsrc(p,a)
#define IHTMLInputElement_get_readyState(p,a) (p)->lpVtbl->get_readyState(p,a)
#define IHTMLInputElement_get_complete(p,a) (p)->lpVtbl->get_complete(p,a)
#define IHTMLInputElement_put_loop(p,a) (p)->lpVtbl->put_loop(p,a)
#define IHTMLInputElement_get_loop(p,a) (p)->lpVtbl->get_loop(p,a)
#define IHTMLInputElement_put_align(p,a) (p)->lpVtbl->put_align(p,a)
#define IHTMLInputElement_get_align(p,a) (p)->lpVtbl->get_align(p,a)
#define IHTMLInputElement_put_onload(p,a) (p)->lpVtbl->put_onload(p,a)
#define IHTMLInputElement_get_onload(p,a) (p)->lpVtbl->get_onload(p,a)
#define IHTMLInputElement_put_onerror(p,a) (p)->lpVtbl->put_onerror(p,a)
#define IHTMLInputElement_get_onerror(p,a) (p)->lpVtbl->get_onerror(p,a)
#define IHTMLInputElement_put_onabort(p,a) (p)->lpVtbl->put_onabort(p,a)
#define IHTMLInputElement_get_onabort(p,a) (p)->lpVtbl->get_onabort(p,a)
#define IHTMLInputElement_put_width(p,a) (p)->lpVtbl->put_width(p,a)
#define IHTMLInputElement_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLInputElement_put_height(p,a) (p)->lpVtbl->put_height(p,a)
#define IHTMLInputElement_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLInputElement_put_start(p,a) (p)->lpVtbl->put_start(p,a)
#define IHTMLInputElement_get_start(p,a) (p)->lpVtbl->get_start(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLInputElement_put_type_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_type_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_value_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_value_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_name_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_name_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_status_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_status_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_disabled_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_disabled_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_form_Proxy(
    IHTMLInputElement* This,
    IHTMLFormElement **p);
void __RPC_STUB IHTMLInputElement_get_form_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_size_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_size_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_size_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_size_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_maxLength_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_maxLength_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_maxLength_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_maxLength_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_select_Proxy(
    IHTMLInputElement* This);
void __RPC_STUB IHTMLInputElement_select_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_onchange_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_onchange_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_onselect_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_onselect_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_defaultValue_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_defaultValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_defaultValue_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_defaultValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_readOnly_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_readOnly_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_createTextRange_Proxy(
    IHTMLInputElement* This,
    IHTMLTxtRange **range);
void __RPC_STUB IHTMLInputElement_createTextRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_indeterminate_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_indeterminate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_indeterminate_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_indeterminate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_defaultChecked_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_defaultChecked_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_defaultChecked_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_defaultChecked_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_checked_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLInputElement_put_checked_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_checked_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_checked_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_border_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_border_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_border_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_vspace_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_vspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_vspace_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_vspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_hspace_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_hspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_hspace_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_hspace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_alt_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_alt_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_alt_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_alt_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_src_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_src_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_src_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_src_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_lowsrc_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_lowsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_lowsrc_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_lowsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_vrml_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_vrml_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_vrml_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_vrml_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_dynsrc_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_dynsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_dynsrc_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_dynsrc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_readyState_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_readyState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_complete_Proxy(
    IHTMLInputElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLInputElement_get_complete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_loop_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_loop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_loop_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_loop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_align_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_align_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_align_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_align_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_onload_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_onload_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_onerror_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_onerror_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_onabort_Proxy(
    IHTMLInputElement* This,
    VARIANT v);
void __RPC_STUB IHTMLInputElement_put_onabort_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_onabort_Proxy(
    IHTMLInputElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLInputElement_get_onabort_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_width_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_width_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_height_Proxy(
    IHTMLInputElement* This,
    long v);
void __RPC_STUB IHTMLInputElement_put_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_height_Proxy(
    IHTMLInputElement* This,
    long *p);
void __RPC_STUB IHTMLInputElement_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_put_start_Proxy(
    IHTMLInputElement* This,
    BSTR v);
void __RPC_STUB IHTMLInputElement_put_start_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLInputElement_get_start_Proxy(
    IHTMLInputElement* This,
    BSTR *p);
void __RPC_STUB IHTMLInputElement_get_start_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLInputElement_INTERFACE_DEFINED__ */

#ifndef __IHTMLTextAreaElement_FWD_DEFINED__
#define __IHTMLTextAreaElement_FWD_DEFINED__
typedef interface IHTMLTextAreaElement IHTMLTextAreaElement;
#endif

/*****************************************************************************
 * IHTMLTextAreaElement interface
 */
#ifndef __IHTMLTextAreaElement_INTERFACE_DEFINED__
#define __IHTMLTextAreaElement_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLTextAreaElement, 0x3050f2aa, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLTextAreaElement : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_value(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_value(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_status(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_status(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_disabled(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_disabled(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_form(
        IHTMLFormElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultValue(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultValue(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE select(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselect(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselect(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_readOnly(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readOnly(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_rows(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_rows(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cols(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cols(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_wrap(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_wrap(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createTextRange(
        IHTMLTxtRange **range) = 0;

};
#else
typedef struct IHTMLTextAreaElementVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLTextAreaElement* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLTextAreaElement* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLTextAreaElement* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLTextAreaElement* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLTextAreaElement* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLTextAreaElement* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLTextAreaElement* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLTextAreaElement methods ***/
    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLTextAreaElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_value)(
        IHTMLTextAreaElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_value)(
        IHTMLTextAreaElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLTextAreaElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLTextAreaElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_status)(
        IHTMLTextAreaElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_status)(
        IHTMLTextAreaElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_disabled)(
        IHTMLTextAreaElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_disabled)(
        IHTMLTextAreaElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_form)(
        IHTMLTextAreaElement* This,
        IHTMLFormElement **p);

    HRESULT (STDMETHODCALLTYPE *put_defaultValue)(
        IHTMLTextAreaElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_defaultValue)(
        IHTMLTextAreaElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *select)(
        IHTMLTextAreaElement* This);

    HRESULT (STDMETHODCALLTYPE *put_onchange)(
        IHTMLTextAreaElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onchange)(
        IHTMLTextAreaElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onselect)(
        IHTMLTextAreaElement* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselect)(
        IHTMLTextAreaElement* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_readOnly)(
        IHTMLTextAreaElement* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_readOnly)(
        IHTMLTextAreaElement* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_rows)(
        IHTMLTextAreaElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_rows)(
        IHTMLTextAreaElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_cols)(
        IHTMLTextAreaElement* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_cols)(
        IHTMLTextAreaElement* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_wrap)(
        IHTMLTextAreaElement* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_wrap)(
        IHTMLTextAreaElement* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *createTextRange)(
        IHTMLTextAreaElement* This,
        IHTMLTxtRange **range);

    END_INTERFACE
} IHTMLTextAreaElementVtbl;
interface IHTMLTextAreaElement {
    CONST_VTBL IHTMLTextAreaElementVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLTextAreaElement_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLTextAreaElement_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLTextAreaElement_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLTextAreaElement_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLTextAreaElement_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLTextAreaElement_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLTextAreaElement_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLTextAreaElement methods ***/
#define IHTMLTextAreaElement_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#define IHTMLTextAreaElement_put_value(p,a) (p)->lpVtbl->put_value(p,a)
#define IHTMLTextAreaElement_get_value(p,a) (p)->lpVtbl->get_value(p,a)
#define IHTMLTextAreaElement_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLTextAreaElement_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLTextAreaElement_put_status(p,a) (p)->lpVtbl->put_status(p,a)
#define IHTMLTextAreaElement_get_status(p,a) (p)->lpVtbl->get_status(p,a)
#define IHTMLTextAreaElement_put_disabled(p,a) (p)->lpVtbl->put_disabled(p,a)
#define IHTMLTextAreaElement_get_disabled(p,a) (p)->lpVtbl->get_disabled(p,a)
#define IHTMLTextAreaElement_get_form(p,a) (p)->lpVtbl->get_form(p,a)
#define IHTMLTextAreaElement_put_defaultValue(p,a) (p)->lpVtbl->put_defaultValue(p,a)
#define IHTMLTextAreaElement_get_defaultValue(p,a) (p)->lpVtbl->get_defaultValue(p,a)
#define IHTMLTextAreaElement_select(p) (p)->lpVtbl->select(p)
#define IHTMLTextAreaElement_put_onchange(p,a) (p)->lpVtbl->put_onchange(p,a)
#define IHTMLTextAreaElement_get_onchange(p,a) (p)->lpVtbl->get_onchange(p,a)
#define IHTMLTextAreaElement_put_onselect(p,a) (p)->lpVtbl->put_onselect(p,a)
#define IHTMLTextAreaElement_get_onselect(p,a) (p)->lpVtbl->get_onselect(p,a)
#define IHTMLTextAreaElement_put_readOnly(p,a) (p)->lpVtbl->put_readOnly(p,a)
#define IHTMLTextAreaElement_get_readOnly(p,a) (p)->lpVtbl->get_readOnly(p,a)
#define IHTMLTextAreaElement_put_rows(p,a) (p)->lpVtbl->put_rows(p,a)
#define IHTMLTextAreaElement_get_rows(p,a) (p)->lpVtbl->get_rows(p,a)
#define IHTMLTextAreaElement_put_cols(p,a) (p)->lpVtbl->put_cols(p,a)
#define IHTMLTextAreaElement_get_cols(p,a) (p)->lpVtbl->get_cols(p,a)
#define IHTMLTextAreaElement_put_wrap(p,a) (p)->lpVtbl->put_wrap(p,a)
#define IHTMLTextAreaElement_get_wrap(p,a) (p)->lpVtbl->get_wrap(p,a)
#define IHTMLTextAreaElement_createTextRange(p,a) (p)->lpVtbl->createTextRange(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLTextAreaElement_get_type_Proxy(
    IHTMLTextAreaElement* This,
    BSTR *p);
void __RPC_STUB IHTMLTextAreaElement_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_value_Proxy(
    IHTMLTextAreaElement* This,
    BSTR v);
void __RPC_STUB IHTMLTextAreaElement_put_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_value_Proxy(
    IHTMLTextAreaElement* This,
    BSTR *p);
void __RPC_STUB IHTMLTextAreaElement_get_value_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_name_Proxy(
    IHTMLTextAreaElement* This,
    BSTR v);
void __RPC_STUB IHTMLTextAreaElement_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_name_Proxy(
    IHTMLTextAreaElement* This,
    BSTR *p);
void __RPC_STUB IHTMLTextAreaElement_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_status_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT v);
void __RPC_STUB IHTMLTextAreaElement_put_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_status_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLTextAreaElement_get_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_disabled_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLTextAreaElement_put_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_disabled_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLTextAreaElement_get_disabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_form_Proxy(
    IHTMLTextAreaElement* This,
    IHTMLFormElement **p);
void __RPC_STUB IHTMLTextAreaElement_get_form_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_defaultValue_Proxy(
    IHTMLTextAreaElement* This,
    BSTR v);
void __RPC_STUB IHTMLTextAreaElement_put_defaultValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_defaultValue_Proxy(
    IHTMLTextAreaElement* This,
    BSTR *p);
void __RPC_STUB IHTMLTextAreaElement_get_defaultValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_select_Proxy(
    IHTMLTextAreaElement* This);
void __RPC_STUB IHTMLTextAreaElement_select_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_onchange_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT v);
void __RPC_STUB IHTMLTextAreaElement_put_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_onchange_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLTextAreaElement_get_onchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_onselect_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT v);
void __RPC_STUB IHTMLTextAreaElement_put_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_onselect_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT *p);
void __RPC_STUB IHTMLTextAreaElement_get_onselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_readOnly_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLTextAreaElement_put_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_readOnly_Proxy(
    IHTMLTextAreaElement* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLTextAreaElement_get_readOnly_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_rows_Proxy(
    IHTMLTextAreaElement* This,
    long v);
void __RPC_STUB IHTMLTextAreaElement_put_rows_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_rows_Proxy(
    IHTMLTextAreaElement* This,
    long *p);
void __RPC_STUB IHTMLTextAreaElement_get_rows_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_cols_Proxy(
    IHTMLTextAreaElement* This,
    long v);
void __RPC_STUB IHTMLTextAreaElement_put_cols_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_cols_Proxy(
    IHTMLTextAreaElement* This,
    long *p);
void __RPC_STUB IHTMLTextAreaElement_get_cols_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_put_wrap_Proxy(
    IHTMLTextAreaElement* This,
    BSTR v);
void __RPC_STUB IHTMLTextAreaElement_put_wrap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_get_wrap_Proxy(
    IHTMLTextAreaElement* This,
    BSTR *p);
void __RPC_STUB IHTMLTextAreaElement_get_wrap_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLTextAreaElement_createTextRange_Proxy(
    IHTMLTextAreaElement* This,
    IHTMLTxtRange **range);
void __RPC_STUB IHTMLTextAreaElement_createTextRange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLTextAreaElement_INTERFACE_DEFINED__ */

#ifndef __IOmHistory_FWD_DEFINED__
#define __IOmHistory_FWD_DEFINED__
typedef interface IOmHistory IOmHistory;
#endif

/*****************************************************************************
 * IOmHistory interface
 */
#ifndef __IOmHistory_INTERFACE_DEFINED__
#define __IOmHistory_INTERFACE_DEFINED__

DEFINE_GUID(IID_IOmHistory, 0xfeceaaa2, 0x8405, 0x11cf, 0x8b,0xa1, 0x00,0xaa,0x00,0x47,0x6d,0xa6);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IOmHistory : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        short *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE back(
        VARIANT *pvargdistance) = 0;

    virtual HRESULT STDMETHODCALLTYPE forward(
        VARIANT *pvargdistance) = 0;

    virtual HRESULT STDMETHODCALLTYPE go(
        VARIANT *pvargdistance) = 0;

};
#else
typedef struct IOmHistoryVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IOmHistory* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IOmHistory* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IOmHistory* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IOmHistory* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IOmHistory* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IOmHistory* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IOmHistory* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IOmHistory methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IOmHistory* This,
        short *p);

    HRESULT (STDMETHODCALLTYPE *back)(
        IOmHistory* This,
        VARIANT *pvargdistance);

    HRESULT (STDMETHODCALLTYPE *forward)(
        IOmHistory* This,
        VARIANT *pvargdistance);

    HRESULT (STDMETHODCALLTYPE *go)(
        IOmHistory* This,
        VARIANT *pvargdistance);

    END_INTERFACE
} IOmHistoryVtbl;
interface IOmHistory {
    CONST_VTBL IOmHistoryVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IOmHistory_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IOmHistory_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IOmHistory_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IOmHistory_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IOmHistory_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IOmHistory_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IOmHistory_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IOmHistory methods ***/
#define IOmHistory_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IOmHistory_back(p,a) (p)->lpVtbl->back(p,a)
#define IOmHistory_forward(p,a) (p)->lpVtbl->forward(p,a)
#define IOmHistory_go(p,a) (p)->lpVtbl->go(p,a)
#endif

#endif

HRESULT CALLBACK IOmHistory_get_length_Proxy(
    IOmHistory* This,
    short *p);
void __RPC_STUB IOmHistory_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmHistory_back_Proxy(
    IOmHistory* This,
    VARIANT *pvargdistance);
void __RPC_STUB IOmHistory_back_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmHistory_forward_Proxy(
    IOmHistory* This,
    VARIANT *pvargdistance);
void __RPC_STUB IOmHistory_forward_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmHistory_go_Proxy(
    IOmHistory* This,
    VARIANT *pvargdistance);
void __RPC_STUB IOmHistory_go_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IOmHistory_INTERFACE_DEFINED__ */

#ifndef __IHTMLMimeTypesCollection_FWD_DEFINED__
#define __IHTMLMimeTypesCollection_FWD_DEFINED__
typedef interface IHTMLMimeTypesCollection IHTMLMimeTypesCollection;
#endif

/*****************************************************************************
 * IHTMLMimeTypesCollection interface
 */
#ifndef __IHTMLMimeTypesCollection_INTERFACE_DEFINED__
#define __IHTMLMimeTypesCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLMimeTypesCollection, 0x3050f3fc, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLMimeTypesCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

};
#else
typedef struct IHTMLMimeTypesCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLMimeTypesCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLMimeTypesCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLMimeTypesCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLMimeTypesCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLMimeTypesCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLMimeTypesCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLMimeTypesCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLMimeTypesCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLMimeTypesCollection* This,
        long *p);

    END_INTERFACE
} IHTMLMimeTypesCollectionVtbl;
interface IHTMLMimeTypesCollection {
    CONST_VTBL IHTMLMimeTypesCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLMimeTypesCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLMimeTypesCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLMimeTypesCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLMimeTypesCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLMimeTypesCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLMimeTypesCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLMimeTypesCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLMimeTypesCollection methods ***/
#define IHTMLMimeTypesCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLMimeTypesCollection_get_length_Proxy(
    IHTMLMimeTypesCollection* This,
    long *p);
void __RPC_STUB IHTMLMimeTypesCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLMimeTypesCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLPluginsCollection_FWD_DEFINED__
#define __IHTMLPluginsCollection_FWD_DEFINED__
typedef interface IHTMLPluginsCollection IHTMLPluginsCollection;
#endif

/*****************************************************************************
 * IHTMLPluginsCollection interface
 */
#ifndef __IHTMLPluginsCollection_INTERFACE_DEFINED__
#define __IHTMLPluginsCollection_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLPluginsCollection, 0x3050f3fd, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLPluginsCollection : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE refresh(
        VARIANT_BOOL reload) = 0;

};
#else
typedef struct IHTMLPluginsCollectionVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLPluginsCollection* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLPluginsCollection* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLPluginsCollection* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLPluginsCollection* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLPluginsCollection* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLPluginsCollection* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLPluginsCollection* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLPluginsCollection methods ***/
    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLPluginsCollection* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *refresh)(
        IHTMLPluginsCollection* This,
        VARIANT_BOOL reload);

    END_INTERFACE
} IHTMLPluginsCollectionVtbl;
interface IHTMLPluginsCollection {
    CONST_VTBL IHTMLPluginsCollectionVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLPluginsCollection_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLPluginsCollection_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLPluginsCollection_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLPluginsCollection_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLPluginsCollection_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLPluginsCollection_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLPluginsCollection_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLPluginsCollection methods ***/
#define IHTMLPluginsCollection_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#define IHTMLPluginsCollection_refresh(p,a) (p)->lpVtbl->refresh(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLPluginsCollection_get_length_Proxy(
    IHTMLPluginsCollection* This,
    long *p);
void __RPC_STUB IHTMLPluginsCollection_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLPluginsCollection_refresh_Proxy(
    IHTMLPluginsCollection* This,
    VARIANT_BOOL reload);
void __RPC_STUB IHTMLPluginsCollection_refresh_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLPluginsCollection_INTERFACE_DEFINED__ */

#ifndef __IHTMLOpsProfile_FWD_DEFINED__
#define __IHTMLOpsProfile_FWD_DEFINED__
typedef interface IHTMLOpsProfile IHTMLOpsProfile;
#endif

/*****************************************************************************
 * IHTMLOpsProfile interface
 */
#ifndef __IHTMLOpsProfile_INTERFACE_DEFINED__
#define __IHTMLOpsProfile_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLOpsProfile, 0x3050f401, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLOpsProfile : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE addRequest(
        BSTR name,
        VARIANT reserved,
        VARIANT_BOOL *success) = 0;

    virtual HRESULT STDMETHODCALLTYPE clearRequest(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE doRequest(
        VARIANT usage,
        VARIANT fname,
        VARIANT domain,
        VARIANT path,
        VARIANT expire,
        VARIANT reserved) = 0;

    virtual HRESULT STDMETHODCALLTYPE getAttribute(
        BSTR name,
        BSTR *value) = 0;

    virtual HRESULT STDMETHODCALLTYPE setAttribute(
        BSTR name,
        BSTR value,
        VARIANT prefs,
        VARIANT_BOOL *success) = 0;

    virtual HRESULT STDMETHODCALLTYPE commitChanges(
        VARIANT_BOOL *success) = 0;

    virtual HRESULT STDMETHODCALLTYPE addReadRequest(
        BSTR name,
        VARIANT reserved,
        VARIANT_BOOL *success) = 0;

    virtual HRESULT STDMETHODCALLTYPE doReadRequest(
        VARIANT usage,
        VARIANT fname,
        VARIANT domain,
        VARIANT path,
        VARIANT expire,
        VARIANT reserved) = 0;

    virtual HRESULT STDMETHODCALLTYPE doWriteRequest(
        VARIANT_BOOL *success) = 0;

};
#else
typedef struct IHTMLOpsProfileVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLOpsProfile* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLOpsProfile* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLOpsProfile* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLOpsProfile* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLOpsProfile* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLOpsProfile* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLOpsProfile* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLOpsProfile methods ***/
    HRESULT (STDMETHODCALLTYPE *addRequest)(
        IHTMLOpsProfile* This,
        BSTR name,
        VARIANT reserved,
        VARIANT_BOOL *success);

    HRESULT (STDMETHODCALLTYPE *clearRequest)(
        IHTMLOpsProfile* This);

    HRESULT (STDMETHODCALLTYPE *doRequest)(
        IHTMLOpsProfile* This,
        VARIANT usage,
        VARIANT fname,
        VARIANT domain,
        VARIANT path,
        VARIANT expire,
        VARIANT reserved);

    HRESULT (STDMETHODCALLTYPE *getAttribute)(
        IHTMLOpsProfile* This,
        BSTR name,
        BSTR *value);

    HRESULT (STDMETHODCALLTYPE *setAttribute)(
        IHTMLOpsProfile* This,
        BSTR name,
        BSTR value,
        VARIANT prefs,
        VARIANT_BOOL *success);

    HRESULT (STDMETHODCALLTYPE *commitChanges)(
        IHTMLOpsProfile* This,
        VARIANT_BOOL *success);

    HRESULT (STDMETHODCALLTYPE *addReadRequest)(
        IHTMLOpsProfile* This,
        BSTR name,
        VARIANT reserved,
        VARIANT_BOOL *success);

    HRESULT (STDMETHODCALLTYPE *doReadRequest)(
        IHTMLOpsProfile* This,
        VARIANT usage,
        VARIANT fname,
        VARIANT domain,
        VARIANT path,
        VARIANT expire,
        VARIANT reserved);

    HRESULT (STDMETHODCALLTYPE *doWriteRequest)(
        IHTMLOpsProfile* This,
        VARIANT_BOOL *success);

    END_INTERFACE
} IHTMLOpsProfileVtbl;
interface IHTMLOpsProfile {
    CONST_VTBL IHTMLOpsProfileVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLOpsProfile_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLOpsProfile_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLOpsProfile_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLOpsProfile_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLOpsProfile_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLOpsProfile_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLOpsProfile_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLOpsProfile methods ***/
#define IHTMLOpsProfile_addRequest(p,a,b,c) (p)->lpVtbl->addRequest(p,a,b,c)
#define IHTMLOpsProfile_clearRequest(p) (p)->lpVtbl->clearRequest(p)
#define IHTMLOpsProfile_doRequest(p,a,b,c,d,e,f) (p)->lpVtbl->doRequest(p,a,b,c,d,e,f)
#define IHTMLOpsProfile_getAttribute(p,a,b) (p)->lpVtbl->getAttribute(p,a,b)
#define IHTMLOpsProfile_setAttribute(p,a,b,c,d) (p)->lpVtbl->setAttribute(p,a,b,c,d)
#define IHTMLOpsProfile_commitChanges(p,a) (p)->lpVtbl->commitChanges(p,a)
#define IHTMLOpsProfile_addReadRequest(p,a,b,c) (p)->lpVtbl->addReadRequest(p,a,b,c)
#define IHTMLOpsProfile_doReadRequest(p,a,b,c,d,e,f) (p)->lpVtbl->doReadRequest(p,a,b,c,d,e,f)
#define IHTMLOpsProfile_doWriteRequest(p,a) (p)->lpVtbl->doWriteRequest(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLOpsProfile_addRequest_Proxy(
    IHTMLOpsProfile* This,
    BSTR name,
    VARIANT reserved,
    VARIANT_BOOL *success);
void __RPC_STUB IHTMLOpsProfile_addRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_clearRequest_Proxy(
    IHTMLOpsProfile* This);
void __RPC_STUB IHTMLOpsProfile_clearRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_doRequest_Proxy(
    IHTMLOpsProfile* This,
    VARIANT usage,
    VARIANT fname,
    VARIANT domain,
    VARIANT path,
    VARIANT expire,
    VARIANT reserved);
void __RPC_STUB IHTMLOpsProfile_doRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_getAttribute_Proxy(
    IHTMLOpsProfile* This,
    BSTR name,
    BSTR *value);
void __RPC_STUB IHTMLOpsProfile_getAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_setAttribute_Proxy(
    IHTMLOpsProfile* This,
    BSTR name,
    BSTR value,
    VARIANT prefs,
    VARIANT_BOOL *success);
void __RPC_STUB IHTMLOpsProfile_setAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_commitChanges_Proxy(
    IHTMLOpsProfile* This,
    VARIANT_BOOL *success);
void __RPC_STUB IHTMLOpsProfile_commitChanges_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_addReadRequest_Proxy(
    IHTMLOpsProfile* This,
    BSTR name,
    VARIANT reserved,
    VARIANT_BOOL *success);
void __RPC_STUB IHTMLOpsProfile_addReadRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_doReadRequest_Proxy(
    IHTMLOpsProfile* This,
    VARIANT usage,
    VARIANT fname,
    VARIANT domain,
    VARIANT path,
    VARIANT expire,
    VARIANT reserved);
void __RPC_STUB IHTMLOpsProfile_doReadRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLOpsProfile_doWriteRequest_Proxy(
    IHTMLOpsProfile* This,
    VARIANT_BOOL *success);
void __RPC_STUB IHTMLOpsProfile_doWriteRequest_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLOpsProfile_INTERFACE_DEFINED__ */

#ifndef __IOmNavigator_FWD_DEFINED__
#define __IOmNavigator_FWD_DEFINED__
typedef interface IOmNavigator IOmNavigator;
#endif

/*****************************************************************************
 * IOmNavigator interface
 */
#ifndef __IOmNavigator_INTERFACE_DEFINED__
#define __IOmNavigator_INTERFACE_DEFINED__

DEFINE_GUID(IID_IOmNavigator, 0xfeceaaa5, 0x8405, 0x11cf, 0x8b,0xa1, 0x00,0xaa,0x00,0x47,0x6d,0xa6);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IOmNavigator : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_appCodeName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_appName(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_appVersion(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_userAgent(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE javaEnabled(
        VARIANT_BOOL *enabled) = 0;

    virtual HRESULT STDMETHODCALLTYPE taintEnabled(
        VARIANT_BOOL *enabled) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_mimeTypes(
        IHTMLMimeTypesCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_plugins(
        IHTMLPluginsCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cookieEnabled(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_opsProfile(
        IHTMLOpsProfile **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cpuClass(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_systemLanguage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_browserLanguage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_userLanguage(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_platform(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_appMinorVersion(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_connectionSpeed(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onLine(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_userProfile(
        IHTMLOpsProfile **p) = 0;

};
#else
typedef struct IOmNavigatorVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IOmNavigator* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IOmNavigator* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IOmNavigator* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IOmNavigator* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IOmNavigator* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IOmNavigator* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IOmNavigator* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IOmNavigator methods ***/
    HRESULT (STDMETHODCALLTYPE *get_appCodeName)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_appName)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_appVersion)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_userAgent)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *javaEnabled)(
        IOmNavigator* This,
        VARIANT_BOOL *enabled);

    HRESULT (STDMETHODCALLTYPE *taintEnabled)(
        IOmNavigator* This,
        VARIANT_BOOL *enabled);

    HRESULT (STDMETHODCALLTYPE *get_mimeTypes)(
        IOmNavigator* This,
        IHTMLMimeTypesCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_plugins)(
        IOmNavigator* This,
        IHTMLPluginsCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_cookieEnabled)(
        IOmNavigator* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_opsProfile)(
        IOmNavigator* This,
        IHTMLOpsProfile **p);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IOmNavigator* This,
        BSTR *String);

    HRESULT (STDMETHODCALLTYPE *get_cpuClass)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_systemLanguage)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_browserLanguage)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_userLanguage)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_platform)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_appMinorVersion)(
        IOmNavigator* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_connectionSpeed)(
        IOmNavigator* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_onLine)(
        IOmNavigator* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_userProfile)(
        IOmNavigator* This,
        IHTMLOpsProfile **p);

    END_INTERFACE
} IOmNavigatorVtbl;
interface IOmNavigator {
    CONST_VTBL IOmNavigatorVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IOmNavigator_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IOmNavigator_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IOmNavigator_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IOmNavigator_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IOmNavigator_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IOmNavigator_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IOmNavigator_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IOmNavigator methods ***/
#define IOmNavigator_get_appCodeName(p,a) (p)->lpVtbl->get_appCodeName(p,a)
#define IOmNavigator_get_appName(p,a) (p)->lpVtbl->get_appName(p,a)
#define IOmNavigator_get_appVersion(p,a) (p)->lpVtbl->get_appVersion(p,a)
#define IOmNavigator_get_userAgent(p,a) (p)->lpVtbl->get_userAgent(p,a)
#define IOmNavigator_javaEnabled(p,a) (p)->lpVtbl->javaEnabled(p,a)
#define IOmNavigator_taintEnabled(p,a) (p)->lpVtbl->taintEnabled(p,a)
#define IOmNavigator_get_mimeTypes(p,a) (p)->lpVtbl->get_mimeTypes(p,a)
#define IOmNavigator_get_plugins(p,a) (p)->lpVtbl->get_plugins(p,a)
#define IOmNavigator_get_cookieEnabled(p,a) (p)->lpVtbl->get_cookieEnabled(p,a)
#define IOmNavigator_get_opsProfile(p,a) (p)->lpVtbl->get_opsProfile(p,a)
#define IOmNavigator_toString(p,a) (p)->lpVtbl->toString(p,a)
#define IOmNavigator_get_cpuClass(p,a) (p)->lpVtbl->get_cpuClass(p,a)
#define IOmNavigator_get_systemLanguage(p,a) (p)->lpVtbl->get_systemLanguage(p,a)
#define IOmNavigator_get_browserLanguage(p,a) (p)->lpVtbl->get_browserLanguage(p,a)
#define IOmNavigator_get_userLanguage(p,a) (p)->lpVtbl->get_userLanguage(p,a)
#define IOmNavigator_get_platform(p,a) (p)->lpVtbl->get_platform(p,a)
#define IOmNavigator_get_appMinorVersion(p,a) (p)->lpVtbl->get_appMinorVersion(p,a)
#define IOmNavigator_get_connectionSpeed(p,a) (p)->lpVtbl->get_connectionSpeed(p,a)
#define IOmNavigator_get_onLine(p,a) (p)->lpVtbl->get_onLine(p,a)
#define IOmNavigator_get_userProfile(p,a) (p)->lpVtbl->get_userProfile(p,a)
#endif

#endif

HRESULT CALLBACK IOmNavigator_get_appCodeName_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_appCodeName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_appName_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_appName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_appVersion_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_appVersion_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_userAgent_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_userAgent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_javaEnabled_Proxy(
    IOmNavigator* This,
    VARIANT_BOOL *enabled);
void __RPC_STUB IOmNavigator_javaEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_taintEnabled_Proxy(
    IOmNavigator* This,
    VARIANT_BOOL *enabled);
void __RPC_STUB IOmNavigator_taintEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_mimeTypes_Proxy(
    IOmNavigator* This,
    IHTMLMimeTypesCollection **p);
void __RPC_STUB IOmNavigator_get_mimeTypes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_plugins_Proxy(
    IOmNavigator* This,
    IHTMLPluginsCollection **p);
void __RPC_STUB IOmNavigator_get_plugins_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_cookieEnabled_Proxy(
    IOmNavigator* This,
    VARIANT_BOOL *p);
void __RPC_STUB IOmNavigator_get_cookieEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_opsProfile_Proxy(
    IOmNavigator* This,
    IHTMLOpsProfile **p);
void __RPC_STUB IOmNavigator_get_opsProfile_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_toString_Proxy(
    IOmNavigator* This,
    BSTR *String);
void __RPC_STUB IOmNavigator_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_cpuClass_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_cpuClass_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_systemLanguage_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_systemLanguage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_browserLanguage_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_browserLanguage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_userLanguage_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_userLanguage_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_platform_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_platform_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_appMinorVersion_Proxy(
    IOmNavigator* This,
    BSTR *p);
void __RPC_STUB IOmNavigator_get_appMinorVersion_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_connectionSpeed_Proxy(
    IOmNavigator* This,
    long *p);
void __RPC_STUB IOmNavigator_get_connectionSpeed_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_onLine_Proxy(
    IOmNavigator* This,
    VARIANT_BOOL *p);
void __RPC_STUB IOmNavigator_get_onLine_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IOmNavigator_get_userProfile_Proxy(
    IOmNavigator* This,
    IHTMLOpsProfile **p);
void __RPC_STUB IOmNavigator_get_userProfile_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IOmNavigator_INTERFACE_DEFINED__ */

#ifndef __IHTMLLocation_FWD_DEFINED__
#define __IHTMLLocation_FWD_DEFINED__
typedef interface IHTMLLocation IHTMLLocation;
#endif

/*****************************************************************************
 * IHTMLLocation interface
 */
#ifndef __IHTMLLocation_INTERFACE_DEFINED__
#define __IHTMLLocation_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLLocation, 0x163bb1e0, 0x6e00, 0x11cf, 0x83,0x7a, 0x48,0xdc,0x04,0xc1,0x00,0x00);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLLocation : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_href(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_href(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_protocol(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_protocol(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_host(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_host(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_hostname(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_hostname(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_port(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_port(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_pathname(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_pathname(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_search(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_search(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_hash(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_hash(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE reload(
        VARIANT_BOOL flag) = 0;

    virtual HRESULT STDMETHODCALLTYPE replace(
        BSTR bstr) = 0;

    virtual HRESULT STDMETHODCALLTYPE assign(
        BSTR bstr) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

};
#else
typedef struct IHTMLLocationVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLLocation* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLLocation* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLLocation* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLLocation* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLLocation* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLLocation* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLLocation* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLLocation methods ***/
    HRESULT (STDMETHODCALLTYPE *put_href)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_href)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_protocol)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_protocol)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_host)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_host)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_hostname)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_hostname)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_port)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_port)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_pathname)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_pathname)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_search)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_search)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_hash)(
        IHTMLLocation* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_hash)(
        IHTMLLocation* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *reload)(
        IHTMLLocation* This,
        VARIANT_BOOL flag);

    HRESULT (STDMETHODCALLTYPE *replace)(
        IHTMLLocation* This,
        BSTR bstr);

    HRESULT (STDMETHODCALLTYPE *assign)(
        IHTMLLocation* This,
        BSTR bstr);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLLocation* This,
        BSTR *String);

    END_INTERFACE
} IHTMLLocationVtbl;
interface IHTMLLocation {
    CONST_VTBL IHTMLLocationVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLLocation_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLLocation_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLLocation_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLLocation_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLLocation_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLLocation_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLLocation_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLLocation methods ***/
#define IHTMLLocation_put_href(p,a) (p)->lpVtbl->put_href(p,a)
#define IHTMLLocation_get_href(p,a) (p)->lpVtbl->get_href(p,a)
#define IHTMLLocation_put_protocol(p,a) (p)->lpVtbl->put_protocol(p,a)
#define IHTMLLocation_get_protocol(p,a) (p)->lpVtbl->get_protocol(p,a)
#define IHTMLLocation_put_host(p,a) (p)->lpVtbl->put_host(p,a)
#define IHTMLLocation_get_host(p,a) (p)->lpVtbl->get_host(p,a)
#define IHTMLLocation_put_hostname(p,a) (p)->lpVtbl->put_hostname(p,a)
#define IHTMLLocation_get_hostname(p,a) (p)->lpVtbl->get_hostname(p,a)
#define IHTMLLocation_put_port(p,a) (p)->lpVtbl->put_port(p,a)
#define IHTMLLocation_get_port(p,a) (p)->lpVtbl->get_port(p,a)
#define IHTMLLocation_put_pathname(p,a) (p)->lpVtbl->put_pathname(p,a)
#define IHTMLLocation_get_pathname(p,a) (p)->lpVtbl->get_pathname(p,a)
#define IHTMLLocation_put_search(p,a) (p)->lpVtbl->put_search(p,a)
#define IHTMLLocation_get_search(p,a) (p)->lpVtbl->get_search(p,a)
#define IHTMLLocation_put_hash(p,a) (p)->lpVtbl->put_hash(p,a)
#define IHTMLLocation_get_hash(p,a) (p)->lpVtbl->get_hash(p,a)
#define IHTMLLocation_reload(p,a) (p)->lpVtbl->reload(p,a)
#define IHTMLLocation_replace(p,a) (p)->lpVtbl->replace(p,a)
#define IHTMLLocation_assign(p,a) (p)->lpVtbl->assign(p,a)
#define IHTMLLocation_toString(p,a) (p)->lpVtbl->toString(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLLocation_put_href_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_href_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_href_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_href_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_protocol_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_protocol_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_protocol_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_protocol_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_host_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_host_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_host_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_host_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_hostname_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_hostname_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_hostname_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_hostname_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_port_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_port_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_port_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_port_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_pathname_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_pathname_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_pathname_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_pathname_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_search_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_search_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_search_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_search_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_put_hash_Proxy(
    IHTMLLocation* This,
    BSTR v);
void __RPC_STUB IHTMLLocation_put_hash_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_get_hash_Proxy(
    IHTMLLocation* This,
    BSTR *p);
void __RPC_STUB IHTMLLocation_get_hash_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_reload_Proxy(
    IHTMLLocation* This,
    VARIANT_BOOL flag);
void __RPC_STUB IHTMLLocation_reload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_replace_Proxy(
    IHTMLLocation* This,
    BSTR bstr);
void __RPC_STUB IHTMLLocation_replace_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_assign_Proxy(
    IHTMLLocation* This,
    BSTR bstr);
void __RPC_STUB IHTMLLocation_assign_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLLocation_toString_Proxy(
    IHTMLLocation* This,
    BSTR *String);
void __RPC_STUB IHTMLLocation_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLLocation_INTERFACE_DEFINED__ */

#ifndef __IHTMLEventObj_FWD_DEFINED__
#define __IHTMLEventObj_FWD_DEFINED__
typedef interface IHTMLEventObj IHTMLEventObj;
#endif

/*****************************************************************************
 * IHTMLEventObj interface
 */
#ifndef __IHTMLEventObj_INTERFACE_DEFINED__
#define __IHTMLEventObj_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLEventObj, 0x3050f32d, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLEventObj : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_srcElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_altKey(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ctrlKey(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_shiftKey(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_returnValue(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_returnValue(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cancelBubble(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cancelBubble(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fromElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_toElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_keyCode(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_keyCode(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_button(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_type(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_qualifier(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_reason(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_x(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_y(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientX(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientY(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetX(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offsetY(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_screenX(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_screenY(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_srcFilter(
        IDispatch **p) = 0;

};
#else
typedef struct IHTMLEventObjVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLEventObj* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLEventObj* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLEventObj* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLEventObj* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLEventObj* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLEventObj* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLEventObj* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLEventObj methods ***/
    HRESULT (STDMETHODCALLTYPE *get_srcElement)(
        IHTMLEventObj* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_altKey)(
        IHTMLEventObj* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_ctrlKey)(
        IHTMLEventObj* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_shiftKey)(
        IHTMLEventObj* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_returnValue)(
        IHTMLEventObj* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_returnValue)(
        IHTMLEventObj* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_cancelBubble)(
        IHTMLEventObj* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_cancelBubble)(
        IHTMLEventObj* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *get_fromElement)(
        IHTMLEventObj* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_toElement)(
        IHTMLEventObj* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *put_keyCode)(
        IHTMLEventObj* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_keyCode)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_button)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_type)(
        IHTMLEventObj* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_qualifier)(
        IHTMLEventObj* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_reason)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_x)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_y)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_clientX)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_clientY)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetX)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_offsetY)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_screenX)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_screenY)(
        IHTMLEventObj* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_srcFilter)(
        IHTMLEventObj* This,
        IDispatch **p);

    END_INTERFACE
} IHTMLEventObjVtbl;
interface IHTMLEventObj {
    CONST_VTBL IHTMLEventObjVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLEventObj_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLEventObj_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLEventObj_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLEventObj_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLEventObj_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLEventObj_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLEventObj_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLEventObj methods ***/
#define IHTMLEventObj_get_srcElement(p,a) (p)->lpVtbl->get_srcElement(p,a)
#define IHTMLEventObj_get_altKey(p,a) (p)->lpVtbl->get_altKey(p,a)
#define IHTMLEventObj_get_ctrlKey(p,a) (p)->lpVtbl->get_ctrlKey(p,a)
#define IHTMLEventObj_get_shiftKey(p,a) (p)->lpVtbl->get_shiftKey(p,a)
#define IHTMLEventObj_put_returnValue(p,a) (p)->lpVtbl->put_returnValue(p,a)
#define IHTMLEventObj_get_returnValue(p,a) (p)->lpVtbl->get_returnValue(p,a)
#define IHTMLEventObj_put_cancelBubble(p,a) (p)->lpVtbl->put_cancelBubble(p,a)
#define IHTMLEventObj_get_cancelBubble(p,a) (p)->lpVtbl->get_cancelBubble(p,a)
#define IHTMLEventObj_get_fromElement(p,a) (p)->lpVtbl->get_fromElement(p,a)
#define IHTMLEventObj_get_toElement(p,a) (p)->lpVtbl->get_toElement(p,a)
#define IHTMLEventObj_put_keyCode(p,a) (p)->lpVtbl->put_keyCode(p,a)
#define IHTMLEventObj_get_keyCode(p,a) (p)->lpVtbl->get_keyCode(p,a)
#define IHTMLEventObj_get_button(p,a) (p)->lpVtbl->get_button(p,a)
#define IHTMLEventObj_get_type(p,a) (p)->lpVtbl->get_type(p,a)
#define IHTMLEventObj_get_qualifier(p,a) (p)->lpVtbl->get_qualifier(p,a)
#define IHTMLEventObj_get_reason(p,a) (p)->lpVtbl->get_reason(p,a)
#define IHTMLEventObj_get_x(p,a) (p)->lpVtbl->get_x(p,a)
#define IHTMLEventObj_get_y(p,a) (p)->lpVtbl->get_y(p,a)
#define IHTMLEventObj_get_clientX(p,a) (p)->lpVtbl->get_clientX(p,a)
#define IHTMLEventObj_get_clientY(p,a) (p)->lpVtbl->get_clientY(p,a)
#define IHTMLEventObj_get_offsetX(p,a) (p)->lpVtbl->get_offsetX(p,a)
#define IHTMLEventObj_get_offsetY(p,a) (p)->lpVtbl->get_offsetY(p,a)
#define IHTMLEventObj_get_screenX(p,a) (p)->lpVtbl->get_screenX(p,a)
#define IHTMLEventObj_get_screenY(p,a) (p)->lpVtbl->get_screenY(p,a)
#define IHTMLEventObj_get_srcFilter(p,a) (p)->lpVtbl->get_srcFilter(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLEventObj_get_srcElement_Proxy(
    IHTMLEventObj* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLEventObj_get_srcElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_altKey_Proxy(
    IHTMLEventObj* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLEventObj_get_altKey_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_ctrlKey_Proxy(
    IHTMLEventObj* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLEventObj_get_ctrlKey_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_shiftKey_Proxy(
    IHTMLEventObj* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLEventObj_get_shiftKey_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_put_returnValue_Proxy(
    IHTMLEventObj* This,
    VARIANT v);
void __RPC_STUB IHTMLEventObj_put_returnValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_returnValue_Proxy(
    IHTMLEventObj* This,
    VARIANT *p);
void __RPC_STUB IHTMLEventObj_get_returnValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_put_cancelBubble_Proxy(
    IHTMLEventObj* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLEventObj_put_cancelBubble_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_cancelBubble_Proxy(
    IHTMLEventObj* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLEventObj_get_cancelBubble_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_fromElement_Proxy(
    IHTMLEventObj* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLEventObj_get_fromElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_toElement_Proxy(
    IHTMLEventObj* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLEventObj_get_toElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_put_keyCode_Proxy(
    IHTMLEventObj* This,
    long v);
void __RPC_STUB IHTMLEventObj_put_keyCode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_keyCode_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_keyCode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_button_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_button_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_type_Proxy(
    IHTMLEventObj* This,
    BSTR *p);
void __RPC_STUB IHTMLEventObj_get_type_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_qualifier_Proxy(
    IHTMLEventObj* This,
    BSTR *p);
void __RPC_STUB IHTMLEventObj_get_qualifier_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_reason_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_reason_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_x_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_x_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_y_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_y_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_clientX_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_clientX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_clientY_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_clientY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_offsetX_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_offsetX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_offsetY_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_offsetY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_screenX_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_screenX_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_screenY_Proxy(
    IHTMLEventObj* This,
    long *p);
void __RPC_STUB IHTMLEventObj_get_screenY_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLEventObj_get_srcFilter_Proxy(
    IHTMLEventObj* This,
    IDispatch **p);
void __RPC_STUB IHTMLEventObj_get_srcFilter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLEventObj_INTERFACE_DEFINED__ */

#ifndef __IHTMLFramesCollection2_FWD_DEFINED__
#define __IHTMLFramesCollection2_FWD_DEFINED__
typedef interface IHTMLFramesCollection2 IHTMLFramesCollection2;
#endif

/*****************************************************************************
 * IHTMLFramesCollection2 interface
 */
#ifndef __IHTMLFramesCollection2_INTERFACE_DEFINED__
#define __IHTMLFramesCollection2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLFramesCollection2, 0x332c4426, 0x26cb, 0x11d0, 0xb4,0x83, 0x00,0xc0,0x4f,0xd9,0x01,0x19);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLFramesCollection2 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE item(
        VARIANT *pvarIndex,
        VARIANT *pvarResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_length(
        long *p) = 0;

};
#else
typedef struct IHTMLFramesCollection2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLFramesCollection2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLFramesCollection2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLFramesCollection2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLFramesCollection2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLFramesCollection2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLFramesCollection2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLFramesCollection2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLFramesCollection2 methods ***/
    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLFramesCollection2* This,
        VARIANT *pvarIndex,
        VARIANT *pvarResult);

    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLFramesCollection2* This,
        long *p);

    END_INTERFACE
} IHTMLFramesCollection2Vtbl;
interface IHTMLFramesCollection2 {
    CONST_VTBL IHTMLFramesCollection2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLFramesCollection2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLFramesCollection2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLFramesCollection2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLFramesCollection2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLFramesCollection2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLFramesCollection2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLFramesCollection2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLFramesCollection2 methods ***/
#define IHTMLFramesCollection2_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#define IHTMLFramesCollection2_get_length(p,a) (p)->lpVtbl->get_length(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLFramesCollection2_item_Proxy(
    IHTMLFramesCollection2* This,
    VARIANT *pvarIndex,
    VARIANT *pvarResult);
void __RPC_STUB IHTMLFramesCollection2_item_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFramesCollection2_get_length_Proxy(
    IHTMLFramesCollection2* This,
    long *p);
void __RPC_STUB IHTMLFramesCollection2_get_length_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLFramesCollection2_INTERFACE_DEFINED__ */

#ifndef __IHTMLScreen_FWD_DEFINED__
#define __IHTMLScreen_FWD_DEFINED__
typedef interface IHTMLScreen IHTMLScreen;
#endif

/*****************************************************************************
 * IHTMLScreen interface
 */
#ifndef __IHTMLScreen_INTERFACE_DEFINED__
#define __IHTMLScreen_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLScreen, 0x3050f35c, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLScreen : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_colorDepth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bufferDepth(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bufferDepth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_width(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_height(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_updateInterval(
        long v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_updateInterval(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_availHeight(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_availWidth(
        long *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fontSmoothingEnabled(
        VARIANT_BOOL *p) = 0;

};
#else
typedef struct IHTMLScreenVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLScreen* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLScreen* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLScreen* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLScreen* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLScreen* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLScreen* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLScreen* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLScreen methods ***/
    HRESULT (STDMETHODCALLTYPE *get_colorDepth)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_bufferDepth)(
        IHTMLScreen* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_bufferDepth)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_width)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_height)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *put_updateInterval)(
        IHTMLScreen* This,
        long v);

    HRESULT (STDMETHODCALLTYPE *get_updateInterval)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_availHeight)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_availWidth)(
        IHTMLScreen* This,
        long *p);

    HRESULT (STDMETHODCALLTYPE *get_fontSmoothingEnabled)(
        IHTMLScreen* This,
        VARIANT_BOOL *p);

    END_INTERFACE
} IHTMLScreenVtbl;
interface IHTMLScreen {
    CONST_VTBL IHTMLScreenVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLScreen_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLScreen_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLScreen_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLScreen_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLScreen_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLScreen_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLScreen_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLScreen methods ***/
#define IHTMLScreen_get_colorDepth(p,a) (p)->lpVtbl->get_colorDepth(p,a)
#define IHTMLScreen_put_bufferDepth(p,a) (p)->lpVtbl->put_bufferDepth(p,a)
#define IHTMLScreen_get_bufferDepth(p,a) (p)->lpVtbl->get_bufferDepth(p,a)
#define IHTMLScreen_get_width(p,a) (p)->lpVtbl->get_width(p,a)
#define IHTMLScreen_get_height(p,a) (p)->lpVtbl->get_height(p,a)
#define IHTMLScreen_put_updateInterval(p,a) (p)->lpVtbl->put_updateInterval(p,a)
#define IHTMLScreen_get_updateInterval(p,a) (p)->lpVtbl->get_updateInterval(p,a)
#define IHTMLScreen_get_availHeight(p,a) (p)->lpVtbl->get_availHeight(p,a)
#define IHTMLScreen_get_availWidth(p,a) (p)->lpVtbl->get_availWidth(p,a)
#define IHTMLScreen_get_fontSmoothingEnabled(p,a) (p)->lpVtbl->get_fontSmoothingEnabled(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLScreen_get_colorDepth_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_colorDepth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_put_bufferDepth_Proxy(
    IHTMLScreen* This,
    long v);
void __RPC_STUB IHTMLScreen_put_bufferDepth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_bufferDepth_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_bufferDepth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_width_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_width_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_height_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_height_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_put_updateInterval_Proxy(
    IHTMLScreen* This,
    long v);
void __RPC_STUB IHTMLScreen_put_updateInterval_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_updateInterval_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_updateInterval_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_availHeight_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_availHeight_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_availWidth_Proxy(
    IHTMLScreen* This,
    long *p);
void __RPC_STUB IHTMLScreen_get_availWidth_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLScreen_get_fontSmoothingEnabled_Proxy(
    IHTMLScreen* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLScreen_get_fontSmoothingEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLScreen_INTERFACE_DEFINED__ */

#ifndef __IHTMLWindow2_FWD_DEFINED__
#define __IHTMLWindow2_FWD_DEFINED__
typedef interface IHTMLWindow2 IHTMLWindow2;
#endif

/*****************************************************************************
 * IHTMLWindow2 interface
 */
#ifndef __IHTMLWindow2_INTERFACE_DEFINED__
#define __IHTMLWindow2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLWindow2, 0x332c4427, 0x26cb, 0x11d0, 0xb4,0x83, 0x00,0xc0,0x4f,0xd9,0x01,0x19);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLWindow2 : public IHTMLFramesCollection2
{
    virtual HRESULT STDMETHODCALLTYPE get_frames(
        IHTMLFramesCollection2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultStatus(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultStatus(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_status(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_status(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE setTimeout(
        BSTR expression,
        long msec,
        VARIANT *language,
        long *timerID) = 0;

    virtual HRESULT STDMETHODCALLTYPE clearTimeout(
        long timerID) = 0;

    virtual HRESULT STDMETHODCALLTYPE alert(
        BSTR message) = 0;

    virtual HRESULT STDMETHODCALLTYPE confirm(
        BSTR message,
        VARIANT_BOOL *confirmed) = 0;

    virtual HRESULT STDMETHODCALLTYPE prompt(
        BSTR message,
        BSTR defstr,
        VARIANT *textdata) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_Image(
        IHTMLImageElementFactory **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_location(
        IHTMLLocation **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_history(
        IOmHistory **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE close(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_opener(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_opener(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_navigator(
        IOmNavigator **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_name(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_name(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parent(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE open(
        BSTR url,
        BSTR name,
        BSTR features,
        VARIANT_BOOL replace,
        IHTMLWindow2 **pomWindowResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_self(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_top(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_window(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE navigate(
        BSTR url) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onfocus(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onfocus(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onblur(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onblur(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeunload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeunload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onunload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onunload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onhelp(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onhelp(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onerror(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onerror(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onresize(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onresize(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onscroll(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onscroll(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_document(
        IHTMLDocument2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_event(
        IHTMLEventObj **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get__newEnum(
        IUnknown **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE showModalDialog(
        BSTR dialog,
        VARIANT *varArgIn,
        VARIANT *varOptions,
        VARIANT *varArgOut) = 0;

    virtual HRESULT STDMETHODCALLTYPE showHelp(
        BSTR helpURL,
        VARIANT helpArg,
        BSTR features) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_screen(
        IHTMLScreen **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_Option(
        IHTMLOptionElementFactory **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE focus(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_closed(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE blur(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE scroll(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_clientInformation(
        IOmNavigator **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE setInterval(
        BSTR expression,
        long msec,
        VARIANT *language,
        long *timerID) = 0;

    virtual HRESULT STDMETHODCALLTYPE clearInterval(
        long timerID) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_offscreenBuffering(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_offscreenBuffering(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE execScript(
        BSTR scode,
        BSTR language,
        VARIANT *pvarRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

    virtual HRESULT STDMETHODCALLTYPE scrollBy(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE scrollTo(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveTo(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE moveBy(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE resizeTo(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE resizeBy(
        long x,
        long y) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_external(
        IDispatch **p) = 0;

};
#else
typedef struct IHTMLWindow2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLWindow2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLWindow2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLWindow2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLWindow2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLWindow2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLWindow2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLWindow2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLFramesCollection2 methods ***/
    HRESULT (STDMETHODCALLTYPE *item)(
        IHTMLWindow2* This,
        VARIANT *pvarIndex,
        VARIANT *pvarResult);

    HRESULT (STDMETHODCALLTYPE *get_length)(
        IHTMLWindow2* This,
        long *p);

    /*** IHTMLWindow2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_frames)(
        IHTMLWindow2* This,
        IHTMLFramesCollection2 **p);

    HRESULT (STDMETHODCALLTYPE *put_defaultStatus)(
        IHTMLWindow2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_defaultStatus)(
        IHTMLWindow2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_status)(
        IHTMLWindow2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_status)(
        IHTMLWindow2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *setTimeout)(
        IHTMLWindow2* This,
        BSTR expression,
        long msec,
        VARIANT *language,
        long *timerID);

    HRESULT (STDMETHODCALLTYPE *clearTimeout)(
        IHTMLWindow2* This,
        long timerID);

    HRESULT (STDMETHODCALLTYPE *alert)(
        IHTMLWindow2* This,
        BSTR message);

    HRESULT (STDMETHODCALLTYPE *confirm)(
        IHTMLWindow2* This,
        BSTR message,
        VARIANT_BOOL *confirmed);

    HRESULT (STDMETHODCALLTYPE *prompt)(
        IHTMLWindow2* This,
        BSTR message,
        BSTR defstr,
        VARIANT *textdata);

    HRESULT (STDMETHODCALLTYPE *get_Image)(
        IHTMLWindow2* This,
        IHTMLImageElementFactory **p);

    HRESULT (STDMETHODCALLTYPE *get_location)(
        IHTMLWindow2* This,
        IHTMLLocation **p);

    HRESULT (STDMETHODCALLTYPE *get_history)(
        IHTMLWindow2* This,
        IOmHistory **p);

    HRESULT (STDMETHODCALLTYPE *close)(
        IHTMLWindow2* This);

    HRESULT (STDMETHODCALLTYPE *put_opener)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_opener)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_navigator)(
        IHTMLWindow2* This,
        IOmNavigator **p);

    HRESULT (STDMETHODCALLTYPE *put_name)(
        IHTMLWindow2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_name)(
        IHTMLWindow2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_parent)(
        IHTMLWindow2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *open)(
        IHTMLWindow2* This,
        BSTR url,
        BSTR name,
        BSTR features,
        VARIANT_BOOL replace,
        IHTMLWindow2 **pomWindowResult);

    HRESULT (STDMETHODCALLTYPE *get_self)(
        IHTMLWindow2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *get_top)(
        IHTMLWindow2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *get_window)(
        IHTMLWindow2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *navigate)(
        IHTMLWindow2* This,
        BSTR url);

    HRESULT (STDMETHODCALLTYPE *put_onfocus)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onfocus)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onblur)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onblur)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onload)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onload)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeunload)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeunload)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onunload)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onunload)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onhelp)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onhelp)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onerror)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onerror)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onresize)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onresize)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onscroll)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onscroll)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_document)(
        IHTMLWindow2* This,
        IHTMLDocument2 **p);

    HRESULT (STDMETHODCALLTYPE *get_event)(
        IHTMLWindow2* This,
        IHTMLEventObj **p);

    HRESULT (STDMETHODCALLTYPE *get__newEnum)(
        IHTMLWindow2* This,
        IUnknown **p);

    HRESULT (STDMETHODCALLTYPE *showModalDialog)(
        IHTMLWindow2* This,
        BSTR dialog,
        VARIANT *varArgIn,
        VARIANT *varOptions,
        VARIANT *varArgOut);

    HRESULT (STDMETHODCALLTYPE *showHelp)(
        IHTMLWindow2* This,
        BSTR helpURL,
        VARIANT helpArg,
        BSTR features);

    HRESULT (STDMETHODCALLTYPE *get_screen)(
        IHTMLWindow2* This,
        IHTMLScreen **p);

    HRESULT (STDMETHODCALLTYPE *get_Option)(
        IHTMLWindow2* This,
        IHTMLOptionElementFactory **p);

    HRESULT (STDMETHODCALLTYPE *focus)(
        IHTMLWindow2* This);

    HRESULT (STDMETHODCALLTYPE *get_closed)(
        IHTMLWindow2* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *blur)(
        IHTMLWindow2* This);

    HRESULT (STDMETHODCALLTYPE *scroll)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *get_clientInformation)(
        IHTMLWindow2* This,
        IOmNavigator **p);

    HRESULT (STDMETHODCALLTYPE *setInterval)(
        IHTMLWindow2* This,
        BSTR expression,
        long msec,
        VARIANT *language,
        long *timerID);

    HRESULT (STDMETHODCALLTYPE *clearInterval)(
        IHTMLWindow2* This,
        long timerID);

    HRESULT (STDMETHODCALLTYPE *put_offscreenBuffering)(
        IHTMLWindow2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_offscreenBuffering)(
        IHTMLWindow2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *execScript)(
        IHTMLWindow2* This,
        BSTR scode,
        BSTR language,
        VARIANT *pvarRet);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLWindow2* This,
        BSTR *String);

    HRESULT (STDMETHODCALLTYPE *scrollBy)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *scrollTo)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *moveTo)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *moveBy)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *resizeTo)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *resizeBy)(
        IHTMLWindow2* This,
        long x,
        long y);

    HRESULT (STDMETHODCALLTYPE *get_external)(
        IHTMLWindow2* This,
        IDispatch **p);

    END_INTERFACE
} IHTMLWindow2Vtbl;
interface IHTMLWindow2 {
    CONST_VTBL IHTMLWindow2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLWindow2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLWindow2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLWindow2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLWindow2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLWindow2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLWindow2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLWindow2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLFramesCollection2 methods ***/
#define IHTMLWindow2_item(p,a,b) (p)->lpVtbl->item(p,a,b)
#define IHTMLWindow2_get_length(p,a) (p)->lpVtbl->get_length(p,a)
/*** IHTMLWindow2 methods ***/
#define IHTMLWindow2_get_frames(p,a) (p)->lpVtbl->get_frames(p,a)
#define IHTMLWindow2_put_defaultStatus(p,a) (p)->lpVtbl->put_defaultStatus(p,a)
#define IHTMLWindow2_get_defaultStatus(p,a) (p)->lpVtbl->get_defaultStatus(p,a)
#define IHTMLWindow2_put_status(p,a) (p)->lpVtbl->put_status(p,a)
#define IHTMLWindow2_get_status(p,a) (p)->lpVtbl->get_status(p,a)
#define IHTMLWindow2_setTimeout(p,a,b,c,d) (p)->lpVtbl->setTimeout(p,a,b,c,d)
#define IHTMLWindow2_clearTimeout(p,a) (p)->lpVtbl->clearTimeout(p,a)
#define IHTMLWindow2_alert(p,a) (p)->lpVtbl->alert(p,a)
#define IHTMLWindow2_confirm(p,a,b) (p)->lpVtbl->confirm(p,a,b)
#define IHTMLWindow2_prompt(p,a,b,c) (p)->lpVtbl->prompt(p,a,b,c)
#define IHTMLWindow2_get_Image(p,a) (p)->lpVtbl->get_Image(p,a)
#define IHTMLWindow2_get_location(p,a) (p)->lpVtbl->get_location(p,a)
#define IHTMLWindow2_get_history(p,a) (p)->lpVtbl->get_history(p,a)
#define IHTMLWindow2_close(p) (p)->lpVtbl->close(p)
#define IHTMLWindow2_put_opener(p,a) (p)->lpVtbl->put_opener(p,a)
#define IHTMLWindow2_get_opener(p,a) (p)->lpVtbl->get_opener(p,a)
#define IHTMLWindow2_get_navigator(p,a) (p)->lpVtbl->get_navigator(p,a)
#define IHTMLWindow2_put_name(p,a) (p)->lpVtbl->put_name(p,a)
#define IHTMLWindow2_get_name(p,a) (p)->lpVtbl->get_name(p,a)
#define IHTMLWindow2_get_parent(p,a) (p)->lpVtbl->get_parent(p,a)
#define IHTMLWindow2_open(p,a,b,c,d,e) (p)->lpVtbl->open(p,a,b,c,d,e)
#define IHTMLWindow2_get_self(p,a) (p)->lpVtbl->get_self(p,a)
#define IHTMLWindow2_get_top(p,a) (p)->lpVtbl->get_top(p,a)
#define IHTMLWindow2_get_window(p,a) (p)->lpVtbl->get_window(p,a)
#define IHTMLWindow2_navigate(p,a) (p)->lpVtbl->navigate(p,a)
#define IHTMLWindow2_put_onfocus(p,a) (p)->lpVtbl->put_onfocus(p,a)
#define IHTMLWindow2_get_onfocus(p,a) (p)->lpVtbl->get_onfocus(p,a)
#define IHTMLWindow2_put_onblur(p,a) (p)->lpVtbl->put_onblur(p,a)
#define IHTMLWindow2_get_onblur(p,a) (p)->lpVtbl->get_onblur(p,a)
#define IHTMLWindow2_put_onload(p,a) (p)->lpVtbl->put_onload(p,a)
#define IHTMLWindow2_get_onload(p,a) (p)->lpVtbl->get_onload(p,a)
#define IHTMLWindow2_put_onbeforeunload(p,a) (p)->lpVtbl->put_onbeforeunload(p,a)
#define IHTMLWindow2_get_onbeforeunload(p,a) (p)->lpVtbl->get_onbeforeunload(p,a)
#define IHTMLWindow2_put_onunload(p,a) (p)->lpVtbl->put_onunload(p,a)
#define IHTMLWindow2_get_onunload(p,a) (p)->lpVtbl->get_onunload(p,a)
#define IHTMLWindow2_put_onhelp(p,a) (p)->lpVtbl->put_onhelp(p,a)
#define IHTMLWindow2_get_onhelp(p,a) (p)->lpVtbl->get_onhelp(p,a)
#define IHTMLWindow2_put_onerror(p,a) (p)->lpVtbl->put_onerror(p,a)
#define IHTMLWindow2_get_onerror(p,a) (p)->lpVtbl->get_onerror(p,a)
#define IHTMLWindow2_put_onresize(p,a) (p)->lpVtbl->put_onresize(p,a)
#define IHTMLWindow2_get_onresize(p,a) (p)->lpVtbl->get_onresize(p,a)
#define IHTMLWindow2_put_onscroll(p,a) (p)->lpVtbl->put_onscroll(p,a)
#define IHTMLWindow2_get_onscroll(p,a) (p)->lpVtbl->get_onscroll(p,a)
#define IHTMLWindow2_get_document(p,a) (p)->lpVtbl->get_document(p,a)
#define IHTMLWindow2_get_event(p,a) (p)->lpVtbl->get_event(p,a)
#define IHTMLWindow2_get__newEnum(p,a) (p)->lpVtbl->get__newEnum(p,a)
#define IHTMLWindow2_showModalDialog(p,a,b,c,d) (p)->lpVtbl->showModalDialog(p,a,b,c,d)
#define IHTMLWindow2_showHelp(p,a,b,c) (p)->lpVtbl->showHelp(p,a,b,c)
#define IHTMLWindow2_get_screen(p,a) (p)->lpVtbl->get_screen(p,a)
#define IHTMLWindow2_get_Option(p,a) (p)->lpVtbl->get_Option(p,a)
#define IHTMLWindow2_focus(p) (p)->lpVtbl->focus(p)
#define IHTMLWindow2_get_closed(p,a) (p)->lpVtbl->get_closed(p,a)
#define IHTMLWindow2_blur(p) (p)->lpVtbl->blur(p)
#define IHTMLWindow2_scroll(p,a,b) (p)->lpVtbl->scroll(p,a,b)
#define IHTMLWindow2_get_clientInformation(p,a) (p)->lpVtbl->get_clientInformation(p,a)
#define IHTMLWindow2_setInterval(p,a,b,c,d) (p)->lpVtbl->setInterval(p,a,b,c,d)
#define IHTMLWindow2_clearInterval(p,a) (p)->lpVtbl->clearInterval(p,a)
#define IHTMLWindow2_put_offscreenBuffering(p,a) (p)->lpVtbl->put_offscreenBuffering(p,a)
#define IHTMLWindow2_get_offscreenBuffering(p,a) (p)->lpVtbl->get_offscreenBuffering(p,a)
#define IHTMLWindow2_execScript(p,a,b,c) (p)->lpVtbl->execScript(p,a,b,c)
#define IHTMLWindow2_toString(p,a) (p)->lpVtbl->toString(p,a)
#define IHTMLWindow2_scrollBy(p,a,b) (p)->lpVtbl->scrollBy(p,a,b)
#define IHTMLWindow2_scrollTo(p,a,b) (p)->lpVtbl->scrollTo(p,a,b)
#define IHTMLWindow2_moveTo(p,a,b) (p)->lpVtbl->moveTo(p,a,b)
#define IHTMLWindow2_moveBy(p,a,b) (p)->lpVtbl->moveBy(p,a,b)
#define IHTMLWindow2_resizeTo(p,a,b) (p)->lpVtbl->resizeTo(p,a,b)
#define IHTMLWindow2_resizeBy(p,a,b) (p)->lpVtbl->resizeBy(p,a,b)
#define IHTMLWindow2_get_external(p,a) (p)->lpVtbl->get_external(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLWindow2_get_frames_Proxy(
    IHTMLWindow2* This,
    IHTMLFramesCollection2 **p);
void __RPC_STUB IHTMLWindow2_get_frames_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_defaultStatus_Proxy(
    IHTMLWindow2* This,
    BSTR v);
void __RPC_STUB IHTMLWindow2_put_defaultStatus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_defaultStatus_Proxy(
    IHTMLWindow2* This,
    BSTR *p);
void __RPC_STUB IHTMLWindow2_get_defaultStatus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_status_Proxy(
    IHTMLWindow2* This,
    BSTR v);
void __RPC_STUB IHTMLWindow2_put_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_status_Proxy(
    IHTMLWindow2* This,
    BSTR *p);
void __RPC_STUB IHTMLWindow2_get_status_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_setTimeout_Proxy(
    IHTMLWindow2* This,
    BSTR expression,
    long msec,
    VARIANT *language,
    long *timerID);
void __RPC_STUB IHTMLWindow2_setTimeout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_clearTimeout_Proxy(
    IHTMLWindow2* This,
    long timerID);
void __RPC_STUB IHTMLWindow2_clearTimeout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_alert_Proxy(
    IHTMLWindow2* This,
    BSTR message);
void __RPC_STUB IHTMLWindow2_alert_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_confirm_Proxy(
    IHTMLWindow2* This,
    BSTR message,
    VARIANT_BOOL *confirmed);
void __RPC_STUB IHTMLWindow2_confirm_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_prompt_Proxy(
    IHTMLWindow2* This,
    BSTR message,
    BSTR defstr,
    VARIANT *textdata);
void __RPC_STUB IHTMLWindow2_prompt_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_Image_Proxy(
    IHTMLWindow2* This,
    IHTMLImageElementFactory **p);
void __RPC_STUB IHTMLWindow2_get_Image_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_location_Proxy(
    IHTMLWindow2* This,
    IHTMLLocation **p);
void __RPC_STUB IHTMLWindow2_get_location_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_history_Proxy(
    IHTMLWindow2* This,
    IOmHistory **p);
void __RPC_STUB IHTMLWindow2_get_history_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_close_Proxy(
    IHTMLWindow2* This);
void __RPC_STUB IHTMLWindow2_close_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_opener_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_opener_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_opener_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_opener_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_navigator_Proxy(
    IHTMLWindow2* This,
    IOmNavigator **p);
void __RPC_STUB IHTMLWindow2_get_navigator_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_name_Proxy(
    IHTMLWindow2* This,
    BSTR v);
void __RPC_STUB IHTMLWindow2_put_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_name_Proxy(
    IHTMLWindow2* This,
    BSTR *p);
void __RPC_STUB IHTMLWindow2_get_name_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_parent_Proxy(
    IHTMLWindow2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLWindow2_get_parent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_open_Proxy(
    IHTMLWindow2* This,
    BSTR url,
    BSTR name,
    BSTR features,
    VARIANT_BOOL replace,
    IHTMLWindow2 **pomWindowResult);
void __RPC_STUB IHTMLWindow2_open_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_self_Proxy(
    IHTMLWindow2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLWindow2_get_self_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_top_Proxy(
    IHTMLWindow2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLWindow2_get_top_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_window_Proxy(
    IHTMLWindow2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLWindow2_get_window_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_navigate_Proxy(
    IHTMLWindow2* This,
    BSTR url);
void __RPC_STUB IHTMLWindow2_navigate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onfocus_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onfocus_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onblur_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onblur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onblur_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onblur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onload_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onload_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onbeforeunload_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onbeforeunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onbeforeunload_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onbeforeunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onunload_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onunload_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onunload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onhelp_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onhelp_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onerror_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onerror_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onerror_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onresize_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onresize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onresize_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onresize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_onscroll_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_onscroll_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_onscroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_document_Proxy(
    IHTMLWindow2* This,
    IHTMLDocument2 **p);
void __RPC_STUB IHTMLWindow2_get_document_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_event_Proxy(
    IHTMLWindow2* This,
    IHTMLEventObj **p);
void __RPC_STUB IHTMLWindow2_get_event_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get__newEnum_Proxy(
    IHTMLWindow2* This,
    IUnknown **p);
void __RPC_STUB IHTMLWindow2_get__newEnum_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_showModalDialog_Proxy(
    IHTMLWindow2* This,
    BSTR dialog,
    VARIANT *varArgIn,
    VARIANT *varOptions,
    VARIANT *varArgOut);
void __RPC_STUB IHTMLWindow2_showModalDialog_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_showHelp_Proxy(
    IHTMLWindow2* This,
    BSTR helpURL,
    VARIANT helpArg,
    BSTR features);
void __RPC_STUB IHTMLWindow2_showHelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_screen_Proxy(
    IHTMLWindow2* This,
    IHTMLScreen **p);
void __RPC_STUB IHTMLWindow2_get_screen_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_Option_Proxy(
    IHTMLWindow2* This,
    IHTMLOptionElementFactory **p);
void __RPC_STUB IHTMLWindow2_get_Option_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_focus_Proxy(
    IHTMLWindow2* This);
void __RPC_STUB IHTMLWindow2_focus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_closed_Proxy(
    IHTMLWindow2* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLWindow2_get_closed_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_blur_Proxy(
    IHTMLWindow2* This);
void __RPC_STUB IHTMLWindow2_blur_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_scroll_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_scroll_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_clientInformation_Proxy(
    IHTMLWindow2* This,
    IOmNavigator **p);
void __RPC_STUB IHTMLWindow2_get_clientInformation_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_setInterval_Proxy(
    IHTMLWindow2* This,
    BSTR expression,
    long msec,
    VARIANT *language,
    long *timerID);
void __RPC_STUB IHTMLWindow2_setInterval_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_clearInterval_Proxy(
    IHTMLWindow2* This,
    long timerID);
void __RPC_STUB IHTMLWindow2_clearInterval_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_put_offscreenBuffering_Proxy(
    IHTMLWindow2* This,
    VARIANT v);
void __RPC_STUB IHTMLWindow2_put_offscreenBuffering_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_offscreenBuffering_Proxy(
    IHTMLWindow2* This,
    VARIANT *p);
void __RPC_STUB IHTMLWindow2_get_offscreenBuffering_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_execScript_Proxy(
    IHTMLWindow2* This,
    BSTR scode,
    BSTR language,
    VARIANT *pvarRet);
void __RPC_STUB IHTMLWindow2_execScript_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_toString_Proxy(
    IHTMLWindow2* This,
    BSTR *String);
void __RPC_STUB IHTMLWindow2_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_scrollBy_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_scrollBy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_scrollTo_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_scrollTo_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_moveTo_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_moveTo_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_moveBy_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_moveBy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_resizeTo_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_resizeTo_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_resizeBy_Proxy(
    IHTMLWindow2* This,
    long x,
    long y);
void __RPC_STUB IHTMLWindow2_resizeBy_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLWindow2_get_external_Proxy(
    IHTMLWindow2* This,
    IDispatch **p);
void __RPC_STUB IHTMLWindow2_get_external_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLWindow2_INTERFACE_DEFINED__ */

#ifndef __HTMLDocumentEvents2_FWD_DEFINED__
#define __HTMLDocumentEvents2_FWD_DEFINED__
typedef interface HTMLDocumentEvents2 HTMLDocumentEvents2;
#endif

/*****************************************************************************
 * HTMLDocumentEvents2 dispinterface
 */
#ifndef __HTMLDocumentEvents2_DISPINTERFACE_DEFINED__
#define __HTMLDocumentEvents2_DISPINTERFACE_DEFINED__

DEFINE_GUID(DIID_HTMLDocumentEvents2, 0x3050f613, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface HTMLDocumentEvents2 : public IDispatch
{
};
#else
typedef struct HTMLDocumentEvents2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        HTMLDocumentEvents2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        HTMLDocumentEvents2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        HTMLDocumentEvents2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        HTMLDocumentEvents2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        HTMLDocumentEvents2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        HTMLDocumentEvents2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        HTMLDocumentEvents2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    END_INTERFACE
} HTMLDocumentEvents2Vtbl;
interface HTMLDocumentEvents2 {
    CONST_VTBL HTMLDocumentEvents2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define HTMLDocumentEvents2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define HTMLDocumentEvents2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define HTMLDocumentEvents2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define HTMLDocumentEvents2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define HTMLDocumentEvents2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define HTMLDocumentEvents2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define HTMLDocumentEvents2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
#endif

#endif

#endif  /* __HTMLDocumentEvents2_DISPINTERFACE_DEFINED__ */

#ifndef __HTMLDocumentEvents_FWD_DEFINED__
#define __HTMLDocumentEvents_FWD_DEFINED__
typedef interface HTMLDocumentEvents HTMLDocumentEvents;
#endif

/*****************************************************************************
 * HTMLDocumentEvents dispinterface
 */
#ifndef __HTMLDocumentEvents_DISPINTERFACE_DEFINED__
#define __HTMLDocumentEvents_DISPINTERFACE_DEFINED__

DEFINE_GUID(DIID_HTMLDocumentEvents, 0x3050f260, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface HTMLDocumentEvents : public IDispatch
{
};
#else
typedef struct HTMLDocumentEventsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        HTMLDocumentEvents* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        HTMLDocumentEvents* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        HTMLDocumentEvents* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        HTMLDocumentEvents* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        HTMLDocumentEvents* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        HTMLDocumentEvents* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        HTMLDocumentEvents* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    END_INTERFACE
} HTMLDocumentEventsVtbl;
interface HTMLDocumentEvents {
    CONST_VTBL HTMLDocumentEventsVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define HTMLDocumentEvents_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define HTMLDocumentEvents_AddRef(p) (p)->lpVtbl->AddRef(p)
#define HTMLDocumentEvents_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define HTMLDocumentEvents_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define HTMLDocumentEvents_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define HTMLDocumentEvents_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define HTMLDocumentEvents_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
#endif

#endif

#endif  /* __HTMLDocumentEvents_DISPINTERFACE_DEFINED__ */

#ifndef __HTMLTextContainerEvents_FWD_DEFINED__
#define __HTMLTextContainerEvents_FWD_DEFINED__
typedef interface HTMLTextContainerEvents HTMLTextContainerEvents;
#endif

/*****************************************************************************
 * HTMLTextContainerEvents dispinterface
 */
#ifndef __HTMLTextContainerEvents_DISPINTERFACE_DEFINED__
#define __HTMLTextContainerEvents_DISPINTERFACE_DEFINED__

DEFINE_GUID(DIID_HTMLTextContainerEvents, 0x1ff6aa72, 0x5842, 0x11cf, 0xa7,0x07, 0x00,0xaa,0x00,0xc0,0x09,0x8d);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface HTMLTextContainerEvents : public IDispatch
{
};
#else
typedef struct HTMLTextContainerEventsVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        HTMLTextContainerEvents* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        HTMLTextContainerEvents* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        HTMLTextContainerEvents* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        HTMLTextContainerEvents* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        HTMLTextContainerEvents* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        HTMLTextContainerEvents* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        HTMLTextContainerEvents* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    END_INTERFACE
} HTMLTextContainerEventsVtbl;
interface HTMLTextContainerEvents {
    CONST_VTBL HTMLTextContainerEventsVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define HTMLTextContainerEvents_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define HTMLTextContainerEvents_AddRef(p) (p)->lpVtbl->AddRef(p)
#define HTMLTextContainerEvents_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define HTMLTextContainerEvents_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define HTMLTextContainerEvents_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define HTMLTextContainerEvents_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define HTMLTextContainerEvents_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
#endif

#endif

#endif  /* __HTMLTextContainerEvents_DISPINTERFACE_DEFINED__ */

#ifndef __IHTMLDocument_FWD_DEFINED__
#define __IHTMLDocument_FWD_DEFINED__
typedef interface IHTMLDocument IHTMLDocument;
#endif

/*****************************************************************************
 * IHTMLDocument interface
 */
#ifndef __IHTMLDocument_INTERFACE_DEFINED__
#define __IHTMLDocument_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDocument, 0x626fc520, 0xa41e, 0x11cf, 0xa7,0x31, 0x00,0xa0,0xc9,0x08,0x26,0x37);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDocument : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_Script(
        IDispatch **p) = 0;

};
#else
typedef struct IHTMLDocumentVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDocument* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDocument* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDocument* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDocument* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDocument* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDocument* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDocument* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDocument methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Script)(
        IHTMLDocument* This,
        IDispatch **p);

    END_INTERFACE
} IHTMLDocumentVtbl;
interface IHTMLDocument {
    CONST_VTBL IHTMLDocumentVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDocument_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDocument_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDocument_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDocument_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDocument_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDocument_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDocument_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDocument methods ***/
#define IHTMLDocument_get_Script(p,a) (p)->lpVtbl->get_Script(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDocument_get_Script_Proxy(
    IHTMLDocument* This,
    IDispatch **p);
void __RPC_STUB IHTMLDocument_get_Script_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDocument_INTERFACE_DEFINED__ */

/*****************************************************************************
 * IHTMLDocument2 interface
 */
#ifndef __IHTMLDocument2_INTERFACE_DEFINED__
#define __IHTMLDocument2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDocument2, 0x332c4425, 0x26cb, 0x11d0, 0xb4,0x83, 0x00,0xc0,0x4f,0xd9,0x01,0x19);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDocument2 : public IHTMLDocument
{
    virtual HRESULT STDMETHODCALLTYPE get_all(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_body(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_activeElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_images(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_applets(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_links(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_forms(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_anchors(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_title(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_title(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_scripts(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_designMode(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_designMode(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_selection(
        IHTMLSelectionObject **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyState(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_frames(
        IHTMLFramesCollection2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_embeds(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_plugins(
        IHTMLElementCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_alinkColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_alinkColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_bgColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_bgColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_fgColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fgColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_linkColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_linkColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_vlinkColor(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_vlinkColor(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_referrer(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_location(
        IHTMLLocation **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_lastModified(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_URL(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_URL(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_domain(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_domain(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_cookie(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_cookie(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_expando(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_expando(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_charset(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_charset(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_defaultCharset(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_defaultCharset(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_mimeType(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileSize(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileCreatedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileModifiedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_fileUpdatedDate(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_security(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_protocol(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_nameProp(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE write(
        SAFEARRAY *psarray) = 0;

    virtual HRESULT STDMETHODCALLTYPE writeln(
        SAFEARRAY *psarray) = 0;

    virtual HRESULT STDMETHODCALLTYPE open(
        BSTR url,
        VARIANT name,
        VARIANT features,
        VARIANT replace,
        IDispatch **pomWindowResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE close(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE clear(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandSupported(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandEnabled(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandState(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandIndeterm(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandText(
        BSTR cmdID,
        BSTR *pcmdText) = 0;

    virtual HRESULT STDMETHODCALLTYPE queryCommandValue(
        BSTR cmdID,
        VARIANT *pcmdValue) = 0;

    virtual HRESULT STDMETHODCALLTYPE execCommand(
        BSTR cmdID,
        VARIANT_BOOL showUI,
        VARIANT value,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE execCommandShowHelp(
        BSTR cmdID,
        VARIANT_BOOL *pfRet) = 0;

    virtual HRESULT STDMETHODCALLTYPE createElement(
        BSTR eTag,
        IHTMLElement **newElem) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onhelp(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onhelp(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onclick(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onclick(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondblclick(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondblclick(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeyup(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeyup(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeydown(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeydown(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onkeypress(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onkeypress(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseup(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseup(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmousedown(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmousedown(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmousemove(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmousemove(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseout(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseout(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onmouseover(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmouseover(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onreadystatechange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onreadystatechange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onafterupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onafterupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowexit(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowexit(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowenter(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowenter(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondragstart(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondragstart(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselectstart(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselectstart(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE elementFromPoint(
        long x,
        long y,
        IHTMLElement **elementHit) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentWindow(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_styleSheets(
        IHTMLStyleSheetsCollection **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onerrorupdate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onerrorupdate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE toString(
        BSTR *String) = 0;

    virtual HRESULT STDMETHODCALLTYPE createStyleSheet(
        BSTR bstrHref,
        long lIndex,
        IHTMLStyleSheet **ppnewStyleSheet) = 0;

};
#else
typedef struct IHTMLDocument2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDocument2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDocument2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDocument2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDocument2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDocument2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDocument2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDocument2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDocument methods ***/
    HRESULT (STDMETHODCALLTYPE *get_Script)(
        IHTMLDocument2* This,
        IDispatch **p);

    /*** IHTMLDocument2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_all)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_body)(
        IHTMLDocument2* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_activeElement)(
        IHTMLDocument2* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_images)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_applets)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_links)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_forms)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_anchors)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_title)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_title)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_scripts)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_designMode)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_designMode)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_selection)(
        IHTMLDocument2* This,
        IHTMLSelectionObject **p);

    HRESULT (STDMETHODCALLTYPE *get_readyState)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_frames)(
        IHTMLDocument2* This,
        IHTMLFramesCollection2 **p);

    HRESULT (STDMETHODCALLTYPE *get_embeds)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *get_plugins)(
        IHTMLDocument2* This,
        IHTMLElementCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_alinkColor)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_alinkColor)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_bgColor)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_bgColor)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_fgColor)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_fgColor)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_linkColor)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_linkColor)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_vlinkColor)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_vlinkColor)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_referrer)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_location)(
        IHTMLDocument2* This,
        IHTMLLocation **p);

    HRESULT (STDMETHODCALLTYPE *get_lastModified)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_URL)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_URL)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_domain)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_domain)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_cookie)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_cookie)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_expando)(
        IHTMLDocument2* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_expando)(
        IHTMLDocument2* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_charset)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_charset)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_defaultCharset)(
        IHTMLDocument2* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_defaultCharset)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_mimeType)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileSize)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileCreatedDate)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileModifiedDate)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_fileUpdatedDate)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_security)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_protocol)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_nameProp)(
        IHTMLDocument2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *write)(
        IHTMLDocument2* This,
        SAFEARRAY *psarray);

    HRESULT (STDMETHODCALLTYPE *writeln)(
        IHTMLDocument2* This,
        SAFEARRAY *psarray);

    HRESULT (STDMETHODCALLTYPE *open)(
        IHTMLDocument2* This,
        BSTR url,
        VARIANT name,
        VARIANT features,
        VARIANT replace,
        IDispatch **pomWindowResult);

    HRESULT (STDMETHODCALLTYPE *close)(
        IHTMLDocument2* This);

    HRESULT (STDMETHODCALLTYPE *clear)(
        IHTMLDocument2* This);

    HRESULT (STDMETHODCALLTYPE *queryCommandSupported)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandEnabled)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandState)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandIndeterm)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *queryCommandText)(
        IHTMLDocument2* This,
        BSTR cmdID,
        BSTR *pcmdText);

    HRESULT (STDMETHODCALLTYPE *queryCommandValue)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT *pcmdValue);

    HRESULT (STDMETHODCALLTYPE *execCommand)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL showUI,
        VARIANT value,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *execCommandShowHelp)(
        IHTMLDocument2* This,
        BSTR cmdID,
        VARIANT_BOOL *pfRet);

    HRESULT (STDMETHODCALLTYPE *createElement)(
        IHTMLDocument2* This,
        BSTR eTag,
        IHTMLElement **newElem);

    HRESULT (STDMETHODCALLTYPE *put_onhelp)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onhelp)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onclick)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onclick)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondblclick)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondblclick)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeyup)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeyup)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeydown)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeydown)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onkeypress)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onkeypress)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseup)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseup)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmousedown)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmousedown)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmousemove)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmousemove)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseout)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseout)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onmouseover)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmouseover)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onreadystatechange)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onreadystatechange)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onafterupdate)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onafterupdate)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowexit)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowexit)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowenter)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowenter)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondragstart)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondragstart)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onselectstart)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselectstart)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *elementFromPoint)(
        IHTMLDocument2* This,
        long x,
        long y,
        IHTMLElement **elementHit);

    HRESULT (STDMETHODCALLTYPE *get_parentWindow)(
        IHTMLDocument2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *get_styleSheets)(
        IHTMLDocument2* This,
        IHTMLStyleSheetsCollection **p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeupdate)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeupdate)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onerrorupdate)(
        IHTMLDocument2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onerrorupdate)(
        IHTMLDocument2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *toString)(
        IHTMLDocument2* This,
        BSTR *String);

    HRESULT (STDMETHODCALLTYPE *createStyleSheet)(
        IHTMLDocument2* This,
        BSTR bstrHref,
        long lIndex,
        IHTMLStyleSheet **ppnewStyleSheet);

    END_INTERFACE
} IHTMLDocument2Vtbl;
interface IHTMLDocument2 {
    CONST_VTBL IHTMLDocument2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDocument2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDocument2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDocument2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDocument2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDocument2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDocument2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDocument2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDocument methods ***/
#define IHTMLDocument2_get_Script(p,a) (p)->lpVtbl->get_Script(p,a)
/*** IHTMLDocument2 methods ***/
#define IHTMLDocument2_get_all(p,a) (p)->lpVtbl->get_all(p,a)
#define IHTMLDocument2_get_body(p,a) (p)->lpVtbl->get_body(p,a)
#define IHTMLDocument2_get_activeElement(p,a) (p)->lpVtbl->get_activeElement(p,a)
#define IHTMLDocument2_get_images(p,a) (p)->lpVtbl->get_images(p,a)
#define IHTMLDocument2_get_applets(p,a) (p)->lpVtbl->get_applets(p,a)
#define IHTMLDocument2_get_links(p,a) (p)->lpVtbl->get_links(p,a)
#define IHTMLDocument2_get_forms(p,a) (p)->lpVtbl->get_forms(p,a)
#define IHTMLDocument2_get_anchors(p,a) (p)->lpVtbl->get_anchors(p,a)
#define IHTMLDocument2_put_title(p,a) (p)->lpVtbl->put_title(p,a)
#define IHTMLDocument2_get_title(p,a) (p)->lpVtbl->get_title(p,a)
#define IHTMLDocument2_get_scripts(p,a) (p)->lpVtbl->get_scripts(p,a)
#define IHTMLDocument2_put_designMode(p,a) (p)->lpVtbl->put_designMode(p,a)
#define IHTMLDocument2_get_designMode(p,a) (p)->lpVtbl->get_designMode(p,a)
#define IHTMLDocument2_get_selection(p,a) (p)->lpVtbl->get_selection(p,a)
#define IHTMLDocument2_get_readyState(p,a) (p)->lpVtbl->get_readyState(p,a)
#define IHTMLDocument2_get_frames(p,a) (p)->lpVtbl->get_frames(p,a)
#define IHTMLDocument2_get_embeds(p,a) (p)->lpVtbl->get_embeds(p,a)
#define IHTMLDocument2_get_plugins(p,a) (p)->lpVtbl->get_plugins(p,a)
#define IHTMLDocument2_put_alinkColor(p,a) (p)->lpVtbl->put_alinkColor(p,a)
#define IHTMLDocument2_get_alinkColor(p,a) (p)->lpVtbl->get_alinkColor(p,a)
#define IHTMLDocument2_put_bgColor(p,a) (p)->lpVtbl->put_bgColor(p,a)
#define IHTMLDocument2_get_bgColor(p,a) (p)->lpVtbl->get_bgColor(p,a)
#define IHTMLDocument2_put_fgColor(p,a) (p)->lpVtbl->put_fgColor(p,a)
#define IHTMLDocument2_get_fgColor(p,a) (p)->lpVtbl->get_fgColor(p,a)
#define IHTMLDocument2_put_linkColor(p,a) (p)->lpVtbl->put_linkColor(p,a)
#define IHTMLDocument2_get_linkColor(p,a) (p)->lpVtbl->get_linkColor(p,a)
#define IHTMLDocument2_put_vlinkColor(p,a) (p)->lpVtbl->put_vlinkColor(p,a)
#define IHTMLDocument2_get_vlinkColor(p,a) (p)->lpVtbl->get_vlinkColor(p,a)
#define IHTMLDocument2_get_referrer(p,a) (p)->lpVtbl->get_referrer(p,a)
#define IHTMLDocument2_get_location(p,a) (p)->lpVtbl->get_location(p,a)
#define IHTMLDocument2_get_lastModified(p,a) (p)->lpVtbl->get_lastModified(p,a)
#define IHTMLDocument2_put_URL(p,a) (p)->lpVtbl->put_URL(p,a)
#define IHTMLDocument2_get_URL(p,a) (p)->lpVtbl->get_URL(p,a)
#define IHTMLDocument2_put_domain(p,a) (p)->lpVtbl->put_domain(p,a)
#define IHTMLDocument2_get_domain(p,a) (p)->lpVtbl->get_domain(p,a)
#define IHTMLDocument2_put_cookie(p,a) (p)->lpVtbl->put_cookie(p,a)
#define IHTMLDocument2_get_cookie(p,a) (p)->lpVtbl->get_cookie(p,a)
#define IHTMLDocument2_put_expando(p,a) (p)->lpVtbl->put_expando(p,a)
#define IHTMLDocument2_get_expando(p,a) (p)->lpVtbl->get_expando(p,a)
#define IHTMLDocument2_put_charset(p,a) (p)->lpVtbl->put_charset(p,a)
#define IHTMLDocument2_get_charset(p,a) (p)->lpVtbl->get_charset(p,a)
#define IHTMLDocument2_put_defaultCharset(p,a) (p)->lpVtbl->put_defaultCharset(p,a)
#define IHTMLDocument2_get_defaultCharset(p,a) (p)->lpVtbl->get_defaultCharset(p,a)
#define IHTMLDocument2_get_mimeType(p,a) (p)->lpVtbl->get_mimeType(p,a)
#define IHTMLDocument2_get_fileSize(p,a) (p)->lpVtbl->get_fileSize(p,a)
#define IHTMLDocument2_get_fileCreatedDate(p,a) (p)->lpVtbl->get_fileCreatedDate(p,a)
#define IHTMLDocument2_get_fileModifiedDate(p,a) (p)->lpVtbl->get_fileModifiedDate(p,a)
#define IHTMLDocument2_get_fileUpdatedDate(p,a) (p)->lpVtbl->get_fileUpdatedDate(p,a)
#define IHTMLDocument2_get_security(p,a) (p)->lpVtbl->get_security(p,a)
#define IHTMLDocument2_get_protocol(p,a) (p)->lpVtbl->get_protocol(p,a)
#define IHTMLDocument2_get_nameProp(p,a) (p)->lpVtbl->get_nameProp(p,a)
#define IHTMLDocument2_write(p,a) (p)->lpVtbl->write(p,a)
#define IHTMLDocument2_writeln(p,a) (p)->lpVtbl->writeln(p,a)
#define IHTMLDocument2_open(p,a,b,c,d,e) (p)->lpVtbl->open(p,a,b,c,d,e)
#define IHTMLDocument2_close(p) (p)->lpVtbl->close(p)
#define IHTMLDocument2_clear(p) (p)->lpVtbl->clear(p)
#define IHTMLDocument2_queryCommandSupported(p,a,b) (p)->lpVtbl->queryCommandSupported(p,a,b)
#define IHTMLDocument2_queryCommandEnabled(p,a,b) (p)->lpVtbl->queryCommandEnabled(p,a,b)
#define IHTMLDocument2_queryCommandState(p,a,b) (p)->lpVtbl->queryCommandState(p,a,b)
#define IHTMLDocument2_queryCommandIndeterm(p,a,b) (p)->lpVtbl->queryCommandIndeterm(p,a,b)
#define IHTMLDocument2_queryCommandText(p,a,b) (p)->lpVtbl->queryCommandText(p,a,b)
#define IHTMLDocument2_queryCommandValue(p,a,b) (p)->lpVtbl->queryCommandValue(p,a,b)
#define IHTMLDocument2_execCommand(p,a,b,c,d) (p)->lpVtbl->execCommand(p,a,b,c,d)
#define IHTMLDocument2_execCommandShowHelp(p,a,b) (p)->lpVtbl->execCommandShowHelp(p,a,b)
#define IHTMLDocument2_createElement(p,a,b) (p)->lpVtbl->createElement(p,a,b)
#define IHTMLDocument2_put_onhelp(p,a) (p)->lpVtbl->put_onhelp(p,a)
#define IHTMLDocument2_get_onhelp(p,a) (p)->lpVtbl->get_onhelp(p,a)
#define IHTMLDocument2_put_onclick(p,a) (p)->lpVtbl->put_onclick(p,a)
#define IHTMLDocument2_get_onclick(p,a) (p)->lpVtbl->get_onclick(p,a)
#define IHTMLDocument2_put_ondblclick(p,a) (p)->lpVtbl->put_ondblclick(p,a)
#define IHTMLDocument2_get_ondblclick(p,a) (p)->lpVtbl->get_ondblclick(p,a)
#define IHTMLDocument2_put_onkeyup(p,a) (p)->lpVtbl->put_onkeyup(p,a)
#define IHTMLDocument2_get_onkeyup(p,a) (p)->lpVtbl->get_onkeyup(p,a)
#define IHTMLDocument2_put_onkeydown(p,a) (p)->lpVtbl->put_onkeydown(p,a)
#define IHTMLDocument2_get_onkeydown(p,a) (p)->lpVtbl->get_onkeydown(p,a)
#define IHTMLDocument2_put_onkeypress(p,a) (p)->lpVtbl->put_onkeypress(p,a)
#define IHTMLDocument2_get_onkeypress(p,a) (p)->lpVtbl->get_onkeypress(p,a)
#define IHTMLDocument2_put_onmouseup(p,a) (p)->lpVtbl->put_onmouseup(p,a)
#define IHTMLDocument2_get_onmouseup(p,a) (p)->lpVtbl->get_onmouseup(p,a)
#define IHTMLDocument2_put_onmousedown(p,a) (p)->lpVtbl->put_onmousedown(p,a)
#define IHTMLDocument2_get_onmousedown(p,a) (p)->lpVtbl->get_onmousedown(p,a)
#define IHTMLDocument2_put_onmousemove(p,a) (p)->lpVtbl->put_onmousemove(p,a)
#define IHTMLDocument2_get_onmousemove(p,a) (p)->lpVtbl->get_onmousemove(p,a)
#define IHTMLDocument2_put_onmouseout(p,a) (p)->lpVtbl->put_onmouseout(p,a)
#define IHTMLDocument2_get_onmouseout(p,a) (p)->lpVtbl->get_onmouseout(p,a)
#define IHTMLDocument2_put_onmouseover(p,a) (p)->lpVtbl->put_onmouseover(p,a)
#define IHTMLDocument2_get_onmouseover(p,a) (p)->lpVtbl->get_onmouseover(p,a)
#define IHTMLDocument2_put_onreadystatechange(p,a) (p)->lpVtbl->put_onreadystatechange(p,a)
#define IHTMLDocument2_get_onreadystatechange(p,a) (p)->lpVtbl->get_onreadystatechange(p,a)
#define IHTMLDocument2_put_onafterupdate(p,a) (p)->lpVtbl->put_onafterupdate(p,a)
#define IHTMLDocument2_get_onafterupdate(p,a) (p)->lpVtbl->get_onafterupdate(p,a)
#define IHTMLDocument2_put_onrowexit(p,a) (p)->lpVtbl->put_onrowexit(p,a)
#define IHTMLDocument2_get_onrowexit(p,a) (p)->lpVtbl->get_onrowexit(p,a)
#define IHTMLDocument2_put_onrowenter(p,a) (p)->lpVtbl->put_onrowenter(p,a)
#define IHTMLDocument2_get_onrowenter(p,a) (p)->lpVtbl->get_onrowenter(p,a)
#define IHTMLDocument2_put_ondragstart(p,a) (p)->lpVtbl->put_ondragstart(p,a)
#define IHTMLDocument2_get_ondragstart(p,a) (p)->lpVtbl->get_ondragstart(p,a)
#define IHTMLDocument2_put_onselectstart(p,a) (p)->lpVtbl->put_onselectstart(p,a)
#define IHTMLDocument2_get_onselectstart(p,a) (p)->lpVtbl->get_onselectstart(p,a)
#define IHTMLDocument2_elementFromPoint(p,a,b,c) (p)->lpVtbl->elementFromPoint(p,a,b,c)
#define IHTMLDocument2_get_parentWindow(p,a) (p)->lpVtbl->get_parentWindow(p,a)
#define IHTMLDocument2_get_styleSheets(p,a) (p)->lpVtbl->get_styleSheets(p,a)
#define IHTMLDocument2_put_onbeforeupdate(p,a) (p)->lpVtbl->put_onbeforeupdate(p,a)
#define IHTMLDocument2_get_onbeforeupdate(p,a) (p)->lpVtbl->get_onbeforeupdate(p,a)
#define IHTMLDocument2_put_onerrorupdate(p,a) (p)->lpVtbl->put_onerrorupdate(p,a)
#define IHTMLDocument2_get_onerrorupdate(p,a) (p)->lpVtbl->get_onerrorupdate(p,a)
#define IHTMLDocument2_toString(p,a) (p)->lpVtbl->toString(p,a)
#define IHTMLDocument2_createStyleSheet(p,a,b,c) (p)->lpVtbl->createStyleSheet(p,a,b,c)
#endif

#endif

HRESULT CALLBACK IHTMLDocument2_get_all_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_all_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_body_Proxy(
    IHTMLDocument2* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLDocument2_get_body_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_activeElement_Proxy(
    IHTMLDocument2* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLDocument2_get_activeElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_images_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_images_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_applets_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_applets_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_links_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_links_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_forms_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_forms_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_anchors_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_anchors_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_title_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_title_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_title_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_scripts_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_scripts_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_designMode_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_designMode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_designMode_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_designMode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_selection_Proxy(
    IHTMLDocument2* This,
    IHTMLSelectionObject **p);
void __RPC_STUB IHTMLDocument2_get_selection_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_readyState_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_readyState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_frames_Proxy(
    IHTMLDocument2* This,
    IHTMLFramesCollection2 **p);
void __RPC_STUB IHTMLDocument2_get_frames_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_embeds_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_embeds_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_plugins_Proxy(
    IHTMLDocument2* This,
    IHTMLElementCollection **p);
void __RPC_STUB IHTMLDocument2_get_plugins_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_alinkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_alinkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_alinkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_alinkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_bgColor_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_bgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_bgColor_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_bgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_fgColor_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_fgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_fgColor_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_fgColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_linkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_linkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_linkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_linkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_vlinkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_vlinkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_vlinkColor_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_vlinkColor_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_referrer_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_referrer_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_location_Proxy(
    IHTMLDocument2* This,
    IHTMLLocation **p);
void __RPC_STUB IHTMLDocument2_get_location_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_lastModified_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_lastModified_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_URL_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_URL_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_URL_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_URL_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_domain_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_domain_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_domain_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_domain_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_cookie_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_cookie_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_cookie_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_cookie_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_expando_Proxy(
    IHTMLDocument2* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLDocument2_put_expando_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_expando_Proxy(
    IHTMLDocument2* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLDocument2_get_expando_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_charset_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_charset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_charset_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_charset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_defaultCharset_Proxy(
    IHTMLDocument2* This,
    BSTR v);
void __RPC_STUB IHTMLDocument2_put_defaultCharset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_defaultCharset_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_defaultCharset_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_mimeType_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_mimeType_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_fileSize_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_fileSize_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_fileCreatedDate_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_fileCreatedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_fileModifiedDate_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_fileModifiedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_fileUpdatedDate_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_fileUpdatedDate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_security_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_security_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_protocol_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_protocol_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_nameProp_Proxy(
    IHTMLDocument2* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument2_get_nameProp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_write_Proxy(
    IHTMLDocument2* This,
    SAFEARRAY *psarray);
void __RPC_STUB IHTMLDocument2_write_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_writeln_Proxy(
    IHTMLDocument2* This,
    SAFEARRAY *psarray);
void __RPC_STUB IHTMLDocument2_writeln_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_open_Proxy(
    IHTMLDocument2* This,
    BSTR url,
    VARIANT name,
    VARIANT features,
    VARIANT replace,
    IDispatch **pomWindowResult);
void __RPC_STUB IHTMLDocument2_open_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_close_Proxy(
    IHTMLDocument2* This);
void __RPC_STUB IHTMLDocument2_close_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_clear_Proxy(
    IHTMLDocument2* This);
void __RPC_STUB IHTMLDocument2_clear_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandSupported_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_queryCommandSupported_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandEnabled_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_queryCommandEnabled_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandState_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_queryCommandState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandIndeterm_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_queryCommandIndeterm_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandText_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    BSTR *pcmdText);
void __RPC_STUB IHTMLDocument2_queryCommandText_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_queryCommandValue_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT *pcmdValue);
void __RPC_STUB IHTMLDocument2_queryCommandValue_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_execCommand_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL showUI,
    VARIANT value,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_execCommand_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_execCommandShowHelp_Proxy(
    IHTMLDocument2* This,
    BSTR cmdID,
    VARIANT_BOOL *pfRet);
void __RPC_STUB IHTMLDocument2_execCommandShowHelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_createElement_Proxy(
    IHTMLDocument2* This,
    BSTR eTag,
    IHTMLElement **newElem);
void __RPC_STUB IHTMLDocument2_createElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onhelp_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onhelp_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onhelp_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onclick_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onclick_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_ondblclick_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_ondblclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_ondblclick_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_ondblclick_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onkeyup_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onkeyup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onkeyup_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onkeyup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onkeydown_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onkeydown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onkeydown_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onkeydown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onkeypress_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onkeypress_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onkeypress_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onkeypress_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onmouseup_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onmouseup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onmouseup_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onmouseup_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onmousedown_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onmousedown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onmousedown_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onmousedown_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onmousemove_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onmousemove_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onmousemove_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onmousemove_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onmouseout_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onmouseout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onmouseout_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onmouseout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onmouseover_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onmouseover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onmouseover_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onmouseover_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onreadystatechange_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onreadystatechange_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onafterupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onafterupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onafterupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onafterupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onrowexit_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onrowexit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onrowexit_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onrowexit_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onrowenter_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onrowenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onrowenter_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onrowenter_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_ondragstart_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_ondragstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_ondragstart_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_ondragstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onselectstart_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onselectstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onselectstart_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onselectstart_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_elementFromPoint_Proxy(
    IHTMLDocument2* This,
    long x,
    long y,
    IHTMLElement **elementHit);
void __RPC_STUB IHTMLDocument2_elementFromPoint_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_parentWindow_Proxy(
    IHTMLDocument2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLDocument2_get_parentWindow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_styleSheets_Proxy(
    IHTMLDocument2* This,
    IHTMLStyleSheetsCollection **p);
void __RPC_STUB IHTMLDocument2_get_styleSheets_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onbeforeupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onbeforeupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onbeforeupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onbeforeupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_put_onerrorupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument2_put_onerrorupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_get_onerrorupdate_Proxy(
    IHTMLDocument2* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument2_get_onerrorupdate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_toString_Proxy(
    IHTMLDocument2* This,
    BSTR *String);
void __RPC_STUB IHTMLDocument2_toString_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument2_createStyleSheet_Proxy(
    IHTMLDocument2* This,
    BSTR bstrHref,
    long lIndex,
    IHTMLStyleSheet **ppnewStyleSheet);
void __RPC_STUB IHTMLDocument2_createStyleSheet_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDocument2_INTERFACE_DEFINED__ */

#ifndef __IHTMLDocument3_FWD_DEFINED__
#define __IHTMLDocument3_FWD_DEFINED__
typedef interface IHTMLDocument3 IHTMLDocument3;
#endif

/*****************************************************************************
 * IHTMLDocument3 interface
 */
#ifndef __IHTMLDocument3_INTERFACE_DEFINED__
#define __IHTMLDocument3_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDocument3, 0x3050f485, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDocument3 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE releaseCapture(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE recalc(
        VARIANT_BOOL fForce) = 0;

    virtual HRESULT STDMETHODCALLTYPE createTextNode(
        BSTR text,
        IHTMLDOMNode **newTextNode) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_documentElement(
        IHTMLElement **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_uniqueID(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE attachEvent(
        BSTR event,
        IDispatch *pDisp,
        VARIANT_BOOL *pfResult) = 0;

    virtual HRESULT STDMETHODCALLTYPE detachEvent(
        BSTR event,
        IDispatch *pDisp) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowsdelete(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowsdelete(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onrowsinserted(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onrowsinserted(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncellchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncellchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondatasetchanged(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondatasetchanged(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondataavailable(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondataavailable(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondatasetcomplete(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondatasetcomplete(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onpropertychange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onpropertychange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_dir(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_dir(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncontextmenu(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncontextmenu(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onstop(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onstop(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createDocumentFragment(
        IHTMLDocument2 **pNewDoc) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_parentDocument(
        IHTMLDocument2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_enableDownload(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_enableDownload(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_baseUrl(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_baseUrl(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_childNodes(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_inheritStyleSheets(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_inheritStyleSheets(
        VARIANT_BOOL *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeeditfocus(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeeditfocus(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE getElementsByName(
        BSTR v,
        IHTMLElementCollection **pelColl) = 0;

    virtual HRESULT STDMETHODCALLTYPE getElementById(
        BSTR v,
        IHTMLElement **pel) = 0;

    virtual HRESULT STDMETHODCALLTYPE getElementsByTagName(
        BSTR v,
        IHTMLElementCollection **pelColl) = 0;

};
#else
typedef struct IHTMLDocument3Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDocument3* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDocument3* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDocument3* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDocument3* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDocument3* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDocument3* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDocument3* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDocument3 methods ***/
    HRESULT (STDMETHODCALLTYPE *releaseCapture)(
        IHTMLDocument3* This);

    HRESULT (STDMETHODCALLTYPE *recalc)(
        IHTMLDocument3* This,
        VARIANT_BOOL fForce);

    HRESULT (STDMETHODCALLTYPE *createTextNode)(
        IHTMLDocument3* This,
        BSTR text,
        IHTMLDOMNode **newTextNode);

    HRESULT (STDMETHODCALLTYPE *get_documentElement)(
        IHTMLDocument3* This,
        IHTMLElement **p);

    HRESULT (STDMETHODCALLTYPE *get_uniqueID)(
        IHTMLDocument3* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *attachEvent)(
        IHTMLDocument3* This,
        BSTR event,
        IDispatch *pDisp,
        VARIANT_BOOL *pfResult);

    HRESULT (STDMETHODCALLTYPE *detachEvent)(
        IHTMLDocument3* This,
        BSTR event,
        IDispatch *pDisp);

    HRESULT (STDMETHODCALLTYPE *put_onrowsdelete)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowsdelete)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onrowsinserted)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onrowsinserted)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_oncellchange)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncellchange)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondatasetchanged)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondatasetchanged)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondataavailable)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondataavailable)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondatasetcomplete)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondatasetcomplete)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onpropertychange)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onpropertychange)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_dir)(
        IHTMLDocument3* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_dir)(
        IHTMLDocument3* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_oncontextmenu)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncontextmenu)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onstop)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onstop)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *createDocumentFragment)(
        IHTMLDocument3* This,
        IHTMLDocument2 **pNewDoc);

    HRESULT (STDMETHODCALLTYPE *get_parentDocument)(
        IHTMLDocument3* This,
        IHTMLDocument2 **p);

    HRESULT (STDMETHODCALLTYPE *put_enableDownload)(
        IHTMLDocument3* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_enableDownload)(
        IHTMLDocument3* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_baseUrl)(
        IHTMLDocument3* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_baseUrl)(
        IHTMLDocument3* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *get_childNodes)(
        IHTMLDocument3* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *put_inheritStyleSheets)(
        IHTMLDocument3* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_inheritStyleSheets)(
        IHTMLDocument3* This,
        VARIANT_BOOL *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeeditfocus)(
        IHTMLDocument3* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeeditfocus)(
        IHTMLDocument3* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *getElementsByName)(
        IHTMLDocument3* This,
        BSTR v,
        IHTMLElementCollection **pelColl);

    HRESULT (STDMETHODCALLTYPE *getElementById)(
        IHTMLDocument3* This,
        BSTR v,
        IHTMLElement **pel);

    HRESULT (STDMETHODCALLTYPE *getElementsByTagName)(
        IHTMLDocument3* This,
        BSTR v,
        IHTMLElementCollection **pelColl);

    END_INTERFACE
} IHTMLDocument3Vtbl;
interface IHTMLDocument3 {
    CONST_VTBL IHTMLDocument3Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDocument3_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDocument3_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDocument3_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDocument3_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDocument3_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDocument3_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDocument3_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDocument3 methods ***/
#define IHTMLDocument3_releaseCapture(p) (p)->lpVtbl->releaseCapture(p)
#define IHTMLDocument3_recalc(p,a) (p)->lpVtbl->recalc(p,a)
#define IHTMLDocument3_createTextNode(p,a,b) (p)->lpVtbl->createTextNode(p,a,b)
#define IHTMLDocument3_get_documentElement(p,a) (p)->lpVtbl->get_documentElement(p,a)
#define IHTMLDocument3_get_uniqueID(p,a) (p)->lpVtbl->get_uniqueID(p,a)
#define IHTMLDocument3_attachEvent(p,a,b,c) (p)->lpVtbl->attachEvent(p,a,b,c)
#define IHTMLDocument3_detachEvent(p,a,b) (p)->lpVtbl->detachEvent(p,a,b)
#define IHTMLDocument3_put_onrowsdelete(p,a) (p)->lpVtbl->put_onrowsdelete(p,a)
#define IHTMLDocument3_get_onrowsdelete(p,a) (p)->lpVtbl->get_onrowsdelete(p,a)
#define IHTMLDocument3_put_onrowsinserted(p,a) (p)->lpVtbl->put_onrowsinserted(p,a)
#define IHTMLDocument3_get_onrowsinserted(p,a) (p)->lpVtbl->get_onrowsinserted(p,a)
#define IHTMLDocument3_put_oncellchange(p,a) (p)->lpVtbl->put_oncellchange(p,a)
#define IHTMLDocument3_get_oncellchange(p,a) (p)->lpVtbl->get_oncellchange(p,a)
#define IHTMLDocument3_put_ondatasetchanged(p,a) (p)->lpVtbl->put_ondatasetchanged(p,a)
#define IHTMLDocument3_get_ondatasetchanged(p,a) (p)->lpVtbl->get_ondatasetchanged(p,a)
#define IHTMLDocument3_put_ondataavailable(p,a) (p)->lpVtbl->put_ondataavailable(p,a)
#define IHTMLDocument3_get_ondataavailable(p,a) (p)->lpVtbl->get_ondataavailable(p,a)
#define IHTMLDocument3_put_ondatasetcomplete(p,a) (p)->lpVtbl->put_ondatasetcomplete(p,a)
#define IHTMLDocument3_get_ondatasetcomplete(p,a) (p)->lpVtbl->get_ondatasetcomplete(p,a)
#define IHTMLDocument3_put_onpropertychange(p,a) (p)->lpVtbl->put_onpropertychange(p,a)
#define IHTMLDocument3_get_onpropertychange(p,a) (p)->lpVtbl->get_onpropertychange(p,a)
#define IHTMLDocument3_put_dir(p,a) (p)->lpVtbl->put_dir(p,a)
#define IHTMLDocument3_get_dir(p,a) (p)->lpVtbl->get_dir(p,a)
#define IHTMLDocument3_put_oncontextmenu(p,a) (p)->lpVtbl->put_oncontextmenu(p,a)
#define IHTMLDocument3_get_oncontextmenu(p,a) (p)->lpVtbl->get_oncontextmenu(p,a)
#define IHTMLDocument3_put_onstop(p,a) (p)->lpVtbl->put_onstop(p,a)
#define IHTMLDocument3_get_onstop(p,a) (p)->lpVtbl->get_onstop(p,a)
#define IHTMLDocument3_createDocumentFragment(p,a) (p)->lpVtbl->createDocumentFragment(p,a)
#define IHTMLDocument3_get_parentDocument(p,a) (p)->lpVtbl->get_parentDocument(p,a)
#define IHTMLDocument3_put_enableDownload(p,a) (p)->lpVtbl->put_enableDownload(p,a)
#define IHTMLDocument3_get_enableDownload(p,a) (p)->lpVtbl->get_enableDownload(p,a)
#define IHTMLDocument3_put_baseUrl(p,a) (p)->lpVtbl->put_baseUrl(p,a)
#define IHTMLDocument3_get_baseUrl(p,a) (p)->lpVtbl->get_baseUrl(p,a)
#define IHTMLDocument3_get_childNodes(p,a) (p)->lpVtbl->get_childNodes(p,a)
#define IHTMLDocument3_put_inheritStyleSheets(p,a) (p)->lpVtbl->put_inheritStyleSheets(p,a)
#define IHTMLDocument3_get_inheritStyleSheets(p,a) (p)->lpVtbl->get_inheritStyleSheets(p,a)
#define IHTMLDocument3_put_onbeforeeditfocus(p,a) (p)->lpVtbl->put_onbeforeeditfocus(p,a)
#define IHTMLDocument3_get_onbeforeeditfocus(p,a) (p)->lpVtbl->get_onbeforeeditfocus(p,a)
#define IHTMLDocument3_getElementsByName(p,a,b) (p)->lpVtbl->getElementsByName(p,a,b)
#define IHTMLDocument3_getElementById(p,a,b) (p)->lpVtbl->getElementById(p,a,b)
#define IHTMLDocument3_getElementsByTagName(p,a,b) (p)->lpVtbl->getElementsByTagName(p,a,b)
#endif

#endif

HRESULT CALLBACK IHTMLDocument3_releaseCapture_Proxy(
    IHTMLDocument3* This);
void __RPC_STUB IHTMLDocument3_releaseCapture_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_recalc_Proxy(
    IHTMLDocument3* This,
    VARIANT_BOOL fForce);
void __RPC_STUB IHTMLDocument3_recalc_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_createTextNode_Proxy(
    IHTMLDocument3* This,
    BSTR text,
    IHTMLDOMNode **newTextNode);
void __RPC_STUB IHTMLDocument3_createTextNode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_documentElement_Proxy(
    IHTMLDocument3* This,
    IHTMLElement **p);
void __RPC_STUB IHTMLDocument3_get_documentElement_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_uniqueID_Proxy(
    IHTMLDocument3* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument3_get_uniqueID_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_attachEvent_Proxy(
    IHTMLDocument3* This,
    BSTR event,
    IDispatch *pDisp,
    VARIANT_BOOL *pfResult);
void __RPC_STUB IHTMLDocument3_attachEvent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_detachEvent_Proxy(
    IHTMLDocument3* This,
    BSTR event,
    IDispatch *pDisp);
void __RPC_STUB IHTMLDocument3_detachEvent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_onrowsdelete_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_onrowsdelete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_onrowsdelete_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_onrowsdelete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_onrowsinserted_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_onrowsinserted_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_onrowsinserted_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_onrowsinserted_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_oncellchange_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_oncellchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_oncellchange_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_oncellchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_ondatasetchanged_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_ondatasetchanged_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_ondatasetchanged_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_ondatasetchanged_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_ondataavailable_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_ondataavailable_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_ondataavailable_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_ondataavailable_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_ondatasetcomplete_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_ondatasetcomplete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_ondatasetcomplete_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_ondatasetcomplete_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_onpropertychange_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_onpropertychange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_onpropertychange_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_onpropertychange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_dir_Proxy(
    IHTMLDocument3* This,
    BSTR v);
void __RPC_STUB IHTMLDocument3_put_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_dir_Proxy(
    IHTMLDocument3* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument3_get_dir_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_oncontextmenu_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_oncontextmenu_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_oncontextmenu_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_oncontextmenu_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_onstop_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_onstop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_onstop_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_onstop_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_createDocumentFragment_Proxy(
    IHTMLDocument3* This,
    IHTMLDocument2 **pNewDoc);
void __RPC_STUB IHTMLDocument3_createDocumentFragment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_parentDocument_Proxy(
    IHTMLDocument3* This,
    IHTMLDocument2 **p);
void __RPC_STUB IHTMLDocument3_get_parentDocument_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_enableDownload_Proxy(
    IHTMLDocument3* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLDocument3_put_enableDownload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_enableDownload_Proxy(
    IHTMLDocument3* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLDocument3_get_enableDownload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_baseUrl_Proxy(
    IHTMLDocument3* This,
    BSTR v);
void __RPC_STUB IHTMLDocument3_put_baseUrl_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_baseUrl_Proxy(
    IHTMLDocument3* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument3_get_baseUrl_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_childNodes_Proxy(
    IHTMLDocument3* This,
    IDispatch **p);
void __RPC_STUB IHTMLDocument3_get_childNodes_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_inheritStyleSheets_Proxy(
    IHTMLDocument3* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLDocument3_put_inheritStyleSheets_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_inheritStyleSheets_Proxy(
    IHTMLDocument3* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLDocument3_get_inheritStyleSheets_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_put_onbeforeeditfocus_Proxy(
    IHTMLDocument3* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument3_put_onbeforeeditfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_get_onbeforeeditfocus_Proxy(
    IHTMLDocument3* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument3_get_onbeforeeditfocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_getElementsByName_Proxy(
    IHTMLDocument3* This,
    BSTR v,
    IHTMLElementCollection **pelColl);
void __RPC_STUB IHTMLDocument3_getElementsByName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_getElementById_Proxy(
    IHTMLDocument3* This,
    BSTR v,
    IHTMLElement **pel);
void __RPC_STUB IHTMLDocument3_getElementById_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument3_getElementsByTagName_Proxy(
    IHTMLDocument3* This,
    BSTR v,
    IHTMLElementCollection **pelColl);
void __RPC_STUB IHTMLDocument3_getElementsByTagName_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDocument3_INTERFACE_DEFINED__ */

#ifndef __IHTMLDocument4_FWD_DEFINED__
#define __IHTMLDocument4_FWD_DEFINED__
typedef interface IHTMLDocument4 IHTMLDocument4;
#endif

/*****************************************************************************
 * IHTMLDocument4 interface
 */
#ifndef __IHTMLDocument4_INTERFACE_DEFINED__
#define __IHTMLDocument4_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDocument4, 0x3050f69a, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDocument4 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE focus(
        ) = 0;

    virtual HRESULT STDMETHODCALLTYPE hasFocus(
        VARIANT_BOOL *pfFocus) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onselectionchange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onselectionchange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_namespaces(
        IDispatch **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createDocumentFromUrl(
        BSTR bstrUrl,
        BSTR bstrOptions,
        IHTMLDocument2 **newDoc) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_media(
        BSTR v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_media(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createEventObject(
        VARIANT *pvarEventObject,
        IHTMLEventObj **ppEventObj) = 0;

    virtual HRESULT STDMETHODCALLTYPE fireEvent(
        BSTR bstrEventName,
        VARIANT *pvarEventObject,
        VARIANT_BOOL *pfCancelled) = 0;

    virtual HRESULT STDMETHODCALLTYPE createRenderStyle(
        BSTR v,
        IHTMLRenderStyle **ppIHTMLRenderStyle) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_oncontrolselect(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_oncontrolselect(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_URLUnencoded(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLDocument4Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDocument4* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDocument4* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDocument4* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDocument4* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDocument4* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDocument4* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDocument4* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDocument4 methods ***/
    HRESULT (STDMETHODCALLTYPE *focus)(
        IHTMLDocument4* This);

    HRESULT (STDMETHODCALLTYPE *hasFocus)(
        IHTMLDocument4* This,
        VARIANT_BOOL *pfFocus);

    HRESULT (STDMETHODCALLTYPE *put_onselectionchange)(
        IHTMLDocument4* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onselectionchange)(
        IHTMLDocument4* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_namespaces)(
        IHTMLDocument4* This,
        IDispatch **p);

    HRESULT (STDMETHODCALLTYPE *createDocumentFromUrl)(
        IHTMLDocument4* This,
        BSTR bstrUrl,
        BSTR bstrOptions,
        IHTMLDocument2 **newDoc);

    HRESULT (STDMETHODCALLTYPE *put_media)(
        IHTMLDocument4* This,
        BSTR v);

    HRESULT (STDMETHODCALLTYPE *get_media)(
        IHTMLDocument4* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *createEventObject)(
        IHTMLDocument4* This,
        VARIANT *pvarEventObject,
        IHTMLEventObj **ppEventObj);

    HRESULT (STDMETHODCALLTYPE *fireEvent)(
        IHTMLDocument4* This,
        BSTR bstrEventName,
        VARIANT *pvarEventObject,
        VARIANT_BOOL *pfCancelled);

    HRESULT (STDMETHODCALLTYPE *createRenderStyle)(
        IHTMLDocument4* This,
        BSTR v,
        IHTMLRenderStyle **ppIHTMLRenderStyle);

    HRESULT (STDMETHODCALLTYPE *put_oncontrolselect)(
        IHTMLDocument4* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_oncontrolselect)(
        IHTMLDocument4* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_URLUnencoded)(
        IHTMLDocument4* This,
        BSTR *p);

    END_INTERFACE
} IHTMLDocument4Vtbl;
interface IHTMLDocument4 {
    CONST_VTBL IHTMLDocument4Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDocument4_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDocument4_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDocument4_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDocument4_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDocument4_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDocument4_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDocument4_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDocument4 methods ***/
#define IHTMLDocument4_focus(p) (p)->lpVtbl->focus(p)
#define IHTMLDocument4_hasFocus(p,a) (p)->lpVtbl->hasFocus(p,a)
#define IHTMLDocument4_put_onselectionchange(p,a) (p)->lpVtbl->put_onselectionchange(p,a)
#define IHTMLDocument4_get_onselectionchange(p,a) (p)->lpVtbl->get_onselectionchange(p,a)
#define IHTMLDocument4_get_namespaces(p,a) (p)->lpVtbl->get_namespaces(p,a)
#define IHTMLDocument4_createDocumentFromUrl(p,a,b,c) (p)->lpVtbl->createDocumentFromUrl(p,a,b,c)
#define IHTMLDocument4_put_media(p,a) (p)->lpVtbl->put_media(p,a)
#define IHTMLDocument4_get_media(p,a) (p)->lpVtbl->get_media(p,a)
#define IHTMLDocument4_createEventObject(p,a,b) (p)->lpVtbl->createEventObject(p,a,b)
#define IHTMLDocument4_fireEvent(p,a,b,c) (p)->lpVtbl->fireEvent(p,a,b,c)
#define IHTMLDocument4_createRenderStyle(p,a,b) (p)->lpVtbl->createRenderStyle(p,a,b)
#define IHTMLDocument4_put_oncontrolselect(p,a) (p)->lpVtbl->put_oncontrolselect(p,a)
#define IHTMLDocument4_get_oncontrolselect(p,a) (p)->lpVtbl->get_oncontrolselect(p,a)
#define IHTMLDocument4_get_URLUnencoded(p,a) (p)->lpVtbl->get_URLUnencoded(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDocument4_focus_Proxy(
    IHTMLDocument4* This);
void __RPC_STUB IHTMLDocument4_focus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_hasFocus_Proxy(
    IHTMLDocument4* This,
    VARIANT_BOOL *pfFocus);
void __RPC_STUB IHTMLDocument4_hasFocus_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_put_onselectionchange_Proxy(
    IHTMLDocument4* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument4_put_onselectionchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_get_onselectionchange_Proxy(
    IHTMLDocument4* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument4_get_onselectionchange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_get_namespaces_Proxy(
    IHTMLDocument4* This,
    IDispatch **p);
void __RPC_STUB IHTMLDocument4_get_namespaces_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_createDocumentFromUrl_Proxy(
    IHTMLDocument4* This,
    BSTR bstrUrl,
    BSTR bstrOptions,
    IHTMLDocument2 **newDoc);
void __RPC_STUB IHTMLDocument4_createDocumentFromUrl_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_put_media_Proxy(
    IHTMLDocument4* This,
    BSTR v);
void __RPC_STUB IHTMLDocument4_put_media_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_get_media_Proxy(
    IHTMLDocument4* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument4_get_media_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_createEventObject_Proxy(
    IHTMLDocument4* This,
    VARIANT *pvarEventObject,
    IHTMLEventObj **ppEventObj);
void __RPC_STUB IHTMLDocument4_createEventObject_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_fireEvent_Proxy(
    IHTMLDocument4* This,
    BSTR bstrEventName,
    VARIANT *pvarEventObject,
    VARIANT_BOOL *pfCancelled);
void __RPC_STUB IHTMLDocument4_fireEvent_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_createRenderStyle_Proxy(
    IHTMLDocument4* This,
    BSTR v,
    IHTMLRenderStyle **ppIHTMLRenderStyle);
void __RPC_STUB IHTMLDocument4_createRenderStyle_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_put_oncontrolselect_Proxy(
    IHTMLDocument4* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument4_put_oncontrolselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_get_oncontrolselect_Proxy(
    IHTMLDocument4* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument4_get_oncontrolselect_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument4_get_URLUnencoded_Proxy(
    IHTMLDocument4* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument4_get_URLUnencoded_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDocument4_INTERFACE_DEFINED__ */

#ifndef __IHTMLDocument5_FWD_DEFINED__
#define __IHTMLDocument5_FWD_DEFINED__
typedef interface IHTMLDocument5 IHTMLDocument5;
#endif

/*****************************************************************************
 * IHTMLDocument5 interface
 */
#ifndef __IHTMLDocument5_INTERFACE_DEFINED__
#define __IHTMLDocument5_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLDocument5, 0x3050f80c, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLDocument5 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE put_onmousewheel(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onmousewheel(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_doctype(
        IHTMLDOMNode **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_implementation(
        IHTMLDOMImplementation **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE createAttribute(
        BSTR bstrattrName,
        IHTMLDOMAttribute **ppattribute) = 0;

    virtual HRESULT STDMETHODCALLTYPE createComment(
        BSTR bstrdata,
        IHTMLDOMNode **ppRetNode) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onfocusin(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onfocusin(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onfocusout(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onfocusout(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onactivate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onactivate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_ondeactivate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_ondeactivate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforeactivate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforeactivate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onbeforedeactivate(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onbeforedeactivate(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_compatMode(
        BSTR *p) = 0;

};
#else
typedef struct IHTMLDocument5Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLDocument5* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLDocument5* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLDocument5* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLDocument5* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLDocument5* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLDocument5* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLDocument5* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLDocument5 methods ***/
    HRESULT (STDMETHODCALLTYPE *put_onmousewheel)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onmousewheel)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_doctype)(
        IHTMLDocument5* This,
        IHTMLDOMNode **p);

    HRESULT (STDMETHODCALLTYPE *get_implementation)(
        IHTMLDocument5* This,
        IHTMLDOMImplementation **p);

    HRESULT (STDMETHODCALLTYPE *createAttribute)(
        IHTMLDocument5* This,
        BSTR bstrattrName,
        IHTMLDOMAttribute **ppattribute);

    HRESULT (STDMETHODCALLTYPE *createComment)(
        IHTMLDocument5* This,
        BSTR bstrdata,
        IHTMLDOMNode **ppRetNode);

    HRESULT (STDMETHODCALLTYPE *put_onfocusin)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onfocusin)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onfocusout)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onfocusout)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onactivate)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onactivate)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_ondeactivate)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_ondeactivate)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforeactivate)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforeactivate)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onbeforedeactivate)(
        IHTMLDocument5* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onbeforedeactivate)(
        IHTMLDocument5* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_compatMode)(
        IHTMLDocument5* This,
        BSTR *p);

    END_INTERFACE
} IHTMLDocument5Vtbl;
interface IHTMLDocument5 {
    CONST_VTBL IHTMLDocument5Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLDocument5_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLDocument5_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLDocument5_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLDocument5_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLDocument5_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLDocument5_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLDocument5_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLDocument5 methods ***/
#define IHTMLDocument5_put_onmousewheel(p,a) (p)->lpVtbl->put_onmousewheel(p,a)
#define IHTMLDocument5_get_onmousewheel(p,a) (p)->lpVtbl->get_onmousewheel(p,a)
#define IHTMLDocument5_get_doctype(p,a) (p)->lpVtbl->get_doctype(p,a)
#define IHTMLDocument5_get_implementation(p,a) (p)->lpVtbl->get_implementation(p,a)
#define IHTMLDocument5_createAttribute(p,a,b) (p)->lpVtbl->createAttribute(p,a,b)
#define IHTMLDocument5_createComment(p,a,b) (p)->lpVtbl->createComment(p,a,b)
#define IHTMLDocument5_put_onfocusin(p,a) (p)->lpVtbl->put_onfocusin(p,a)
#define IHTMLDocument5_get_onfocusin(p,a) (p)->lpVtbl->get_onfocusin(p,a)
#define IHTMLDocument5_put_onfocusout(p,a) (p)->lpVtbl->put_onfocusout(p,a)
#define IHTMLDocument5_get_onfocusout(p,a) (p)->lpVtbl->get_onfocusout(p,a)
#define IHTMLDocument5_put_onactivate(p,a) (p)->lpVtbl->put_onactivate(p,a)
#define IHTMLDocument5_get_onactivate(p,a) (p)->lpVtbl->get_onactivate(p,a)
#define IHTMLDocument5_put_ondeactivate(p,a) (p)->lpVtbl->put_ondeactivate(p,a)
#define IHTMLDocument5_get_ondeactivate(p,a) (p)->lpVtbl->get_ondeactivate(p,a)
#define IHTMLDocument5_put_onbeforeactivate(p,a) (p)->lpVtbl->put_onbeforeactivate(p,a)
#define IHTMLDocument5_get_onbeforeactivate(p,a) (p)->lpVtbl->get_onbeforeactivate(p,a)
#define IHTMLDocument5_put_onbeforedeactivate(p,a) (p)->lpVtbl->put_onbeforedeactivate(p,a)
#define IHTMLDocument5_get_onbeforedeactivate(p,a) (p)->lpVtbl->get_onbeforedeactivate(p,a)
#define IHTMLDocument5_get_compatMode(p,a) (p)->lpVtbl->get_compatMode(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLDocument5_put_onmousewheel_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onmousewheel_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onmousewheel_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onmousewheel_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_doctype_Proxy(
    IHTMLDocument5* This,
    IHTMLDOMNode **p);
void __RPC_STUB IHTMLDocument5_get_doctype_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_implementation_Proxy(
    IHTMLDocument5* This,
    IHTMLDOMImplementation **p);
void __RPC_STUB IHTMLDocument5_get_implementation_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_createAttribute_Proxy(
    IHTMLDocument5* This,
    BSTR bstrattrName,
    IHTMLDOMAttribute **ppattribute);
void __RPC_STUB IHTMLDocument5_createAttribute_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_createComment_Proxy(
    IHTMLDocument5* This,
    BSTR bstrdata,
    IHTMLDOMNode **ppRetNode);
void __RPC_STUB IHTMLDocument5_createComment_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_onfocusin_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onfocusin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onfocusin_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onfocusin_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_onfocusout_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onfocusout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onfocusout_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onfocusout_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_onactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_ondeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_ondeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_ondeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_ondeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_onbeforeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onbeforeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onbeforeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onbeforeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_put_onbeforedeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT v);
void __RPC_STUB IHTMLDocument5_put_onbeforedeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_onbeforedeactivate_Proxy(
    IHTMLDocument5* This,
    VARIANT *p);
void __RPC_STUB IHTMLDocument5_get_onbeforedeactivate_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLDocument5_get_compatMode_Proxy(
    IHTMLDocument5* This,
    BSTR *p);
void __RPC_STUB IHTMLDocument5_get_compatMode_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLDocument5_INTERFACE_DEFINED__ */

#ifndef __DispHTMLDocument_FWD_DEFINED__
#define __DispHTMLDocument_FWD_DEFINED__
typedef interface DispHTMLDocument DispHTMLDocument;
#endif

/*****************************************************************************
 * DispHTMLDocument dispinterface
 */
#ifndef __DispHTMLDocument_DISPINTERFACE_DEFINED__
#define __DispHTMLDocument_DISPINTERFACE_DEFINED__

DEFINE_GUID(DIID_DispHTMLDocument, 0x3050f55f, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface DispHTMLDocument : public IDispatch
{
};
#else
typedef struct DispHTMLDocumentVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        DispHTMLDocument* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        DispHTMLDocument* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        DispHTMLDocument* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        DispHTMLDocument* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        DispHTMLDocument* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        DispHTMLDocument* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        DispHTMLDocument* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    END_INTERFACE
} DispHTMLDocumentVtbl;
interface DispHTMLDocument {
    CONST_VTBL DispHTMLDocumentVtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define DispHTMLDocument_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define DispHTMLDocument_AddRef(p) (p)->lpVtbl->AddRef(p)
#define DispHTMLDocument_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define DispHTMLDocument_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define DispHTMLDocument_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define DispHTMLDocument_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define DispHTMLDocument_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
#endif

#endif

#endif  /* __DispHTMLDocument_DISPINTERFACE_DEFINED__ */

/*****************************************************************************
 * HTMLDocument coclass
 */

DEFINE_GUID(CLSID_HTMLDocument, 0x25336920, 0x03f9, 0x11cf, 0x8f,0xd0, 0x00,0xaa,0x00,0x68,0x6f,0x13);

#ifndef __HTMLDocument_FWD_DEFINED__
#define __HTMLDocument_FWD_DEFINED__
typedef struct HTMLDocument HTMLDocument;
#endif /* defined __HTMLDocument_FWD_DEFINED__ */

#ifndef __IHTMLFrameBase2_FWD_DEFINED__
#define __IHTMLFrameBase2_FWD_DEFINED__
typedef interface IHTMLFrameBase2 IHTMLFrameBase2;
#endif

/*****************************************************************************
 * IHTMLFrameBase2 interface
 */
#ifndef __IHTMLFrameBase2_INTERFACE_DEFINED__
#define __IHTMLFrameBase2_INTERFACE_DEFINED__

DEFINE_GUID(IID_IHTMLFrameBase2, 0x3050f6db, 0x98b5, 0x11cf, 0xbb,0x82, 0x00,0xaa,0x00,0xbd,0xce,0x0b);
#if defined(__cplusplus) && !defined(CINTERFACE)
interface IHTMLFrameBase2 : public IDispatch
{
    virtual HRESULT STDMETHODCALLTYPE get_contentWindow(
        IHTMLWindow2 **p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onload(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onload(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_onreadystatechange(
        VARIANT v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_onreadystatechange(
        VARIANT *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_readyState(
        BSTR *p) = 0;

    virtual HRESULT STDMETHODCALLTYPE put_allowTransparency(
        VARIANT_BOOL v) = 0;

    virtual HRESULT STDMETHODCALLTYPE get_allowTransparency(
        VARIANT_BOOL *p) = 0;

};
#else
typedef struct IHTMLFrameBase2Vtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IHTMLFrameBase2* This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IHTMLFrameBase2* This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IHTMLFrameBase2* This);

    /*** IDispatch methods ***/
    HRESULT (STDMETHODCALLTYPE *GetTypeInfoCount)(
        IHTMLFrameBase2* This,
        UINT *pctinfo);

    HRESULT (STDMETHODCALLTYPE *GetTypeInfo)(
        IHTMLFrameBase2* This,
        UINT iTInfo,
        LCID lcid,
        ITypeInfo **ppTInfo);

    HRESULT (STDMETHODCALLTYPE *GetIDsOfNames)(
        IHTMLFrameBase2* This,
        REFIID riid,
        LPOLESTR *rgszNames,
        UINT cNames,
        LCID lcid,
        DISPID *rgDispId);

    HRESULT (STDMETHODCALLTYPE *Invoke)(
        IHTMLFrameBase2* This,
        DISPID dispIdMember,
        REFIID riid,
        LCID lcid,
        WORD wFlags,
        DISPPARAMS *pDispParams,
        VARIANT *pVarResult,
        EXCEPINFO *pExcepInfo,
        UINT *puArgErr);

    /*** IHTMLFrameBase2 methods ***/
    HRESULT (STDMETHODCALLTYPE *get_contentWindow)(
        IHTMLFrameBase2* This,
        IHTMLWindow2 **p);

    HRESULT (STDMETHODCALLTYPE *put_onload)(
        IHTMLFrameBase2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onload)(
        IHTMLFrameBase2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *put_onreadystatechange)(
        IHTMLFrameBase2* This,
        VARIANT v);

    HRESULT (STDMETHODCALLTYPE *get_onreadystatechange)(
        IHTMLFrameBase2* This,
        VARIANT *p);

    HRESULT (STDMETHODCALLTYPE *get_readyState)(
        IHTMLFrameBase2* This,
        BSTR *p);

    HRESULT (STDMETHODCALLTYPE *put_allowTransparency)(
        IHTMLFrameBase2* This,
        VARIANT_BOOL v);

    HRESULT (STDMETHODCALLTYPE *get_allowTransparency)(
        IHTMLFrameBase2* This,
        VARIANT_BOOL *p);

    END_INTERFACE
} IHTMLFrameBase2Vtbl;
interface IHTMLFrameBase2 {
    CONST_VTBL IHTMLFrameBase2Vtbl* lpVtbl;
};

#ifdef COBJMACROS
/*** IUnknown methods ***/
#define IHTMLFrameBase2_QueryInterface(p,a,b) (p)->lpVtbl->QueryInterface(p,a,b)
#define IHTMLFrameBase2_AddRef(p) (p)->lpVtbl->AddRef(p)
#define IHTMLFrameBase2_Release(p) (p)->lpVtbl->Release(p)
/*** IDispatch methods ***/
#define IHTMLFrameBase2_GetTypeInfoCount(p,a) (p)->lpVtbl->GetTypeInfoCount(p,a)
#define IHTMLFrameBase2_GetTypeInfo(p,a,b,c) (p)->lpVtbl->GetTypeInfo(p,a,b,c)
#define IHTMLFrameBase2_GetIDsOfNames(p,a,b,c,d,e) (p)->lpVtbl->GetIDsOfNames(p,a,b,c,d,e)
#define IHTMLFrameBase2_Invoke(p,a,b,c,d,e,f,g,h) (p)->lpVtbl->Invoke(p,a,b,c,d,e,f,g,h)
/*** IHTMLFrameBase2 methods ***/
#define IHTMLFrameBase2_get_contentWindow(p,a) (p)->lpVtbl->get_contentWindow(p,a)
#define IHTMLFrameBase2_put_onload(p,a) (p)->lpVtbl->put_onload(p,a)
#define IHTMLFrameBase2_get_onload(p,a) (p)->lpVtbl->get_onload(p,a)
#define IHTMLFrameBase2_put_onreadystatechange(p,a) (p)->lpVtbl->put_onreadystatechange(p,a)
#define IHTMLFrameBase2_get_onreadystatechange(p,a) (p)->lpVtbl->get_onreadystatechange(p,a)
#define IHTMLFrameBase2_get_readyState(p,a) (p)->lpVtbl->get_readyState(p,a)
#define IHTMLFrameBase2_put_allowTransparency(p,a) (p)->lpVtbl->put_allowTransparency(p,a)
#define IHTMLFrameBase2_get_allowTransparency(p,a) (p)->lpVtbl->get_allowTransparency(p,a)
#endif

#endif

HRESULT CALLBACK IHTMLFrameBase2_get_contentWindow_Proxy(
    IHTMLFrameBase2* This,
    IHTMLWindow2 **p);
void __RPC_STUB IHTMLFrameBase2_get_contentWindow_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_put_onload_Proxy(
    IHTMLFrameBase2* This,
    VARIANT v);
void __RPC_STUB IHTMLFrameBase2_put_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_get_onload_Proxy(
    IHTMLFrameBase2* This,
    VARIANT *p);
void __RPC_STUB IHTMLFrameBase2_get_onload_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_put_onreadystatechange_Proxy(
    IHTMLFrameBase2* This,
    VARIANT v);
void __RPC_STUB IHTMLFrameBase2_put_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_get_onreadystatechange_Proxy(
    IHTMLFrameBase2* This,
    VARIANT *p);
void __RPC_STUB IHTMLFrameBase2_get_onreadystatechange_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_get_readyState_Proxy(
    IHTMLFrameBase2* This,
    BSTR *p);
void __RPC_STUB IHTMLFrameBase2_get_readyState_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_put_allowTransparency_Proxy(
    IHTMLFrameBase2* This,
    VARIANT_BOOL v);
void __RPC_STUB IHTMLFrameBase2_put_allowTransparency_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);
HRESULT CALLBACK IHTMLFrameBase2_get_allowTransparency_Proxy(
    IHTMLFrameBase2* This,
    VARIANT_BOOL *p);
void __RPC_STUB IHTMLFrameBase2_get_allowTransparency_Stub(
    IRpcStubBuffer* This,
    IRpcChannelBuffer* pRpcChannelBuffer,
    PRPC_MESSAGE pRpcMessage,
    DWORD* pdwStubPhase);

#endif  /* __IHTMLFrameBase2_INTERFACE_DEFINED__ */

/* Begin additional prototypes for all interfaces */

ULONG           __RPC_USER VARIANT_UserSize     (ULONG *, ULONG, VARIANT *);
unsigned char * __RPC_USER VARIANT_UserMarshal  (ULONG *, unsigned char *, VARIANT *);
unsigned char * __RPC_USER VARIANT_UserUnmarshal(ULONG *, unsigned char *, VARIANT *);
void            __RPC_USER VARIANT_UserFree     (ULONG *, VARIANT *);
ULONG           __RPC_USER BSTR_UserSize     (ULONG *, ULONG, BSTR *);
unsigned char * __RPC_USER BSTR_UserMarshal  (ULONG *, unsigned char *, BSTR *);
unsigned char * __RPC_USER BSTR_UserUnmarshal(ULONG *, unsigned char *, BSTR *);
void            __RPC_USER BSTR_UserFree     (ULONG *, BSTR *);

/* End additional prototypes */

#ifdef __cplusplus
}
#endif
#endif /* __WIDL_MSHTML_H */
